@@ -46,8 +46,8 @@
 #include <cantor/panelplugin.h>
 #include <cantor/worksheetaccess.h>
 
-CantorWorksheet::CantorWorksheet(const QString &name, bool loading) : AbstractPart(name),
-	m_backendName(name)  {
+CantorWorksheet::CantorWorksheet(const QString &name, bool loading)
+	: AbstractPart(name, AspectType::CantorWorksheet), m_backendName(name) {
 
 	if (!loading)
 		init();
@@ -57,11 +57,20 @@ CantorWorksheet::CantorWorksheet(const QString &name, bool loading) : AbstractPa
 	initializes Cantor's part and plugins
 */
 bool CantorWorksheet::init(QByteArray* content) {
-	KPluginFactory* factory = KPluginLoader(QLatin1String("libcantorpart")).factory();
-	if (factory) {
+	KPluginLoader loader(QLatin1String("libcantorpart"));
+	KPluginFactory* factory = loader.factory();
+
+	if (!factory) {
+		//we can only get to this here if we open a project having Cantor content and Cantor plugins were not found.
+		//return false here, a proper error message will be created in load() and propagated further.
+		WARN("Failed to load Cantor plugin:")
+		WARN("Cantor Part file name: " << loader.fileName().toStdString())
+		WARN("	" << loader.errorString().toStdString())
+		return false;
+	} else {
 		m_part = factory->create<KParts::ReadWritePart>(this, QVariantList() << m_backendName << QLatin1String("--noprogress"));
 		if (!m_part) {
-			qDebug() << "Could not create the Cantor Part.";
+			DEBUG("Could not create the Cantor Part.")
 			return false;
 		}
 		m_worksheetAccess = m_part->findChild<Cantor::WorksheetAccessInterface*>(Cantor::WorksheetAccessInterface::Name);
@@ -82,10 +91,10 @@ bool CantorWorksheet::init(QByteArray* content) {
 #else
 		m_variableModel = m_session->variableModel();
 #endif
-		connect(m_variableModel, SIGNAL(dataChanged(QModelIndex, QModelIndex)), this, SLOT(dataChanged(QModelIndex)));
-		connect(m_variableModel, SIGNAL(rowsInserted(QModelIndex,int,int)), this, SLOT(rowsInserted(QModelIndex,int,int)));
-		connect(m_variableModel, SIGNAL(rowsAboutToBeRemoved(QModelIndex,int,int)), this, SLOT(rowsAboutToBeRemoved(QModelIndex,int,int)));
-		connect(m_variableModel, SIGNAL(modelReset()), this, SLOT(modelReset()));
+		connect(m_variableModel, &QAbstractItemModel::dataChanged, this, &CantorWorksheet::dataChanged);
+		connect(m_variableModel, &QAbstractItemModel::rowsInserted, this, &CantorWorksheet::rowsInserted);
+		connect(m_variableModel, &QAbstractItemModel::rowsAboutToBeRemoved, this, &CantorWorksheet::rowsAboutToBeRemoved);
+		connect(m_variableModel, &QAbstractItemModel::modelReset, this, &CantorWorksheet::modelReset);
 
 		//available plugins
 		auto* handler = m_part->findChild<Cantor::PanelPluginHandler*>(QLatin1String("PanelPluginHandler"));
@@ -95,12 +104,7 @@ bool CantorWorksheet::init(QByteArray* content) {
 		}
 		m_plugins = handler->plugins();
 	}
-	else {
-		//we can only get to this here if we open a project having Cantor content and Cantor plugins were not found.
-		//return false here, a proper error message will be created in load() and propagated further.
-		DEBUG("Failed to load cantor plugin");
-		return false;
-	}
+
 	return true;
 }
 
@@ -114,9 +118,9 @@ void CantorWorksheet::dataChanged(const QModelIndex& index) {
 		if (dataValue.isNull())
 			dataValue = m_variableModel->data(m_variableModel->index(index.row(), 1));
 		const QString& value = dataValue.toString();
-		auto* parser = new VariableParser(m_backendName, value);
-		if (parser->isParsed())
-			col->replaceValues(0, parser->values());
+		VariableParser parser(m_backendName, value);
+		if (parser.isParsed())
+			col->replaceValues(0, parser.values());
 	}
 
 }
@@ -129,13 +133,13 @@ void CantorWorksheet::rowsInserted(const QModelIndex& parent, int first, int las
 		if (dataValue.isNull())
 			dataValue = m_variableModel->data(m_variableModel->index(i, 1));
 		const QString& value = dataValue.toString();
-		auto* parser = new VariableParser(m_backendName, value);
-		if (parser->isParsed()) {
+		VariableParser parser(m_backendName, value);
+		if (parser.isParsed()) {
 			Column* col = child<Column>(name);
 			if (col) {
-				col->replaceValues(0, parser->values());
+				col->replaceValues(0, parser.values());
 			} else {
-				col = new Column(name, parser->values());
+				col = new Column(name, parser.values());
 				col->setUndoAware(false);
 				addChild(col);
 
@@ -150,8 +154,6 @@ void CantorWorksheet::rowsInserted(const QModelIndex& parent, int first, int las
 			if (col)
 				removeChild(col);
 		}
-
-		delete(parser);
 	}
 
 	project()->setChanged(true);
@@ -274,7 +276,6 @@ bool CantorWorksheet::load(XmlStreamReader* reader, bool preview) {
 
 	KLocalizedString attributeWarning = ki18n("Attribute '%1' missing or empty, default value is used");
 	QXmlStreamAttributes attribs;
-	QString str;
 	bool rc = false;
 
 	while (!reader->atEnd()) {
@@ -292,12 +293,12 @@ bool CantorWorksheet::load(XmlStreamReader* reader, bool preview) {
 			attribs = reader->attributes();
 
 			m_backendName = attribs.value("backend_name").toString().trimmed();
-			if (str.isEmpty())
+			if (m_backendName.isEmpty())
 				reader->raiseWarning(attributeWarning.subs("backend_name").toString());
 		} else if (!preview && reader->name() == "worksheet") {
 			attribs = reader->attributes();
 
-			str = attribs.value("content").toString().trimmed();
+			QString str = attribs.value("content").toString().trimmed();
 			if (str.isEmpty())
 				reader->raiseWarning(attributeWarning.subs("content").toString());
 
