@@ -34,16 +34,80 @@
 #include <QVector>
 
 class AbstractAspectPrivate;
+class Folder;
 class Project;
-class QUndoStack;
+class XmlStreamReader;
+
 class QDateTime;
-class QUndoCommand;
+class QDropEvent;
 class QIcon;
 class QMenu;
-class Folder;
-class XmlStreamReader;
+class QUndoCommand;
+class QUndoStack;
 class QXmlStreamWriter;
 
+/// Information about class inheritance
+/// enum values are chosen such that @verbatim inherits(base)@endverbatim
+/// returns true iff the class inherits from @verbatim base@endverbatim.
+///
+/// AspectType is used in GuiObserver to select the correct dock widget.
+enum class AspectType : quint64 {
+	AbstractAspect = 0,
+
+	// classes without inheriters
+	AbstractFilter = 0x0100001,
+	DatapickerCurve = 0x0100002,
+	DatapickerPoint = 0x0100004,
+
+	WorksheetElement = 0x0200000,
+		Axis = 0x0210001,
+		CartesianPlotLegend = 0x0210002,
+		CustomPoint = 0x0210004,
+		Histogram = 0x0210008,
+		PlotArea = 0x0210010,
+		TextLabel = 0x0210020,
+		WorksheetElementContainer = 0x0220000,
+			AbstractPlot = 0x0221000,
+				CartesianPlot = 0x0221001,
+			WorksheetElementGroup = 0x0222000,
+		XYCurve = 0x0240000,
+			XYEquationCurve = 0x0240001,
+		XYAnalysisCurve = 0x0280000,
+			XYConvolution = 0x0280001,
+			XYCorrelationCurve = 0x0280002,
+			XYDataReductionCurve = 0x0280004,
+			XYDifferentiationCurve = 0x0280008,
+			XYFitCurve = 0x0280010,
+			XYFourierFilterCurve = 0x0280020,
+			XYFourierTransformCurve = 0x0280040,
+			XYInterpolationCurve = 0x0280080,
+			XYIntegrationCurve = 0x0280100,
+			XYSmoothCurve = 0x0280200,
+
+	AbstractPart = 0x0400000,
+		AbstractDataSource = 0x0410000,
+			Matrix = 0x0411000,
+			Spreadsheet = 0x0412000,
+				LiveDataSource = 0x0412001,
+				MQTTTopic = 0x0412002,
+		CantorWorksheet = 0x0420001,
+		Datapicker = 0x0420002,
+		DatapickerImage = 0x0420004,
+		Note = 0x0420008,
+		Workbook = 0x0420010,
+		Worksheet = 0x0420020,
+
+	AbstractColumn = 0x1000000,
+		Column = 0x1000001,
+		SimpleFilterColumn = 0x1000002,
+		ColumnStringIO = 0x1000004,
+
+	Folder = 0x2000000,
+		Project = 0x2000001,
+		MQTTClient = 0x2000002,
+		MQTTSubscription = 0x2000004,
+};
+
 class AbstractAspect : public QObject {
 	Q_OBJECT
 
@@ -53,13 +117,14 @@ public:
 		Recursive = 0x02,
 		Compress = 0x04
 	};
+
 	Q_DECLARE_FLAGS(ChildIndexFlags, ChildIndexFlag)
 
 	friend class AspectChildAddCmd;
 	friend class AspectChildRemoveCmd;
 	friend class AbstractAspectPrivate;
 
-	explicit AbstractAspect(const QString& name);
+	AbstractAspect(const QString& name, AspectType type);
 	~AbstractAspect() override;
 
 	QString name() const;
@@ -76,15 +141,19 @@ public:
 	virtual QIcon icon() const;
 	virtual QMenu* createContextMenu();
 
+	AspectType type() const;
+	bool inherits(AspectType type) const;
+
 	//functions related to the handling of the tree-like project structure
 	AbstractAspect* parentAspect() const;
+	AbstractAspect* parent(AspectType type) const;
 	void setParentAspect(AbstractAspect*);
 	Folder* folder();
 	bool isDescendantOf(AbstractAspect* other);
 	void addChild(AbstractAspect*);
 	void addChildFast(AbstractAspect*);
 	virtual void finalizeAdd() {};
-	QVector<AbstractAspect*> children(const char* className, ChildIndexFlags flags=nullptr);
+	QVector<AbstractAspect*> children(AspectType type, ChildIndexFlags flags=nullptr) const;
 	void insertChildBefore(AbstractAspect* child, AbstractAspect* before);
 	void insertChildBeforeFast(AbstractAspect* child, AbstractAspect* before);
 	void reparent(AbstractAspect* newParent, int newIndex = -1);
@@ -92,6 +161,10 @@ public:
 	void removeAllChildren();
 	virtual QVector<AbstractAspect*> dependsOn() const;
 
+	virtual bool isDraggable() const;
+	virtual QVector<AspectType> dropableOn() const;
+	virtual void processDropEvent(QDropEvent*) {};
+
 	template <class T> T* ancestor() const {
 		AbstractAspect* parent = parentAspect();
 		while (parent) {
@@ -111,7 +184,7 @@ public:
 				if (i)
 					result << i;
 
-				if (flags & Recursive)
+				if (child && flags & Recursive)
 					result << child->template children<T>(flags);
 			}
 		}
@@ -181,6 +254,8 @@ protected:
 	void writeCommentElement(QXmlStreamWriter*) const;
 	bool readCommentElement(XmlStreamReader*);
 
+	const AspectType m_type;
+
 private:
 	AbstractAspectPrivate* d;
 
@@ -189,7 +264,7 @@ private:
 	void connectChild(AbstractAspect*);
 
 public slots:
-	void setName(const QString&);
+	bool setName(const QString&, bool autoUnique = true);
 	void setComment(const QString&);
 	void remove();
 
