@@ -81,8 +81,8 @@
  *
  * \param name the column name (= aspect name)
  */
-AbstractColumn::AbstractColumn(const QString &name) : AbstractAspect(name),
-	d( new AbstractColumnPrivate(this) ) {
+AbstractColumn::AbstractColumn(const QString &name, AspectType type)
+	: AbstractAspect(name, type), d( new AbstractColumnPrivate(this) ) {
 }
 
 AbstractColumn::~AbstractColumn() {
@@ -555,11 +555,36 @@ double AbstractColumn::minimum(int count) const {
 	return -INFINITY;
 }
 
+double AbstractColumn::minimum(int startIndex, int endIndex) const {
+	Q_UNUSED(startIndex);
+	Q_UNUSED(endIndex);
+	return -INFINITY;
+}
+
 double AbstractColumn::maximum(int count) const {
 	Q_UNUSED(count);
 	return INFINITY;
 }
 
+double AbstractColumn::maximum(int startIndex, int endIndex) const {
+	Q_UNUSED(startIndex);
+	Q_UNUSED(endIndex);
+	return INFINITY;
+}
+
+bool AbstractColumn::indicesMinMax(double v1, double v2, int& start, int& end)  const {
+	Q_UNUSED(v1)
+	Q_UNUSED(v2)
+	Q_UNUSED(start)
+	Q_UNUSED(end)
+	return false;
+}
+
+int AbstractColumn::indexForValue(double x) const {
+	Q_UNUSED(x)
+	return 0;
+}
+
 ////////////////////////////////////////////////////////////////////////////////////////////////////
 //@}
 ////////////////////////////////////////////////////////////////////////////////////////////////////
