@@ -134,7 +134,7 @@ public:
 		double entropy;
 	};
 
-	explicit AbstractColumn(const QString& name);
+	AbstractColumn(const QString& name, AspectType type);
 	~AbstractColumn() override;
 
 	static QStringList dateFormats();	// supported date formats
@@ -148,6 +148,7 @@ public:
 	virtual ColumnMode columnMode() const = 0;
 	virtual void setColumnMode(AbstractColumn::ColumnMode);
 	virtual PlotDesignation plotDesignation() const = 0;
+	virtual QString plotDesignationString() const = 0;
 	virtual void setPlotDesignation(AbstractColumn::PlotDesignation);
 	bool isNumeric() const;
 	bool isPlottable() const;
@@ -161,7 +162,11 @@ public:
 	virtual void clear();
 
 	virtual double maximum(int count = 0) const;
+	virtual double maximum(int startIndex, int endIndex) const;
 	virtual double minimum(int count = 0) const;
+	virtual double minimum(int startIndex, int endIndex) const;
+	virtual bool indicesMinMax(double v1, double v2, int& start, int& end) const;
+	virtual int indexForValue(double x) const;
 
 	bool isValid(int row) const;
 
@@ -203,6 +208,7 @@ signals:
 	void modeChanged(const AbstractColumn* source);
 	void dataAboutToChange(const AbstractColumn* source);
 	void dataChanged(const AbstractColumn* source);
+	void formatChanged(const AbstractColumn* source);
 	void rowsAboutToBeInserted(const AbstractColumn* source, int before, int count);
 	void rowsInserted(const AbstractColumn* source, int before, int count);
 	void rowsAboutToBeRemoved(const AbstractColumn* source, int first, int count);
@@ -210,6 +216,7 @@ signals:
 	void maskingAboutToChange(const AbstractColumn* source);
 	void maskingChanged(const AbstractColumn* source);
 	void aboutToBeDestroyed(const AbstractColumn* source);
+	void reset(const AbstractColumn* source); // this signal is emitted when the column is reused for another purpose. The curves must know that and disconnect all connections
 
 protected:
 	bool XmlReadMask(XmlStreamReader*);
