@@ -130,7 +130,7 @@
  */
 AbstractSimpleFilter::AbstractSimpleFilter()
 	: AbstractFilter("SimpleFilter"), m_output_column(new SimpleFilterColumn(this)) {
-	addChild(m_output_column);
+	addChildFast(m_output_column);
 }
 
 /**
@@ -154,6 +154,13 @@ AbstractColumn::PlotDesignation AbstractSimpleFilter::plotDesignation() const {
 	return m_inputs.value(0) ? m_inputs.at(0)->plotDesignation() : AbstractColumn::NoDesignation;
 }
 
+/**
+ * \brief Copy plot designation string of input port 0.
+ */
+QString AbstractSimpleFilter::plotDesignationString() const {
+	return m_inputs.value(0) ? m_inputs.at(0)->plotDesignationString() : QString("");
+}
+
 /**
  * \brief Return the column mode
  *
