@@ -3,7 +3,7 @@
     Project              : LabPlot
     Description          : Represents a LabPlot project.
     --------------------------------------------------------------------
-    Copyright            : (C) 2011-2014 Alexander Semke (alexander.semke@web.de)
+    Copyright            : (C) 2011-2019 Alexander Semke (alexander.semke@web.de)
     Copyright            : (C) 2007-2008 Tilman Benkert (thzs@gmx.net)
     Copyright            : (C) 2007 Knut Franke (knut.franke@gmx.de)
  ***************************************************************************/
@@ -34,14 +34,7 @@
 #include "backend/worksheet/plots/cartesian/CartesianPlot.h"
 #include "backend/worksheet/plots/cartesian/Histogram.h"
 #include "backend/worksheet/plots/cartesian/XYEquationCurve.h"
-#include "backend/worksheet/plots/cartesian/XYDataReductionCurve.h"
-#include "backend/worksheet/plots/cartesian/XYDifferentiationCurve.h"
-#include "backend/worksheet/plots/cartesian/XYIntegrationCurve.h"
-#include "backend/worksheet/plots/cartesian/XYInterpolationCurve.h"
-#include "backend/worksheet/plots/cartesian/XYSmoothCurve.h"
 #include "backend/worksheet/plots/cartesian/XYFitCurve.h"
-#include "backend/worksheet/plots/cartesian/XYFourierFilterCurve.h"
-#include "backend/worksheet/plots/cartesian/XYFourierTransformCurve.h"
 #include "backend/worksheet/plots/cartesian/Axis.h"
 #include "backend/datapicker/DatapickerCurve.h"
 #ifdef HAVE_MQTT
@@ -53,6 +46,7 @@
 #include <QMenu>
 #include <QThreadPool>
 #include <QUndoStack>
+#include <QBuffer>
 
 #include <KConfig>
 #include <KConfigGroup>
@@ -100,9 +94,10 @@ public:
 	QString author;
 	QDateTime modificationTime;
 	bool changed{false};
+	bool aspectAddedSignalSuppressed{false};
 };
 
-Project::Project() : Folder(i18n("Project")), d(new Private()) {
+Project::Project() : Folder(i18n("Project"), AspectType::Project), d(new Private()) {
 	//load default values for name, comment and author from config
 	KConfig config;
 	KConfigGroup group = config.group("Project");
@@ -110,7 +105,7 @@ Project::Project() : Folder(i18n("Project")), d(new Private()) {
 	d->author = group.readEntry("Author", QString());
 
 	//we don't have direct access to the members name and comment
-	//->temporaly disable the undo stack and call the setters
+	//->temporary disable the undo stack and call the setters
 	setUndoAware(false);
 	setIsLoading(true);
 	setName(group.readEntry("Name", i18n("Project")));
@@ -120,6 +115,7 @@ Project::Project() : Folder(i18n("Project")), d(new Private()) {
 	d->changed = false;
 
 	connect(this, &Project::aspectDescriptionChanged,this, &Project::descriptionChanged);
+	connect(this, &Project::aspectAdded,this, &Project::aspectAddedSlot);
 }
 
 Project::~Project() {
@@ -149,8 +145,15 @@ QUndoStack* Project::undoStack() const {
 }
 
 QMenu* Project::createContextMenu() {
-	QMenu* menu = new QMenu(); // no remove action from AbstractAspect in the project context menu
+	QMenu* menu = AbstractAspect::createContextMenu();
+
+	//add close action
+	menu->addSeparator();
+	menu->addAction(QIcon::fromTheme(QLatin1String("document-close")), i18n("Close"), this, SIGNAL(closeRequested()));
+
+	//add the actions from MainWin
 	emit requestProjectContextMenu(menu);
+
 	return menu;
 }
 
@@ -184,21 +187,165 @@ void Project::setChanged(const bool value) {
 	d->changed = value;
 }
 
-bool Project ::hasChanged() const {
+void Project::setSuppressAspectAddedSignal(bool value) {
+	d->aspectAddedSignalSuppressed = value;
+}
+
+bool Project::aspectAddedSignalSuppressed() const {
+	return d->aspectAddedSignalSuppressed;
+}
+
+bool Project::hasChanged() const {
 	return d->changed ;
 }
 
+/*!
+ * \brief Project::descriptionChanged
+ * This function is called, when an object changes its name. When a column changed its name and wasn't connected before to the curve/column(formula) then
+ * this is done in this function
+ * \param column
+ */
 void Project::descriptionChanged(const AbstractAspect* aspect) {
 	if (isLoading())
 		return;
 
-	if (this != aspect)
+	if (this != aspect) {
+		const auto* column = dynamic_cast<const AbstractColumn*>(aspect);
+		if (!column)
+			return;
+
+		// When the column is created, it gets a random name and is eventually not connected to any curve.
+		// When changing the name it can match a curve and should than be connected to the curve.
+		QVector<XYCurve*> curves = children<XYCurve>(AbstractAspect::ChildIndexFlag::Recursive);
+		QString columnPath = column->path();
+
+		// setXColumnPath must not be set, because if curve->column matches column, there already exist a
+		// signal/slot connection between the curve and the column to update this. If they are not same,
+		// xColumnPath is set in setXColumn. Same for the yColumn.
+		for (auto* curve : curves) {
+			curve->setUndoAware(false);
+			auto* analysisCurve = dynamic_cast<XYAnalysisCurve*>(curve);
+			if (analysisCurve) {
+				if (analysisCurve->xDataColumnPath() == columnPath)
+					analysisCurve->setXDataColumn(column);
+				if (analysisCurve->yDataColumnPath() == columnPath)
+					analysisCurve->setYDataColumn(column);
+				if (analysisCurve->y2DataColumnPath() == columnPath)
+					analysisCurve->setY2DataColumn(column);
+
+				auto* fitCurve = dynamic_cast<XYFitCurve*>(curve);
+				if (fitCurve) {
+					if (fitCurve->xErrorColumnPath() == columnPath)
+						fitCurve->setXErrorColumn(column);
+					if (fitCurve->yErrorColumnPath() == columnPath)
+						fitCurve->setYErrorColumn(column);
+				}
+			} else {
+				if (curve->xColumnPath() == columnPath)
+					curve->setXColumn(column);
+				if (curve->yColumnPath() == columnPath)
+					curve->setYColumn(column);
+				if (curve->valuesColumnPath() == columnPath)
+					curve->setValuesColumn(column);
+				if (curve->xErrorPlusColumnPath() == columnPath)
+					curve->setXErrorPlusColumn(column);
+				if (curve->xErrorMinusColumnPath() == columnPath)
+					curve->setXErrorMinusColumn(column);
+				if (curve->yErrorPlusColumnPath() == columnPath)
+					curve->setYErrorPlusColumn(column);
+				if (curve->yErrorMinusColumnPath() == columnPath)
+					curve->setYErrorMinusColumn(column);
+			}
+			curve->setUndoAware(true);
+
+		}
+
+		QVector<Column*> columns = children<Column>(AbstractAspect::ChildIndexFlag::Recursive);
+		for (auto* tempColumn : columns) {
+			const QStringList formulaVariableColumnsPath = tempColumn->formulaVariableColumnPaths();
+			for (int i = 0; i < formulaVariableColumnsPath.count(); i++) {
+				if (formulaVariableColumnsPath[i] == columnPath)
+					tempColumn->setformulVariableColumn(i, const_cast<Column*>(static_cast<const Column*>(column)));
+			}
+		}
 		return;
+	}
 
 	d->changed = true;
 	emit changed();
 }
 
+/*!
+ * \brief Project::aspectAddedSlot
+ * When adding new columns, these should be connected to the corresponding curves
+ * \param aspect
+ */
+void Project::aspectAddedSlot(const AbstractAspect* aspect) {
+
+	QVector<AbstractAspect*> _children = aspect->children(AspectType::Column, ChildIndexFlag::Recursive);
+	QVector<const AbstractColumn*> columns;
+	for (auto child : _children)
+		columns.append(static_cast<const AbstractColumn*>(child));
+
+	const auto* column = dynamic_cast<const AbstractColumn*>(aspect);
+	if (column)
+		columns.append(column);
+
+	if (columns.isEmpty())
+		return;
+
+	for (auto column : columns) {
+		QVector<XYCurve*> curves = children<XYCurve>(AbstractAspect::ChildIndexFlag::Recursive);
+		QString columnPath = column->path();
+
+		for (auto* curve : curves) {
+			curve->setUndoAware(false);
+			auto* analysisCurve = dynamic_cast<XYAnalysisCurve*>(curve);
+			if (analysisCurve) {
+				if (analysisCurve->xDataColumnPath() == columnPath)
+					analysisCurve->setXDataColumn(column);
+				if (analysisCurve->yDataColumnPath() == columnPath)
+					analysisCurve->setYDataColumn(column);
+				if (analysisCurve->y2DataColumnPath() == columnPath)
+					analysisCurve->setY2DataColumn(column);
+
+				auto* fitCurve = dynamic_cast<XYFitCurve*>(curve);
+				if (fitCurve) {
+					if (fitCurve->xErrorColumnPath() == columnPath)
+						fitCurve->setXErrorColumn(column);
+					if (fitCurve->yErrorColumnPath() == columnPath)
+						fitCurve->setYErrorColumn(column);
+				}
+			} else {
+				if (curve->xColumnPath() == columnPath)
+					curve->setXColumn(column);
+				if (curve->yColumnPath() == columnPath)
+					curve->setYColumn(column);
+				if (curve->valuesColumnPath() == columnPath)
+					curve->setValuesColumn(column);
+				if (curve->xErrorPlusColumnPath() == columnPath)
+					curve->setXErrorPlusColumn(column);
+				if (curve->xErrorMinusColumnPath() == columnPath)
+					curve->setXErrorMinusColumn(column);
+				if (curve->yErrorPlusColumnPath() == columnPath)
+					curve->setYErrorPlusColumn(column);
+				if (curve->yErrorMinusColumnPath() == columnPath)
+					curve->setYErrorMinusColumn(column);
+			}
+			curve->setUndoAware(true);
+		}
+		QVector<Column*> columns = children<Column>(AbstractAspect::ChildIndexFlag::Recursive);
+		for (auto* tempColumn : columns) {
+			const QStringList formulaVariableColumnPaths = tempColumn->formulaVariableColumnPaths();
+			for (int i = 0; i < formulaVariableColumnPaths.count(); i++) {
+				if (formulaVariableColumnPaths[i] == column->path())
+					tempColumn->setformulVariableColumn(i, const_cast<Column*>(static_cast<const Column*>(column)));
+			}
+		}
+	}
+
+}
+
 void Project::navigateTo(const QString& path) {
 	emit requestNavigateTo(path);
 }
@@ -216,10 +363,8 @@ QString Project::supportedExtensions() {
 //##############################################################################
 //##################  Serialization/Deserialization  ###########################
 //##############################################################################
-/**
- * \brief Save as XML
- */
-void Project::save(QXmlStreamWriter* writer) const {
+
+void Project::save(const QPixmap& thumbnail, QXmlStreamWriter* writer) const {
 	//set the version and the modification time to the current values
 	d->version = LVERSION;
 	d->modificationTime = QDateTime::currentDateTime();
@@ -233,10 +378,26 @@ void Project::save(QXmlStreamWriter* writer) const {
 	writer->writeAttribute("fileName", fileName());
 	writer->writeAttribute("modificationTime", modificationTime().toString("yyyy-dd-MM hh:mm:ss:zzz"));
 	writer->writeAttribute("author", author());
+
+	QByteArray bArray;
+	QBuffer buffer(&bArray);
+	buffer.open(QIODevice::WriteOnly);
+	QPixmap scaledThumbnail = thumbnail.scaled(512,512, Qt::KeepAspectRatio);
+	scaledThumbnail.save(&buffer, "JPEG");
+	QString image = QString::fromLatin1(bArray.toBase64().data());
+	writer->writeAttribute("thumbnail", image);
+
 	writeBasicAttributes(writer);
 
 	writeCommentElement(writer);
 
+	save(writer);
+}
+
+/**
+ * \brief Save as XML
+ */
+void Project::save(QXmlStreamWriter* writer) const {
 	//save all children
 	for (auto* child : children<AbstractAspect>(IncludeHidden)) {
 		writer->writeStartElement("child_aspect");
@@ -285,8 +446,10 @@ bool Project::load(const QString& filename, bool preview) {
 	setIsLoading(false);
 	if (rc == false) {
 		RESET_CURSOR;
-		QString msg_text = reader.errorString();
-		KMessageBox::error(nullptr, msg_text, i18n("Error when opening the project"));
+		QString msg = reader.errorString();
+		if (msg.isEmpty())
+			msg = i18n("Unknown error when opening the project %1.", filename);
+		KMessageBox::error(nullptr, msg, i18n("Error when opening the project"));
 		return false;
 	}
 
@@ -349,86 +512,151 @@ bool Project::load(XmlStreamReader* reader, bool preview) {
 					}
 				}
 			}
-
-			//wait until all columns are decoded from base64-encoded data
-			QThreadPool::globalInstance()->waitForDone();
-
-			//everything is read now.
-			//restore the pointer to the data sets (columns) in xy-curves etc.
-			QVector<Column*> columns = children<Column>(AbstractAspect::Recursive);
-
-			//xy-curves
-			QVector<XYCurve*> curves = children<XYCurve>(AbstractAspect::Recursive);
-			for (auto* curve : curves) {
-				if (!curve) continue;
-				curve->suppressRetransform(true);
-
-				auto* equationCurve = dynamic_cast<XYEquationCurve*>(curve);
-				auto* analysisCurve = dynamic_cast<XYAnalysisCurve*>(curve);
-				if (equationCurve) {
-					//curves defined by a mathematical equations recalculate their own columns on load again.
-					if (!preview)
-						equationCurve->recalculate();
-				} else if (analysisCurve) {
-					RESTORE_COLUMN_POINTER(analysisCurve, xDataColumn, XDataColumn);
-					RESTORE_COLUMN_POINTER(analysisCurve, yDataColumn, YDataColumn);
-					RESTORE_COLUMN_POINTER(analysisCurve, y2DataColumn, Y2DataColumn);
-					auto* fitCurve = dynamic_cast<XYFitCurve*>(curve);
-					if (fitCurve) {
-						RESTORE_COLUMN_POINTER(fitCurve, xErrorColumn, XErrorColumn);
-						RESTORE_COLUMN_POINTER(fitCurve, yErrorColumn, YErrorColumn);
-					}
-				} else {
-					RESTORE_COLUMN_POINTER(curve, xColumn, XColumn);
-					RESTORE_COLUMN_POINTER(curve, yColumn, YColumn);
-					RESTORE_COLUMN_POINTER(curve, valuesColumn, ValuesColumn);
-					RESTORE_COLUMN_POINTER(curve, xErrorPlusColumn, XErrorPlusColumn);
-					RESTORE_COLUMN_POINTER(curve, xErrorMinusColumn, XErrorMinusColumn);
-					RESTORE_COLUMN_POINTER(curve, yErrorPlusColumn, YErrorPlusColumn);
-					RESTORE_COLUMN_POINTER(curve, yErrorMinusColumn, YErrorMinusColumn);
-				}
-				if (dynamic_cast<XYAnalysisCurve*>(curve))
-					RESTORE_POINTER(dynamic_cast<XYAnalysisCurve*>(curve), dataSourceCurve, DataSourceCurve, XYCurve, curves);
-
-				curve->suppressRetransform(false);
-			}
-
-			//axes
-			QVector<Axis*> axes = children<Axis>(AbstractAspect::Recursive);
-			for (auto* axis : axes) {
-				if (!axis) continue;
-				RESTORE_COLUMN_POINTER(axis, majorTicksColumn, MajorTicksColumn);
-				RESTORE_COLUMN_POINTER(axis, minorTicksColumn, MinorTicksColumn);
-			}
-
-			//histograms
-			QVector<Histogram*> hists = children<Histogram>(AbstractAspect::Recursive);
-			for (auto* hist : hists) {
-				if (!hist) continue;
-				RESTORE_COLUMN_POINTER(hist, dataColumn, DataColumn);
-			}
-
-			//data picker curves
-			QVector<DatapickerCurve*> dataPickerCurves = children<DatapickerCurve>(AbstractAspect::Recursive);
-			for (auto* dataPickerCurve : dataPickerCurves) {
-				if (!dataPickerCurve) continue;
-				RESTORE_COLUMN_POINTER(dataPickerCurve, posXColumn, PosXColumn);
-				RESTORE_COLUMN_POINTER(dataPickerCurve, posYColumn, PosYColumn);
-				RESTORE_COLUMN_POINTER(dataPickerCurve, plusDeltaXColumn, PlusDeltaXColumn);
-				RESTORE_COLUMN_POINTER(dataPickerCurve, minusDeltaXColumn, MinusDeltaXColumn);
-				RESTORE_COLUMN_POINTER(dataPickerCurve, plusDeltaYColumn, PlusDeltaYColumn);
-				RESTORE_COLUMN_POINTER(dataPickerCurve, minusDeltaYColumn, MinusDeltaYColumn);
-			}
 		} else  // no project element
 			reader->raiseError(i18n("no project element found"));
 	} else  // no start document
 		reader->raiseError(i18n("no valid XML document found"));
 
 	if (!preview) {
-		for (auto* plot : children<WorksheetElementContainer>(AbstractAspect::Recursive)) {
+		//wait until all columns are decoded from base64-encoded data
+		QThreadPool::globalInstance()->waitForDone();
+
+		//LiveDataSource:
+		//call finalizeLoad() to replace relative with absolute paths if required
+		//and to create columns during the initial read
+		QVector<LiveDataSource*> sources = children<LiveDataSource>(AbstractAspect::Recursive);
+		for (auto* source : sources) {
+			if (!source) continue;
+			source->finalizeLoad();
+		}
+
+		//everything is read now.
+		//restore the pointer to the data sets (columns) in xy-curves etc.
+		QVector<Column*> columns = children<Column>(AbstractAspect::Recursive);
+
+		//xy-curves
+		// cannot be removed by the column observer, because it does not react
+		// on curve changes
+		QVector<XYCurve*> curves = children<XYCurve>(AbstractAspect::Recursive);
+		for (auto* curve : curves) {
+			if (!curve) continue;
+			curve->suppressRetransform(true);
+
+			auto* equationCurve = dynamic_cast<XYEquationCurve*>(curve);
+			auto* analysisCurve = dynamic_cast<XYAnalysisCurve*>(curve);
+			if (equationCurve) {
+				//curves defined by a mathematical equations recalculate their own columns on load again.
+				if (!preview)
+					equationCurve->recalculate();
+			} else if (analysisCurve) {
+				RESTORE_COLUMN_POINTER(analysisCurve, xDataColumn, XDataColumn);
+				RESTORE_COLUMN_POINTER(analysisCurve, yDataColumn, YDataColumn);
+				RESTORE_COLUMN_POINTER(analysisCurve, y2DataColumn, Y2DataColumn);
+				auto* fitCurve = dynamic_cast<XYFitCurve*>(curve);
+				if (fitCurve) {
+					RESTORE_COLUMN_POINTER(fitCurve, xErrorColumn, XErrorColumn);
+					RESTORE_COLUMN_POINTER(fitCurve, yErrorColumn, YErrorColumn);
+				}
+			} else {
+				RESTORE_COLUMN_POINTER(curve, xColumn, XColumn);
+				RESTORE_COLUMN_POINTER(curve, yColumn, YColumn);
+				RESTORE_COLUMN_POINTER(curve, valuesColumn, ValuesColumn);
+				RESTORE_COLUMN_POINTER(curve, xErrorPlusColumn, XErrorPlusColumn);
+				RESTORE_COLUMN_POINTER(curve, xErrorMinusColumn, XErrorMinusColumn);
+				RESTORE_COLUMN_POINTER(curve, yErrorPlusColumn, YErrorPlusColumn);
+				RESTORE_COLUMN_POINTER(curve, yErrorMinusColumn, YErrorMinusColumn);
+				qDebug()<<"curve columns " << curve->xColumn() << "  " << curve->yColumn();
+			}
+			if (dynamic_cast<XYAnalysisCurve*>(curve))
+				RESTORE_POINTER(dynamic_cast<XYAnalysisCurve*>(curve), dataSourceCurve, DataSourceCurve, XYCurve, curves);
+
+			curve->suppressRetransform(false);
+		}
+
+		//axes
+		QVector<Axis*> axes = children<Axis>(AbstractAspect::Recursive);
+		for (auto* axis : axes) {
+			if (!axis) continue;
+			RESTORE_COLUMN_POINTER(axis, majorTicksColumn, MajorTicksColumn);
+			RESTORE_COLUMN_POINTER(axis, minorTicksColumn, MinorTicksColumn);
+		}
+
+		//histograms
+		QVector<Histogram*> hists = children<Histogram>(AbstractAspect::Recursive);
+		for (auto* hist : hists) {
+			if (!hist) continue;
+			RESTORE_COLUMN_POINTER(hist, dataColumn, DataColumn);
+		}
+
+		//data picker curves
+		QVector<DatapickerCurve*> dataPickerCurves = children<DatapickerCurve>(AbstractAspect::Recursive);
+		for (auto* dataPickerCurve : dataPickerCurves) {
+			if (!dataPickerCurve) continue;
+			RESTORE_COLUMN_POINTER(dataPickerCurve, posXColumn, PosXColumn);
+			RESTORE_COLUMN_POINTER(dataPickerCurve, posYColumn, PosYColumn);
+			RESTORE_COLUMN_POINTER(dataPickerCurve, plusDeltaXColumn, PlusDeltaXColumn);
+			RESTORE_COLUMN_POINTER(dataPickerCurve, minusDeltaXColumn, MinusDeltaXColumn);
+			RESTORE_COLUMN_POINTER(dataPickerCurve, plusDeltaYColumn, PlusDeltaYColumn);
+			RESTORE_COLUMN_POINTER(dataPickerCurve, minusDeltaYColumn, MinusDeltaYColumn);
+		}
+
+		//if a column was calculated via a formula, restore the pointers to the variable columns defining the formula
+		for (auto* col : columns) {
+			if (!col->formulaVariableColumnPaths().isEmpty()) {
+				auto& formulaVariableColumns = const_cast<QVector<Column*>&>(col->formulaVariableColumns());
+				formulaVariableColumns.resize(col->formulaVariableColumnPaths().length());
+
+				for (int i = 0; i < col->formulaVariableColumnPaths().length(); i++) {
+					auto path = col->formulaVariableColumnPaths()[i];
+					for (Column* c : columns) {
+						if (!c) continue;
+						if (c->path() == path) {
+							formulaVariableColumns[i] = c;
+							col->finalizeLoad();
+							break;
+						}
+					}
+				}
+			}
+		}
+
+		//all data was read in spreadsheets:
+		//call CartesianPlot::retransform() to retransform the plots
+		for (auto* plot : children<CartesianPlot>(AbstractAspect::Recursive)) {
 			plot->setIsLoading(false);
 			plot->retransform();
 		}
+
+		//all data was read in live-data sources:
+		//call CartesianPlot::dataChanged() to notify affected plots about the new data.
+		//this needs to be done here since in LiveDataSource::finalizeImport() called above
+		//where the data is read the column pointers are not restored yes in curves.
+		QVector<CartesianPlot*> plots;
+		for (auto* source : sources) {
+			for (int n = 0; n < source->columnCount(); ++n) {
+				Column* column = source->column(n);
+
+				//determine the plots where the column is consumed
+				for (const auto* curve : curves) {
+					if (curve->xColumn() == column || curve->yColumn() == column) {
+						auto* plot = dynamic_cast<CartesianPlot*>(curve->parentAspect());
+						if (plots.indexOf(plot) == -1) {
+							plots << plot;
+							plot->setSuppressDataChangedSignal(true);
+						}
+					}
+				}
+
+				column->setChanged();
+			}
+		}
+
+		//loop over all affected plots and retransform them
+		for (auto* plot : plots) {
+			plot->setSuppressDataChangedSignal(true);
+			plot->dataChanged();
+		}
+
 	}
 
 	emit loaded();
@@ -437,14 +665,7 @@ bool Project::load(XmlStreamReader* reader, bool preview) {
 
 bool Project::readProjectAttributes(XmlStreamReader* reader) {
 	QXmlStreamAttributes attribs = reader->attributes();
-	QString str = attribs.value(reader->namespaceUri().toString(), "fileName").toString();
-	if (str.isEmpty()) {
-		reader->raiseError(i18n("Project file name missing."));
-		return false;
-	}
-	d->fileName = str;
-
-	str = attribs.value(reader->namespaceUri().toString(), "modificationTime").toString();
+	QString str = attribs.value(reader->namespaceUri().toString(), "modificationTime").toString();
 	QDateTime modificationTime = QDateTime::fromString(str, "yyyy-dd-MM hh:mm:ss:zzz");
 	if (str.isEmpty() || !modificationTime.isValid()) {
 		reader->raiseWarning(i18n("Invalid project modification time. Using current time."));
@@ -452,8 +673,7 @@ bool Project::readProjectAttributes(XmlStreamReader* reader) {
 	} else
 		d->modificationTime = modificationTime;
 
-	str = attribs.value(reader->namespaceUri().toString(), "author").toString();
-	d->author = str;
+	d->author = attribs.value(reader->namespaceUri().toString(), "author").toString();
 
 	return true;
 }
