@@ -36,6 +36,8 @@
 #include "backend/lib/XmlStreamReader.h"
 #include "backend/core/datatypes/String2DateTimeFilter.h"
 #include "backend/core/datatypes/DateTime2StringFilter.h"
+#include "backend/worksheet/plots/cartesian/CartesianPlot.h"
+#include "backend/worksheet/plots/cartesian/Histogram.h"
 #include "backend/worksheet/plots/cartesian/XYCurve.h"
 #include "backend/worksheet/plots/cartesian/XYAnalysisCurve.h"
 
@@ -43,6 +45,7 @@ extern "C" {
 #include <gsl/gsl_sort.h>
 }
 
+#include <array>
 #include <QFont>
 #include <QFontMetrics>
 #include <QIcon>
@@ -67,8 +70,9 @@ extern "C" {
  * have a view as they are intended to be displayed inside a spreadsheet.
  */
 
-Column::Column(const QString& name, AbstractColumn::ColumnMode mode)
-	: AbstractColumn(name), d(new ColumnPrivate(this, mode)) {
+Column::Column(const QString& name, ColumnMode mode)
+	: AbstractColumn(name, AspectType::Column), d(new ColumnPrivate(this, mode)) {
+
 	init();
 }
 
@@ -81,12 +85,13 @@ void Column::init() {
 	d->outputFilter()->input(0, this);
 	d->inputFilter()->setHidden(true);
 	d->outputFilter()->setHidden(true);
-	addChild(d->inputFilter());
-	addChild(d->outputFilter());
+	addChildFast(d->inputFilter());
+	addChildFast(d->outputFilter());
 	m_suppressDataChangedSignal = false;
 
 	m_usedInActionGroup = new QActionGroup(this);
 	connect(m_usedInActionGroup, &QActionGroup::triggered, this, &Column::navigateTo);
+	connect(this, &AbstractColumn::maskingChanged, this, [=]{d->propertiesAvailable = false;});
 }
 
 Column::~Column() {
@@ -107,20 +112,24 @@ QMenu* Column::createContextMenu() {
 	//TODO: we don't need to add anything from the view for MQTTTopic columns.
 	//at the moment it's ok to check to the null pointer for firstAction here.
 	//later, once we have some actions in the menu also for MQTT topics we'll
-	//need to explicitely to dynamic_cast for MQTTTopic
+	//need to explicitly to dynamic_cast for MQTTTopic
 	if (firstAction)
 		emit requestProjectContextMenu(menu);
 
 	//"Used in" menu containing all curves where the column is used
 	QMenu* usedInMenu = new QMenu(i18n("Used in"));
 	usedInMenu->setIcon(QIcon::fromTheme("go-next-view"));
+	usedInMenu->addSection(i18n("Curves"));
 
 	//remove previously added actions
 	for (auto* action : m_usedInActionGroup->actions())
 		m_usedInActionGroup->removeAction(action);
 
+	Project* project = this->project();
+
 	//add curves where the column is currently in use
-	QVector<XYCurve*> curves = project()->children<XYCurve>(AbstractAspect::Recursive);
+	usedInMenu->addSection(i18n("XY-Curves"));
+	auto curves = project->children<XYCurve>(AbstractAspect::Recursive);
 	for (const auto* curve : curves) {
 		bool used = false;
 
@@ -141,6 +150,32 @@ QMenu* Column::createContextMenu() {
 		}
 	}
 
+	//add histograms where the column is used
+	usedInMenu->addSection(i18n("Histograms"));
+	auto hists = project->children<Histogram>(AbstractAspect::Recursive);
+	for (const auto* hist : hists) {
+		bool used = (hist->dataColumn() == this);
+		if (used) {
+			QAction* action = new QAction(hist->icon(), hist->name(), m_usedInActionGroup);
+			action->setData(hist->path());
+			usedInMenu->addAction(action);
+		}
+	}
+
+	//add calculated columns where the column is used in formula variables
+	usedInMenu->addSection(i18n("Calculated Columns"));
+	QVector<Column*> columns = project->children<Column>(AbstractAspect::Recursive);
+	const QString& path = this->path();
+	for (const auto* column : columns) {
+		auto paths = column->formulaVariableColumnPaths();
+		if (paths.indexOf(path) != -1) {
+			QAction* action = new QAction(column->icon(), column->name(), m_usedInActionGroup);
+			action->setData(column->path());
+			usedInMenu->addAction(action);
+		}
+	}
+
+
 	if (firstAction)
 		menu->insertSeparator(firstAction);
 
@@ -161,6 +196,39 @@ void Column::setSuppressDataChangedSignal(bool b) {
 	m_suppressDataChangedSignal = b;
 }
 
+void Column::addUsedInPlots(QVector<CartesianPlot*>& plots) {
+	const Project* project = this->project();
+
+	//when executing tests we don't create any project,
+	//add a null-pointer check for tests here.
+	if (!project)
+		return;
+
+	QVector<const XYCurve*> curves = project->children<const XYCurve>(AbstractAspect::Recursive);
+
+	//determine the plots where the column is consumed
+	for (const auto* curve : curves) {
+		if (curve->xColumn() == this || curve->yColumn() == this
+			|| (curve->xErrorType() == XYCurve::SymmetricError && curve->xErrorPlusColumn() == this)
+			|| (curve->xErrorType() == XYCurve::AsymmetricError && (curve->xErrorPlusColumn() == this ||curve->xErrorMinusColumn() == this))
+			|| (curve->yErrorType() == XYCurve::SymmetricError && curve->yErrorPlusColumn() == this)
+			|| (curve->yErrorType() == XYCurve::AsymmetricError && (curve->yErrorPlusColumn() == this ||curve->yErrorMinusColumn() == this)) ) {
+			auto* plot = dynamic_cast<CartesianPlot*>(curve->parentAspect());
+			if (plots.indexOf(plot) == -1)
+				plots << plot;
+		}
+	}
+
+	QVector<const Histogram*> hists = project->children<const Histogram>(AbstractAspect::Recursive);
+	for (const auto* hist : hists) {
+		if (hist->dataColumn() == this ) {
+			auto* plot = dynamic_cast<CartesianPlot*>(hist->parentAspect());
+			if (plots.indexOf(plot) == -1)
+				plots << plot;
+		}
+	}
+}
+
 /**
  * \brief Set the column mode
  *
@@ -213,6 +281,14 @@ void Column::setColumnModeFast(AbstractColumn::ColumnMode mode) {
 	}
 }
 
+bool Column::isDraggable() const {
+	return true;
+}
+
+QVector<AspectType> Column::dropableOn() const {
+	return QVector<AspectType>{AspectType::CartesianPlot};
+}
+
 /**
  * \brief Copy another column of the same type
  *
@@ -320,15 +396,44 @@ const QStringList& Column::formulaVariableNames() const {
 	return d->formulaVariableNames();
 }
 
-const QStringList& Column::formulaVariableColumnPathes() const {
-	return d->formulaVariableColumnPathes();
+const QVector<Column*>& Column::formulaVariableColumns() const {
+	return d->formulaVariableColumns();
+}
+
+const QStringList& Column::formulaVariableColumnPaths() const {
+	return d->formulaVariableColumnPaths();
+}
+
+void Column::setformulVariableColumnsPath(int index, const QString path) {
+	d->setformulVariableColumnsPath(index, path);
+}
+
+void Column::setformulVariableColumn(int index, Column* column) {
+	d->setformulVariableColumn(index, column);
+}
+
+bool Column::formulaAutoUpdate() const {
+	return d->formulaAutoUpdate();
 }
 
 /**
  * \brief Sets the formula used to generate column values
  */
-void Column::setFormula(const QString& formula, const QStringList& variableNames, const QStringList& columnPathes) {
-	exec(new ColumnSetGlobalFormulaCmd(d, formula, variableNames, columnPathes));
+void Column::setFormula(const QString& formula, const QStringList& variableNames,
+						const QVector<Column*>& columns, bool autoUpdate) {
+	exec(new ColumnSetGlobalFormulaCmd(d, formula, variableNames, columns, autoUpdate));
+}
+
+/*!
+ * in case the cell values are calculated via a global column formula,
+ * updates the values on data changes in all the dependent changes in the
+ * "variable columns".
+ */
+void Column::updateFormula() {
+	d->statisticsAvailable = false;
+	d->hasValuesAvailable = false;
+	d->propertiesAvailable = false;
+	d->updateFormula();
 }
 
 /**
@@ -369,6 +474,7 @@ void Column::clearFormulas() {
 void Column::setTextAt(int row, const QString& new_value) {
 	DEBUG("Column::setTextAt()");
 	d->statisticsAvailable = false;
+	d->hasValuesAvailable = false;
 	d->propertiesAvailable = false;
 	exec(new ColumnSetTextCmd(d, row, new_value));
 }
@@ -382,6 +488,7 @@ void Column::replaceTexts(int first, const QVector<QString>& new_values) {
 	DEBUG("Column::replaceTexts()");
 	if (!new_values.isEmpty()) { //TODO: do we really need this check?
 		d->statisticsAvailable = false;
+		d->hasValuesAvailable = false;
 		d->propertiesAvailable = false;
 		exec(new ColumnReplaceTextsCmd(d, first, new_values));
 	}
@@ -393,8 +500,6 @@ void Column::replaceTexts(int first, const QVector<QString>& new_values) {
  * Use this only when columnMode() is DateTime, Month or Day
  */
 void Column::setDateAt(int row, QDate new_value) {
-	d->statisticsAvailable = false;
-	d->propertiesAvailable = false;
 	setDateTimeAt(row, QDateTime(new_value, timeAt(row)));
 }
 
@@ -404,8 +509,6 @@ void Column::setDateAt(int row, QDate new_value) {
  * Use this only when columnMode() is DateTime, Month or Day
  */
 void Column::setTimeAt(int row, QTime new_value) {
-	d->statisticsAvailable = false;
-	d->propertiesAvailable = false;
 	setDateTimeAt(row, QDateTime(dateAt(row), new_value));
 }
 
@@ -416,6 +519,7 @@ void Column::setTimeAt(int row, QTime new_value) {
  */
 void Column::setDateTimeAt(int row, const QDateTime& new_value) {
 	d->statisticsAvailable = false;
+	d->hasValuesAvailable = false;
 	d->propertiesAvailable = false;
 	exec(new ColumnSetDateTimeCmd(d, row, new_value));
 }
@@ -428,6 +532,7 @@ void Column::setDateTimeAt(int row, const QDateTime& new_value) {
 void Column::replaceDateTimes(int first, const QVector<QDateTime>& new_values) {
 	if (!new_values.isEmpty()) {
 		d->statisticsAvailable = false;
+		d->hasValuesAvailable = false;
 		d->propertiesAvailable = false;
 		exec(new ColumnReplaceDateTimesCmd(d, first, new_values));
 	}
@@ -508,13 +613,15 @@ const Column::ColumnStatistics& Column::statistics() const {
 }
 
 void Column::calculateStatistics() const {
+	if ( (columnMode() != AbstractColumn::Numeric)
+		&& (columnMode() != AbstractColumn::Integer) )
+		return;
+
 	d->statistics = ColumnStatistics();
 	ColumnStatistics& statistics = d->statistics;
 
-	// TODO: support other data types?
-	auto* rowValues = reinterpret_cast<QVector<double>*>(data());
-
-	size_t notNanCount = 0;
+	int rowValuesSize = 0;
+	int notNanCount = 0;
 	double val;
 	double columnSum = 0.0;
 	double columnProduct = 1.0;
@@ -524,26 +631,57 @@ void Column::calculateStatistics() const {
 	statistics.maximum = -INFINITY;
 	QMap<double, int> frequencyOfValues;
 	QVector<double> rowData;
-	rowData.reserve(rowValues->size());
-	for (int row = 0; row < rowValues->size(); ++row) {
-		val = rowValues->value(row);
-		if (std::isnan(val) || isMasked(row))
-			continue;
 
-		if (val < statistics.minimum)
-			statistics.minimum = val;
-		if (val > statistics.maximum)
-			statistics.maximum = val;
-		columnSum+= val;
-		columnSumNeg += (1.0 / val);
-		columnSumSquare += pow(val, 2.0);
-		columnProduct *= val;
-		if (frequencyOfValues.contains(val))
-			frequencyOfValues.operator [](val)++;
-		else
-			frequencyOfValues.insert(val, 1);
-		++notNanCount;
-		rowData.push_back(val);
+	if (columnMode() == AbstractColumn::Numeric) {
+		auto* rowValues = reinterpret_cast<QVector<double>*>(data());
+		rowValuesSize = rowValues->size();
+		rowData.reserve(rowValuesSize);
+
+		for (int row = 0; row < rowValuesSize; ++row) {
+			val = rowValues->value(row);
+			if (std::isnan(val) || isMasked(row))
+				continue;
+
+			if (val < statistics.minimum)
+				statistics.minimum = val;
+			if (val > statistics.maximum)
+				statistics.maximum = val;
+			columnSum += val;
+			columnSumNeg += (1.0 / val);
+			columnSumSquare += pow(val, 2.0);
+			columnProduct *= val;
+			if (frequencyOfValues.contains(val))
+				frequencyOfValues.operator [](val)++;
+			else
+				frequencyOfValues.insert(val, 1);
+			++notNanCount;
+			rowData.push_back(val);
+		}
+	} else if (columnMode() == AbstractColumn::Integer) {
+		//TODO: code duplication because of the reinterpret_cast...
+		auto* rowValues = reinterpret_cast<QVector<int>*>(data());
+		rowValuesSize = rowValues->size();
+		rowData.reserve(rowValuesSize);
+		for (int row = 0; row < rowValuesSize; ++row) {
+			val = rowValues->value(row);
+			if (std::isnan(val) || isMasked(row))
+				continue;
+
+			if (val < statistics.minimum)
+				statistics.minimum = val;
+			if (val > statistics.maximum)
+				statistics.maximum = val;
+			columnSum += val;
+			columnSumNeg += (1.0 / val);
+			columnSumSquare += pow(val, 2.0);
+			columnProduct *= val;
+			if (frequencyOfValues.contains(val))
+				frequencyOfValues.operator [](val)++;
+			else
+				frequencyOfValues.insert(val, 1);
+			++notNanCount;
+			rowData.push_back(val);
+		}
 	}
 
 	if (notNanCount == 0) {
@@ -551,7 +689,7 @@ void Column::calculateStatistics() const {
 		return;
 	}
 
-	if (rowData.size() < rowValues->size())
+	if (rowData.size() < rowValuesSize)
 		rowData.squeeze();
 
 	statistics.arithmeticMean = columnSum / notNanCount;
@@ -572,20 +710,16 @@ void Column::calculateStatistics() const {
 	absoluteMedianList.reserve((int)notNanCount);
 	absoluteMedianList.resize((int)notNanCount);
 
-	int idx = 0;
-	for (int row = 0; row < rowValues->size(); ++row) {
-		val = rowValues->value(row);
-		if (std::isnan(val) || isMasked(row) )
-			continue;
+	for (int row = 0; row < notNanCount; ++row) {
+		val = rowData.value(row);
 		columnSumVariance += pow(val - statistics.arithmeticMean, 2.0);
 
 		sumForCentralMoment_r3 += pow(val - statistics.arithmeticMean, 3.0);
 		sumForCentralMoment_r4 += pow(val - statistics.arithmeticMean, 4.0);
 		columnSumMeanDeviation += fabs( val - statistics.arithmeticMean );
 
-		absoluteMedianList[idx] = fabs(val - statistics.median);
-		columnSumMedianDeviation += absoluteMedianList[idx];
-		idx++;
+		absoluteMedianList[row] = fabs(val - statistics.median);
+		columnSumMedianDeviation += absoluteMedianList[row];
 	}
 
 	statistics.meanDeviationAroundMedian = columnSumMedianDeviation / notNanCount;
@@ -707,7 +841,6 @@ int Column::integerAt(int row) const {
  * This is used e.g. in \c XYFitCurvePrivate::recalculate()
  */
 void Column::setChanged() {
-
     d->propertiesAvailable = false;
 
 	if (!m_suppressDataChangedSignal)
@@ -715,7 +848,6 @@ void Column::setChanged() {
 
 	d->statisticsAvailable = false;
 	d->hasValuesAvailable = false;
-
 }
 
 ////////////////////////////////////////////////////////////////////////////////
@@ -749,6 +881,7 @@ void Column::save(QXmlStreamWriter* writer) const {
 	//save the formula used to generate column values, if available
 	if (!formula().isEmpty() ) {
 		writer->writeStartElement("formula");
+		writer->writeAttribute("autoUpdate", QString::number(d->formulaAutoUpdate()));
 		writer->writeTextElement("text", formula());
 
 		writer->writeStartElement("variableNames");
@@ -757,7 +890,7 @@ void Column::save(QXmlStreamWriter* writer) const {
 		writer->writeEndElement();
 
 		writer->writeStartElement("columnPathes");
-		for (const auto& path : formulaVariableColumnPathes())
+		for (const auto path : formulaVariableColumnPaths())
 			writer->writeTextElement("path", path);
 		writer->writeEndElement();
 
@@ -921,6 +1054,10 @@ bool Column::load(XmlStreamReader* reader, bool preview) {
 	return !reader->error();
 }
 
+void Column::finalizeLoad() {
+	d->finalizeLoad();
+}
+
 /**
  * \brief Read XML input filter element
  */
@@ -952,6 +1089,7 @@ bool Column::XmlReadFormula(XmlStreamReader* reader) {
 	QString formula;
 	QStringList variableNames;
 	QStringList columnPathes;
+	bool autoUpdate = reader->attributes().value("autoUpdate").toInt();
 	while (reader->readNext()) {
 		if (reader->isEndElement()) break;
 
@@ -973,7 +1111,9 @@ bool Column::XmlReadFormula(XmlStreamReader* reader) {
 			}
 		}
 	}
-	setFormula(formula, variableNames, columnPathes);
+
+	d->setFormula(formula, variableNames, columnPathes, autoUpdate);
+
 	return true;
 }
 
@@ -1087,6 +1227,33 @@ AbstractColumn::PlotDesignation Column::plotDesignation() const {
 	return d->plotDesignation();
 }
 
+QString Column::plotDesignationString() const {
+	switch (plotDesignation()) {
+	case AbstractColumn::NoDesignation:
+		return QString("");
+	case AbstractColumn::X:
+		return QLatin1String("[X]");
+	case AbstractColumn::Y:
+		return QLatin1String("[Y]");
+	case AbstractColumn::Z:
+		return QLatin1String("[Z]");
+	case AbstractColumn::XError:
+		return QLatin1String("[") + i18n("X-error") + QLatin1Char(']');
+	case AbstractColumn::XErrorPlus:
+		return QLatin1String("[") + i18n("X-error +") + QLatin1Char(']');
+	case AbstractColumn::XErrorMinus:
+		return QLatin1String("[") + i18n("X-error -") + QLatin1Char(']');
+	case AbstractColumn::YError:
+		return QLatin1String("[") + i18n("Y-error") + QLatin1Char(']');
+	case AbstractColumn::YErrorPlus:
+		return QLatin1String("[") + i18n("Y-error +") + QLatin1Char(']');
+	case AbstractColumn::YErrorMinus:
+		return QLatin1String("[") + i18n("Y-error -") + QLatin1Char(']');
+	}
+
+	return QString("");
+}
+
 AbstractSimpleFilter* Column::outputFilter() const {
 	return d->outputFilter();
 }
@@ -1137,7 +1304,7 @@ void Column::handleFormatChange() {
 
 	emit aspectDescriptionChanged(this); // the icon for the type changed
 	if (!m_suppressDataChangedSignal)
-		emit dataChanged(this); // all cells must be repainted
+		emit formatChanged(this); // all cells must be repainted
 
 	d->statisticsAvailable = false;
 	d->hasValuesAvailable = false;
@@ -1156,7 +1323,6 @@ double Column::minimum(int count) const {
 	if (count == 0 && d->statisticsAvailable)
 		min = const_cast<Column*>(this)->statistics().minimum;
 	else {
-		ColumnMode mode = columnMode();
 		int start, end;
 
 		if (count == 0) {
@@ -1169,11 +1335,48 @@ double Column::minimum(int count) const {
 			start = qMax(rowCount() + count, 0);
 			end = rowCount();
 		}
+		return minimum(start, end);
+	}
 
+	return min;
+}
+
+/*!
+ * \brief Column::minimum
+ * Calculates the minimum value in the column between the \p startIndex and \p endIndex, endIndex is excluded.
+ * If startIndex is greater than endIndex the indices are swapped
+ * \p startIndex
+ * \p endIndex
+ */
+double Column::minimum(int startIndex, int endIndex) const {
+	double min = INFINITY;
+
+	if (rowCount() == 0)
+		return min;
+
+	if (startIndex > endIndex && startIndex >= 0 && endIndex >= 0)
+		std::swap(startIndex, endIndex);
+
+	startIndex = qMax(startIndex, 0);
+	endIndex = qMax(endIndex, 0);
+
+	startIndex = qMin(startIndex, rowCount() - 1);
+	endIndex = qMin(endIndex, rowCount() - 1);
+
+	int foundIndex = 0;
+
+	ColumnMode mode = columnMode();
+	Properties property = properties();
+	if (property == Properties::No) {
+		// skipping values is only in Properties::No needed, because
+		// when there are invalid values the property must be Properties::No
 		switch (mode) {
 		case Numeric: {
 			auto* vec = static_cast<QVector<double>*>(data());
-			for (int row = start; row < end; ++row) {
+			for (int row = startIndex; row < endIndex; ++row) {
+				if (!isValid(row) || isMasked(row))
+					continue;
+
 				const double val = vec->at(row);
 				if (std::isnan(val))
 					continue;
@@ -1185,7 +1388,10 @@ double Column::minimum(int count) const {
 		}
 		case Integer: {
 			auto* vec = static_cast<QVector<int>*>(data());
-			for (int row = start; row < end; ++row) {
+			for (int row = startIndex; row < endIndex; ++row) {
+				if (!isValid(row) || isMasked(row))
+					continue;
+
 				const int val = vec->at(row);
 
 				if (val < min)
@@ -1197,7 +1403,10 @@ double Column::minimum(int count) const {
 			break;
 		case DateTime: {
 			auto* vec = static_cast<QVector<QDateTime>*>(data());
-			for (int row = start; row < end; ++row) {
+			for (int row = startIndex; row < endIndex; ++row) {
+				if (!isValid(row) || isMasked(row))
+					continue;
+
 				const qint64 val = vec->at(row).toMSecsSinceEpoch();
 
 				if (val < min)
@@ -1210,7 +1419,26 @@ double Column::minimum(int count) const {
 		default:
 			break;
 		}
+		return min;
+	}
 
+	// use the properties knowledge to determine maximum faster
+	if (property == Properties::Constant || property == Properties::MonotonicIncreasing)
+		foundIndex = startIndex;
+	else if (property == Properties::MonotonicDecreasing)
+		foundIndex = endIndex;
+
+	switch (mode) {
+		case Numeric:
+		case Integer:
+			return valueAt(foundIndex);
+		case DateTime:
+		case Month:
+		case Day:
+			return dateTimeAt(foundIndex).toMSecsSinceEpoch();
+		case Text:
+		default:
+			break;
 	}
 
 	return min;
@@ -1228,7 +1456,6 @@ double Column::maximum(int count) const {
 	if (count == 0 && d->statisticsAvailable)
 		max = const_cast<Column*>(this)->statistics().maximum;
 	else {
-		ColumnMode mode = columnMode();
 		int start, end;
 
 		if (count == 0) {
@@ -1241,11 +1468,43 @@ double Column::maximum(int count) const {
 			start = qMax(rowCount() + count, 0);
 			end = rowCount();
 		}
+		return maximum(start, end);
+	}
 
+	return max;
+}
+
+/*!
+ * \brief Column::maximum
+ * Calculates the maximum value in the column between the \p startIndex and \p endIndex.
+ * If startIndex is greater than endIndex the indices are swapped
+ * \p startIndex
+ * \p endIndex
+ */
+double Column::maximum(int startIndex, int endIndex) const {
+	double max = -INFINITY;
+	if (rowCount() == 0)
+		return max;
+
+	if (startIndex > endIndex && startIndex >= 0 && endIndex >= 0)
+		std::swap(startIndex, endIndex);
+
+	startIndex = qMax(startIndex, 0);
+	endIndex = qMax(endIndex, 0);
+
+	startIndex = qMin(startIndex, rowCount() - 1);
+	endIndex = qMin(endIndex, rowCount() - 1);
+	int foundIndex = 0;
+
+	ColumnMode mode = columnMode();
+	Properties property = properties();
+	if (property == Properties::No) {
 		switch (mode) {
 		case Numeric: {
 			auto* vec = static_cast<QVector<double>*>(data());
-			for (int row = start; row < end; ++row) {
+			for (int row = startIndex; row < endIndex; ++row) {
+				if (!isValid(row) || isMasked(row))
+					continue;
 				const double val = vec->at(row);
 				if (std::isnan(val))
 					continue;
@@ -1257,7 +1516,9 @@ double Column::maximum(int count) const {
 		}
 		case Integer: {
 			auto* vec = static_cast<QVector<int>*>(data());
-			for (int row = start; row < end; ++row) {
+			for (int row = startIndex; row < endIndex; ++row) {
+				if (!isValid(row) || isMasked(row))
+					continue;
 				const int val = vec->at(row);
 
 				if (val > max)
@@ -1269,7 +1530,9 @@ double Column::maximum(int count) const {
 			break;
 		case DateTime: {
 			auto* vec = static_cast<QVector<QDateTime>*>(data());
-			for (int row = start; row < end; ++row) {
+			for (int row = startIndex; row < endIndex; ++row) {
+				if (!isValid(row) || isMasked(row))
+					continue;
 				const qint64 val = vec->at(row).toMSecsSinceEpoch();
 
 				if (val > max)
@@ -1282,8 +1545,497 @@ double Column::maximum(int count) const {
 		default:
 			break;
 		}
-
+		return max;
 	}
 
+	// use the properties knowledge to determine maximum faster
+	if (property == Properties::Constant || property == Properties::MonotonicDecreasing)
+		foundIndex = startIndex;
+	else if (property == Properties::MonotonicIncreasing)
+		foundIndex = endIndex;
+
+	switch (mode) {
+		case Numeric:
+		case Integer:
+			return valueAt(foundIndex);
+		case DateTime:
+		case Month:
+		case Day:
+			return dateTimeAt(foundIndex).toMSecsSinceEpoch();
+		case Text:
+		default:
+			break;
+	}
 	return max;
 }
+
+/*!
+ * calculates log2(x)+1 for an integer value.
+ * Used in y(double x) to calculate the maximum steps
+ * source: https://stackoverflow.com/questions/11376288/fast-computing-of-log2-for-64-bit-integers
+ * source: http://graphics.stanford.edu/~seander/bithacks.html#IntegerLogLookup
+ * @param value
+ * @return returns calculated value
+ */
+// TODO: testing if it is faster than calculating log2.
+int Column::calculateMaxSteps (unsigned int value) {
+	const std::array<signed char, 256> LogTable256 = {
+		-1,0,1,1,2,2,2,2,3,3,3,3,3,3,3,3,
+		4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,
+		5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,
+		5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,
+		6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,
+		6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,
+		6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,
+		6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,
+		7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,
+		7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,
+		7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,
+		7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,
+		7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,
+		7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,
+		7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,
+		7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7
+	};
+
+	unsigned int r;     // r will be lg(v)
+	unsigned int t, tt; // temporaries
+	if ((tt = value >> 16))
+		r = (t = tt >> 8) ? 24 + LogTable256[t] : 16 + LogTable256[tt];
+	else
+		r = (t = value >> 8) ? 8 + LogTable256[t] : LogTable256[value];
+
+	return r+1;
+}
+
+/*!
+* Find index which corresponds to a @p x . In a vector of values
+* When monotonic increasing or decreasing a different algorithm will be used, which needs less steps (mean) (log_2(rowCount)) to find the value.
+* @param x
+* @return -1 if index not found, otherwise the index
+*/
+int Column::indexForValue(double x, QVector<double>& column, Properties properties) {
+	int rowCount = column.count();
+	if (rowCount == 0)
+		return -1;
+
+	double prevValue = 0;
+	//qint64 prevValueDateTime = 0;
+	if (properties == AbstractColumn::Properties::MonotonicIncreasing ||
+			properties == AbstractColumn::Properties::MonotonicDecreasing) {
+		// bisects the index every time, so it is possible to find the value in log_2(rowCount) steps
+		bool increase = true;
+		if(properties == AbstractColumn::Properties::MonotonicDecreasing)
+			increase = false;
+
+		int lowerIndex = 0;
+		int higherIndex = rowCount-1;
+
+		unsigned int maxSteps = calculateMaxSteps(static_cast<unsigned int>(rowCount))+1;
+
+		for (unsigned int i = 0; i < maxSteps; i++) { // so no log_2(rowCount) needed
+			int index = lowerIndex + round(static_cast<double>(higherIndex - lowerIndex)/2);
+			double value = column[index];
+
+			if (higherIndex - lowerIndex < 2) {
+				if (qAbs(column[lowerIndex] - x) < qAbs(column[higherIndex] - x))
+					index = lowerIndex;
+				else
+					index = higherIndex;
+
+				return index;
+			}
+
+			if (value > x && increase)
+				higherIndex = index;
+			else if (value >= x && !increase)
+				lowerIndex = index;
+			else if (value <= x && increase)
+				lowerIndex = index;
+			else if (value < x && !increase)
+				higherIndex = index;
+
+		}
+
+	} else if (properties == AbstractColumn::Properties::Constant) {
+		return 0;
+	} else {
+		// AbstractColumn::Properties::No
+		// naiv way
+		int index = 0;
+		prevValue = column[0];
+		for (int row = 0; row < rowCount; row++) {
+
+			double value = column[row];
+			if (qAbs(value - x) <= qAbs(prevValue - x)) { // "<=" prevents also that row - 1 become < 0
+					prevValue = value;
+					index = row;
+			}
+		}
+		return index;
+	}
+	return -1;
+}
+
+/*!
+* Find index which corresponds to a @p x . In a vector of values
+* When monotonic increasing or decreasing a different algorithm will be used, which needs less steps (mean) (log_2(rowCount)) to find the value.
+* @param x
+* @return -1 if index not found, otherwise the index
+*/
+int Column::indexForValue(const double x, const QVector<QPointF>& points, Properties properties) {
+	int rowCount = points.count();
+
+	if (rowCount == 0)
+		return -1;
+
+	double prevValue = 0;
+	//qint64 prevValueDateTime = 0;
+	if (properties == AbstractColumn::Properties::MonotonicIncreasing ||
+			properties == AbstractColumn::Properties::MonotonicDecreasing) {
+		// bisects the index every time, so it is possible to find the value in log_2(rowCount) steps
+		bool increase = true;
+		if(properties == AbstractColumn::Properties::MonotonicDecreasing)
+			increase = false;
+
+		int lowerIndex = 0;
+		int higherIndex = rowCount - 1;
+
+		unsigned int maxSteps = calculateMaxSteps(static_cast<unsigned int>(rowCount))+1;
+
+		for (unsigned int i = 0; i < maxSteps; i++) { // so no log_2(rowCount) needed
+			int index = lowerIndex + round(static_cast<double>(higherIndex - lowerIndex)/2);
+			double value = points[index].x();
+
+			if (higherIndex - lowerIndex < 2) {
+				if (qAbs(points[lowerIndex].x() - x) < qAbs(points[higherIndex].x() - x))
+					index = lowerIndex;
+				else
+					index = higherIndex;
+
+				return index;
+			}
+
+			if (value > x && increase)
+				higherIndex = index;
+			else if (value >= x && !increase)
+				lowerIndex = index;
+			else if (value <= x && increase)
+				lowerIndex = index;
+			else if (value < x && !increase)
+				higherIndex = index;
+
+		}
+
+	} else if (properties == AbstractColumn::Properties::Constant) {
+		return 0;
+	} else {
+		// AbstractColumn::Properties::No
+		// naiv way
+		prevValue = points[0].x();
+		int index = 0;
+		for (int row = 0; row < rowCount; row++) {
+
+			double value = points[row].x();
+			if (qAbs(value - x) <= qAbs(prevValue - x)) { // "<=" prevents also that row - 1 become < 0
+					prevValue = value;
+					index = row;
+			}
+		}
+		return index;
+	}
+	return -1;
+}
+
+/*!
+* Find index which corresponds to a @p x . In a vector of values
+* When monotonic increasing or decreasing a different algorithm will be used, which needs less steps (mean) (log_2(rowCount)) to find the value.
+* @param x
+* @return -1 if index not found, otherwise the index
+*/
+int Column::indexForValue(double x, QVector<QLineF>& lines, Properties properties) {
+	int rowCount = lines.count();
+	if (rowCount == 0)
+		return -1;
+	// use only p1 to find index
+	double prevValue = 0;
+	//qint64 prevValueDateTime = 0;
+	if (properties == AbstractColumn::Properties::MonotonicIncreasing ||
+			properties == AbstractColumn::Properties::MonotonicDecreasing) {
+		// bisects the index every time, so it is possible to find the value in log_2(rowCount) steps
+		bool increase = true;
+		if(properties == AbstractColumn::Properties::MonotonicDecreasing)
+			increase = false;
+
+		int lowerIndex = 0;
+		int higherIndex = rowCount-1;
+
+		unsigned int maxSteps = calculateMaxSteps(static_cast<unsigned int>(rowCount))+1;
+
+		for (unsigned int i = 0; i < maxSteps; i++) { // so no log_2(rowCount) needed
+			int index = lowerIndex + round(static_cast<double>(higherIndex - lowerIndex)/2);
+			double value = lines[index].p1().x();
+
+			if (higherIndex - lowerIndex < 2) {
+				if (qAbs(lines[lowerIndex].p1().x() - x) < qAbs(lines[higherIndex].p1().x() - x))
+					index = lowerIndex;
+				else
+					index = higherIndex;
+
+				return index;
+			}
+
+			if (value > x && increase)
+				higherIndex = index;
+			else if (value >= x && !increase)
+				lowerIndex = index;
+			else if (value <= x && increase)
+				lowerIndex = index;
+			else if (value < x && !increase)
+				higherIndex = index;
+
+		}
+
+	} else if (properties == AbstractColumn::Properties::Constant) {
+		return 0;
+	} else {
+		// AbstractColumn::Properties::No
+		// naiv way
+		int index = 0;
+		prevValue = lines[0].p1().x();
+		for (int row = 0; row < rowCount; row++) {
+			double value = lines[row].p1().x();
+			if (qAbs(value - x) <= qAbs(prevValue - x)) { // "<=" prevents also that row - 1 become < 0
+				prevValue = value;
+				index = row;
+			}
+		}
+		return index;
+	}
+	return -1;
+}
+
+int Column::indexForValue(double x) const {
+
+	double prevValue = 0;
+	qint64 prevValueDateTime = 0;
+	AbstractColumn::ColumnMode mode = columnMode();
+	int property = properties();
+	if (property == AbstractColumn::Properties::MonotonicIncreasing ||
+			property == AbstractColumn::Properties::MonotonicDecreasing) {
+		// bisects the index every time, so it is possible to find the value in log_2(rowCount) steps
+		bool increase = (property != AbstractColumn::Properties::MonotonicDecreasing);
+
+		int lowerIndex = 0;
+		int higherIndex = rowCount() - 1;
+
+		unsigned int maxSteps = calculateMaxSteps(static_cast<unsigned int>(rowCount()))+1;
+
+		if ((mode == AbstractColumn::ColumnMode::Numeric ||
+			 mode == AbstractColumn::ColumnMode::Integer)) {
+			for (unsigned int i = 0; i < maxSteps; i++) { // so no log_2(rowCount) needed
+				int index = lowerIndex + round(static_cast<double>(higherIndex - lowerIndex)/2);
+				double value = valueAt(index);
+
+				if (higherIndex - lowerIndex < 2) {
+					if (qAbs(valueAt(lowerIndex) - x) < qAbs(valueAt(higherIndex) - x))
+						index = lowerIndex;
+					else
+						index = higherIndex;
+
+					return index;
+				}
+
+				if (value > x && increase)
+					higherIndex = index;
+				else if (value >= x && !increase)
+					lowerIndex = index;
+				else if (value <= x && increase)
+					lowerIndex = index;
+				else if (value < x && !increase)
+					higherIndex = index;
+
+			}
+		} else if ((mode == AbstractColumn::ColumnMode::DateTime ||
+					mode == AbstractColumn::ColumnMode::Month ||
+					mode == AbstractColumn::ColumnMode::Day)) {
+			qint64 xInt64 = static_cast<qint64>(x);
+			for (unsigned int i = 0; i < maxSteps; i++) { // so no log_2(rowCount) needed
+				int index = lowerIndex + round(static_cast<double>(higherIndex - lowerIndex)/2);
+				qint64 value = dateTimeAt(index).toMSecsSinceEpoch();
+
+				if (higherIndex - lowerIndex < 2) {
+					if (abs(dateTimeAt(lowerIndex).toMSecsSinceEpoch() - xInt64) < abs(dateTimeAt(higherIndex).toMSecsSinceEpoch() - xInt64))
+						index = lowerIndex;
+					else
+						index = higherIndex;
+
+					return index;
+				}
+
+				if (value > xInt64 && increase)
+					higherIndex = index;
+				else if (value >= xInt64 && !increase)
+					lowerIndex = index;
+				else if (value <= xInt64 && increase)
+					lowerIndex = index;
+				else if (value < xInt64 && !increase)
+					higherIndex = index;
+
+			}
+		}
+
+	} else if (property == AbstractColumn::Properties::Constant) {
+		if (rowCount() > 0)
+			return 0;
+		else
+			return -1;
+	} else {
+		// naiv way
+		int index = 0;
+		if ((mode == AbstractColumn::ColumnMode::Numeric ||
+			 mode == AbstractColumn::ColumnMode::Integer)) {
+			for (int row = 0; row < rowCount(); row++) {
+				if (!isValid(row) || isMasked(row))
+					continue;
+				if (row == 0)
+					prevValue = valueAt(row);
+
+				double value = valueAt(row);
+				if (abs(value - x) <= abs(prevValue - x)) { // <= prevents also that row - 1 become < 0
+					if (row < rowCount() - 1) {
+						prevValue = value;
+						index = row;
+					}
+				}
+			}
+			return index;
+		} else if ((mode == AbstractColumn::ColumnMode::DateTime ||
+					mode == AbstractColumn::ColumnMode::Month ||
+					mode == AbstractColumn::ColumnMode::Day)) {
+			qint64 xInt64 = static_cast<qint64>(x);
+			for (int row = 0; row < rowCount(); row++) {
+				if (!isValid(row) || isMasked(row))
+					continue;
+
+				if (row == 0)
+					prevValueDateTime = dateTimeAt(row).toMSecsSinceEpoch();
+
+				qint64 value = dateTimeAt(row).toMSecsSinceEpoch();
+				if (abs(value - xInt64) <= abs(prevValueDateTime - xInt64)) { // "<=" prevents also that row - 1 become < 0
+					prevValueDateTime = value;
+					index = row;
+				}
+			}
+			return index;
+		}
+	}
+	return -1;
+}
+
+/*!
+ * Finds the minimal and maximal index which are between v1 and v2
+ * \brief Column::indicesForX
+ * \param x1
+ * \param x2
+ * \param start
+ * \param end
+ * \return
+ */
+bool Column::indicesMinMax(double v1, double v2, int& start, int& end) const {
+
+	start = -1;
+	end = -1;
+	if (rowCount() == 0)
+		return false;
+
+	// Assumption: v1 is always the smaller value
+	if (v1 > v2)
+		qSwap(v1, v2);
+
+	Properties property = properties();
+	if (property == Properties::MonotonicIncreasing ||
+		property == Properties::MonotonicDecreasing) {
+		start = indexForValue(v1);
+		end = indexForValue(v2);
+
+		switch (columnMode()) {
+			case Integer:
+			case Numeric: {
+			if (start > 0 && valueAt(start -1) <= v2 && valueAt(start -1) >= v1)
+				start--;
+			if (end < rowCount() - 1 && valueAt(end + 1) <= v2 && valueAt(end + 1) >= v1)
+				end++;
+
+			break;
+			}
+			case DateTime:
+			case Month:
+			case Day: {
+				qint64 v1int64 = v1;
+				qint64 v2int64 = v2;
+				qint64 value;
+				if (start > 0) {
+					value = dateTimeAt(start -1).toMSecsSinceEpoch();
+					if (value <= v2int64 && value >= v1int64)
+						start--;
+				}
+
+				if (end > rowCount() - 1) {
+					value = dateTimeAt(end + 1).toMSecsSinceEpoch();
+					if (value <= v2int64 && value >= v1int64)
+						end++;
+				}
+				break;
+			}
+			case Text:
+				return false;
+		}
+		return true;
+	} else if (property == Properties::Constant) {
+		start = 0;
+		end = rowCount() - 1;
+		return true;
+	}
+	// property == Properties::No
+	switch (columnMode()) {
+		case Integer:
+		case Numeric: {
+			double value;
+			for (int i = 0; i < rowCount(); i++) {
+				if (!isValid(i) || isMasked(i))
+					continue;
+				value = valueAt(i);
+				if (value <= v2 && value >= v1) {
+					end = i;
+					if (start < 0)
+						start = i;
+				}
+
+			}
+			break;
+		}
+		case DateTime:
+		case Month:
+		case Day: {
+			qint64 value;
+			qint64 v2int64 = v2;
+			qint64 v1int64 = v2;
+			for (int i = 0; i < rowCount(); i++) {
+				if (!isValid(i) || isMasked(i))
+					continue;
+				value = dateTimeAt(i).toMSecsSinceEpoch();
+				if (value <= v2int64 && value >= v1int64) {
+					end = i;
+					if (start < 0)
+						start = i;
+				}
+			}
+			break;
+		}
+		case Text:
+			return false;
+
+	}
+	return true;
+}
