@@ -35,6 +35,7 @@
 #include "backend/lib/XmlStreamReader.h"
 #include "backend/core/column/ColumnPrivate.h"
 
+class CartesianPlot;
 class ColumnStringIO;
 class QActionGroup;
 
@@ -45,8 +46,8 @@ public:
 	explicit Column(const QString& name, AbstractColumn::ColumnMode = AbstractColumn::Numeric);
 	// template constructor for all supported data types (AbstractColumn::ColumnMode) must be defined in header
 	template <typename T>
-	explicit Column(const QString& name, QVector<T> data, AbstractColumn::ColumnMode mode = AbstractColumn::Numeric)
-		: AbstractColumn(name), d(new ColumnPrivate(this, mode, new QVector<T>(data))) {
+	Column(const QString& name, QVector<T> data, AbstractColumn::ColumnMode mode = AbstractColumn::Numeric)
+		: AbstractColumn(name, AspectType::Column), d(new ColumnPrivate(this, mode, new QVector<T>(data))) {
 		init();
 	}
 	void init();
@@ -59,10 +60,14 @@ public:
 	void setColumnMode(AbstractColumn::ColumnMode) override;
 	void setColumnModeFast(AbstractColumn::ColumnMode);
 
+	bool isDraggable() const override;
+	QVector<AspectType> dropableOn() const override;
+
 	bool copy(const AbstractColumn*) override;
 	bool copy(const AbstractColumn* source, int source_start, int dest_start, int num_rows) override;
 
 	AbstractColumn::PlotDesignation plotDesignation() const override;
+	QString plotDesignationString() const override;
 	void setPlotDesignation(AbstractColumn::PlotDesignation) override;
 
 	bool isReadOnly() const override;
@@ -73,10 +78,15 @@ public:
 	AbstractSimpleFilter* outputFilter() const;
 	ColumnStringIO* asStringColumn() const;
 
-	void setFormula(const QString& formula, const QStringList& variableNames, const QStringList& variableColumnPathes);
+	void setFormula(const QString& formula, const QStringList& variableNames,
+					const QVector<Column*>& columns, bool autoUpdate);
 	QString formula() const;
 	const QStringList& formulaVariableNames() const;
-	const QStringList& formulaVariableColumnPathes() const;
+	const QVector<Column*>& formulaVariableColumns() const;
+	const QStringList& formulaVariableColumnPaths() const;
+	void setformulVariableColumnsPath(int index, const QString path);
+	void setformulVariableColumn(int index, Column *column);
+	bool formulaAutoUpdate() const;
 
 	QString formula(int) const  override;
 	QVector< Interval<int> > formulaIntervals() const override;
@@ -107,13 +117,27 @@ public:
 	Properties properties() const override;
 
 	double maximum(int count = 0) const override;
+	double maximum(int startIndex, int endIndex) const override;
 	double minimum(int count = 0) const override;
+	double minimum(int startIndex, int endIndex) const override;
+	static int calculateMaxSteps(unsigned int value);
+	static int indexForValue(double x, QVector<double>& column, Properties properties = Properties::No);
+	static int indexForValue(const double x, const QVector<QPointF> &column, Properties properties = Properties::No);
+	static int indexForValue(double x, QVector<QLineF>& lines, Properties properties = Properties::No);
+	int indexForValue(double x) const override;
+	bool indicesMinMax(double v1, double v2, int& start, int& end) const override;
 
 	void setChanged();
 	void setSuppressDataChangedSignal(const bool);
 
+	void addUsedInPlots(QVector<CartesianPlot*>&);
+
 	void save(QXmlStreamWriter*) const override;
 	bool load(XmlStreamReader*, bool preview) override;
+	void finalizeLoad();
+
+public slots:
+	void updateFormula();
 
 private:
 	bool XmlReadInputFilter(XmlStreamReader*);
