@@ -4,7 +4,7 @@
     Description          : Private data class of Column
     --------------------------------------------------------------------
     Copyright            : (C) 2007-2008 Tilman Benkert (thzs@gmx.net)
-    Copyright            : (C) 2012-2017 Alexander Semke (alexander.semke@web.de)
+    Copyright            : (C) 2012-2019 Alexander Semke (alexander.semke@web.de)
     Copyright            : (C) 2017 Stefan Gerlach (stefan.gerlach@uni.kn)
  ***************************************************************************/
 
@@ -30,7 +30,9 @@
 #include "ColumnPrivate.h"
 #include "ColumnStringIO.h"
 #include "Column.h"
+#include "backend/spreadsheet/Spreadsheet.h"
 #include "backend/core/datatypes/filter.h"
+#include "backend/gsl/ExpressionParser.h"
 
 ColumnPrivate::ColumnPrivate(Column* owner, AbstractColumn::ColumnMode mode) :
 	m_column_mode(mode), m_owner(owner) {
@@ -39,7 +41,7 @@ ColumnPrivate::ColumnPrivate(Column* owner, AbstractColumn::ColumnMode mode) :
 	switch (mode) {
 	case AbstractColumn::Numeric:
 		m_input_filter = new String2DoubleFilter();
-		m_output_filter = new Double2StringFilter();
+		m_output_filter = new Double2StringFilter('g');
 		m_data = new QVector<double>();
 		break;
 	case AbstractColumn::Integer:
@@ -73,8 +75,8 @@ ColumnPrivate::ColumnPrivate(Column* owner, AbstractColumn::ColumnMode mode) :
 
 	connect(m_output_filter, &AbstractSimpleFilter::formatChanged, m_owner, &Column::handleFormatChange);
 
-	m_input_filter->setName("InputFilter");
-	m_output_filter->setName("OutputFilter");
+	//m_input_filter->setName("InputFilter");
+	//m_output_filter->setName("OutputFilter");
 }
 
 /**
@@ -122,8 +124,8 @@ ColumnPrivate::ColumnPrivate(Column* owner, AbstractColumn::ColumnMode mode, voi
 		break;
 	}
 
-	m_input_filter->setName("InputFilter");
-	m_output_filter->setName("OutputFilter");
+	//m_input_filter->setName("InputFilter");
+	//m_output_filter->setName("OutputFilter");
 }
 
 ColumnPrivate::~ColumnPrivate() {
@@ -161,7 +163,7 @@ AbstractColumn::ColumnMode ColumnPrivate::columnMode() const {
  */
 void ColumnPrivate::setColumnMode(AbstractColumn::ColumnMode mode) {
 	DEBUG("ColumnPrivate::setColumnMode() " << ENUM_TO_STRING(AbstractColumn, ColumnMode, m_column_mode)
-		<< " -> " << ENUM_TO_STRING(AbstractColumn, ColumnMode, mode));
+		<< " -> " << ENUM_TO_STRING(AbstractColumn, ColumnMode, mode))
 	if (mode == m_column_mode) return;
 
 	void* old_data = m_data;
@@ -380,8 +382,8 @@ void ColumnPrivate::setColumnMode(AbstractColumn::ColumnMode mode) {
 
 	m_column_mode = mode;
 
-	new_in_filter->setName("InputFilter");
-	new_out_filter->setName("OutputFilter");
+	//new_in_filter->setName("InputFilter");
+	//new_out_filter->setName("OutputFilter");
 	m_input_filter = new_in_filter;
 	m_output_filter = new_out_filter;
 	m_input_filter->input(0, m_owner->m_string_io);
@@ -436,8 +438,8 @@ void ColumnPrivate::replaceModeData(AbstractColumn::ColumnMode mode, void* data,
 	m_column_mode = mode;
 	m_data = data;
 
-	in_filter->setName("InputFilter");
-	out_filter->setName("OutputFilter");
+	//in_filter->setName("InputFilter");
+	//out_filter->setName("OutputFilter");
 	m_input_filter = in_filter;
 	m_output_filter = out_filter;
 	m_input_filter->input(0, m_owner->m_string_io);
@@ -509,15 +511,17 @@ bool ColumnPrivate::copy(const AbstractColumn* other) {
 		break;
 	}
 	case AbstractColumn::Text: {
+		auto* vec = static_cast<QVector<QString>*>(m_data);
 		for (int i = 0; i < num_rows; ++i)
-			static_cast<QVector<QString>*>(m_data)->replace(i, other->textAt(i));
+			vec->replace(i, other->textAt(i));
 		break;
 	}
 	case AbstractColumn::DateTime:
 	case AbstractColumn::Month:
 	case AbstractColumn::Day: {
+		auto* vec = static_cast<QVector<QDateTime>*>(m_data);
 		for (int i = 0; i < num_rows; ++i)
-			static_cast<QVector<QDateTime>*>(m_data)->replace(i, other->dateTimeAt(i));
+			vec->replace(i, other->dateTimeAt(i));
 		break;
 	}
 	}
@@ -710,8 +714,10 @@ int ColumnPrivate::rowCount() const {
  */
 void ColumnPrivate::resizeTo(int new_size) {
 	int old_size = rowCount();
+	if (new_size == old_size)
+		return;
+
 	DEBUG("ColumnPrivate::resizeTo() " << old_size << " -> " << new_size);
-	if (new_size == old_size) return;
 
 	switch (m_column_mode) {
 	case AbstractColumn::Numeric: {
@@ -882,13 +888,178 @@ QString ColumnPrivate::formula() const {
 	return m_formula;
 }
 
+bool ColumnPrivate::formulaAutoUpdate() const {
+	return m_formulaAutoUpdate;
+}
+
 /**
  * \brief Sets the formula used to generate column values
  */
-void ColumnPrivate::setFormula(const QString& formula, const QStringList& variableNames, const QStringList& variableColumnPathes) {
+void ColumnPrivate::setFormula(const QString& formula, const QStringList& variableNames,
+							   const QVector<Column*>& variableColumns, bool autoUpdate) {
 	m_formula = formula;
 	m_formulaVariableNames = variableNames;
-	m_formulaVariableColumnPathes = variableColumnPathes;
+	m_formulaVariableColumns = variableColumns;
+	m_formulaAutoUpdate = autoUpdate;
+
+	for (auto connection: m_connectionsUpdateFormula)
+		disconnect(connection);
+
+	m_formulaVariableColumnPaths.clear();
+
+	for (auto column : variableColumns) {
+		m_formulaVariableColumnPaths << column->path();
+		if (autoUpdate)
+			connectFormulaColumn(column);
+	}
+}
+
+/*!
+ * called after the import of the project was done and all columns were loaded in \sa Project::load()
+ * to establish the required slot-signal connections for the formula update
+ */
+void ColumnPrivate::finalizeLoad() {
+	if (m_formulaAutoUpdate) {
+		for (auto column : m_formulaVariableColumns)
+			connectFormulaColumn(column);
+	}
+}
+
+/*!
+ * \brief ColumnPrivate::connectFormulaColumn
+ * This function is used to connect the columns to the needed slots for updating formulas
+ * \param column
+ */
+void ColumnPrivate::connectFormulaColumn(const AbstractColumn* column) {
+	if (!column)
+		return;
+
+	m_connectionsUpdateFormula << connect(column, &Column::dataChanged, m_owner, &Column::updateFormula);
+	connect(column->parentAspect(), &AbstractAspect::aspectAboutToBeRemoved, this, &ColumnPrivate::formulaVariableColumnRemoved);
+	connect(column, &AbstractColumn::reset, this, &ColumnPrivate::formulaVariableColumnRemoved);
+	connect(column->parentAspect(), &AbstractAspect::aspectAdded, this, &ColumnPrivate::formulaVariableColumnAdded);
+}
+
+/*!
+ * helper function used in \c Column::load() to set parameters read from the xml file.
+ * \param variableColumnPathes is used to restore the pointers to columns from pathes
+ * after the project was loaded in Project::load().
+ */
+ void ColumnPrivate::setFormula(const QString& formula, const QStringList& variableNames,
+								const QStringList& variableColumnPaths, bool autoUpdate) {
+	m_formula = formula;
+	m_formulaVariableNames = variableNames;
+	m_formulaVariableColumnPaths = variableColumnPaths;
+	m_formulaVariableColumns.resize(variableColumnPaths.length());
+	m_formulaAutoUpdate = autoUpdate;
+}
+
+const QStringList& ColumnPrivate::formulaVariableNames() const {
+	return m_formulaVariableNames;
+}
+
+const QVector<Column*>& ColumnPrivate::formulaVariableColumns() const {
+	return m_formulaVariableColumns;
+}
+
+const QStringList& ColumnPrivate::formulaVariableColumnPaths() const {
+	return m_formulaVariableColumnPaths;
+}
+
+void ColumnPrivate::setformulVariableColumnsPath(int index, QString path) {
+	m_formulaVariableColumnPaths[index] = path;
+}
+
+void ColumnPrivate::setformulVariableColumn(int index, Column* column) {
+	if (m_formulaVariableColumns[index]) // if there exists already a valid column, disconnect it first
+		disconnect(m_formulaVariableColumns[index], nullptr, this, nullptr);
+	m_formulaVariableColumns[index] = column;
+	connectFormulaColumn(column);
+}
+
+/*!
+ * \sa FunctionValuesDialog::generate()
+ */
+void ColumnPrivate::updateFormula() {
+	//determine variable names and the data vectors of the specified columns
+	QVector<QVector<double>*> xVectors;
+	QVector<QVector<double>*> xNewVectors;
+	int maxRowCount = 0;
+
+	bool valid = true;
+	for (auto column : m_formulaVariableColumns) {
+		if (!column) {
+			valid = false;
+			break;
+		}
+
+		if (column->columnMode() == AbstractColumn::Integer) {
+			//convert integers to doubles first
+			auto* xVector = new QVector<double>(column->rowCount());
+			for (int i = 0; i<column->rowCount(); ++i)
+				xVector->operator[](i) = column->valueAt(i);
+
+			xNewVectors << xVector;
+			xVectors << xVector;
+		} else
+			xVectors << static_cast<QVector<double>* >(column->data());
+
+		if (column->rowCount() > maxRowCount)
+			maxRowCount = column->rowCount();
+	}
+
+	if (valid) {
+		//resize the spreadsheet if one of the data vectors from
+		//other spreadsheet(s) has more elements than the parent spreadsheet
+		Spreadsheet* spreadsheet = dynamic_cast<Spreadsheet*>(m_owner->parentAspect());
+		Q_ASSERT(spreadsheet);
+		if (spreadsheet->rowCount() < maxRowCount)
+			spreadsheet->setRowCount(maxRowCount);
+
+		//create new vector for storing the calculated values
+		//the vectors with the variable data can be smaller then the result vector. So, not all values in the result vector might get initialized.
+		//->"clean" the result vector first
+		QVector<double> new_data(rowCount(), NAN);
+
+		//evaluate the expression for f(x_1, x_2, ...) and write the calculated values into a new vector.
+		ExpressionParser* parser = ExpressionParser::getInstance();
+		parser->evaluateCartesian(m_formula, m_formulaVariableNames, xVectors, &new_data);
+		replaceValues(0, new_data);
+
+		// initialize remaining rows with NAN
+		int remainingRows = rowCount() - maxRowCount;
+		if (remainingRows > 0) {
+			QVector<double> emptyRows(remainingRows, NAN);
+			replaceValues(maxRowCount, emptyRows);
+		}
+	} else {
+		QVector<double> new_data(rowCount(), NAN);
+		replaceValues(0, new_data);
+	}
+
+	//delete help vectors created for the conversion from int to double
+	for (auto* vector : xNewVectors)
+		delete vector;
+}
+
+void ColumnPrivate::formulaVariableColumnRemoved(const AbstractAspect* aspect) {
+	const Column* column = dynamic_cast<const Column*>(aspect);
+	disconnect(column, nullptr, this, nullptr);
+	//TODO: why is const_cast required here?!?
+	int index = m_formulaVariableColumns.indexOf(const_cast<Column*>(column));
+	if (index != -1) {
+		m_formulaVariableColumns[index] = nullptr;
+		updateFormula();
+	}
+}
+
+void ColumnPrivate::formulaVariableColumnAdded(const AbstractAspect* aspect) {
+	int index = m_formulaVariableColumnPaths.indexOf(aspect->path());
+	if (index != -1) {
+		const Column* column = dynamic_cast<const Column*>(aspect);
+		m_formulaVariableColumns[index] = const_cast<Column*>(column);
+		updateFormula();
+	}
 }
 
 /**
@@ -898,14 +1069,6 @@ QString ColumnPrivate::formula(int row) const {
 	return m_formulas.value(row);
 }
 
-const QStringList& ColumnPrivate::formulaVariableNames() const {
-	return m_formulaVariableNames;
-}
-
-const QStringList& ColumnPrivate::formulaVariableColumnPathes() const {
-	return m_formulaVariableColumnPathes;
-}
-
 /**
  * \brief Return the intervals that have associated formulas
  *
@@ -1214,7 +1377,7 @@ void ColumnPrivate::replaceInteger(int first, const QVector<int>& new_values) {
 
 /*!
  * Updates the properties. Will be called, when data in the column changed.
- * The properies will be used to speed up some algorithms.
+ * The properties will be used to speed up some algorithms.
  * See where variable properties will be used.
  */
 void ColumnPrivate::updateProperties() {
@@ -1253,40 +1416,72 @@ void ColumnPrivate::updateProperties() {
 	qint64 valueDateTime;
 
 	for (int row = 1; row < rowCount(); row++) {
+		if (!m_owner->isValid(row) || m_owner->isMasked(row)) {
+			// if there is one invalid or masked value, the property is No, because
+			// otherwise it's difficult to find the correct index in indexForValue().
+			// You don't know if you should increase the index or decrease it when
+			// you hit an invalid value
+			properties = AbstractColumn::Properties::No;
+			propertiesAvailable = true;
+			return;
+		}
 
 		if (m_column_mode == AbstractColumn::Integer) {
 			valueInt = integerAt(row);
 
-			// check monotonic increasing
-			if (valueInt >= prevValueInt && monotonic_increasing < 0)
-				monotonic_increasing = 1;
-			else if (valueInt < prevValueInt && monotonic_increasing >= 0)
-				monotonic_increasing = 0;
-			// else: nothing
-
-			// check monotonic decreasing
-			if (valueInt <= prevValueInt && monotonic_decreasing < 0)
-				monotonic_decreasing = 1;
-			else if (valueInt > prevValueInt && monotonic_decreasing >= 0)
+			if (valueInt > prevValueInt) {
 				monotonic_decreasing = 0;
+				if (monotonic_increasing < 0)
+					monotonic_increasing = 1;
+				else if (monotonic_increasing == 0)
+					break; // when nor increasing, nor decreasing, break
+
+			} else if (valueInt < prevValueInt) {
+				monotonic_increasing = 0;
+				if (monotonic_decreasing < 0)
+					monotonic_decreasing = 1;
+				else if (monotonic_decreasing == 0)
+					break; // when nor increasing, nor decreasing, break
+
+			} else {
+				if (monotonic_increasing < 0 && monotonic_decreasing < 0) {
+					monotonic_decreasing = 1;
+					monotonic_increasing = 1;
+				}
+			}
+
 
 			prevValueInt = valueInt;
 
 			} else if (m_column_mode == AbstractColumn::Numeric) {
 				value = valueAt(row);
 
-				// check monotonic increasing
-				if (value >= prevValue && monotonic_increasing < 0)
-					monotonic_increasing = 1;
-				else if (value < prevValue)
+				if (std::isnan(value)) {
 					monotonic_increasing = 0;
-				// else: nothing
-
-				// check monotonic decreasing
-				if (value <= prevValue && monotonic_decreasing < 0)
-					monotonic_decreasing = 1;
-				else if (value > prevValue)
 					monotonic_decreasing = 0;
+					break;
+				}
+
+				if (value > prevValue) {
+					monotonic_decreasing = 0;
+					if (monotonic_increasing < 0)
+						monotonic_increasing = 1;
+					else if (monotonic_increasing == 0)
+						break; // when nor increasing, nor decreasing, break
+
+				} else if (value < prevValue) {
+					monotonic_increasing = 0;
+					if (monotonic_decreasing < 0)
+						monotonic_decreasing = 1;
+					else if (monotonic_decreasing == 0)
+						break; // when nor increasing, nor decreasing, break
+
+				} else {
+					if (monotonic_increasing < 0 && monotonic_decreasing < 0) {
+						monotonic_decreasing = 1;
+						monotonic_increasing = 1;
+					}
+				}
 
 				prevValue = value;
 
@@ -1296,18 +1491,26 @@ void ColumnPrivate::updateProperties() {
 
 				valueDateTime = dateTimeAt(row).toMSecsSinceEpoch();
 
-				// check monotonic increasing
-				if (valueDateTime >= prevValueDatetime && monotonic_increasing < 0)
-					monotonic_increasing = 1;
-				else if (valueDateTime < prevValueDatetime)
-					monotonic_increasing = 0;
-				// else: nothing
-
-				// check monotonic decreasing
-				if (valueDateTime <= prevValueDatetime && monotonic_decreasing < 0)
-					monotonic_decreasing = 1;
-				else if (valueDateTime > prevValueDatetime)
+				if (valueDateTime > prevValueDatetime) {
 					monotonic_decreasing = 0;
+					if (monotonic_increasing < 0)
+						monotonic_increasing = 1;
+					else if (monotonic_increasing == 0)
+						break; // when nor increasing, nor decreasing, break
+
+				} else if (valueDateTime < prevValueDatetime) {
+					monotonic_increasing = 0;
+					if (monotonic_decreasing < 0)
+						monotonic_decreasing = 1;
+					else if (monotonic_decreasing == 0)
+						break; // when nor increasing, nor decreasing, break
+
+				} else {
+					if (monotonic_increasing < 0 && monotonic_decreasing < 0) {
+						monotonic_decreasing = 1;
+						monotonic_increasing = 1;
+					}
+				}
 
 				prevValueDatetime = valueDateTime;
 			}
