@@ -50,7 +50,7 @@ public:
 
 private:
 	ColumnPrivate* m_col;
-	AbstractColumn::ColumnMode m_old_mode;
+	AbstractColumn::ColumnMode m_old_mode{AbstractColumn::Numeric};
 	AbstractColumn::ColumnMode m_mode;
 	void* m_old_data{nullptr};
 	void* m_new_data{nullptr};
@@ -138,7 +138,7 @@ public:
 private:
 	ColumnPrivate* m_col;
 	AbstractColumn::PlotDesignation m_new_pd;
-	AbstractColumn::PlotDesignation m_old_pd;
+	AbstractColumn::PlotDesignation m_old_pd{AbstractColumn::X};
 };
 
 class ColumnClearCmd : public QUndoCommand {
@@ -159,7 +159,9 @@ private:
 
 class ColumnSetGlobalFormulaCmd : public QUndoCommand {
 public:
-	explicit ColumnSetGlobalFormulaCmd(ColumnPrivate* col, QString formula, QStringList variableNames, QStringList variableColumnPathes);
+	explicit ColumnSetGlobalFormulaCmd(ColumnPrivate* col, QString formula,
+									   QStringList variableNames, QVector<Column*> columns,
+									   bool autoUpdate);
 
 	void redo() override;
 	void undo() override;
@@ -168,10 +170,12 @@ private:
 	ColumnPrivate* m_col;
 	QString m_formula;
 	QStringList m_variableNames;
-	QStringList m_variableColumnPathes;
+	QVector<Column*> m_variableColumns;
+	bool m_autoUpdate{false};
 	QString m_newFormula;
 	QStringList m_newVariableNames;
-	QStringList m_newVariableColumnPathes;
+	QVector<Column*> m_newVariableColumns;
+	bool m_newAutoUpdate{false};
 	bool m_copied{false};
 };
 
