@@ -74,12 +74,11 @@ bool Double2StringFilter::load(XmlStreamReader* reader, bool preview) {
 	if (AbstractSimpleFilter::load(reader, preview)) {
 		bool ok;
 		int digits = digits_str.toInt(&ok);
-		if ( (format_str.size() != 1) || !ok ) {
-			reader->raiseError(i18n("missing or invalid format attribute"));
-		} else {
-			setNumericFormat( format_str.at(0).toLatin1() );
-			setNumDigits( digits );
-		}
+		if (ok)
+			setNumDigits(digits);
+
+		if (format_str.size() >= 1)
+			setNumericFormat(format_str.at(0).toLatin1());
 	} else
 		return false;
 
