@@ -30,7 +30,6 @@
 #define DATAPICKER_H
 
 #include "backend/core/AbstractPart.h"
-#include "backend/core/AbstractScriptingEngine.h"
 
 class Spreadsheet;
 class DatapickerCurve;
@@ -43,11 +42,11 @@ class Transform;
 class QPointF;
 class QVector3D;
 
-class Datapicker : public AbstractPart, public scripted {
+class Datapicker : public AbstractPart {
 	Q_OBJECT
 
 public:
-	explicit Datapicker(AbstractScriptingEngine* engine, const QString& name, const bool loading = false);
+	explicit Datapicker(const QString& name, const bool loading = false);
 	~Datapicker() override;
 
 	QIcon icon() const override;
@@ -76,10 +75,10 @@ public slots:
 	void childSelected(const AbstractAspect*) override;
 
 private:
-	mutable DatapickerView* m_view;
-	DatapickerCurve* m_activeCurve;
+	mutable DatapickerView* m_view{nullptr};
+	DatapickerCurve* m_activeCurve{nullptr};
 	Transform* m_transform;
-	DatapickerImage* m_image;
+	DatapickerImage* m_image{nullptr};
 	void init();
 	void handleChildAspectAboutToBeRemoved(const AbstractAspect*);
 	void handleChildAspectAdded(const AbstractAspect*);
