@@ -4,7 +4,7 @@
     Description          : Worksheet for Datapicker
     --------------------------------------------------------------------
     Copyright            : (C) 2015 by Ankit Wagadre (wagadre.ankit@gmail.com)
-    Copyright            : (C) 2015-2016 by Alexander Semke (alexander.semke@web.de)
+    Copyright            : (C) 2015-2019 by Alexander Semke (alexander.semke@web.de)
 
  ***************************************************************************/
 /***************************************************************************
@@ -56,7 +56,8 @@
  *
  * * \ingroup datapicker
  */
-DatapickerImage::DatapickerImage(const QString& name, bool loading) : AbstractPart(name),
+DatapickerImage::DatapickerImage(const QString& name, bool loading) :
+	AbstractPart(name, AspectType::DatapickerImage),
 	foregroundBins( new int[ImageEditor::colorAttributeMax(Foreground) + 1]),
 	hueBins( new int[ImageEditor::colorAttributeMax(Hue) + 1]),
 	saturationBins( new int[ImageEditor::colorAttributeMax(Saturation) + 1]),
@@ -82,12 +83,17 @@ DatapickerImage::~DatapickerImage() {
 void DatapickerImage::init() {
 	KConfig config;
 	KConfigGroup group = config.group( "DatapickerImage" );
+
+	//general properties
 	d->fileName = group.readEntry("FileName", QString());
 	d->rotationAngle = group.readEntry("RotationAngle", 0.0);
 	d->minSegmentLength = group.readEntry("MinSegmentLength", 30);
 	d->pointSeparation = group.readEntry("PointSeparation", 30);
 	d->axisPoints.type = (DatapickerImage::GraphType) group.readEntry("GraphType", (int) DatapickerImage::Cartesian);
 	d->axisPoints.ternaryScale = group.readEntry("TernaryScale", 1);
+
+	//edit image settings
+	d->plotImageType = DatapickerImage::OriginalImage;
 	d->settings.foregroundThresholdHigh = group.readEntry("ForegroundThresholdHigh", 90);
 	d->settings.foregroundThresholdLow = group.readEntry("ForegroundThresholdLow", 30);
 	d->settings.hueThresholdHigh = group.readEntry("HueThresholdHigh", 360);
@@ -98,9 +104,8 @@ void DatapickerImage::init() {
 	d->settings.saturationThresholdLow = group.readEntry("SaturationThresholdLow", 30);
 	d->settings.valueThresholdHigh = group.readEntry("ValueThresholdHigh", 90);
 	d->settings.valueThresholdLow = group.readEntry("ValueThresholdLow", 30);
-	d->plotPointsType = (DatapickerImage::PointsType) group.readEntry("PlotPointsType", (int) DatapickerImage::AxisPoints);
-	d->plotImageType = DatapickerImage::OriginalImage;
-	// point properties
+
+	// reference point symbol properties
 	d->pointStyle = (Symbol::Style)group.readEntry("PointStyle", (int)Symbol::Cross);
 	d->pointSize = group.readEntry("Size", Worksheet::convertToSceneUnits(7, Worksheet::Point));
 	d->pointRotationAngle = group.readEntry("Rotation", 0.0);
@@ -219,33 +224,6 @@ DatapickerImage::PlotImageType DatapickerImage::plotImageType() {
 	return d->plotImageType;
 }
 
-void DatapickerImage::initSceneParameters() {
-	setRotationAngle(0.0);
-	setminSegmentLength(30);
-	setPointSeparation(30);
-
-	ReferencePoints axisPoints = d->axisPoints;
-	axisPoints.ternaryScale = 1;
-	axisPoints.type = DatapickerImage::Cartesian;
-	setAxisPoints(axisPoints);
-
-	EditorSettings settings;
-	settings.foregroundThresholdHigh = 90;
-	settings.foregroundThresholdLow = 30;
-	settings.hueThresholdHigh = 360;
-	settings.hueThresholdLow = 0;
-	settings.intensityThresholdHigh = 100;
-	settings.intensityThresholdLow = 20;
-	settings.saturationThresholdHigh = 100;
-	settings.saturationThresholdLow = 30;
-	settings.valueThresholdHigh = 90;
-	settings.valueThresholdLow = 30;
-	setSettings(settings);
-
-	DatapickerImage::PointsType plotPointsType = DatapickerImage::AxisPoints;
-	setPlotPointsType(plotPointsType);
-}
-
 /* =============================== getter methods for background options ================================= */
 CLASS_D_READER_IMPL(DatapickerImage, QString, fileName, fileName)
 CLASS_D_READER_IMPL(DatapickerImage, DatapickerImage::ReferencePoints, axisPoints, axisPoints)
@@ -301,7 +279,6 @@ void DatapickerImage::setPointStyle(Symbol::Style newStyle) {
 		exec(new DatapickerImageSetPointStyleCmd(d, newStyle, ki18n("%1: set point's style")));
 }
 
-
 STD_SETTER_CMD_IMPL_F_S(DatapickerImage, SetPointSize, qreal, pointSize, retransform)
 void DatapickerImage::setPointSize(qreal value) {
 	if (!qFuzzyCompare(1 + value, 1 + d->pointSize))
@@ -345,6 +322,9 @@ void DatapickerImage::setPrinting(bool on) const {
 }
 
 void DatapickerImage::setPlotPointsType(const PointsType pointsType) {
+	if (d->plotPointsType == pointsType)
+		return;
+
 	d->plotPointsType = pointsType;
 
 	if (pointsType == DatapickerImage::AxisPoints) {
@@ -374,7 +354,7 @@ void DatapickerImage::setPointSeparation(const int value) {
 //######################  Private implementation ###############################
 //##############################################################################
 DatapickerImagePrivate::DatapickerImagePrivate(DatapickerImage *owner) : q(owner),
-	pageRect(0, 0, 1500, 1500),
+	pageRect(0, 0, 1000, 1000),
 	m_scene(new QGraphicsScene(pageRect)) {
 }
 
@@ -446,10 +426,8 @@ void DatapickerImagePrivate::updateFileName() {
 	const QString& address = fileName.trimmed();
 
 	if (!address.isEmpty()) {
-		if (uploadImage(address)) {
-			q->initSceneParameters();
+		if (uploadImage(address))
 			fileName = address;
-		}
 	} else {
 		//hide segments if they are visible
 		q->m_segments->setSegmentsVisible(false);
@@ -474,7 +452,7 @@ void DatapickerImagePrivate::updateFileName() {
 void DatapickerImage::save(QXmlStreamWriter* writer) const {
 	writer->writeStartElement( "datapickerImage" );
 	writeBasicAttributes(writer);
-	writeCommentElement(writer);
+
 	//general properties
 	writer->writeStartElement( "general" );
 	writer->writeAttribute( "fileName", d->fileName );
@@ -554,34 +532,18 @@ bool DatapickerImage::load(XmlStreamReader* reader, bool preview) {
 		if (!reader->isStartElement())
 			continue;
 
-		if (reader->name() == "comment") {
-			if (!readCommentElement(reader)) return false;
-		} else if (!preview && reader->name() == "general") {
+		if (!preview && reader->name() == "general") {
 			attribs = reader->attributes();
 
 			str = attribs.value("fileName").toString();
 			d->fileName = str;
 
-			str = attribs.value("plotPointsType").toString();
-			if (str.isEmpty())
-				reader->raiseWarning(attributeWarning.subs("plotPointsType").toString());
-			else
-				d->plotPointsType = DatapickerImage::PointsType(str.toInt());
-
+			READ_INT_VALUE("plotPointsType", plotPointsType, DatapickerImage::PointsType);
 		} else if (!preview && reader->name() == "axisPoint") {
 			attribs = reader->attributes();
 
-			str = attribs.value("graphType").toString();
-			if (str.isEmpty())
-				reader->raiseWarning(attributeWarning.subs("graphType").toString());
-			else
-				d->axisPoints.type = DatapickerImage::GraphType(str.toInt());
-
-			str = attribs.value("ternaryScale").toString();
-			if (str.isEmpty())
-				reader->raiseWarning(attributeWarning.subs("ternaryScale").toString());
-			else
-				d->axisPoints.ternaryScale = str.toDouble();
+			READ_INT_VALUE("graphType", axisPoints.type, DatapickerImage::GraphType);
+			READ_INT_VALUE("ternaryScale", axisPoints.ternaryScale, int);
 
 			str = attribs.value("axisPointLogicalX1").toString();
 			if (str.isEmpty())
@@ -676,123 +638,28 @@ bool DatapickerImage::load(XmlStreamReader* reader, bool preview) {
 		} else if (!preview && reader->name() == "editorSettings") {
 			attribs = reader->attributes();
 
-			str = attribs.value("plotImageType").toString();
-			if (str.isEmpty())
-				reader->raiseWarning(attributeWarning.subs("plotImageType").toString());
-			else
-				d->plotImageType = DatapickerImage::PlotImageType(str.toInt());
-
-			str = attribs.value("rotationAngle").toString();
-			if (str.isEmpty())
-				reader->raiseWarning(attributeWarning.subs("rotationAngle").toString());
-			else
-				d->rotationAngle = str.toFloat();
-
-			str = attribs.value("minSegmentLength").toString();
-			if (str.isEmpty())
-				reader->raiseWarning(attributeWarning.subs("minSegmentLength").toString());
-			else
-				d->minSegmentLength = str.toInt();
-
-			str = attribs.value("pointSeparation").toString();
-			if (str.isEmpty())
-				reader->raiseWarning(attributeWarning.subs("pointSeparation").toString());
-			else
-				d->pointSeparation = str.toInt();
-
-			str = attribs.value("foregroundThresholdHigh").toString();
-			if (str.isEmpty())
-				reader->raiseWarning(attributeWarning.subs("foregroundThresholdHigh").toString());
-			else
-				d->settings.foregroundThresholdHigh = str.toInt();
-
-			str = attribs.value("foregroundThresholdLow").toString();
-			if (str.isEmpty())
-				reader->raiseWarning(attributeWarning.subs("foregroundThresholdLow").toString());
-			else
-				d->settings.foregroundThresholdLow = str.toInt();
-
-			str = attribs.value("hueThresholdHigh").toString();
-			if (str.isEmpty())
-				reader->raiseWarning(attributeWarning.subs("hueThresholdHigh").toString());
-			else
-				d->settings.hueThresholdHigh = str.toInt();
-
-			str = attribs.value("hueThresholdLow").toString();
-			if (str.isEmpty())
-				reader->raiseWarning(attributeWarning.subs("hueThresholdLow").toString());
-			else
-				d->settings.hueThresholdLow = str.toInt();
-
-			str = attribs.value("intensityThresholdHigh").toString();
-			if (str.isEmpty())
-				reader->raiseWarning(attributeWarning.subs("intensityThresholdHigh").toString());
-			else
-				d->settings.intensityThresholdHigh = str.toInt();
-
-			str = attribs.value("intensityThresholdLow").toString();
-			if (str.isEmpty())
-				reader->raiseWarning(attributeWarning.subs("intensityThresholdLow").toString());
-			else
-				d->settings.intensityThresholdLow = str.toInt();
-
-			str = attribs.value("saturationThresholdHigh").toString();
-			if (str.isEmpty())
-				reader->raiseWarning(attributeWarning.subs("saturationThresholdHigh").toString());
-			else
-				d->settings.saturationThresholdHigh = str.toInt();
-
-			str = attribs.value("saturationThresholdLow").toString();
-			if (str.isEmpty())
-				reader->raiseWarning(attributeWarning.subs("saturationThresholdLow").toString());
-			else
-				d->settings.saturationThresholdLow = str.toInt();
-
-			str = attribs.value("valueThresholdHigh").toString();
-			if (str.isEmpty())
-				reader->raiseWarning(attributeWarning.subs("valueThresholdHigh").toString());
-			else
-				d->settings.valueThresholdHigh = str.toInt();
-
-			str = attribs.value("valueThresholdLow").toString();
-			if (str.isEmpty())
-				reader->raiseWarning(attributeWarning.subs("valueThresholdLow").toString());
-			else
-				d->settings.valueThresholdLow = str.toInt();
-
+			READ_INT_VALUE("plotImageType", plotImageType, DatapickerImage::PlotImageType);
+			READ_DOUBLE_VALUE("rotationAngle", rotationAngle);
+			READ_INT_VALUE("minSegmentLength", minSegmentLength, int);
+			READ_INT_VALUE("pointSeparation", pointSeparation, int);
+			READ_INT_VALUE("foregroundThresholdHigh", settings.foregroundThresholdHigh, int);
+			READ_INT_VALUE("foregroundThresholdLow", settings.foregroundThresholdLow, int);
+			READ_INT_VALUE("hueThresholdHigh", settings.hueThresholdHigh, int);
+			READ_INT_VALUE("hueThresholdLow", settings.hueThresholdLow, int);
+			READ_INT_VALUE("intensityThresholdHigh", settings.intensityThresholdHigh, int);
+			READ_INT_VALUE("intensityThresholdLow", settings.intensityThresholdLow, int);
+			READ_INT_VALUE("saturationThresholdHigh", settings.saturationThresholdHigh, int);
+			READ_INT_VALUE("saturationThresholdLow", settings.saturationThresholdLow, int);
+			READ_INT_VALUE("valueThresholdHigh", settings.valueThresholdHigh, int);
+			READ_INT_VALUE("valueThresholdLow", settings.valueThresholdLow, int);
 		} else if (!preview && reader->name() == "symbolProperties") {
 			attribs = reader->attributes();
 
-			str = attribs.value("pointRotationAngle").toString();
-			if (str.isEmpty())
-				reader->raiseWarning(attributeWarning.subs("pointRotationAngle").toString());
-			else
-				d->pointRotationAngle = str.toFloat();
-
-			str = attribs.value("pointOpacity").toString();
-			if (str.isEmpty())
-				reader->raiseWarning(attributeWarning.subs("pointOpacity").toString());
-			else
-				d->pointOpacity = str.toFloat();
-
-			str = attribs.value("pointSize").toString();
-			if (str.isEmpty())
-				reader->raiseWarning(attributeWarning.subs("pointSize").toString());
-			else
-				d->pointSize = str.toFloat();
-
-			str = attribs.value("pointStyle").toString();
-			if (str.isEmpty())
-				reader->raiseWarning(attributeWarning.subs("pointStyle").toString());
-			else
-				d->pointStyle = (Symbol::Style)str.toInt();
-
-			str = attribs.value("pointVisibility").toString();
-			if (str.isEmpty())
-				reader->raiseWarning(attributeWarning.subs("pointVisibility").toString());
-			else
-				d->pointVisibility = (bool)str.toInt();
-
+			READ_DOUBLE_VALUE("pointRotationAngle", pointRotationAngle);
+			READ_DOUBLE_VALUE("pointOpacity", pointOpacity);
+			READ_DOUBLE_VALUE("pointSize", pointSize);
+			READ_INT_VALUE("pointStyle", pointStyle, Symbol::Style);
+			READ_INT_VALUE("pointVisibility", pointVisibility, bool);
 			READ_QBRUSH(d->pointBrush);
 			READ_QPEN(d->pointPen);
 		} else if (reader->name() == "datapickerPoint") {
