@@ -4,6 +4,7 @@
     Description          : Graphic Item for coordinate points of Datapicker
     --------------------------------------------------------------------
     Copyright            : (C) 2015 by Ankit Wagadre (wagadre.ankit@gmail.com)
+	Copyright            : (C) 2015-2019 Alexander Semke (alexander.semke@web.de)
  ***************************************************************************/
 /***************************************************************************
  *                                                                         *
@@ -27,16 +28,10 @@
 #ifndef DATAPICKERPOINT_H
 #define DATAPICKERPOINT_H
 
-#include "backend/core/AbstractAspect.h"
-#include "backend/lib/macros.h"
 #include "backend/datapicker/DatapickerCurve.h"
-#include <QGraphicsItem>
-#include "backend/worksheet/plots/cartesian/Symbol.h"
+#include "backend/lib/macros.h"
 
-class QObject;
-class QBrush;
-class QPen;
-class DatapickerPoint;
+#include <QGraphicsItem>
 
 //TODO: own file
 class ErrorBarItem : public QObject, public QGraphicsRectItem {
@@ -46,8 +41,6 @@ public:
 	enum ErrorBarType {PlusDeltaX, MinusDeltaX, PlusDeltaY, MinusDeltaY};
 
 	explicit ErrorBarItem(DatapickerPoint* parent = nullptr, const ErrorBarType& type = PlusDeltaX);
-
-	QVariant itemChange(GraphicsItemChange change, const QVariant &value) override;
 	void setRectSize(const qreal);
 
 public slots:
@@ -56,6 +49,9 @@ public slots:
 private:
 	void initRect();
 	void mouseReleaseEvent(QGraphicsSceneMouseEvent*) override;
+	void hoverEnterEvent(QGraphicsSceneHoverEvent*) override;
+	QVariant itemChange(GraphicsItemChange, const QVariant &value) override;
+
 	QGraphicsLineItem* barLineItem;
 	QRectF m_rect;
 	ErrorBarType m_type;
