@@ -37,7 +37,7 @@ public:
 	QString name() const;
 	void retransform();
 	virtual void recalcShapeAndBoundingRect();
-	void updateData();
+	void updatePoint();
 	void updatePropeties();
 	void retransformErrorBar();
 
@@ -70,6 +70,9 @@ public:
 
 private:
 	void contextMenuEvent(QGraphicsSceneContextMenuEvent*) override;
+	void mouseReleaseEvent(QGraphicsSceneMouseEvent*) override;
+	void hoverEnterEvent(QGraphicsSceneHoverEvent*) override;
+	void hoverLeaveEvent(QGraphicsSceneHoverEvent*) override;
 };
 
 #endif
