@@ -3,7 +3,7 @@ File		: LiveDataSource.cpp
 Project		: LabPlot
 Description	: Represents live data source
 --------------------------------------------------------------------
-Copyright	: (C) 2009-2017 Alexander Semke (alexander.semke@web.de)
+Copyright	: (C) 2009-2019 Alexander Semke (alexander.semke@web.de)
 Copyright	: (C) 2017 Fabian Kristof (fkristofszabolcs@gmail.com)
 Copyright	: (C) 2018 Stefan Gerlach (stefan.gerlach@uni.kn)
 
@@ -34,26 +34,23 @@ Copyright	: (C) 2018 Stefan Gerlach (stefan.gerlach@uni.kn)
 #include "backend/datasources/filters/BinaryFilter.h"
 #include "backend/datasources/filters/ROOTFilter.h"
 #include "backend/core/Project.h"
+#include "commonfrontend/spreadsheet/SpreadsheetView.h"
 #include "kdefrontend/spreadsheet/PlotDataDialog.h"
 
-#include "commonfrontend/spreadsheet/SpreadsheetView.h"
-
-#include <QFileInfo>
+#include <QAction>
 #include <QDateTime>
-#include <QProcess>
 #include <QDir>
-#include <QMenu>
+#include <QFileInfo>
 #include <QFileSystemWatcher>
-#include <QFile>
-#include <QTimer>
+#include <QIcon>
+#include <QMenu>
 #include <QMessageBox>
-
+#include <QProcess>
+#include <QTimer>
 #include <QSerialPortInfo>
 #include <QTcpSocket>
 #include <QUdpSocket>
 
-#include <QIcon>
-#include <QAction>
 #include <KLocalizedString>
 
 /*!
@@ -62,12 +59,13 @@ Copyright	: (C) 2018 Stefan Gerlach (stefan.gerlach@uni.kn)
 
   \ingroup datasources
 */
-LiveDataSource::LiveDataSource(const QString& name, bool loading) : Spreadsheet(name, loading),
-	m_updateTimer(new QTimer(this)) {
+LiveDataSource::LiveDataSource(const QString& name, bool loading) : Spreadsheet(name, loading, AspectType::LiveDataSource),
+	m_updateTimer(new QTimer(this)), m_watchTimer(new QTimer(this)) {
 
 	initActions();
 
 	connect(m_updateTimer, &QTimer::timeout, this, &LiveDataSource::read);
+	connect(m_watchTimer, &QTimer::timeout, this, &LiveDataSource::readOnUpdate);
 }
 
 LiveDataSource::~LiveDataSource() {
@@ -76,45 +74,23 @@ LiveDataSource::~LiveDataSource() {
 
 	delete m_filter;
 	delete m_fileSystemWatcher;
-	delete m_file;
 	delete m_localSocket;
 	delete m_tcpSocket;
 	delete m_serialPort;
-
-	delete m_updateTimer;
-}
-
-/*!
- * depending on the update type, periodically or on data changes, starts the timer or activates the file watchers, respectively.
- */
-void LiveDataSource::ready() {
-	DEBUG("LiveDataSource::ready() update type = " << ENUM_TO_STRING(LiveDataSource, UpdateType, m_updateType) << ", interval = " << m_updateInterval);
-	switch (m_updateType) {
-	case TimeInterval:
-		m_updateTimer->start(m_updateInterval);
-		DEBUG("STARTED TIMER. REMAINING TIME = " << m_updateTimer->remainingTime());
-		break;
-	case NewData:
-		DEBUG("STARTING WATCHER");
-		watch();
-	}
 }
 
 void LiveDataSource::initActions() {
-	m_reloadAction = new QAction(QIcon::fromTheme("view-refresh"), i18n("Reload"), this);
-	connect(m_reloadAction, &QAction::triggered, this, &LiveDataSource::read);
-
-	m_toggleLinkAction = new QAction(i18n("Link the file"), this);
-	m_toggleLinkAction->setCheckable(true);
-	connect(m_toggleLinkAction, &QAction::triggered, this, &LiveDataSource::linkToggled);
-
 	m_plotDataAction = new QAction(QIcon::fromTheme("office-chart-line"), i18n("Plot data"), this);
 	connect(m_plotDataAction, &QAction::triggered, this, &LiveDataSource::plotData);
+	m_watchTimer->setSingleShot(true);
+	m_watchTimer->setInterval(100);
 }
 
 QWidget* LiveDataSource::view() const {
-	if (!m_partView)
-		m_partView = new SpreadsheetView(const_cast<LiveDataSource*>(this), true);
+	if (!m_partView) {
+		m_view = new SpreadsheetView(const_cast<LiveDataSource*>(this), true);
+		m_partView = m_view;
+	}
 	return m_partView;
 }
 
@@ -123,7 +99,7 @@ QWidget* LiveDataSource::view() const {
  */
 QStringList LiveDataSource::availablePorts() {
 	QStringList ports;
-	qDebug() << "available ports count:" << QSerialPortInfo::availablePorts().size();
+// 	qDebug() << "available ports count:" << QSerialPortInfo::availablePorts().size();
 
 	for (const QSerialPortInfo& sp : QSerialPortInfo::availablePorts()) {
 		ports.append(sp.portName());
@@ -153,11 +129,14 @@ QStringList LiveDataSource::supportedBaudRates() {
  */
 void LiveDataSource::updateNow() {
 	DEBUG("LiveDataSource::updateNow() update interval = " << m_updateInterval);
-	m_updateTimer->stop();
+	if (m_updateType == TimeInterval)
+		m_updateTimer->stop();
+	else
+		m_pending = false;
 	read();
 
 	//restart the timer after update
-	if (m_updateType == TimeInterval)
+	if (m_updateType == TimeInterval && !m_paused)
 		m_updateTimer->start(m_updateInterval);
 }
 
@@ -166,12 +145,9 @@ void LiveDataSource::updateNow() {
  */
 void LiveDataSource::continueReading() {
 	m_paused = false;
-	switch (m_updateType) {
-	case TimeInterval:
-		m_updateTimer->start(m_updateInterval);
-		break;
-	case  NewData:
-		connect(m_fileSystemWatcher, &QFileSystemWatcher::fileChanged, this, &LiveDataSource::read);
+	if (m_pending) {
+		m_pending = false;
+		updateNow();
 	}
 }
 
@@ -180,12 +156,9 @@ void LiveDataSource::continueReading() {
  */
 void LiveDataSource::pauseReading() {
 	m_paused = true;
-	switch (m_updateType) {
-	case TimeInterval:
+	if (m_updateType == TimeInterval) {
+		m_pending = true;
 		m_updateTimer->stop();
-		break;
-	case NewData:
-		disconnect(m_fileSystemWatcher, &QFileSystemWatcher::fileChanged, this, &LiveDataSource::read);
 	}
 }
 
@@ -226,18 +199,6 @@ AbstractFileFilter* LiveDataSource::filter() const {
 	return m_filter;
 }
 
-/*!
-  sets whether the file should be watched or not.
-  In the first case the data source will be automatically updated on file changes.
-*/
-void LiveDataSource::setFileWatched(bool b) {
-	m_fileWatched = b;
-}
-
-bool LiveDataSource::isFileWatched() const {
-	return m_fileWatched;
-}
-
 /*!
  * \brief Sets the serial port's baud rate
  * \param baudrate
@@ -354,16 +315,30 @@ LiveDataSource::ReadingType LiveDataSource::readingType() const {
  */
 void LiveDataSource::setUpdateType(UpdateType updatetype) {
 	switch (updatetype) {
-	case NewData:
+	case NewData: {
 		m_updateTimer->stop();
-		if (m_fileSystemWatcher == nullptr)
-			watch();
+		if (!m_fileSystemWatcher)
+			m_fileSystemWatcher = new QFileSystemWatcher(this);
+
+		m_fileSystemWatcher->addPath(m_fileName);
+		QFileInfo file(m_fileName);
+		// If the watched file currently does not exist (because it is recreated for instance), watch its containing
+		// directory instead. Once the file exists again, switch to watching the file in readOnUpdate().
+		// Reading will only start 100ms after the last update, to prevent continuous re-reading while the file is updated.
+		// If the watched file intentionally is updated more often than that, the user should switch to periodic reading.
+		if (m_fileSystemWatcher->files().contains(m_fileName))
+			m_fileSystemWatcher->removePath(file.absolutePath());
 		else
-			connect(m_fileSystemWatcher, &QFileSystemWatcher::fileChanged, this, &LiveDataSource::read);
+			m_fileSystemWatcher->addPath(file.absolutePath());
+
+		connect(m_fileSystemWatcher, &QFileSystemWatcher::fileChanged, this, [&](){ m_watchTimer->start(); });
+		connect(m_fileSystemWatcher, &QFileSystemWatcher::directoryChanged, this, [&](){ m_watchTimer->start(); });
 		break;
+	}
 	case TimeInterval:
-		if (m_fileSystemWatcher)
-			disconnect(m_fileSystemWatcher, &QFileSystemWatcher::fileChanged, this, &LiveDataSource::read);
+		delete m_fileSystemWatcher;
+		m_fileSystemWatcher = nullptr;
+		break;
 	}
 	m_updateType = updatetype;
 }
@@ -400,6 +375,14 @@ bool LiveDataSource::isFileLinked() const {
 	return m_fileLinked;
 }
 
+void LiveDataSource::setUseRelativePath(bool b) {
+	m_relativePath = b;
+}
+
+bool LiveDataSource::useRelativePath() const {
+	return m_relativePath;
+}
+
 QIcon LiveDataSource::icon() const {
 	QIcon icon;
 
@@ -445,16 +428,6 @@ QMenu* LiveDataSource::createContextMenu() {
 	menu->insertAction(firstAction, m_plotDataAction);
 	menu->insertSeparator(firstAction);
 
-	//TODO: doesn't always make sense...
-// 	if (!m_fileWatched)
-// 		menu->insertAction(firstAction, m_reloadAction);
-//
-// 	m_toggleWatchAction->setChecked(m_fileWatched);
-// 	menu->insertAction(firstAction, m_toggleWatchAction);
-//
-// 	m_toggleLinkAction->setChecked(m_fileLinked);
-// 	menu->insertAction(firstAction, m_toggleLinkAction);
-
 	return menu;
 }
 
@@ -462,6 +435,28 @@ QMenu* LiveDataSource::createContextMenu() {
 //#################################  SLOTS  ####################################
 //##############################################################################
 
+/*
+ * Called when the watch timer times out, i.e. when modifying the file or directory
+ * presumably has finished. Also see LiveDataSource::setUpdateType().
+ */
+void LiveDataSource::readOnUpdate() {
+	if (!m_fileSystemWatcher->files().contains(m_fileName)) {
+		m_fileSystemWatcher->addPath(m_fileName);
+		QFileInfo file(m_fileName);
+		if (m_fileSystemWatcher->files().contains(m_fileName))
+			m_fileSystemWatcher->removePath(file.absolutePath());
+		else {
+			m_fileSystemWatcher->addPath(file.absolutePath());
+			return;
+		}
+	}
+	if (m_paused)
+		// flag file for reading, once the user decides to continue reading
+		m_pending = true;
+	else
+		read();
+}
+
 /*
  * called periodically or on new data changes (file changed, new data in the socket, etc.)
  */
@@ -470,13 +465,18 @@ void LiveDataSource::read() {
 	if (!m_filter)
 		return;
 
+	if (m_reading)
+		return;
+
+	m_reading = true;
+
 	//initialize the device (file, socket, serial port) when calling this function for the first time
 	if (!m_prepared) {
 		DEBUG("	Preparing device: update type = " << ENUM_TO_STRING(LiveDataSource, UpdateType, m_updateType));
 		switch (m_sourceType) {
 		case FileOrPipe:
-			m_file = new QFile(m_fileName);
-			m_device = m_file;
+			delete m_device;
+			m_device = new QFile(m_fileName);
 			break;
 		case NetworkTcpSocket:
 			m_tcpSocket = new QTcpSocket(this);
@@ -535,9 +535,9 @@ void LiveDataSource::read() {
 		switch (m_fileType) {
 		case AbstractFileFilter::Ascii:
 			if (m_readingType == LiveDataSource::ReadingType::WholeFile) {
-				static_cast<AsciiFilter*>(m_filter)->readFromLiveDevice(*m_file, this, 0);
+				static_cast<AsciiFilter*>(m_filter)->readFromLiveDevice(*m_device, this, 0);
 			} else {
-				bytes = static_cast<AsciiFilter*>(m_filter)->readFromLiveDevice(*m_file, this, m_bytesRead);
+				bytes = static_cast<AsciiFilter*>(m_filter)->readFromLiveDevice(*m_device, this, m_bytesRead);
 				m_bytesRead += bytes;
 				DEBUG("Read " << bytes << " bytes, in total: " << m_bytesRead);
 			}
@@ -593,6 +593,8 @@ void LiveDataSource::read() {
 	case MQTT:
 		break;
 	}
+
+	m_reading = false;
 }
 
 /*!
@@ -703,45 +705,6 @@ void LiveDataSource::serialPortError(QSerialPort::SerialPortError serialPortErro
 	}
 }
 
-void LiveDataSource::watchToggled() {
-	m_fileWatched = !m_fileWatched;
-	watch();
-	project()->setChanged(true);
-}
-
-void LiveDataSource::linkToggled() {
-	m_fileLinked = !m_fileLinked;
-	project()->setChanged(true);
-}
-
-/*!
- * Watch the file upon reading for changes if required
- * uses m_fileName for FileOrPipe and LocalSocket
- */
-void LiveDataSource::watch() {
-	DEBUG("LiveDataSource::watch() file name = " << m_fileName.toStdString());
-	if (m_fileWatched) {
-		DEBUG("	file is watched");
-		if (!m_fileSystemWatcher) {
-			m_fileSystemWatcher = new QFileSystemWatcher;
-
-			//connect to file changes to read the new data
-			connect(m_fileSystemWatcher, &QFileSystemWatcher::fileChanged, this, &LiveDataSource::read);
-
-			//connect to file changes to re-add the file path again - need to cope with deletion of files in text editors which
-			//on save create a new file in the temp folder first and then swap with the original one.
-			connect(m_fileSystemWatcher, &QFileSystemWatcher::fileChanged, this, [=]() {m_fileSystemWatcher->addPath(m_fileName);});
-		}
-
-		if (!m_fileSystemWatcher->files().contains(m_fileName))
-			m_fileSystemWatcher->addPath(m_fileName);
-	} else {
-		DEBUG("	file is not watched");
-		if (m_fileSystemWatcher)
-			m_fileSystemWatcher->removePath(m_fileName);
-	}
-}
-
 void LiveDataSource::plotData() {
 	auto* dlg = new PlotDataDialog(this);
 	dlg->exec();
@@ -754,16 +717,44 @@ void LiveDataSource::plotData() {
   Saves as XML.
  */
 void LiveDataSource::save(QXmlStreamWriter* writer) const {
-	writer->writeStartElement("LiveDataSource");
+	writer->writeStartElement("liveDataSource");
 	writeBasicAttributes(writer);
 	writeCommentElement(writer);
 
 	//general
 	writer->writeStartElement("general");
-	writer->writeAttribute("fileName", m_fileName);
-	writer->writeAttribute("fileType", QString::number(m_fileType));
-	writer->writeAttribute("fileWatched", QString::number(m_fileWatched));
-	writer->writeAttribute("fileLinked", QString::number(m_fileLinked));
+
+	switch (m_sourceType) {
+	case FileOrPipe:
+		writer->writeAttribute("fileType", QString::number(m_fileType));
+		writer->writeAttribute("fileLinked", QString::number(m_fileLinked));
+		writer->writeAttribute("relativePath", QString::number(m_relativePath));
+		if (m_relativePath) {
+			//convert from the absolute to the relative path and save it
+			const Project* p = const_cast<LiveDataSource*>(this)->project();
+			QFileInfo fi(p->fileName());
+			writer->writeAttribute("fileName", fi.dir().relativeFilePath(m_fileName));
+		}else
+			writer->writeAttribute("fileName", m_fileName);
+
+		break;
+	case SerialPort:
+		writer->writeAttribute("baudRate", QString::number(m_baudRate));
+		writer->writeAttribute("serialPortName", m_serialPortName);
+		break;
+	case NetworkTcpSocket:
+	case NetworkUdpSocket:
+		writer->writeAttribute("host", m_host);
+		writer->writeAttribute("port", QString::number(m_port));
+		break;
+	case LocalSocket:
+		break;
+	case MQTT:
+		break;
+	default:
+		break;
+	}
+
 	writer->writeAttribute("updateType", QString::number(m_updateType));
 	writer->writeAttribute("readingType", QString::number(m_readingType));
 	writer->writeAttribute("sourceType", QString::number(m_sourceType));
@@ -774,29 +765,7 @@ void LiveDataSource::save(QXmlStreamWriter* writer) const {
 
 	if (m_readingType != TillEnd)
 		writer->writeAttribute("sampleSize", QString::number(m_sampleSize));
-
-	switch (m_sourceType) {
-	case SerialPort:
-		writer->writeAttribute("baudRate", QString::number(m_baudRate));
-		writer->writeAttribute("serialPortName", m_serialPortName);
-
-		break;
-	case NetworkTcpSocket:
-	case NetworkUdpSocket:
-		writer->writeAttribute("host", m_host);
-		writer->writeAttribute("port", QString::number(m_port));
-		break;
-	case FileOrPipe:
-		break;
-	case LocalSocket:
-		break;
-	case MQTT:
-		break;
-	default:
-		break;
-	}
-
-	writer->writeEndElement();
+	writer->writeEndElement(); //general
 
 	//filter
 	m_filter->save(writer);
@@ -807,7 +776,7 @@ void LiveDataSource::save(QXmlStreamWriter* writer) const {
 			col->save(writer);
 	}
 
-	writer->writeEndElement(); // "LiveDataSource"
+	writer->writeEndElement(); // "liveDataSource"
 }
 
 /*!
@@ -823,7 +792,8 @@ bool LiveDataSource::load(XmlStreamReader* reader, bool preview) {
 
 	while (!reader->atEnd()) {
 		reader->readNext();
-		if (reader->isEndElement() && reader->name() == "LiveDataSource")
+		if (reader->isEndElement()
+			&& (reader->name() == "liveDataSource" || reader->name() == "LiveDataSource")) //TODO: remove "LiveDataSources" in couple of releases
 			break;
 
 		if (!reader->isStartElement())
@@ -847,18 +817,18 @@ bool LiveDataSource::load(XmlStreamReader* reader, bool preview) {
 			else
 				m_fileType = (AbstractFileFilter::FileType)str.toInt();
 
-			str = attribs.value("fileWatched").toString();
-			if (str.isEmpty())
-				reader->raiseWarning(attributeWarning.subs("fileWatched").toString());
-			else
-				m_fileWatched = str.toInt();
-
 			str = attribs.value("fileLinked").toString();
 			if (str.isEmpty())
 				reader->raiseWarning(attributeWarning.subs("fileLinked").toString());
 			else
 				m_fileLinked = str.toInt();
 
+			str = attribs.value("relativePath").toString();
+			if (str.isEmpty())
+				reader->raiseWarning(attributeWarning.subs("relativePath").toString());
+			else
+				m_relativePath = str.toInt();
+
 			str = attribs.value("updateType").toString();
 			if (str.isEmpty())
 				reader->raiseWarning(attributeWarning.subs("updateType").toString());
@@ -954,9 +924,20 @@ bool LiveDataSource::load(XmlStreamReader* reader, bool preview) {
 		}
 	}
 
-	//read the content of the file if it was only linked
-	if (m_fileLinked)
-		this->read();
-
 	return !reader->hasError();
 }
+
+void LiveDataSource::finalizeLoad() {
+	//convert from the relative path saved in the project file to the absolute file to work with
+	if (m_relativePath) {
+		QFileInfo fi(project()->fileName());
+		m_fileName = fi.dir().absoluteFilePath(m_fileName);
+	}
+
+	//read the content of the file if it was only linked
+	if (m_fileLinked && QFile::exists(m_fileName))
+		this->read();
+
+	//call setUpdateType() to start watching the file for changes, is required
+	setUpdateType(m_updateType);
+}
