@@ -45,7 +45,6 @@ class QFileSystemWatcher;
 class QAction;
 class QTcpSocket;
 class QUdpSocket;
-class QFile;
 
 class LiveDataSource : public Spreadsheet {
 	Q_OBJECT
@@ -78,8 +77,6 @@ public:
 	explicit LiveDataSource(const QString& name, bool loading = false);
 	~LiveDataSource() override;
 
-	void ready();
-
 	static QStringList supportedBaudRates();
 	static QStringList availablePorts();
 
@@ -124,12 +121,12 @@ public:
 	void setKeepLastValues(bool);
 	bool keepLastValues() const;
 
-	void setFileWatched(bool);
-	bool isFileWatched() const;
-
 	void setFileLinked(bool);
 	bool isFileLinked() const;
 
+	void setUseRelativePath(bool);
+	bool useRelativePath() const;
+
 	void setFileName(const QString&);
 	QString fileName() const;
 
@@ -149,12 +146,13 @@ public:
 
 	void save(QXmlStreamWriter*) const override;
 	bool load(XmlStreamReader*, bool preview) override;
+	void finalizeLoad();
 
 private:
 	void initActions();
-	void watch();
 
 	QString m_fileName;
+	QString m_dirName;
 	QString m_serialPortName;
 	QString m_localSocketName;
 	QString m_host;
@@ -166,8 +164,11 @@ private:
 
 	bool m_fileWatched{false};
 	bool m_fileLinked{false};
+	bool m_relativePath{false};
 	bool m_paused{false};
 	bool m_prepared{false};
+	bool m_reading{false};
+	bool m_pending{false};
 
 	int m_sampleSize{1};
 	int m_keepNValues{0};	// number of values to keep (0 - all)
@@ -180,29 +181,22 @@ private:
 	AbstractFileFilter* m_filter{nullptr};
 
 	QTimer* m_updateTimer;
+	QTimer* m_watchTimer;
 	QFileSystemWatcher* m_fileSystemWatcher{nullptr};
 
-	QFile* m_file{nullptr};
 	QLocalSocket* m_localSocket{nullptr};
 	QTcpSocket* m_tcpSocket{nullptr};
 	QUdpSocket* m_udpSocket{nullptr};
 	QSerialPort* m_serialPort{nullptr};
 	QIODevice* m_device{nullptr};
-
-	QAction* m_reloadAction;
-	QAction* m_toggleLinkAction;
-	QAction* m_showEditorAction;
-	QAction* m_showSpreadsheetAction;
-	QAction* m_plotDataAction;
+	QAction* m_plotDataAction{nullptr};
 
 public slots:
 	void read();
+	void readOnUpdate();
 
 private slots:
-	void watchToggled();
-	void linkToggled();
 	void plotData();
-
 	void readyRead();
 
 	void localSocketError(QLocalSocket::LocalSocketError);
