@@ -47,7 +47,8 @@ Copyright	: (C) 2018 Kovacs Ferencz (kferike98@gmail.com)
 
   \ingroup datasources
 */
-MQTTTopic::MQTTTopic(const QString& name, MQTTSubscription* subscription, bool loading) : Spreadsheet(name, loading),
+MQTTTopic::MQTTTopic(const QString& name, MQTTSubscription* subscription, bool loading) :
+	Spreadsheet(name, loading, AspectType::MQTTTopic),
 	m_topicName(name),
 	m_MQTTClient(subscription->mqttClient()),
 	m_filter(new AsciiFilter) {
@@ -283,7 +284,7 @@ bool MQTTTopic::load(XmlStreamReader* reader, bool preview) {
 			for (int i = 0; i < pufferSize; ++i) {
 				str = attribs.value("message"+QString::number(i)).toString();
 				if (str.isEmpty())
-					reader->raiseWarning(attributeWarning.arg("'message"+QString::number(i)+"'"));
+					reader->raiseWarning(attributeWarning.arg("'message"+QString::number(i)+'\''));
 				else
 					m_messagePuffer.push_back(str);
 			}
