@@ -3,7 +3,7 @@ File                 : AbstractFileFilter.h
 Project              : LabPlot
 Description          : file I/O-filter related interface
 --------------------------------------------------------------------
-Copyright            : (C) 2009-2013 Alexander Semke (alexander.semke@web.de)
+Copyright            : (C) 2009-2018 Alexander Semke (alexander.semke@web.de)
 Copyright            : (C) 2017 Stefan Gerlach (stefan.gerlach@uni.kn)
 ***************************************************************************/
 
@@ -40,20 +40,23 @@ class QXmlStreamWriter;
 
 class AbstractFileFilter : public QObject {
 	Q_OBJECT
+	Q_ENUMS(FileType)
 	Q_ENUMS(ImportMode)
 
 public:
+	enum FileType {Ascii, Binary, Image, HDF5, NETCDF, FITS, JSON, ROOT, NgspiceRawAscii, NgspiceRawBinary};
 	enum ImportMode {Append, Prepend, Replace};
 
-	AbstractFileFilter() {}
-	~AbstractFileFilter() override {}
+	explicit AbstractFileFilter(FileType type) : m_type(type) {}
+	~AbstractFileFilter() override = default;
 
 	static bool isNan(QString);
 	static AbstractColumn::ColumnMode columnMode(const QString& valueString, const QString& dateTimeFormat, QLocale::Language);
 	static QStringList numberFormats();
+	static AbstractFileFilter::FileType fileType(const QString&);
+	static QStringList fileTypes();
 
-	virtual QVector<QStringList> readDataFromFile(const QString& fileName, AbstractDataSource* = nullptr,
-        ImportMode = AbstractFileFilter::Replace, int lines = -1) = 0;
+	virtual void readDataFromFile(const QString& fileName, AbstractDataSource* = nullptr, ImportMode = AbstractFileFilter::Replace) = 0;
 	virtual void write(const QString& fileName, AbstractDataSource*) = 0;
 
 	virtual void loadFilterSettings(const QString& filterName) = 0;
@@ -62,8 +65,13 @@ public:
 	virtual void save(QXmlStreamWriter*) const = 0;
 	virtual bool load(XmlStreamReader*) = 0;
 
+	FileType type() const { return m_type; }
+
 signals:
 	void completed(int) const; //!< int ranging from 0 to 100 notifies about the status of a read/write process
+
+protected:
+	const FileType m_type;
 };
 
 #endif
