@@ -252,8 +252,11 @@ size_t AsciiFilter::lineNumber(const QString& fileName) {
 		QProcess wc;
 		wc.start(QLatin1String("wc"), QStringList() << QLatin1String("-l") << fileName);
 		size_t lineCount = 0;
-		while (wc.waitForReadyRead())
-			lineCount = wc.readLine().split(' ')[0].toInt();
+		while (wc.waitForReadyRead()) {
+			QString line(wc.readLine());
+			// wc on macOS has leading spaces: use SkipEmptyParts
+			lineCount = line.split(' ', QString::SkipEmptyParts)[0].toInt();
+		}
 		return lineCount;
 	}
 #endif
@@ -367,7 +370,7 @@ void AsciiFilter::setNaNValueToZero(bool b) {
 	if (b)
 		d->nanValue = 0;
 	else
-		d->nanValue = NAN;
+		d->nanValue = std::numeric_limits<double>::quiet_NaN();
 }
 bool AsciiFilter::NaNValueToZeroEnabled() const {
 	return (d->nanValue == 0);
@@ -437,14 +440,16 @@ QStringList AsciiFilterPrivate::getLineString(QIODevice& device) {
 			DEBUG("WARNING in AsciiFilterPrivate::getLineString(): device cannot 'readLine()' but using it anyway.");
 //			line = device.readAll();
 		line = device.readLine();
-	} while (line.startsWith(commentCharacter));
+	} while (!commentCharacter.isEmpty() && line.startsWith(commentCharacter));
 
 	line.remove(QRegExp("[\\n\\r]"));	// remove any newline
-	if (simplifyWhitespacesEnabled)
-		line = line.simplified();
 	DEBUG("data line : \'" << line.toStdString() << '\'');
 	QStringList lineStringList = line.split(m_separator, (QString::SplitBehavior)skipEmptyParts);
 	//TODO: remove quotes here?
+	if (simplifyWhitespacesEnabled) {
+		for (int i = 0; i < lineStringList.size(); ++i)
+			lineStringList[i] = lineStringList[i].simplified();
+	}
 	QDEBUG("data line, parsed: " << lineStringList);
 
 	return lineStringList;
@@ -463,27 +468,31 @@ int AsciiFilterPrivate::prepareDeviceToRead(QIODevice& device) {
 		return 1;
 
 /////////////////////////////////////////////////////////////////
-	// Find first data line (ignoring comment lines)
-	DEBUG("	Skipping " << startRow - 1 << " lines");
-	for (int i = 0; i < startRow - 1; ++i) {
-		QString line;
-		if (!device.canReadLine())
-			DEBUG("WARNING in AsciiFilterPrivate::prepareDeviceToRead(): device cannot 'readLine()' but using it anyway.");
-		line = device.readLine();
-		DEBUG("	line = " << line.toStdString());
-
-		if (device.atEnd()) {
-			if (device.isSequential())
-				break;
-			else
-				return 1;
-		}
-	}
-
 	// Parse the first line:
 	// Determine the number of columns, create the columns and use (if selected) the first row to name them
 	QString firstLine;
-	do {	// skip comment lines
+
+	// skip the comment lines first
+	if (!commentCharacter.isEmpty()) {
+		do {
+			if (!device.canReadLine())
+				DEBUG("WARNING in AsciiFilterPrivate::prepareDeviceToRead(): device cannot 'readLine()' but using it anyway.");
+
+			if (device.atEnd()) {
+				DEBUG("device at end! Giving up.");
+				if (device.isSequential())
+					break;
+				else
+					return 1;
+			}
+
+			firstLine = device.readLine();
+		} while (firstLine.startsWith(commentCharacter) || firstLine.simplified().isEmpty());
+	}
+
+	// navigate to the line where we asked to start reading from
+	DEBUG("	Skipping " << startRow - 1 << " lines");
+	for (int i = 0; i < startRow - 1; ++i) {
 		if (!device.canReadLine())
 			DEBUG("WARNING in AsciiFilterPrivate::prepareDeviceToRead(): device cannot 'readLine()' but using it anyway.");
 
@@ -496,7 +505,8 @@ int AsciiFilterPrivate::prepareDeviceToRead(QIODevice& device) {
 		}
 
 		firstLine = device.readLine();
-	} while (firstLine.startsWith(commentCharacter));
+		DEBUG("	line = " << firstLine.toStdString());
+	}
 
 	DEBUG(" device position after first line and comments = " << device.pos());
 	firstLine.remove(QRegExp("[\\n\\r]"));	// remove any newline
@@ -517,13 +527,10 @@ int AsciiFilterPrivate::prepareDeviceToRead(QIODevice& device) {
 
 		if (!firstLineStringList.isEmpty()) {
 			int length1 = firstLineStringList.at(0).length();
-			if (firstLineStringList.size() > 1) {
-				int pos2 = firstLine.indexOf(firstLineStringList.at(1), length1);
-				m_separator = firstLine.mid(length1, pos2 - length1);
-			} else {
-				//old: separator = line.right(line.length() - length1);
+			if (firstLineStringList.size() > 1)
+				m_separator = firstLine.mid(length1, 1);
+			else
 				m_separator = ' ';
-			}
 		}
 	} else {	// use given separator
 		// replace symbolic "TAB" with '\t'
@@ -642,7 +649,7 @@ int AsciiFilterPrivate::prepareDeviceToRead(QIODevice& device) {
 
 	const int actualEndRow = (endRow == -1 || endRow > m_actualRows) ? m_actualRows : endRow;
 	if (actualEndRow > m_actualStartRow)
-		m_actualRows = actualEndRow - m_actualStartRow + 1;
+		m_actualRows = actualEndRow - m_actualStartRow;
 	else
 		m_actualRows = 0;
 
@@ -714,6 +721,7 @@ qint64 AsciiFilterPrivate::readFromLiveDevice(QIODevice& device, AbstractDataSou
 				vectorNames << i18n("Value");
 			}
 			QDEBUG("	vector names = " << vectorNames);
+			break;
 		case LiveDataSource::SourceType::MQTT:
 			break;
 		}
@@ -721,8 +729,6 @@ qint64 AsciiFilterPrivate::readFromLiveDevice(QIODevice& device, AbstractDataSou
 		// prepare import for spreadsheet
 		spreadsheet->setUndoAware(false);
 		spreadsheet->resize(AbstractFileFilter::Replace, vectorNames, m_actualCols);
-		DEBUG("	data source resized to col: " << m_actualCols);
-		DEBUG("	data source rowCount: " << spreadsheet->rowCount());
 
 		//columns in a file data source don't have any manual changes.
 		//make the available columns undo unaware and suppress the "data changed" signal.
@@ -739,9 +745,11 @@ qint64 AsciiFilterPrivate::readFromLiveDevice(QIODevice& device, AbstractDataSou
 			spreadsheet->setRowCount(keepNValues);
 			m_actualRows = keepNValues;
 		}
-
 		m_dataContainer.resize(m_actualCols);
 
+		DEBUG("	data source resized to col: " << m_actualCols);
+		DEBUG("	data source rowCount: " << spreadsheet->rowCount());
+
 		DEBUG("	Setting data ..");
 		for (int n = 0; n < m_actualCols; ++n) {
 			// data() returns a void* which is a pointer to any data type (see ColumnPrivate.cpp)
@@ -839,6 +847,7 @@ qint64 AsciiFilterPrivate::readFromLiveDevice(QIODevice& device, AbstractDataSou
 				//TODO: check serial port
 				case LiveDataSource::SourceType::SerialPort:
 					newData[newDataIdx++] = device.read(device.bytesAvailable());
+					break;
 				case LiveDataSource::SourceType::MQTT:
 					break;
 				}
@@ -857,6 +866,7 @@ qint64 AsciiFilterPrivate::readFromLiveDevice(QIODevice& device, AbstractDataSou
 				//TODO: check serial port
 				case LiveDataSource::SourceType::SerialPort:
 					newData.push_back(device.read(device.bytesAvailable()));
+					break;
 				case LiveDataSource::SourceType::MQTT:
 					break;
 				}
@@ -929,23 +939,22 @@ qint64 AsciiFilterPrivate::readFromLiveDevice(QIODevice& device, AbstractDataSou
 				linesToRead = qMin(spreadsheet->sampleSize(), newLinesTillEnd);
 			}
 		}
-		DEBUG("	actual rows = " << m_actualRows);
 
 		if (linesToRead == 0)
 			return 0;
-	} else {	// not prepared
+	} else	// not prepared
 		linesToRead = newLinesTillEnd;
-		if (headerEnabled)
-			--m_actualRows;
-	}
-	DEBUG("	lines to read = " << linesToRead);
 
-	if (spreadsheet->sourceType() == LiveDataSource::SourceType::FileOrPipe || spreadsheet->sourceType() == LiveDataSource::SourceType::NetworkUdpSocket) {
-		if (m_actualRows < linesToRead) {
-			DEBUG("	SET lines to read to " << m_actualRows);
-			linesToRead = m_actualRows;
-		}
-	}
+	DEBUG("	lines to read = " << linesToRead);
+	DEBUG("	actual rows (w/o header) = " << m_actualRows);
+
+	//TODO
+// 	if (spreadsheet->sourceType() == LiveDataSource::SourceType::FileOrPipe || spreadsheet->sourceType() == LiveDataSource::SourceType::NetworkUdpSocket) {
+// 		if (m_actualRows < linesToRead) {
+// 			DEBUG("	SET lines to read to " << m_actualRows);
+// 			linesToRead = m_actualRows;
+// 		}
+// 	}
 
 	//new rows/resize columns if we don't have a fixed size
 	//TODO if the user changes this value..m_resizedToFixedSize..setResizedToFixedSize
@@ -1130,11 +1139,7 @@ qint64 AsciiFilterPrivate::readFromLiveDevice(QIODevice& device, AbstractDataSou
 				}
 			}
 
-			DEBUG("	Line bytes: " << line.size() << " line: " << line.toStdString());
-			if (simplifyWhitespacesEnabled)
-				line = line.simplified();
-
-			if (line.isEmpty() || line.startsWith(commentCharacter)) // skip empty or commented lines
+			if (line.isEmpty() || (!commentCharacter.isEmpty() && line.startsWith(commentCharacter))) // skip empty or commented lines
 				continue;
 
 			QStringList lineStringList;
@@ -1145,6 +1150,12 @@ qint64 AsciiFilterPrivate::readFromLiveDevice(QIODevice& device, AbstractDataSou
 				lineStringList << line;
 			QDEBUG("	line = " << lineStringList << ", separator = \'" << m_separator << "\'");
 
+			DEBUG("	Line bytes: " << line.size() << " line: " << line.toStdString());
+			if (simplifyWhitespacesEnabled) {
+				for (int i = 0; i < lineStringList.size(); ++i)
+					lineStringList[i] = lineStringList[i].simplified();
+			}
+
 			if (createIndexEnabled) {
 				if (spreadsheet->keepNValues() == 0)
 					lineStringList.prepend(QString::number(currentRow + 1));
@@ -1168,16 +1179,15 @@ qint64 AsciiFilterPrivate::readFromLiveDevice(QIODevice& device, AbstractDataSou
 						bool isNumber;
 						const double value = locale.toDouble(valueString, &isNumber);
 						static_cast<QVector<double>*>(m_dataContainer[n])->operator[](currentRow) = (isNumber ? value : nanValue);
-						qDebug() << "dataContainer[" << n << "] size:" << static_cast<QVector<double>*>(m_dataContainer[n])->size();
+// 						qDebug() << "dataContainer[" << n << "] size:" << static_cast<QVector<double>*>(m_dataContainer[n])->size();
 						break;
 					}
 					case AbstractColumn::Integer: {
 						DEBUG("	Integer");
 						bool isNumber;
 						const int value = locale.toInt(valueString, &isNumber);
-						DEBUG("	container size = " << m_dataContainer.size() << ", current row = " << currentRow);
 						static_cast<QVector<int>*>(m_dataContainer[n])->operator[](currentRow) = (isNumber ? value : 0);
-						qDebug() << "dataContainer[" << n << "] size:" << static_cast<QVector<int>*>(m_dataContainer[n])->size();
+// 						qDebug() << "dataContainer[" << n << "] size:" << static_cast<QVector<int>*>(m_dataContainer[n])->size();
 
 						break;
 					}
@@ -1227,27 +1237,20 @@ qint64 AsciiFilterPrivate::readFromLiveDevice(QIODevice& device, AbstractDataSou
 	if (m_prepared) {
 		//notify all affected columns and plots about the changes
 		PERFTRACE("AsciiLiveDataImport, notify affected columns and plots");
-		const Project* project = spreadsheet->project();
-		QVector<const XYCurve*> curves = project->children<const XYCurve>(AbstractAspect::Recursive);
+
+		//determine the dependent plots
 		QVector<CartesianPlot*> plots;
-		for (int n = 0; n < m_actualCols; ++n) {
-			Column* column = spreadsheet->column(n);
+		for (int n = 0; n < m_actualCols; ++n)
+			spreadsheet->column(n)->addUsedInPlots(plots);
 
-			//determine the plots where the column is consumed
-			for (const auto* curve : curves) {
-				if (curve->xColumn() == column || curve->yColumn() == column) {
-					auto* plot = dynamic_cast<CartesianPlot*>(curve->parentAspect());
-					if (plots.indexOf(plot) == -1) {
-						plots << plot;
-						plot->setSuppressDataChangedSignal(true);
-					}
-				}
-			}
+		//suppress retransform in the dependent plots
+		for (auto* plot : plots)
+			plot->setSuppressDataChangedSignal(true);
 
-			column->setChanged();
-		}
+		for (int n = 0; n < m_actualCols; ++n)
+			spreadsheet->column(n)->setChanged();
 
-		//loop over all affected plots and retransform them
+		//retransform the dependent plots
 		for (auto* plot : plots) {
 			plot->setSuppressDataChangedSignal(false);
 			plot->dataChanged();
@@ -1306,28 +1309,39 @@ void AsciiFilterPrivate::readDataFromDevice(QIODevice& device, AbstractDataSourc
 	if (qMin(lines, m_actualRows) == 0 || m_actualCols == 0)
 		return;
 
-	for (int i = 0; i < qMin(lines, m_actualRows); ++i) {
-		QString line = device.readLine();
+	QString line;
+	QString valueString;
+	//Don't put the definition QStringList lineStringList outside of the for-loop,
+	//the compiler doesn't seem to optimize the destructor of QList well enough in this case.
+
+	lines = qMin(lines, m_actualRows);
+	int progressIndex = 0;
+	const float progressInterval = 0.01*lines; //update on every 1% only
+
+	for (int i = 0; i < lines; ++i) {
+		line = device.readLine();
 
 		// remove any newline
 		line.remove(QLatin1Char('\n'));
 		line.remove(QLatin1Char('\r'));
 
-		if (simplifyWhitespacesEnabled)
-			line = line.simplified();
-
 		if (removeQuotesEnabled)
 			line.remove(QLatin1Char('"'));
 
-		if (line.isEmpty() || line.startsWith(commentCharacter)) // skip empty or commented lines
+		if (line.isEmpty() || (!commentCharacter.isEmpty() && line.startsWith(commentCharacter))) // skip empty or commented lines
 			continue;
 
 		QStringList lineStringList = line.split(m_separator, (QString::SplitBehavior)skipEmptyParts);
+// 		DEBUG("	Line bytes: " << line.size() << " line: " << line.toStdString());
+		if (simplifyWhitespacesEnabled) {
+			for (int i = 0; i < lineStringList.size(); ++i)
+				lineStringList[i] = lineStringList[i].simplified();
+		}
 
 		// remove left white spaces
 		if (skipEmptyParts) {
 			for (int n = 0; n < lineStringList.size(); ++n) {
-				QString valueString = lineStringList.at(n);
+				valueString = lineStringList.at(n);
 				if (!QString::compare(valueString, " ")) {
 					lineStringList.removeAt(n);
 					n--;
@@ -1342,14 +1356,14 @@ void AsciiFilterPrivate::readDataFromDevice(QIODevice& device, AbstractDataSourc
 				continue;
 			}
 
-			//column counting starts with 1, substract 1 as well as another 1 for the index column if required
+			//column counting starts with 1, subtract 1 as well as another 1 for the index column if required
 			int col = createIndexEnabled ? n + startColumn - 2: n + startColumn - 1;
 
 			if (col < lineStringList.size()) {
-				QString valueString = lineStringList.at(col);
+				valueString = lineStringList.at(col);
 
 				// set value depending on data type
-				switch (columnModes[n]) {
+				switch (columnModes.at(n)) {
 				case AbstractColumn::Numeric: {
 					bool isNumber;
 					const double value = locale.toDouble(valueString, &isNumber);
@@ -1368,7 +1382,7 @@ void AsciiFilterPrivate::readDataFromDevice(QIODevice& device, AbstractDataSourc
 					break;
 				}
 				case AbstractColumn::Text: {
-					QVector<QString>* colData = static_cast<QVector<QString>*>(m_dataContainer[n]);
+					auto* colData = static_cast<QVector<QString>*>(m_dataContainer[n]);
 					colData->operator[](currentRow) = valueString;
 					break;
 				}
@@ -1377,7 +1391,7 @@ void AsciiFilterPrivate::readDataFromDevice(QIODevice& device, AbstractDataSourc
 					break;
 				}
 			} else {	// missing columns in this line
-				switch (columnModes[n]) {
+				switch (columnModes.at(n)) {
 				case AbstractColumn::Numeric:
 					static_cast<QVector<double>*>(m_dataContainer[n])->operator[](currentRow) = nanValue;
 					break;
@@ -1398,11 +1412,27 @@ void AsciiFilterPrivate::readDataFromDevice(QIODevice& device, AbstractDataSourc
 		}
 
 		currentRow++;
-		emit q->completed(100 * currentRow/m_actualRows);
+
+		//ask to update the progress bar only if we have more than 1000 lines
+		//only in 1% steps
+		progressIndex++;
+		if (lines > 1000 && progressIndex > progressInterval) {
+			emit q->completed(100 * currentRow/lines);
+			progressIndex = 0;
+			QApplication::processEvents(QEventLoop::AllEvents, 0);
+		}
+
 	}
 	DEBUG("	Read " << currentRow << " lines");
 
-	dataSource->finalizeImport(m_columnOffset, startColumn, startColumn + m_actualCols - 1, currentRow, dateTimeFormat, importMode);
+	//we might have skipped empty lines above. shrink the spreadsheet if the number of read lines (=currentRow)
+	//is smaller than the initial size of the spreadsheet (=m_actualRows).
+	//TODO: should also be relevant for Matrix
+	auto* s = dynamic_cast<Spreadsheet*>(dataSource);
+	if (s && currentRow != m_actualRows && importMode == AbstractFileFilter::Replace)
+		s->setRowCount(currentRow);
+
+	dataSource->finalizeImport(m_columnOffset, startColumn, startColumn + m_actualCols - 1, dateTimeFormat, importMode);
 }
 
 /*!
@@ -1458,8 +1488,11 @@ QVector<QStringList> AsciiFilterPrivate::preview(QIODevice &device) {
 		columnModes[col++] = AbstractFileFilter::columnMode(valueString, dateTimeFormat, numberFormat);
 	}
 
+	QString line;
+	QLocale locale(numberFormat);
+	QStringList lineString;
 	for (int i = 0; i < linesToRead; ++i) {
-		QString line = newData.at(i);
+		line = newData.at(i);
 
 		// remove any newline
 		line = line.remove('\n');
@@ -1468,16 +1501,13 @@ QVector<QStringList> AsciiFilterPrivate::preview(QIODevice &device) {
 		if (simplifyWhitespacesEnabled)
 			line = line.simplified();
 
-		if (line.isEmpty() || line.startsWith(commentCharacter)) // skip empty or commented lines
+		if (line.isEmpty() || (!commentCharacter.isEmpty() && line.startsWith(commentCharacter))) // skip empty or commented lines
 			continue;
 
-		QLocale locale(numberFormat);
-
 		QStringList lineStringList = line.split(' ', QString::SkipEmptyParts);
 		if (createIndexEnabled)
 			lineStringList.prepend(QString::number(i + 1));
 
-		QStringList lineString;
 		for (int n = 0; n < lineStringList.size(); ++n) {
 			if (n < lineStringList.size()) {
 				QString valueString = lineStringList.at(n);
@@ -1562,22 +1592,26 @@ QVector<QStringList> AsciiFilterPrivate::preview(const QString& fileName, int li
 		device.readLine();
 
 	DEBUG("	Generating preview for " << qMin(lines, m_actualRows)  << " lines");
+	QString line;
 	for (int i = 0; i < qMin(lines, m_actualRows); ++i) {
-		QString line = device.readLine();
+		line = device.readLine();
 
 		// remove any newline
 		line = line.remove('\n');
 		line = line.remove('\r');
 
-		if (simplifyWhitespacesEnabled)
-			line = line.simplified();
-
-		if (line.isEmpty() || line.startsWith(commentCharacter)) // skip empty or commented lines
+		if (line.isEmpty() || (!commentCharacter.isEmpty() && line.startsWith(commentCharacter))) // skip empty or commented lines
 			continue;
 
-		const QStringList& lineStringList = line.split(m_separator, (QString::SplitBehavior)skipEmptyParts);
+		QStringList lineStringList = line.split(m_separator, (QString::SplitBehavior)skipEmptyParts);
 		QDEBUG(" line = " << lineStringList);
 
+		DEBUG("	Line bytes: " << line.size() << " line: " << line.toStdString());
+		if (simplifyWhitespacesEnabled) {
+			for (int i = 0; i < lineStringList.size(); ++i)
+				lineStringList[i] = lineStringList[i].simplified();
+		}
+
 		QStringList lineString;
 		for (int n = 0; n < m_actualCols; ++n) {
 			// index column if required
@@ -1586,7 +1620,7 @@ QVector<QStringList> AsciiFilterPrivate::preview(const QString& fileName, int li
 				continue;
 			}
 
-			//column counting starts with 1, substract 1 as well as another 1 for the index column if required
+			//column counting starts with 1, subtract 1 as well as another 1 for the index column if required
 			int col = createIndexEnabled ? n + startColumn - 2: n + startColumn - 1;
 
 			if (col < lineStringList.size()) {
@@ -1768,7 +1802,7 @@ int AsciiFilterPrivate::prepareToRead(const QString& message) {
 		if (removeQuotesEnabled)
 			valueString.remove(QLatin1Char('"'));
 
-		vectorNames << i18n("value %1").arg(i);
+		vectorNames << i18n("value %1", i);
 		columnModes << AbstractFileFilter::columnMode(valueString, dateTimeFormat, numberFormat);
 		++i;
 	}
@@ -1800,7 +1834,7 @@ QVector<QStringList> AsciiFilterPrivate::preview(const QString& message) {
 		if (simplifyWhitespacesEnabled)
 			line = line.simplified();
 
-		if (line.isEmpty() || line.startsWith(commentCharacter)) // skip empty or commented lines
+		if (line.isEmpty() || (!commentCharacter.isEmpty() && line.startsWith(commentCharacter))) // skip empty or commented lines
 			continue;
 
 		const QStringList& lineStringList = line.split(m_separator, (QString::SplitBehavior)skipEmptyParts);
@@ -2435,7 +2469,7 @@ void AsciiFilterPrivate::readMQTTTopic(const QString& message, AbstractDataSourc
 			if (simplifyWhitespacesEnabled)
 				line = line.simplified();
 
-			if (line.isEmpty() || line.startsWith(commentCharacter))
+			if (line.isEmpty() || (!commentCharacter.isEmpty() && line.startsWith(commentCharacter)))
 				continue;
 
 			//add index if required
