@@ -103,7 +103,7 @@ private:
 	int m_actualCols{0};
 	int m_prepared{false};
 	int m_columnOffset{0}; // indexes the "start column" in the datasource. Data will be imported starting from this column.
-	QVector<void*> m_dataContainer; // pointers to the actual data containers
+	std::vector<void*> m_dataContainer; // pointers to the actual data containers
 };
 
 #endif
