@@ -37,15 +37,15 @@ class ImageFilter : public AbstractFileFilter {
 	Q_ENUMS(ImportFormat)
 
 public:
-	enum ImportFormat {MATRIX,XYZ,XYRGB};
+	enum ImportFormat {MATRIX, XYZ, XYRGB};
 
 	ImageFilter();
 	~ImageFilter() override;
 
 	static QStringList importFormats();
+	static QString fileInfoString(const QString&);
 
-	QVector<QStringList> readDataFromFile(const QString& fileName, AbstractDataSource* = nullptr,
-					      AbstractFileFilter::ImportMode = AbstractFileFilter::Replace, int lines = -1) override;
+	void readDataFromFile(const QString& fileName, AbstractDataSource* = nullptr, AbstractFileFilter::ImportMode = AbstractFileFilter::Replace) override;
 	void write(const QString& fileName, AbstractDataSource*) override;
 
 	void loadFilterSettings(const QString&) override;
