@@ -3,7 +3,7 @@ File                 : NetCDFFilterPrivate.h
 Project              : LabPlot
 Description          : Private implementation class for NetCDFFilter.
 --------------------------------------------------------------------
-Copyright            : (C) 2015 Stefan Gerlach (stefan.gerlach@uni.kn)
+Copyright            : (C) 2015-2018 Stefan Gerlach (stefan.gerlach@uni.kn)
  ***************************************************************************/
 
 /***************************************************************************
@@ -40,26 +40,29 @@ public:
 
 	void parse(const QString & fileName, QTreeWidgetItem* rootItem);
 	QVector<QStringList> readDataFromFile(const QString& fileName, AbstractDataSource* = nullptr,
-					AbstractFileFilter::ImportMode = AbstractFileFilter::Replace, int lines = -1);
+			AbstractFileFilter::ImportMode = AbstractFileFilter::Replace);
 	QString readAttribute(const QString& fileName, const QString& name, const QString& varName);
 	QVector<QStringList> readCurrentVar(const QString& fileName, AbstractDataSource* = nullptr,
-					    AbstractFileFilter::ImportMode = AbstractFileFilter::Replace, int lines = -1);
+			AbstractFileFilter::ImportMode = AbstractFileFilter::Replace, int lines = -1);
 	void write(const QString& fileName, AbstractDataSource*);
+#ifdef HAVE_NETCDF
+	static void handleError(int status, const QString& function);
+	static QString translateFormat(int format);
+	static QString translateDataType(nc_type type);
+#endif
 
 	const NetCDFFilter* q;
 
 	QString currentVarName;
-	int startRow;
-	int endRow;
-	int startColumn;
-	int endColumn;
+	int startRow{-1};
+	int endRow{-1};
+	int startColumn{1};
+	int endColumn{-1};
 
 private:
 #ifdef HAVE_NETCDF
 	int m_status;
 
-	void handleError(int status, const QString& function);
-	QString translateDataType(nc_type type);
 	QString scanAttrs(int ncid, int varid, int attid, QTreeWidgetItem* parentItem = nullptr);
 	void scanDims(int ncid, int ndims, QTreeWidgetItem* parentItem);
 	void scanVars(int ncid, int nvars, QTreeWidgetItem* parentItem);
