@@ -60,7 +60,9 @@
 */
 
 OriginProjectParser::OriginProjectParser() : ProjectParser() {
-	m_topLevelClasses << "Folder" << "Workbook" << "Spreadsheet" << "Matrix" << "Worksheet" << "Note";
+	m_topLevelClasses = {AspectType::Folder, AspectType::Workbook,
+	                     AspectType::Spreadsheet, AspectType::Matrix,
+	                     AspectType::Worksheet, AspectType::Note};
 }
 
 bool OriginProjectParser::isOriginProject(const QString& fileName) {
@@ -73,11 +75,12 @@ void OriginProjectParser::setImportUnusedObjects(bool importUnusedObjects) {
 }
 
 bool OriginProjectParser::hasUnusedObjects() {
-	if (m_originFile)
-		delete m_originFile;
 	m_originFile = new OriginFile((const char*)m_projectFileName.toLocal8Bit());
-	if (!m_originFile->parse())
+	if (!m_originFile->parse()) {
+		delete m_originFile;
+		m_originFile = nullptr;
 		return false;
+	}
 
 	for (unsigned int i = 0; i < m_originFile->spreadCount(); i++) {
 		const Origin::SpreadSheet& spread = m_originFile->spread(i);
@@ -95,6 +98,8 @@ bool OriginProjectParser::hasUnusedObjects() {
 			return true;
 	}
 
+	delete m_originFile;
+	m_originFile = nullptr;
 	return false;
 }
 
@@ -160,13 +165,14 @@ unsigned int OriginProjectParser::findNoteByName(const QString& name) {
 //##############################################################################
 bool OriginProjectParser::load(Project* project, bool preview) {
 	DEBUG("OriginProjectParser::load()");
-	//read and parse the m_originFile-file
-	if (m_originFile)
-		delete m_originFile;
 
+	//read and parse the m_originFile-file
 	m_originFile = new OriginFile((const char*)m_projectFileName.toLocal8Bit());
-	if (!m_originFile->parse())
+	if (!m_originFile->parse()) {
+		delete m_originFile;
+		m_originFile = nullptr;
 		return false;
+	}
 
 	//Origin project tree and the iterator pointing to the root node
 	const tree<Origin::ProjectNode>* projectTree = m_originFile->project();
@@ -255,6 +261,10 @@ bool OriginProjectParser::load(Project* project, bool preview) {
 
 	emit project->loaded();
 	project->setIsLoading(false);
+
+	delete m_originFile;
+	m_originFile = nullptr;
+
 	return true;
 }
 
@@ -262,7 +272,7 @@ bool OriginProjectParser::loadFolder(Folder* folder, tree<Origin::ProjectNode>::
 	DEBUG("OriginProjectParser::loadFolder()")
 	const tree<Origin::ProjectNode>* projectTree = m_originFile->project();
 
-	// do not skip anything if pathesToLoad() constains only root folder
+	// do not skip anything if pathesToLoad() contains only root folder
 	bool containsRootFolder = (folder->pathesToLoad().size() == 1 && folder->pathesToLoad().contains(folder->path()));
 	if (containsRootFolder) {
 		DEBUG("	pathesToLoad contains only folder path \""  << folder->path().toStdString() << "\". Clearing pathes to load.")
@@ -868,7 +878,7 @@ bool OriginProjectParser::loadSpreadsheet(Spreadsheet* spreadsheet, bool preview
 		}
 	}
 
-	//TODO: "hidden" not supporrted yet
+	//TODO: "hidden" not supported yet
 //	if (spread.hidden || spread.loose)
 //		mw->hideWindow(spreadsheet);
 
@@ -2061,7 +2071,7 @@ QString OriginProjectParser::parseOriginTags(const QString &str) const {
 	line = replaceSpecialChars(line);
 
 	// replace tabs	(not really supported)
-	line.replace("\t", "&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;");
+	line.replace('\t', "&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;");
 
 	//Lookbehind conditions are not supported - so need to reverse string
 	QRegExp rx("\\)[^\\)\\(]*\\((?!\\s*[buig\\+\\-]\\s*\\\\)");
