@@ -59,7 +59,7 @@
 	\ingroup backend
 */
 Matrix::Matrix(int rows, int cols, const QString& name, const AbstractColumn::ColumnMode mode)
-	: AbstractDataSource(name), d(new MatrixPrivate(this, mode)) {
+	: AbstractDataSource(name, AspectType::Matrix), d(new MatrixPrivate(this, mode)) {
 
 	//set initial number of rows and columns
 	appendColumns(cols);
@@ -69,7 +69,7 @@ Matrix::Matrix(int rows, int cols, const QString& name, const AbstractColumn::Co
 }
 
 Matrix::Matrix(const QString& name, bool loading, const AbstractColumn::ColumnMode mode)
-	: AbstractDataSource(name), d(new MatrixPrivate(this, mode)) {
+	: AbstractDataSource(name, AspectType::Matrix), d(new MatrixPrivate(this, mode)) {
 
 	if (!loading)
 		init();
@@ -1211,10 +1211,18 @@ bool Matrix::load(XmlStreamReader* reader, bool preview) {
 	return true;
 }
 
+void Matrix::registerShortcuts() {
+	m_view->registerShortcuts();
+}
+
+void Matrix::unregisterShortcuts() {
+	m_view->unregisterShortcuts();
+}
+
 //##############################################################################
 //########################  Data Import  #######################################
 //##############################################################################
-int Matrix::prepareImport(QVector<void*>& dataContainer, AbstractFileFilter::ImportMode mode,
+int Matrix::prepareImport(std::vector<void*>& dataContainer, AbstractFileFilter::ImportMode mode,
 	int actualRows, int actualCols, QStringList colNameList, QVector<AbstractColumn::ColumnMode> columnMode) {
 	QDEBUG("prepareImport() rows =" << actualRows << " cols =" << actualCols);
 	QDEBUG("	column modes = " << columnMode);
@@ -1277,12 +1285,11 @@ int Matrix::prepareImport(QVector<void*>& dataContainer, AbstractFileFilter::Imp
 	return columnOffset;
 }
 
-void Matrix::finalizeImport(int columnOffset, int startColumn, int endColumn, int numRows, const QString& dateTimeFormat, AbstractFileFilter::ImportMode importMode)  {
+void Matrix::finalizeImport(int columnOffset, int startColumn, int endColumn, const QString& dateTimeFormat, AbstractFileFilter::ImportMode importMode)  {
 	DEBUG("Matrix::finalizeImport()");
 	Q_UNUSED(columnOffset);
 	Q_UNUSED(startColumn);
 	Q_UNUSED(endColumn);
-	Q_UNUSED(numRows);
 	Q_UNUSED(dateTimeFormat);
 	Q_UNUSED(importMode);
 
