@@ -187,8 +187,7 @@ template <typename T>
 class MatrixSetCellValueCmd : public QUndoCommand {
 public:
 	MatrixSetCellValueCmd(MatrixPrivate* private_obj, int row, int col, T value, QUndoCommand* parent = nullptr)
-			: QUndoCommand(parent), m_private_obj(private_obj), m_row(row), m_col(col), m_value(value) {
-				QDEBUG("MatrixSetCellValueCmd() value =" << value << ", m_value =" << m_value);
+			: QUndoCommand(parent), m_private_obj(private_obj), m_row(row), m_col(col), m_value(value), m_old_value(value) {
 		// remark: don't use many QString::arg() calls in ctors of commands that might be called often,
 		// they use a lot of execution time
 		setText(i18n("%1: set cell value", m_private_obj->name()));
@@ -222,10 +221,10 @@ private:
 	double m_new_x2;
 	double m_new_y1;
 	double m_new_y2;
-	double m_old_x1;
-	double m_old_x2;
-	double m_old_y1;
-	double m_old_y2;
+	double m_old_x1{-1};
+	double m_old_x2{-1};
+	double m_old_y1{-1};
+	double m_old_y2{-1};
 };
 
 //! Set matrix formula
