@@ -137,8 +137,13 @@ int nsl_corr_fft_type(double s[], size_t n, double r[], size_t m, nsl_corr_type_
 
 #ifdef HAVE_FFTW3
 int nsl_corr_fft_FFTW(double s[], double r[], size_t n, double out[]) {
-	size_t i;
+	if (n <= 0)
+		return -1;
+
 	const size_t size = 2*(n/2+1);
+	if (size <= 0)
+		return -1;
+
 	double* in = (double*)malloc(size*sizeof(double));
 	fftw_plan rpf = fftw_plan_dft_r2c_1d(n, in, (fftw_complex*)in, FFTW_ESTIMATE);
 
@@ -146,6 +151,8 @@ int nsl_corr_fft_FFTW(double s[], double r[], size_t n, double out[]) {
 	fftw_execute_dft_r2c(rpf, r, (fftw_complex*)r);
 	fftw_destroy_plan(rpf);
 
+	size_t i;
+
 	// multiply
 	for (i = 0; i < size; i += 2) {
 		double re = s[i]*r[i] + s[i+1]*r[i+1];
@@ -164,6 +171,8 @@ int nsl_corr_fft_FFTW(double s[], double r[], size_t n, double out[]) {
 	for (i = 0; i < n; i++)
 		out[i] = s[i]/n;
 
+	free(in);
+	free(o);
 	return 0;
 }
 #endif
@@ -197,4 +206,3 @@ int nsl_corr_fft_GSL(double s[], double r[], size_t n, double out[]) {
 
 	return 0;
 }
-
