@@ -233,7 +233,7 @@ double nsl_sf_voigt(double x, double sigma, double gamma) {
 	return 0.;	// not supported yet
 #else
 	COMPLEX z = (x + I*gamma)/(sqrt(2.)*sigma);
-	return creal(Faddeeva_w(z, 0))/(sqrt(2.*M_PI)*sigma);
+	return creal(Faddeeva_w(z, 0))/(M_SQRT2*M_SQRTPI*sigma);
 #endif
 }
 
