@@ -41,7 +41,7 @@ class Spreadsheet : public AbstractDataSource {
 	Q_OBJECT
 
 public:
-	explicit Spreadsheet(const QString& name, bool loading = false);
+	explicit Spreadsheet(const QString& name, bool loading = false, AspectType type = AspectType::Spreadsheet);
 
 	QIcon icon() const override;
 	QMenu* createContextMenu() override;
@@ -80,10 +80,13 @@ public:
 	void emitRowCountChanged() { emit rowCountChanged(rowCount()); }
 	void emitColumnCountChanged() { emit columnCountChanged(columnCount()); }
 
+	void registerShortcuts() override;
+	void unregisterShortcuts() override;
+
 	//data import
-	int prepareImport(QVector<void*>& dataContainer, AbstractFileFilter::ImportMode,
+	int prepareImport(std::vector<void*>& dataContainer, AbstractFileFilter::ImportMode,
 		int rows, int cols, QStringList colNameList, QVector<AbstractColumn::ColumnMode>) override;
-	void finalizeImport(int columnOffset, int startColumn , int endColumn, int numRows,
+	void finalizeImport(int columnOffset, int startColumn , int endColumn,
 		const QString& dateTimeFormat, AbstractFileFilter::ImportMode) override;
 	int resize(AbstractFileFilter::ImportMode, QStringList colNameList, int cols);
 
@@ -105,9 +108,11 @@ public slots:
 
 private:
 	void init();
-	mutable SpreadsheetView* m_view{nullptr};
 	SpreadsheetModel* m_model{nullptr};
 
+protected:
+	mutable SpreadsheetView* m_view{nullptr};
+
 private slots:
 	void childSelected(const AbstractAspect*) override;
 	void childDeselected(const AbstractAspect*) override;
