@@ -4,7 +4,7 @@
     Description          : Worksheet
     --------------------------------------------------------------------
     Copyright            : (C) 2009 Tilman Benkert (thzs@gmx.net)
-    Copyright            : (C) 2011-2016 by Alexander Semke (alexander.semke@web.de)
+    Copyright            : (C) 2011-2019 by Alexander Semke (alexander.semke@web.de)
  ***************************************************************************/
 
 /***************************************************************************
@@ -32,6 +32,7 @@
 #include "commonfrontend/worksheet/WorksheetView.h"
 #include "backend/core/Project.h"
 #include "backend/worksheet/plots/cartesian/CartesianPlot.h"
+#include "backend/worksheet/TreeModel.h"
 #include "backend/worksheet/TextLabel.h"
 #include "backend/lib/commandtemplates.h"
 #include "backend/lib/XmlStreamReader.h"
@@ -60,7 +61,7 @@
  *
  * * \ingroup worksheet
  */
-Worksheet::Worksheet(const QString& name, bool loading) : AbstractPart(name), d(new WorksheetPrivate(this)) {
+Worksheet::Worksheet(const QString& name, bool loading) : AbstractPart(name, AspectType::Worksheet), d(new WorksheetPrivate(this)) {
 	connect(this, &Worksheet::aspectAdded, this, &Worksheet::handleAspectAdded);
 	connect(this, &Worksheet::aspectAboutToBeRemoved, this, &Worksheet::handleAspectAboutToBeRemoved);
 	connect(this, &Worksheet::aspectRemoved, this, &Worksheet::handleAspectRemoved);
@@ -82,8 +83,8 @@ void Worksheet::init() {
 	d->useViewSize = group.readEntry("UseViewSize", false);
 	d->pageRect.setX(0);
 	d->pageRect.setY(0);
-	d->pageRect.setWidth(group.readEntry("Width", 1500));
-	d->pageRect.setHeight(group.readEntry("Height", 1500));
+	d->pageRect.setWidth(group.readEntry("Width", 1000));
+	d->pageRect.setHeight(group.readEntry("Height", 1000));
 	d->m_scene->setSceneRect(d->pageRect);
 
 	//background
@@ -174,6 +175,7 @@ QWidget* Worksheet::view() const {
 		m_view = new WorksheetView(const_cast<Worksheet*>(this));
 		m_partView = m_view;
 		connect(m_view, &WorksheetView::statusInfo, this, &Worksheet::statusInfo);
+		connect(this, &Worksheet::cartesianPlotMouseModeChanged, m_view, &WorksheetView::cartesianPlotMouseModeChangedSlot);
 	}
 	return m_partView;
 }
@@ -242,6 +244,29 @@ void Worksheet::handleAspectAdded(const AbstractAspect* aspect) {
 	QGraphicsItem* item = addedElement->graphicsItem();
 	d->m_scene->addItem(item);
 
+	const CartesianPlot* plot = dynamic_cast<const CartesianPlot*>(aspect);
+	if (plot) {
+		connect(plot, &CartesianPlot::mouseMoveCursorModeSignal, this, &Worksheet::cartesianPlotMouseMoveCursorMode);
+		connect(plot, &CartesianPlot::mouseMoveZoomSelectionModeSignal, this, &Worksheet::cartesianPlotMouseMoveZoomSelectionMode);
+		connect(plot, &CartesianPlot::mousePressCursorModeSignal, this, &Worksheet::cartesianPlotMousePressCursorMode);
+		connect(plot, &CartesianPlot::mousePressZoomSelectionModeSignal, this, &Worksheet::cartesianPlotMousePressZoomSelectionMode);
+		connect(plot, &CartesianPlot::mouseReleaseZoomSelectionModeSignal, this, &Worksheet::cartesianPlotMouseReleaseZoomSelectionMode);
+		connect(plot, &CartesianPlot::mouseHoverZoomSelectionModeSignal, this, &Worksheet::cartesianPlotMouseHoverZoomSelectionMode);
+		connect(plot, &CartesianPlot::mouseHoverOutsideDataRectSignal, this, &Worksheet::cartesianPlotMouseHoverOutsideDataRect);
+		connect(plot, &CartesianPlot::aspectDescriptionChanged, this, &Worksheet::updateCompleteCursorTreeModel);
+		connect(plot, &CartesianPlot::curveNameChanged, this, &Worksheet::updateCompleteCursorTreeModel);
+		connect(plot, &CartesianPlot::curveRemoved, this, &Worksheet::curveRemoved);
+		connect(plot, &CartesianPlot::curveAdded, this, &Worksheet::curveAdded);
+		connect(plot, &CartesianPlot::visibleChanged, this, &Worksheet::updateCompleteCursorTreeModel);
+		connect(plot, &CartesianPlot::curveVisibilityChangedSignal, this, &Worksheet::updateCompleteCursorTreeModel);
+		connect(plot, &CartesianPlot::curveDataChanged, this, &Worksheet::curveDataChanged);
+		connect(plot, static_cast<void (CartesianPlot::*)(QPen, QString)>(&CartesianPlot::curveLinePenChanged), this, &Worksheet::updateCurveBackground);
+		connect(plot, &CartesianPlot::mouseModeChanged, this, &Worksheet::cartesianPlotMouseModeChangedSlot);
+		auto* p = const_cast<CartesianPlot*>(plot);
+		p->setLocked(d->plotsLocked);
+
+		cursorModelPlotAdded(p->name());
+	}
 	qreal zVal = 0;
 	for (auto* child : children<WorksheetElement>(IncludeHidden))
 		child->graphicsItem()->setZValue(zVal++);
@@ -252,12 +277,6 @@ void Worksheet::handleAspectAdded(const AbstractAspect* aspect) {
 		const_cast<WorksheetElement*>(addedElement)->loadThemeConfig(config);
 	}
 
-	const CartesianPlot* plot = dynamic_cast<const CartesianPlot*>(aspect);
-	if (plot) {
-		auto* p = const_cast<CartesianPlot*>(plot);
-		p->setLocked(d->plotsLocked);
-	}
-
 	//recalculated the layout
 	if (!isLoading()) {
 		if (d->layout != Worksheet::NoLayout)
@@ -276,10 +295,12 @@ void Worksheet::handleAspectAboutToBeRemoved(const AbstractAspect* aspect) {
 void Worksheet::handleAspectRemoved(const AbstractAspect* parent, const AbstractAspect* before, const AbstractAspect* child) {
 	Q_UNUSED(parent);
 	Q_UNUSED(before);
-	Q_UNUSED(child);
 
 	if (d->layout != Worksheet::NoLayout)
 		d->updateLayout(false);
+	auto* plot = dynamic_cast<const CartesianPlot*>(child);
+	if (plot)
+		cursorModelPlotRemoved(plot->name());
 }
 
 QGraphicsScene* Worksheet::scene() const {
@@ -391,6 +412,30 @@ void Worksheet::setIsClosing() {
 		m_view->setIsClosing();
 }
 
+/*!
+ * \brief Worksheet::getPlotCount
+ * \return number of CartesianPlot's in the Worksheet
+ */
+int Worksheet::getPlotCount() {
+	return children<CartesianPlot>().length();
+}
+
+/*!
+ * \brief Worksheet::getPlot
+ * \param index Number of plot which should be returned
+ * \return Pointer to the CartesianPlot which was searched with index
+ */
+WorksheetElement *Worksheet::getPlot(int index) {
+	QVector<CartesianPlot*> cartesianPlots = children<CartesianPlot>();
+	if (cartesianPlots.length()-1 >= index)
+		return cartesianPlots[index];
+	return nullptr;
+}
+
+TreeModel* Worksheet::cursorModel() {
+    return d->cursorData;
+}
+
 void Worksheet::update() {
 	emit requestUpdate();
 }
@@ -407,6 +452,10 @@ Worksheet::CartesianPlotActionMode Worksheet::cartesianPlotActionMode() {
 	return d->cartesianPlotActionMode;
 }
 
+Worksheet::CartesianPlotActionMode Worksheet::cartesianPlotCursorMode() {
+	return d->cartesianPlotCursorMode;
+}
+
 bool Worksheet::plotsLocked() {
 	return d->plotsLocked;
 }
@@ -419,6 +468,28 @@ void Worksheet::setCartesianPlotActionMode(Worksheet::CartesianPlotActionMode mo
 	project()->setChanged(true);
 }
 
+void Worksheet::setCartesianPlotCursorMode(Worksheet::CartesianPlotActionMode mode) {
+	if (d->cartesianPlotCursorMode == mode)
+		return;
+
+	d->cartesianPlotCursorMode = mode;
+
+	if (mode == Worksheet::CartesianPlotActionMode::ApplyActionToAll) {
+		d->suppressCursorPosChanged = true;
+		QVector<CartesianPlot*> plots = children<CartesianPlot>();
+		QPointF logicPos;
+		if (!plots.isEmpty()) {
+			for (int i = 0; i < 2; i++) {
+				logicPos = QPointF(plots[0]->cursorPos(i), 0); // y value does not matter
+				cartesianPlotMousePressCursorMode(i, logicPos);
+			}
+		}
+		d->suppressCursorPosChanged = false;
+	}
+	updateCompleteCursorTreeModel();
+	project()->setChanged(true);
+}
+
 void Worksheet::setPlotsLocked(bool lock) {
 	if (d->plotsLocked == lock)
 		return;
@@ -431,6 +502,14 @@ void Worksheet::setPlotsLocked(bool lock) {
 	project()->setChanged(true);
 }
 
+void Worksheet::registerShortcuts() {
+	m_view->registerShortcuts();
+}
+
+void Worksheet::unregisterShortcuts() {
+	m_view->unregisterShortcuts();
+}
+
 /* =============================== getter methods for general options ==================================== */
 BASIC_D_READER_IMPL(Worksheet, bool, scaleContent, scaleContent)
 BASIC_D_READER_IMPL(Worksheet, bool, useViewSize, useViewSize)
@@ -657,17 +736,487 @@ void Worksheet::setTheme(const QString& theme) {
 	}
 }
 
+void Worksheet::cartesianPlotMousePressZoomSelectionMode(QPointF logicPos) {
+	if (cartesianPlotActionMode() == Worksheet::ApplyActionToAll) {
+		auto plots = children<CartesianPlot>(AbstractAspect::Recursive | AbstractAspect::IncludeHidden);
+		for (auto* plot : plots)
+			plot->mousePressZoomSelectionMode(logicPos);
+	} else {
+		CartesianPlot* plot = static_cast<CartesianPlot*>(QObject::sender());
+		plot->mousePressZoomSelectionMode(logicPos);
+	}
+}
+
+void Worksheet::cartesianPlotMouseReleaseZoomSelectionMode() {
+	if (cartesianPlotActionMode() == Worksheet::ApplyActionToAll) {
+		auto plots = children<CartesianPlot>(AbstractAspect::Recursive | AbstractAspect::IncludeHidden);
+		for (auto* plot : plots)
+			plot->mouseReleaseZoomSelectionMode();
+	} else {
+		CartesianPlot* plot = static_cast<CartesianPlot*>(QObject::sender());
+		plot->mouseReleaseZoomSelectionMode();
+	}
+}
+
+void Worksheet::cartesianPlotMousePressCursorMode(int cursorNumber, QPointF logicPos) {
+	if (cartesianPlotCursorMode() == Worksheet::ApplyActionToAll) {
+		auto plots = children<CartesianPlot>(AbstractAspect::Recursive | AbstractAspect::IncludeHidden);
+		for (auto* plot : plots)
+			plot->mousePressCursorMode(cursorNumber, logicPos);
+	} else {
+		CartesianPlot* plot = static_cast<CartesianPlot*>(QObject::sender());
+		plot->mousePressCursorMode(cursorNumber, logicPos);
+	}
+
+	cursorPosChanged(cursorNumber, logicPos.x());
+}
+
+void Worksheet::cartesianPlotMouseMoveZoomSelectionMode(QPointF logicPos) {
+	if (cartesianPlotActionMode() == Worksheet::ApplyActionToAll) {
+		QVector<CartesianPlot*> plots = children<CartesianPlot>(AbstractAspect::Recursive | AbstractAspect::IncludeHidden);
+		for (auto* plot : plots)
+			plot->mouseMoveZoomSelectionMode(logicPos);
+	} else {
+		CartesianPlot* plot = static_cast<CartesianPlot*>(QObject::sender());
+		plot->mouseMoveZoomSelectionMode(logicPos);
+	}
+}
+
+void Worksheet::cartesianPlotMouseHoverZoomSelectionMode(QPointF logicPos) {
+	if (cartesianPlotActionMode() == Worksheet::ApplyActionToAll) {
+		auto plots = children<CartesianPlot>(AbstractAspect::Recursive | AbstractAspect::IncludeHidden);
+		for (auto* plot : plots)
+			plot->mouseHoverZoomSelectionMode(logicPos);
+	} else {
+		CartesianPlot* plot = static_cast<CartesianPlot*>(QObject::sender());
+		plot->mouseHoverZoomSelectionMode(logicPos);
+	}
+}
+
+void Worksheet::cartesianPlotMouseHoverOutsideDataRect() {
+	if (cartesianPlotActionMode() == Worksheet::ApplyActionToAll) {
+		auto plots = children<CartesianPlot>(AbstractAspect::Recursive | AbstractAspect::IncludeHidden);
+		for (auto* plot : plots)
+			plot->mouseHoverOutsideDataRect();
+	} else {
+		CartesianPlot* plot = static_cast<CartesianPlot*>(QObject::sender());
+		plot->mouseHoverOutsideDataRect();
+	}
+}
+
+void Worksheet::cartesianPlotMouseMoveCursorMode(int cursorNumber, QPointF logicPos) {
+	if (cartesianPlotCursorMode() == Worksheet::ApplyActionToAll) {
+		auto plots = children<CartesianPlot>(AbstractAspect::Recursive | AbstractAspect::IncludeHidden);
+		for (auto* plot : plots)
+			plot->mouseMoveCursorMode(cursorNumber, logicPos);
+	} else {
+		CartesianPlot* plot = static_cast<CartesianPlot*>(QObject::sender());
+		plot->mouseMoveCursorMode(cursorNumber, logicPos);
+	}
+
+	cursorPosChanged(cursorNumber, logicPos.x());
+}
+
+/*!
+ * \brief Worksheet::cursorPosChanged
+ * Updates the cursor treemodel with the new data
+ * \param xPos: new position of the cursor
+ * It is assumed, that the plots/curves are in the same order than receiving from
+ * the children() function. It's not checked if the names are the same
+ */
+void Worksheet::cursorPosChanged(int cursorNumber, double xPos) {
+	if (d->suppressCursorPosChanged)
+		return;
+	TreeModel* treeModel = cursorModel();
+
+	auto* sender = dynamic_cast<CartesianPlot*>(QObject::sender());
+
+	// if ApplyActionToSelection, each plot has it's own x value
+	if (cartesianPlotCursorMode() == Worksheet::ApplyActionToAll) {
+		// x values
+		int rowPlot = 1;
+		QModelIndex xName = treeModel->index(0, WorksheetPrivate::TreeModelColumn::SIGNALNAME);
+		treeModel->setData(xName, QVariant("X"));
+		double valueCursor[2];
+		for (int i = 0; i < 2; i++) { // need both cursors to calculate diff
+			valueCursor[i] = sender->cursorPos(i);
+			treeModel->setTreeData(QVariant(valueCursor[i]), 0, WorksheetPrivate::TreeModelColumn::CURSOR0+i);
+
+		}
+		treeModel->setTreeData(QVariant(valueCursor[1] - valueCursor[0]), 0, WorksheetPrivate::TreeModelColumn::CURSORDIFF);
+
+		// y values
+		for (int i = 0; i < getPlotCount(); i++) { // i=0 is the x Axis
+
+			auto* plot = dynamic_cast<CartesianPlot*>(getPlot(i));
+			if (!plot || !plot->isVisible())
+				continue;
+
+			QModelIndex plotIndex = treeModel->index(rowPlot, WorksheetPrivate::TreeModelColumn::PLOTNAME);
+
+			// curves
+			int rowCurve = 0;
+			for (int j = 0; j < plot->curveCount(); j++) {
+				// assumption: index of signals in model is the same than the index of the signal in the plot
+				bool valueFound;
+
+				const XYCurve* curve = plot->getCurve(j);
+				if (!curve->isVisible())
+					continue;
+
+				double value = curve->y(xPos, valueFound);
+				if (cursorNumber == 0) {
+					treeModel->setTreeData(QVariant(value), rowCurve, WorksheetPrivate::TreeModelColumn::CURSOR0, plotIndex);
+					double valueCursor1 = treeModel->treeData(rowCurve, WorksheetPrivate::TreeModelColumn::CURSOR1, plotIndex).toDouble();
+					treeModel->setTreeData(QVariant(valueCursor1 - value), rowCurve, WorksheetPrivate::TreeModelColumn::CURSORDIFF, plotIndex);
+				} else {
+					treeModel->setTreeData(QVariant(value), rowCurve, WorksheetPrivate::TreeModelColumn::CURSOR1, plotIndex);
+					double valueCursor0 = treeModel->treeData(rowCurve, WorksheetPrivate::TreeModelColumn::CURSOR0, plotIndex).toDouble();
+					treeModel->setTreeData(QVariant(value - valueCursor0), rowCurve, WorksheetPrivate::TreeModelColumn::CURSORDIFF, plotIndex);
+				}
+				rowCurve++;
+			}
+			rowPlot++;
+		}
+	} else { // apply to selection
+		// assumption: plot is visible
+		int rowCount = treeModel->rowCount();
+		for (int i = 0; i < rowCount; i++) {
+			QModelIndex plotIndex = treeModel->index(i, WorksheetPrivate::TreeModelColumn::PLOTNAME);
+			if (plotIndex.data().toString().compare(sender->name()) != 0)
+				continue;
+
+			// x values (first row always exist)
+			treeModel->setTreeData(QVariant("X"), 0, WorksheetPrivate::TreeModelColumn::SIGNALNAME, plotIndex);
+			double valueCursor[2];
+			for (int i = 0; i < 2; i++) { // need both cursors to calculate diff
+				valueCursor[i] = sender->cursorPos(i);
+				treeModel->setTreeData(QVariant(valueCursor[i]), 0, WorksheetPrivate::TreeModelColumn::CURSOR0+i, plotIndex);
+			}
+			treeModel->setTreeData(QVariant(valueCursor[1]-valueCursor[0]), 0, WorksheetPrivate::TreeModelColumn::CURSORDIFF, plotIndex);
+
+			// y values
+			int rowCurve = 1; // first is x value
+			for (int j = 0; j< sender->curveCount(); j++) { // j=0 are the x values
+
+				const XYCurve* curve = sender->getCurve(j); // -1 because we start with 1 for the x axis
+				if (!curve->isVisible())
+					continue;
+
+				// assumption: index of signals in model is the same than the index of the signal in the plot
+				bool valueFound;
+
+				double value = curve->y(xPos, valueFound);
+				if (cursorNumber == 0) {
+					treeModel->setTreeData(QVariant(value), rowCurve, WorksheetPrivate::TreeModelColumn::CURSOR0, plotIndex);
+					double valueCursor1 = treeModel->treeData(rowCurve, WorksheetPrivate::TreeModelColumn::CURSOR1, plotIndex).toDouble();
+					treeModel->setTreeData(QVariant(valueCursor1 - value), rowCurve, WorksheetPrivate::TreeModelColumn::CURSORDIFF, plotIndex);
+				} else {
+					treeModel->setTreeData(QVariant(value), rowCurve, WorksheetPrivate::TreeModelColumn::CURSOR1, plotIndex);
+					double valueCursor0 = treeModel->treeData(rowCurve, WorksheetPrivate::TreeModelColumn::CURSOR0, plotIndex).toDouble();
+					treeModel->setTreeData(QVariant(value - valueCursor0), rowCurve, WorksheetPrivate::TreeModelColumn::CURSORDIFF, plotIndex);
+				}
+				rowCurve++;
+			}
+		}
+	}
+}
+
+void Worksheet::cursorModelPlotAdded(QString name) {
+	Q_UNUSED(name);
+//	TreeModel* treeModel = cursorModel();
+//	int rowCount = treeModel->rowCount();
+//	// add plot at the end
+//	treeModel->insertRows(rowCount, 1); // add empty rows. Then they become filled
+//	treeModel->setTreeData(QVariant(name), rowCount, WorksheetPrivate::TreeModelColumn::PLOTNAME); // rowCount instead of rowCount -1 because first row is the x value
+	updateCompleteCursorTreeModel();
+}
+
+void Worksheet::cursorModelPlotRemoved(QString name) {
+	TreeModel* treeModel = cursorModel();
+	int rowCount = treeModel->rowCount();
+
+	// first is x Axis
+	for (int i = 1; i < rowCount; i++) {
+		QModelIndex plotIndex = treeModel->index(i, WorksheetPrivate::TreeModelColumn::PLOTNAME);
+		if (plotIndex.data().toString().compare(name) != 0)
+			continue;
+		treeModel->removeRows(plotIndex.row(), 1);
+		return;
+	}
+}
+
+void Worksheet::cartesianPlotMouseModeChangedSlot(CartesianPlot::MouseMode mode) {
+	if (d->updateCompleteCursorModel) {
+		updateCompleteCursorTreeModel();
+		d->updateCompleteCursorModel = false;
+	}
+
+	emit cartesianPlotMouseModeChanged(mode);
+}
+
+void Worksheet::curveDataChanged(const XYCurve* curve) {
+	auto* plot = dynamic_cast<CartesianPlot*>(QObject::sender());
+	if (!plot)
+		return;
+
+	TreeModel* treeModel = cursorModel();
+	int rowCount = treeModel->rowCount();
+
+	for (int i = 0; i < rowCount; i++) {
+		QModelIndex plotIndex = treeModel->index(i, WorksheetPrivate::TreeModelColumn::PLOTNAME);
+		if (plotIndex.data().toString().compare(plot->name()) != 0)
+			continue;
+
+		for (int j = 0; j < plot->curveCount(); j++) {
+
+			if (plot->getCurve(j)->name().compare(curve->name()) != 0)
+				continue;
+
+			treeModel->setTreeData(QVariant(curve->name()), j, WorksheetPrivate::TreeModelColumn::SIGNALNAME, plotIndex);
+
+			bool valueFound;
+			double valueCursor0 = curve->y(plot->cursorPos(0), valueFound);
+			treeModel->setTreeData(QVariant(valueCursor0), j, WorksheetPrivate::TreeModelColumn::CURSOR0, plotIndex);
+
+			double valueCursor1 = curve->y(plot->cursorPos(1), valueFound);
+			treeModel->setTreeData(QVariant(valueCursor1), j, WorksheetPrivate::TreeModelColumn::CURSOR1, plotIndex);
+
+			treeModel->setTreeData(QVariant(valueCursor1-valueCursor0), j, WorksheetPrivate::TreeModelColumn::CURSORDIFF, plotIndex);
+			break;
+		}
+		break;
+	}
+}
+
+void Worksheet::curveAdded(const XYCurve* curve) {
+	auto* plot = dynamic_cast<CartesianPlot*>(QObject::sender());
+	if (!plot)
+		return;
+
+	TreeModel* treeModel = cursorModel();
+	int rowCount = treeModel->rowCount();
+
+	int i = 0;
+	// first row is the x axis when applied to all plots. Starting at the second row
+	if (cartesianPlotCursorMode() == Worksheet::ApplyActionToAll)
+		i = 1;
+
+	for (; i < rowCount; i++) {
+		QModelIndex plotIndex = treeModel->index(i, WorksheetPrivate::TreeModelColumn::PLOTNAME);
+		if (plotIndex.data().toString().compare(plot->name()) != 0)
+			continue;
+		int row = 0;
+		for (int j = 0; j < plot->curveCount(); j++) {
+
+			if (plot->getCurve(j)->name().compare(curve->name()) != 0) {
+				if (plot->getCurve(j)->isVisible())
+					row ++;
+				continue;
+			}
+
+			treeModel->insertRow(row, plotIndex);
+
+			treeModel->setTreeData(QVariant(curve->name()), row, WorksheetPrivate::TreeModelColumn::SIGNALNAME, plotIndex);
+			QColor curveColor = curve->linePen().color();
+			curveColor.setAlpha(50);
+			treeModel->setTreeData(QVariant(curveColor),row, WorksheetPrivate::TreeModelColumn::SIGNALNAME, plotIndex, Qt::BackgroundRole);
+			bool valueFound;
+			double valueCursor0 = curve->y(plot->cursorPos(0), valueFound);
+			treeModel->setTreeData(QVariant(valueCursor0), row, WorksheetPrivate::TreeModelColumn::CURSOR0, plotIndex);
+
+			double valueCursor1 = curve->y(plot->cursorPos(1), valueFound);
+			treeModel->setTreeData(QVariant(valueCursor1), row, WorksheetPrivate::TreeModelColumn::CURSOR1, plotIndex);
+
+			treeModel->setTreeData(QVariant(valueCursor1-valueCursor0), row, WorksheetPrivate::TreeModelColumn::CURSORDIFF, plotIndex);
+			break;
+		}
+		break;
+	}
+}
+
+void Worksheet::curveRemoved(const XYCurve* curve) {
+
+	auto* plot = dynamic_cast<CartesianPlot*>(QObject::sender());
+	if (!plot)
+		return;
+
+	TreeModel* treeModel = cursorModel();
+	int rowCount = treeModel->rowCount();
+
+	for (int i = 0; i < rowCount; i++) {
+		QModelIndex plotIndex = treeModel->index(i, WorksheetPrivate::TreeModelColumn::PLOTNAME);
+		if (plotIndex.data().toString().compare(plot->name()) != 0)
+			continue;
+
+		int curveCount = treeModel->rowCount(plotIndex);
+		for (int j = 0; j < curveCount; j++) {
+			QModelIndex curveIndex = treeModel->index(j, WorksheetPrivate::TreeModelColumn::SIGNALNAME, plotIndex);
+
+			if (curveIndex.data().toString().compare(curve->name()) != 0)
+				continue;
+			treeModel->removeRow(j, plotIndex);
+			break;
+		}
+		break;
+	}
+}
+
+/*!
+ * Updates the background of the cuves entry in the treeview
+ * @param pen Pen of the curve
+ * @param curveName Curve name to find in treemodel
+ */
+void Worksheet::updateCurveBackground(QPen pen, QString curveName) {
+	const CartesianPlot* plot = static_cast<const CartesianPlot*>(QObject::sender());
+	TreeModel* treeModel = cursorModel();
+	int rowCount = treeModel->rowCount();
+
+	for (int i = 0; i < rowCount; i++) {
+		QModelIndex plotIndex = treeModel->index(i, WorksheetPrivate::TreeModelColumn::PLOTNAME);
+		if (plotIndex.data().toString().compare(plot->name()) != 0)
+			continue;
+
+		int curveCount = treeModel->rowCount(plotIndex);
+		for (int j = 0; j < curveCount; j++) {
+			QModelIndex curveIndex = treeModel->index(j, WorksheetPrivate::TreeModelColumn::SIGNALNAME,
+													  plotIndex);
+
+			if (curveIndex.data().toString().compare(curveName) != 0)
+				continue;
+
+			QColor curveColor = pen.color();
+			curveColor.setAlpha(50);
+			treeModel->setTreeData(QVariant(curveColor), j,
+								   WorksheetPrivate::TreeModelColumn::SIGNALNAME,
+								   plotIndex, Qt::BackgroundRole);
+			return;
+		}
+		return;
+	}
+}
+
+/**
+ * @brief Worksheet::updateCompleteCursorTreeModel
+ * If the plot or the curve are not available, the plot/curve is not in the treemodel!
+ */
+void Worksheet::updateCompleteCursorTreeModel() {
+	if (isLoading())
+		return;
+
+	TreeModel* treeModel = cursorModel();
+
+	if (treeModel->rowCount() > 0)
+		treeModel->removeRows(0, treeModel->rowCount()); // remove all data
+
+	int plotCount = getPlotCount();
+	if (plotCount < 1)
+		return;
+
+	if (cartesianPlotCursorMode() == Worksheet::CartesianPlotActionMode::ApplyActionToAll) {
+		// 1 because of the X data
+		treeModel->insertRows(0, 1); //, treeModel->index(0,0)); // add empty rows. Then they become filled
+
+		// set X data
+		QModelIndex xName = treeModel->index(0, WorksheetPrivate::TreeModelColumn::SIGNALNAME);
+		treeModel->setData(xName, QVariant("X"));
+		CartesianPlot* plot0 = dynamic_cast<CartesianPlot*>(getPlot(0));
+		double valueCursor[2];
+		for (int i = 0; i < 2; i++) {
+			valueCursor[i] = plot0->cursorPos(i);
+			QModelIndex cursor = treeModel->index(0,WorksheetPrivate::TreeModelColumn::CURSOR0+i);
+
+			treeModel->setData(cursor, QVariant(valueCursor[i]));
+		}
+		QModelIndex diff = treeModel->index(0,WorksheetPrivate::TreeModelColumn::CURSORDIFF);
+		treeModel->setData(diff, QVariant(valueCursor[1]-valueCursor[0]));
+	} else {
+		//treeModel->insertRows(0, plotCount, treeModel->index(0,0)); // add empty rows. Then they become filled
+	}
+
+	// set plot name, y value, background
+	for (int i = 0; i < plotCount; i++) {
+		CartesianPlot* plot = dynamic_cast<CartesianPlot*>(getPlot(i));
+		QModelIndex plotName;
+		int addOne = 0;
+
+		if (!plot || !plot->isVisible())
+			continue;
+
+		// add new entry for the plot
+		treeModel->insertRows(treeModel->rowCount(), 1); //, treeModel->index(0, 0));
+
+		// add plot name and X row if needed
+		if (cartesianPlotCursorMode() == Worksheet::CartesianPlotActionMode::ApplyActionToAll) {
+			plotName = treeModel->index(i + 1, WorksheetPrivate::TreeModelColumn::PLOTNAME); // plus one because first row are the x values
+			treeModel->setData(plotName, QVariant(plot->name()));
+		} else {
+			addOne = 1;
+			plotName = treeModel->index(i, WorksheetPrivate::TreeModelColumn::PLOTNAME);
+			treeModel->setData(plotName, QVariant(plot->name()));
+			treeModel->insertRows(0, 1, plotName); // one, because the first row are the x values
+
+			QModelIndex xName = treeModel->index(0, WorksheetPrivate::TreeModelColumn::SIGNALNAME, plotName);
+			treeModel->setData(xName, QVariant("X"));
+			double valueCursor[2];
+			for (int i = 0; i < 2; i++) {
+				valueCursor[i] = plot->cursorPos(i);
+				QModelIndex cursor = treeModel->index(0, WorksheetPrivate::TreeModelColumn::CURSOR0+i, plotName);
+
+				treeModel->setData(cursor, QVariant(valueCursor[i]));
+			}
+			QModelIndex diff = treeModel->index(0, WorksheetPrivate::TreeModelColumn::CURSORDIFF, plotName);
+			treeModel->setData(diff, QVariant(valueCursor[1]-valueCursor[0]));
+		}
+
+
+		int rowCurve = addOne;
+		for (int j = 0; j < plot->curveCount(); j++) {
+			double cursorValue[2] = {NAN, NAN};
+			const XYCurve* curve = plot->getCurve(j);
+
+			if (!curve->isVisible())
+				continue;
+
+			for (int k = 0; k < 2; k++) {
+				double xPos = plot->cursorPos(k);
+				bool valueFound;
+				cursorValue[k] = curve->y(xPos,valueFound);
+			}
+			treeModel->insertRows(rowCurve, 1, plotName);
+			QColor curveColor = curve->linePen().color();
+			curveColor.setAlpha(50);
+			treeModel->setTreeData(QVariant(curveColor), rowCurve, 0, plotName, Qt::BackgroundRole);
+			treeModel->setTreeData(QVariant(curve->name()), rowCurve, WorksheetPrivate::TreeModelColumn::SIGNALNAME, plotName);
+			treeModel->setTreeData(QVariant(cursorValue[0]), rowCurve, WorksheetPrivate::TreeModelColumn::CURSOR0, plotName);
+			treeModel->setTreeData(QVariant(cursorValue[1]), rowCurve, WorksheetPrivate::TreeModelColumn::CURSOR1, plotName);
+			treeModel->setTreeData(QVariant(cursorValue[1]-cursorValue[0]), rowCurve, WorksheetPrivate::TreeModelColumn::CURSORDIFF, plotName);
+			rowCurve++;
+		}
+	}
+}
+
 //##############################################################################
 //######################  Private implementation ###############################
 //##############################################################################
 WorksheetPrivate::WorksheetPrivate(Worksheet* owner) : q(owner), m_scene(new QGraphicsScene()) {
+	QStringList headers = {i18n("Curves"), "V1", "V2", "V2-V1"};
+	cursorData = new TreeModel(headers, nullptr);
 }
 
 QString WorksheetPrivate::name() const {
 	return q->name();
 }
 
+/*!
+ * called if the worksheet page (the actual size of worksheet's rectangular) was changed.
+ * if a layout is active, it is is updated - this adjusts the sizes of the elements in the layout to the new page size.
+ * if no layout is active and the option "scale content" is active, \c handleResize() is called to adjust zhe properties.
+ */
 void WorksheetPrivate::updatePageRect() {
+	if (q->isLoading())
+		return;
+
 	QRectF oldRect = m_scene->sceneRect();
 	m_scene->setSceneRect(pageRect);
 
@@ -686,8 +1235,8 @@ void WorksheetPrivate::updatePageRect() {
 					elem->setUndoAware(true);
 				}
 			} else {
-				for (auto* child : childElements)
-					child->handleResize(horizontalRatio, verticalRatio, true);
+// 				for (auto* child : childElements)
+// 					child->handleResize(horizontalRatio, verticalRatio, true);
 			}
 		}
 	}
@@ -833,6 +1382,7 @@ void Worksheet::save(QXmlStreamWriter* writer) const {
 	writer->writeStartElement( "plotProperties" );
 	writer->writeAttribute( "plotsLocked", QString::number(d->plotsLocked) );
 	writer->writeAttribute( "cartesianPlotActionMode", QString::number(d->cartesianPlotActionMode));
+	writer->writeAttribute( "cartesianPlotCursorMode", QString::number(d->cartesianPlotCursorMode));
 	writer->writeEndElement();
 
 	//serialize all children
@@ -962,6 +1512,7 @@ bool Worksheet::load(XmlStreamReader* reader, bool preview) {
 
 			READ_INT_VALUE("plotsLocked", plotsLocked, bool);
 			READ_INT_VALUE("cartesianPlotActionMode", cartesianPlotActionMode, Worksheet::CartesianPlotActionMode);
+			READ_INT_VALUE("cartesianPlotCursorMode", cartesianPlotCursorMode, Worksheet::CartesianPlotActionMode);
 		} else if (reader->name() == "cartesianPlot") {
 			CartesianPlot* plot = new CartesianPlot(QString());
 			plot->setIsLoading(true);
@@ -986,6 +1537,7 @@ bool Worksheet::load(XmlStreamReader* reader, bool preview) {
 	if (!preview) {
 		d->m_scene->setSceneRect(rect);
 		d->updateLayout();
+		updateCompleteCursorTreeModel();
 	}
 
 	return true;
