@@ -115,13 +115,13 @@ private:
  *  \ingroup worksheet
  */
 Axis::Axis(const QString& name, AxisOrientation orientation)
-		: WorksheetElement(name), d_ptr(new AxisPrivate(this)) {
+		: WorksheetElement(name, AspectType::Axis), d_ptr(new AxisPrivate(this)) {
 	d_ptr->orientation = orientation;
 	init();
 }
 
 Axis::Axis(const QString& name, AxisOrientation orientation, AxisPrivate* dd)
-		: WorksheetElement(name), d_ptr(dd) {
+		: WorksheetElement(name, AspectType::Axis), d_ptr(dd) {
 	d_ptr->orientation = orientation;
 	init();
 }
@@ -212,7 +212,7 @@ void Axis::init() {
 
 	//minor grid
 	d->minorGridPen.setStyle( (Qt::PenStyle) group.readEntry("MinorGridStyle", (int) Qt::NoPen) );
-	d->minorGridPen.setColor(group.readEntry("MajorGridColor", QColor(Qt::gray)) );
+	d->minorGridPen.setColor(group.readEntry("MinorGridColor", QColor(Qt::gray)) );
 	d->minorGridPen.setWidthF( group.readEntry("MinorGridWidth", Worksheet::convertToSceneUnits( 1.0, Worksheet::Point ) ) );
 	d->minorGridOpacity = group.readEntry("MinorGridOpacity", 1.0);
 }
@@ -222,7 +222,7 @@ void Axis::init() {
  * For some ActionGroups the actual actions are created in \c GuiTool,
  */
 void Axis::initActions() {
-	visibilityAction = new QAction(i18n("Visible"), this);
+	visibilityAction = new QAction(QIcon::fromTheme("view-visible"), i18n("Visible"), this);
 	visibilityAction->setCheckable(true);
 	connect(visibilityAction, &QAction::triggered, this, &Axis::visibilityChangedSlot);
 
@@ -231,10 +231,10 @@ void Axis::initActions() {
 	orientationActionGroup->setExclusive(true);
 	connect(orientationActionGroup, &QActionGroup::triggered, this, &Axis::orientationChangedSlot);
 
-	orientationHorizontalAction = new QAction(i18n("Horizontal"), orientationActionGroup);
+	orientationHorizontalAction = new QAction(QIcon::fromTheme("labplot-axis-horizontal"), i18n("Horizontal"), orientationActionGroup);
 	orientationHorizontalAction->setCheckable(true);
 
-	orientationVerticalAction = new QAction(i18n("Vertical"), orientationActionGroup);
+	orientationVerticalAction = new QAction(QIcon::fromTheme("labplot-axis-vertical"), i18n("Vertical"), orientationActionGroup);
 	orientationVerticalAction->setCheckable(true);
 
 	//Line
@@ -255,15 +255,20 @@ void Axis::initMenus() {
 
 	//Orientation
 	orientationMenu = new QMenu(i18n("Orientation"));
+	orientationMenu->setIcon(QIcon::fromTheme("labplot-axis-horizontal"));
 	orientationMenu->addAction(orientationHorizontalAction);
 	orientationMenu->addAction(orientationVerticalAction);
 
 	//Line
 	lineMenu = new QMenu(i18n("Line"));
+	lineMenu->setIcon(QIcon::fromTheme("draw-line"));
 	lineStyleMenu = new QMenu(i18n("Style"), lineMenu);
+	lineStyleMenu->setIcon(QIcon::fromTheme("object-stroke-style"));
+	lineMenu->setIcon(QIcon::fromTheme("draw-line"));
 	lineMenu->addMenu( lineStyleMenu );
 
 	lineColorMenu = new QMenu(i18n("Color"), lineMenu);
+	lineColorMenu->setIcon(QIcon::fromTheme("fill-color"));
 	GuiTools::fillColorMenu( lineColorMenu, lineColorActionGroup );
 	lineMenu->addMenu( lineColorMenu );
 
@@ -358,7 +363,6 @@ void Axis::setSuppressRetransform(bool value) {
 }
 
 void Axis::handleResize(double horizontalRatio, double verticalRatio, bool pageResize) {
-// 	DEBUG("Axis::handleResize()");
 	Q_D(Axis);
 	Q_UNUSED(pageResize);
 
@@ -729,13 +733,14 @@ STD_SETTER_CMD_IMPL_F_S(Axis, SetLabelsFormat, Axis::LabelsFormat, labelsFormat,
 void Axis::setLabelsFormat(LabelsFormat labelsFormat) {
 	Q_D(Axis);
 	if (labelsFormat != d->labelsFormat) {
-		exec(new AxisSetLabelsFormatCmd(d, labelsFormat, ki18n("%1: set labels format")));
 
 		//TODO: this part is not undo/redo-aware
-		if (d->labelsFormatAutoChanged && labelsFormat == Axis::FormatDecimal)
+		if (labelsFormat == Axis::FormatDecimal)
 			d->labelsFormatDecimalOverruled = true;
 		else
 			d->labelsFormatDecimalOverruled = false;
+
+		exec(new AxisSetLabelsFormatCmd(d, labelsFormat, ki18n("%1: set labels format")));
 	}
 }
 
@@ -824,7 +829,7 @@ void Axis::setMajorGridPen(const QPen& pen) {
 		exec(new AxisSetMajorGridPenCmd(d, pen, ki18n("%1: set major grid style")));
 }
 
-STD_SETTER_CMD_IMPL_F_S(Axis, SetMajorGridOpacity, qreal, majorGridOpacity, update);
+STD_SETTER_CMD_IMPL_F_S(Axis, SetMajorGridOpacity, qreal, majorGridOpacity, updateGrid);
 void Axis::setMajorGridOpacity(qreal opacity) {
 	Q_D(Axis);
 	if (opacity != d->majorGridOpacity)
@@ -839,7 +844,7 @@ void Axis::setMinorGridPen(const QPen& pen) {
 		exec(new AxisSetMinorGridPenCmd(d, pen, ki18n("%1: set minor grid style")));
 }
 
-STD_SETTER_CMD_IMPL_F_S(Axis, SetMinorGridOpacity, qreal, minorGridOpacity, update);
+STD_SETTER_CMD_IMPL_F_S(Axis, SetMinorGridOpacity, qreal, minorGridOpacity, updateGrid);
 void Axis::setMinorGridOpacity(qreal opacity) {
 	Q_D(Axis);
 	if (opacity != d->minorGridOpacity)
@@ -1507,7 +1512,7 @@ int AxisPrivate::upperLabelsPrecision(int precision) {
 	}
 
 	//no duplicates for the current precision found: return the current value
-	DEBUG("	upper precision = " << precision);
+// 	DEBUG("	upper precision = " << precision);
 	return precision;
 }
 
@@ -1529,7 +1534,7 @@ int AxisPrivate::lowerLabelsPrecision(int precision) {
 			if (tempValues.at(i) == tempValues.at(j)) {
 				//duplicate found for the reduced precision
 				//-> current precision cannot be reduced, return the current value
-				DEBUG("	lower precision = " << precision);
+// 				DEBUG("	lower precision = " << precision);
 				return precision;
 			}
 		}
@@ -1572,14 +1577,14 @@ void AxisPrivate::retransformTickLabelPositions() {
 		if ((orientation == Axis::AxisHorizontal && plot->xRangeFormat() == CartesianPlot::Numeric) ||
 				(orientation == Axis::AxisVertical && plot->yRangeFormat() == CartesianPlot::Numeric)) {
 			if (labelsFormat == Axis::FormatDecimal || labelsFormat == Axis::FormatScientificE) {
-				width = fm.width(tickLabelStrings.at(i));
+				width = fm.boundingRect(tickLabelStrings.at(i)).width();
 			} else {
 				td.setHtml(tickLabelStrings.at(i));
 				width = td.size().width();
 				height = td.size().height();
 			}
 		} else { // Datetime
-			width = fm.width(tickLabelStrings.at(i));
+			width = fm.boundingRect(tickLabelStrings.at(i)).width();
 		}
 
 		double diffx = cosinus * width;
@@ -1816,6 +1821,16 @@ void AxisPrivate::retransformMinorGrid() {
 	recalcShapeAndBoundingRect();
 }
 
+/*!
+ * called when the opacity of the grid was changes, update the grid graphics item
+ */
+//TODO: this function is only needed for loaded projects where update() doesn't seem to be enough
+//and we have to call gridItem->update() explicitly.
+//This is not required for newly created plots/axes. Why is this difference?
+void AxisPrivate::updateGrid() {
+	gridItem->update();
+}
+
 void AxisPrivate::recalcShapeAndBoundingRect() {
 	if (m_suppressRecalc)
 		return;
