@@ -4,7 +4,7 @@
     Description          : Axis for cartesian coordinate systems.
     --------------------------------------------------------------------
     Copyright            : (C) 2009 Tilman Benkert (thzs@gmx.net)
-    Copyright            : (C) 2011-2017 Alexander Semke (alexander.semke@web.de)
+    Copyright            : (C) 2011-2018 Alexander Semke (alexander.semke@web.de)
     Copyright            : (C) 2013 Stefan Gerlach (stefan.gerlach@uni.kn)
  ***************************************************************************/
 
@@ -119,6 +119,7 @@ public:
 	BASIC_D_ACCESSOR_DECL(LabelsFormat, labelsFormat, LabelsFormat)
 	BASIC_D_ACCESSOR_DECL(bool, labelsAutoPrecision, LabelsAutoPrecision)
 	BASIC_D_ACCESSOR_DECL(int, labelsPrecision, LabelsPrecision)
+	CLASS_D_ACCESSOR_DECL(QString, labelsDateTimeFormat, LabelsDateTimeFormat)
 	BASIC_D_ACCESSOR_DECL(LabelsPosition, labelsPosition, LabelsPosition)
 	BASIC_D_ACCESSOR_DECL(qreal, labelsOffset, LabelsOffset)
 	BASIC_D_ACCESSOR_DECL(qreal, labelsRotationAngle, LabelsRotationAngle)
@@ -138,6 +139,7 @@ public:
 	void setPrinting(bool) override;
 	void setSuppressRetransform(bool);
 	void retransform() override;
+	void retransformTickLabelStrings();
 	void handleResize(double horizontalRatio, double verticalRatio, bool pageResize) override;
 
 	typedef AxisPrivate Private;
@@ -166,7 +168,7 @@ private:
 	QMenu* lineStyleMenu;
 	QMenu* lineColorMenu;
 
-	bool m_menusInitialized;
+	bool m_menusInitialized{false};
 
 private slots:
 	void labelChanged();
@@ -181,14 +183,6 @@ private slots:
 	void visibilityChangedSlot();
 
 signals:
-	friend class AxisSetOrientationCmd;
-	friend class AxisSetPositionCmd;
-	friend class AxisSetScalingCmd;
-	friend class AxisSetAutoScaleCmd;
-	friend class AxisSetStartCmd;
-	friend class AxisSetEndCmd;
-	friend class AxisSetZeroOffsetCmd;
-	friend class AxisSetScalingFactorCmd;
 	void orientationChanged(Axis::AxisOrientation);
 	void positionChanged(Axis::AxisPosition);
 	void positionChanged(double);
@@ -200,17 +194,10 @@ signals:
 	void scalingFactorChanged(qreal);
 
 	//title
-	friend class AxisSetTitleOffsetXCmd;
-	friend class AxisSetTitleOffsetYCmd;
 	void titleOffsetXChanged(qreal);
 	void titleOffsetYChanged(qreal);
 
 	// line
-	friend class AxisSetLinePenCmd;
-	friend class AxisSetLineOpacityCmd;
-	friend class AxisSetArrowTypeCmd;
-	friend class AxisSetArrowPositionCmd;
-	friend class AxisSetArrowSizeCmd;
 	void linePenChanged(const QPen&);
 	void lineOpacityChanged(qreal);
 	void arrowTypeChanged(Axis::ArrowType);
@@ -218,14 +205,6 @@ signals:
 	void arrowSizeChanged(qreal);
 
 	// major ticks
-	friend class AxisSetMajorTicksDirectionCmd;
-	friend class AxisSetMajorTicksTypeCmd;
-	friend class AxisSetMajorTicksNumberCmd;
-	friend class AxisSetMajorTicksIncrementCmd;
-	friend class AxisSetMajorTicksColumnCmd;
-	friend class AxisSetMajorTicksPenCmd;
-	friend class AxisSetMajorTicksLengthCmd;
-	friend class AxisSetMajorTicksOpacityCmd;
 	void majorTicksDirectionChanged(Axis::TicksDirection);
 	void majorTicksTypeChanged(Axis::TicksType);
 	void majorTicksNumberChanged(int);
@@ -236,14 +215,6 @@ signals:
 	void majorTicksOpacityChanged(qreal);
 
 	// minor ticks
-	friend class AxisSetMinorTicksDirectionCmd;
-	friend class AxisSetMinorTicksTypeCmd;
-	friend class AxisSetMinorTicksNumberCmd;
-	friend class AxisSetMinorTicksIncrementCmd;
-	friend class AxisSetMinorTicksColumnCmd;
-	friend class AxisSetMinorTicksPenCmd;
-	friend class AxisSetMinorTicksLengthCmd;
-	friend class AxisSetMinorTicksOpacityCmd;
 	void minorTicksDirectionChanged(Axis::TicksDirection);
 	void minorTicksTypeChanged(Axis::TicksType);
 	void minorTicksNumberChanged(int);
@@ -254,20 +225,10 @@ signals:
 	void minorTicksOpacityChanged(qreal);
 
 	//labels
-	friend class AxisSetLabelsFormatCmd;
-	friend class AxisSetLabelsAutoPrecisionCmd;
-	friend class AxisSetLabelsPrecisionCmd;
-	friend class AxisSetLabelsPositionCmd;
-	friend class AxisSetLabelsOffsetCmd;
-	friend class AxisSetLabelsRotationAngleCmd;
-	friend class AxisSetLabelsColorCmd;
-	friend class AxisSetLabelsFontCmd;
-	friend class AxisSetLabelsPrefixCmd;
-	friend class AxisSetLabelsSuffixCmd;
-	friend class AxisSetLabelsOpacityCmd;
 	void labelsFormatChanged(Axis::LabelsFormat);
 	void labelsAutoPrecisionChanged(bool);
 	void labelsPrecisionChanged(int);
+	void labelsDateTimeFormatChanged(const QString&);
 	void labelsPositionChanged(Axis::LabelsPosition);
 	void labelsOffsetChanged(double);
 	void labelsRotationAngleChanged(qreal);
@@ -277,10 +238,6 @@ signals:
 	void labelsSuffixChanged(QString);
 	void labelsOpacityChanged(qreal);
 
-	friend class AxisSetMajorGridPenCmd;
-	friend class AxisSetMajorGridOpacityCmd;
-	friend class AxisSetMinorGridPenCmd;
-	friend class AxisSetMinorGridOpacityCmd;
 	void majorGridPenChanged(QPen);
 	void majorGridOpacityChanged(qreal);
 	void minorGridPenChanged(QPen);
