@@ -67,7 +67,7 @@ public:
 	enum RangeFormat {Numeric, DateTime};
 	enum RangeType {RangeFree, RangeLast, RangeFirst};
 	enum RangeBreakStyle {RangeBreakSimple, RangeBreakVertical, RangeBreakSloped};
-	enum MouseMode {SelectionMode, ZoomSelectionMode, ZoomXSelectionMode, ZoomYSelectionMode};
+	enum MouseMode {SelectionMode, ZoomSelectionMode, ZoomXSelectionMode, ZoomYSelectionMode, Cursor};
 	enum NavigationOperation {ScaleAuto, ScaleAutoX, ScaleAutoY, ZoomIn, ZoomOut, ZoomInX, ZoomOutX,
 	                          ZoomInY, ZoomOutY, ShiftLeftX, ShiftRightX, ShiftUpY, ShiftDownY
 	                         };
@@ -106,14 +106,27 @@ public:
 	void navigate(NavigationOperation);
 	void setSuppressDataChangedSignal(bool);
 	const QList<QColor>& themeColorPalette() const;
-	void processDropEvent(QDropEvent*);
+	void processDropEvent(QDropEvent*) override;
 	bool isPanningActive() const;
+	bool isHovered() const;
+	bool isPrinted() const;
+	bool isSelected() const;
 	void addLegend(CartesianPlotLegend*);
+	int curveCount();
+	const XYCurve* getCurve(int index);
+	double cursorPos(int cursorNumber);
 
 	void save(QXmlStreamWriter*) const override;
 	bool load(XmlStreamReader*, bool preview) override;
 	void loadThemeConfig(const KConfig&) override;
 	void saveTheme(KConfig& config);
+	void mousePressZoomSelectionMode(QPointF logicPos);
+	void mousePressCursorMode(int cursorNumber, QPointF logicPos);
+	void mouseMoveZoomSelectionMode(QPointF logicPos);
+	void mouseMoveCursorMode(int cursorNumber, QPointF logicPos);
+	void mouseReleaseZoomSelectionMode();
+	void mouseHoverZoomSelectionMode(QPointF logicPos);
+	void mouseHoverOutsideDataRect();
 
 	BASIC_D_ACCESSOR_DECL(CartesianPlot::RangeFormat, xRangeFormat, XRangeFormat)
 	BASIC_D_ACCESSOR_DECL(CartesianPlot::RangeFormat, yRangeFormat, YRangeFormat)
@@ -134,6 +147,9 @@ public:
 	BASIC_D_ACCESSOR_DECL(bool, yRangeBreakingEnabled, YRangeBreakingEnabled)
 	CLASS_D_ACCESSOR_DECL(RangeBreaks, xRangeBreaks, XRangeBreaks)
 	CLASS_D_ACCESSOR_DECL(RangeBreaks, yRangeBreaks, YRangeBreaks)
+	CLASS_D_ACCESSOR_DECL(QPen, cursorPen, CursorPen);
+	CLASS_D_ACCESSOR_DECL(bool, cursor0Enable, Cursor0Enable);
+	CLASS_D_ACCESSOR_DECL(bool, cursor1Enable, Cursor1Enable);
 
 	QString theme() const;
 
@@ -149,6 +165,9 @@ private:
 	void setColorPalette(const KConfig&);
 	const XYCurve* currentCurve() const;
 
+	void calculateCurvesXMinMax(bool completeRange = true);
+	void calculateCurvesYMinMax(bool completeRange = true);
+
 	CartesianPlotLegend* m_legend{nullptr};
 	double m_zoomFactor{1.2};
 	QList<QColor> m_themeColorPalette;
@@ -199,12 +218,14 @@ private:
 	QAction* addIntegrationAction;
 	QAction* addInterpolationAction;
 	QAction* addSmoothAction;
-	QVector <QAction *> addFitAction;
+	QVector <QAction*> addFitAction;
 	QAction* addFourierFilterAction;
+	QAction* addFourierTransformAction;
 	QAction* addConvolutionAction;
 	QAction* addCorrelationAction;
 
 	QMenu* addNewMenu{nullptr};
+	QMenu* addNewAnalysisMenu{nullptr};
 	QMenu* zoomMenu{nullptr};
 	QMenu* dataAnalysisMenu{nullptr};
 	QMenu* themeMenu{nullptr};
@@ -231,6 +252,7 @@ public slots:
 	void addLegend();
 	void addTextLabel();
 	void addCustomPoint();
+	void scaleAutoTriggered();
 	bool scaleAuto();
 	bool scaleAutoX();
 	bool scaleAutoY();
@@ -244,12 +266,16 @@ public slots:
 	void shiftRightX();
 	void shiftUpY();
 	void shiftDownY();
+	void cursor();
 	void dataChanged();
 
+	void curveLinePenChanged(QPen);
+
 private slots:
 	void updateLegend();
 	void childAdded(const AbstractAspect*);
 	void childRemoved(const AbstractAspect* parent, const AbstractAspect* before, const AbstractAspect* child);
+	void childHovered();
 
 	void xDataChanged();
 	void yDataChanged();
@@ -282,6 +308,25 @@ signals:
 	void yRangeBreakingEnabledChanged(bool);
 	void yRangeBreaksChanged(const CartesianPlot::RangeBreaks&);
 	void themeChanged(const QString&);
+	void mousePressZoomSelectionModeSignal(QPointF logicPos);
+	void mousePressCursorModeSignal(int cursorNumber, QPointF logicPos);
+	void mouseMoveZoomSelectionModeSignal(QPointF logicPos);
+	void mouseMoveCursorModeSignal(int cursorNumber, QPointF logicPos);
+	void mouseReleaseCursorModeSignal();
+	void mouseReleaseZoomSelectionModeSignal();
+	void mouseHoverZoomSelectionModeSignal(QPointF logicalPoint);
+	void mouseHoverOutsideDataRectSignal();
+	void curveNameChanged(const AbstractAspect* curve);
+	void cursorPosChanged(int cursorNumber, double xPos);
+	void curveAdded(const XYCurve*);
+	void curveRemoved(const XYCurve*);
+	void curveLinePenChanged(QPen, QString curveName);
+	void cursorPenChanged(QPen);
+	void curveDataChanged(const XYCurve*);
+	void curveVisibilityChangedSignal();
+	void mouseModeChanged(MouseMode);
+	void cursor0EnableChanged(bool enable);
+	void cursor1EnableChanged(bool enable);
 };
 
 #endif
