@@ -51,12 +51,14 @@
 #include <KLocalizedString>
 
 CartesianPlotLegend::CartesianPlotLegend(CartesianPlot* plot, const QString &name)
-		: WorksheetElement(name), d_ptr(new CartesianPlotLegendPrivate(this)), m_plot(plot) {
+		: WorksheetElement(name, AspectType::CartesianPlotLegend), d_ptr(new CartesianPlotLegendPrivate(this)), m_plot(plot) {
+
 	init();
 }
 
 CartesianPlotLegend::CartesianPlotLegend(CartesianPlot* plot, const QString &name, CartesianPlotLegendPrivate *dd)
-		: WorksheetElement(name), d_ptr(dd), m_plot(plot) {
+		: WorksheetElement(name, AspectType::CartesianPlotLegend), d_ptr(dd), m_plot(plot) {
+
 	init();
 }
 
@@ -126,9 +128,9 @@ void CartesianPlotLegend::init() {
 }
 
 void CartesianPlotLegend::initActions() {
-	visibilityAction = new QAction(i18n("Visible"), this);
+	visibilityAction = new QAction(QIcon::fromTheme("view-visible"), i18n("Visible"), this);
 	visibilityAction->setCheckable(true);
-	connect(visibilityAction, &QAction::triggered, this, &CartesianPlotLegend::visibilityChanged);
+	connect(visibilityAction, &QAction::triggered, this, &CartesianPlotLegend::visibilityChangedSlot);
 }
 
 QMenu* CartesianPlotLegend::createContextMenu() {
@@ -515,7 +517,7 @@ void CartesianPlotLegendPrivate::retransform() {
 				if (!curve->isVisible())
 					continue;
 
-				w = fm.width(curve->name());
+				w = fm.boundingRect(curve->name()).width();
 				if (w>maxTextWidth)
 					maxTextWidth = w;
 			}
@@ -715,7 +717,7 @@ void CartesianPlotLegendPrivate::paint(QPainter* painter, const QStyleOptionGrap
 	float h = fm.ascent();
 	painter->setFont(labelFont);
 
-	//translate to left upper conner of the bounding rect plus the layout offset and the height of the title
+	//translate to left upper corner of the bounding rect plus the layout offset and the height of the title
 	painter->translate(-rect.width()/2+layoutLeftMargin, -rect.height()/2+layoutTopMargin);
 	if (title->isVisible() && !title->text().text.isEmpty())
 		painter->translate(0, title->graphicsItem()->boundingRect().height());
