@@ -3,7 +3,7 @@
     Project              : LabPlot
     Description          : Legend for the cartesian plot
     --------------------------------------------------------------------
-    Copyright            : (C) 2013-2017 Alexander Semke (alexander.semke@web.de)
+    Copyright            : (C) 2013-2018 Alexander Semke (alexander.semke@web.de)
  ***************************************************************************/
 
 /***************************************************************************
@@ -71,6 +71,7 @@ public:
 	CLASS_D_ACCESSOR_DECL(QColor, labelColor, LabelColor)
 	BASIC_D_ACCESSOR_DECL(bool, labelColumnMajor, LabelColumnMajor)
 	CLASS_D_ACCESSOR_DECL(PositionWrapper, position, Position)
+	BASIC_D_ACCESSOR_DECL(qreal, rotationAngle, RotationAngle)
 	BASIC_D_ACCESSOR_DECL(float, lineSymbolWidth, LineSymbolWidth)
 
 	BASIC_D_ACCESSOR_DECL(float, backgroundOpacity, BackgroundOpacity)
@@ -108,42 +109,20 @@ private:
 	void init();
 	void initActions();
 
-	CartesianPlot* m_plot;
-	QAction* visibilityAction;
+	CartesianPlot* m_plot{nullptr};
+	QAction* visibilityAction{nullptr};
 
 private slots:
 	//SLOTs for changes triggered via QActions in the context menu
 	void visibilityChangedSlot();
 
 signals:
-	friend class CartesianPlotLegendSetLabelFontCmd;
-	friend class CartesianPlotLegendSetLabelColorCmd;
-	friend class CartesianPlotLegendSetLabelColumnMajorCmd;
-	friend class CartesianPlotLegendSetLineSymbolWidthCmd;
-	friend class CartesianPlotLegendSetPositionCmd;
-	friend class CartesianPlotLegendSetBackgroundTypeCmd;
-	friend class CartesianPlotLegendSetBackgroundColorStyleCmd;
-	friend class CartesianPlotLegendSetBackgroundImageStyleCmd;
-	friend class CartesianPlotLegendSetBackgroundBrushStyleCmd;
-	friend class CartesianPlotLegendSetBackgroundFirstColorCmd;
-	friend class CartesianPlotLegendSetBackgroundSecondColorCmd;
-	friend class CartesianPlotLegendSetBackgroundFileNameCmd;
-	friend class CartesianPlotLegendSetBackgroundOpacityCmd;
-	friend class CartesianPlotLegendSetBorderPenCmd;
-	friend class CartesianPlotLegendSetBorderCornerRadiusCmd;
-	friend class CartesianPlotLegendSetBorderOpacityCmd;
-	friend class CartesianPlotLegendSetLayoutTopMarginCmd;
-	friend class CartesianPlotLegendSetLayoutBottomMarginCmd;
-	friend class CartesianPlotLegendSetLayoutLeftMarginCmd;
-	friend class CartesianPlotLegendSetLayoutRightMarginCmd;
-	friend class CartesianPlotLegendSetLayoutVerticalSpacingCmd;
-	friend class CartesianPlotLegendSetLayoutHorizontalSpacingCmd;
-	friend class CartesianPlotLegendSetLayoutColumnCountCmd;
 	void labelFontChanged(QFont&);
 	void labelColorChanged(QColor&);
 	void labelColumnMajorChanged(bool);
 	void lineSymbolWidthChanged(float);
 	void positionChanged(const CartesianPlotLegend::PositionWrapper&);
+	void rotationAngleChanged(qreal);
 	void backgroundTypeChanged(PlotArea::BackgroundType);
 	void backgroundColorStyleChanged(PlotArea::BackgroundColorStyle);
 	void backgroundImageStyleChanged(PlotArea::BackgroundImageStyle);
