@@ -32,6 +32,7 @@
 #include "CartesianPlot.h"
 #include "CartesianCoordinateSystem.h"
 #include "backend/worksheet/plots/AbstractPlotPrivate.h"
+#include <QStaticText>
 
 #include <QGraphicsSceneMouseEvent>
 
@@ -45,6 +46,15 @@ public:
 	void rangeChanged();
 	void xRangeFormatChanged();
 	void yRangeFormatChanged();
+	void mouseMoveZoomSelectionMode(QPointF logicalPos);
+	void mouseMoveCursorMode(int cursorNumber, QPointF logicalPos);
+	void mouseReleaseZoomSelectionMode();
+	void mouseHoverZoomSelectionMode(QPointF logicPos);
+	void mouseHoverOutsideDataRect();
+	void mousePressZoomSelectionMode(QPointF logicalPos);
+	void mousePressCursorMode(int cursorNumber, QPointF logicalPos);
+	void updateCursor();
+	void setZoomSelectionBandShow(bool show);
 
 	QRectF dataRect;
 	CartesianPlot::RangeType rangeType{CartesianPlot::RangeFree};
@@ -75,6 +85,17 @@ public:
 	bool suppressRetransform{false};
 	bool panningStarted{false};
 	bool locked{false};
+	// Cursor
+	bool cursor0Enable{false};
+	int selectedCursor{0};
+	QPointF cursor0Pos{QPointF(NAN, NAN)};
+	bool cursor1Enable{false};
+	QPointF cursor1Pos{QPointF(NAN, NAN)};
+	QPen cursorPen{QPen(Qt::red, 5, Qt::SolidLine)};
+
+signals:
+	void mousePressZoomSelectionModeSignal(QPointF logicalPos);
+	void mousePressCursorModeSignal(QPointF logicalPos);
 
 private:
 	QVariant itemChange(GraphicsItemChange change, const QVariant &value) override;
@@ -82,7 +103,9 @@ private:
 	void mouseReleaseEvent(QGraphicsSceneMouseEvent*) override;
 	void mouseMoveEvent(QGraphicsSceneMouseEvent*) override;
 	void wheelEvent(QGraphicsSceneWheelEvent*) override;
+	void keyPressEvent(QKeyEvent*) override;
 	void hoverMoveEvent(QGraphicsSceneHoverEvent*) override;
+	void hoverLeaveEvent(QGraphicsSceneHoverEvent*) override;
 	void paint(QPainter*, const QStyleOptionGraphicsItem*, QWidget* widget = nullptr) override;
 
 	void updateDataRect();
@@ -92,11 +115,15 @@ private:
 		double sceneStart, double sceneEnd,
 		double logicalStart, double logicalEnd);
 
+	bool m_insideDataRect{false};
 	bool m_selectionBandIsShown{false};
 	QPointF m_selectionStart;
 	QPointF m_selectionEnd;
 	QLineF m_selectionStartLine;
 	QPointF m_panningStart;
+
+	QStaticText m_cursor0Text{"1"};
+	QStaticText m_cursor1Text{"2"};
 };
 
 #endif
