@@ -50,13 +50,15 @@
  * x- and y- coordinates in parent's coordinate system
  */
 
-CustomPoint::CustomPoint(const CartesianPlot* plot, const QString& name) : WorksheetElement(name),
-	d_ptr(new CustomPointPrivate(this, plot)) {
+CustomPoint::CustomPoint(const CartesianPlot* plot, const QString& name)
+	: WorksheetElement(name, AspectType::CustomPoint), d_ptr(new CustomPointPrivate(this, plot)) {
 
 	init();
 }
 
-CustomPoint::CustomPoint(const QString& name, CustomPointPrivate* dd) : WorksheetElement(name), d_ptr(dd) {
+CustomPoint::CustomPoint(const QString& name, CustomPointPrivate* dd)
+	: WorksheetElement(name, AspectType::CustomPoint), d_ptr(dd) {
+
 	init();
 }
 
