@@ -61,13 +61,15 @@ extern "C" {
 }
 
 Histogram::Histogram(const QString &name)
-	: WorksheetElement(name), d_ptr(new HistogramPrivate(this)) {
-		init();
+	: WorksheetElement(name, AspectType::Histogram), d_ptr(new HistogramPrivate(this)) {
+
+	init();
 }
 
 Histogram::Histogram(const QString &name, HistogramPrivate *dd)
-	: WorksheetElement(name), d_ptr(dd) {
-		init();
+	: WorksheetElement(name, AspectType::Histogram), d_ptr(dd) {
+
+	init();
 }
 
 void Histogram::init() {
@@ -137,7 +139,7 @@ void Histogram::init() {
 }
 
 void Histogram::initActions() {
-	visibilityAction = new QAction(i18n("Visible"), this);
+	visibilityAction = new QAction(QIcon::fromTheme("view-visible"), i18n("Visible"), this);
 	visibilityAction->setCheckable(true);
 	connect(visibilityAction, &QAction::triggered, this, &Histogram::visibilityChangedSlot);
 }
@@ -1161,7 +1163,7 @@ void HistogramPrivate::updateValues() {
 	switch (valuesPosition) {
 	case Histogram::ValuesAbove:
 		for (int i = 0; i < valuesStrings.size(); i++) {
-			w = fm.width(valuesStrings.at(i));
+			w = fm.boundingRect(valuesStrings.at(i)).width();
 			tempPoint.setX( pointsScene.at(i).x() -w/2);
 			tempPoint.setY( pointsScene.at(i).y() - valuesDistance );
 			valuesPoints.append(tempPoint);
@@ -1169,7 +1171,7 @@ void HistogramPrivate::updateValues() {
 		break;
 	case Histogram::ValuesUnder:
 		for (int i = 0; i < valuesStrings.size(); i++) {
-			w = fm.width(valuesStrings.at(i));
+			w = fm.boundingRect(valuesStrings.at(i)).width();
 			tempPoint.setX( pointsScene.at(i).x() -w/2);
 			tempPoint.setY( pointsScene.at(i).y() + valuesDistance + h/2);
 			valuesPoints.append(tempPoint);
@@ -1177,7 +1179,7 @@ void HistogramPrivate::updateValues() {
 		break;
 	case Histogram::ValuesLeft:
 		for (int i = 0; i < valuesStrings.size(); i++) {
-			w = fm.width(valuesStrings.at(i));
+			w = fm.boundingRect(valuesStrings.at(i)).width();
 			tempPoint.setX( pointsScene.at(i).x() - valuesDistance - w - 1);
 			tempPoint.setY( pointsScene.at(i).y());
 			valuesPoints.append(tempPoint);
