@@ -4,6 +4,7 @@
     Description          : Histogram
     --------------------------------------------------------------------
     Copyright            : (C) 2016 Anu Mittal (anu22mittal@gmail.com)
+    Copyright            : (C) 2018 Alexander Semke (alexander.semke@web.de)
 
  ***************************************************************************/
 
@@ -30,54 +31,67 @@
 #define HISTOGRAM_H
 
 #include "backend/worksheet/WorksheetElement.h"
+#include "backend/worksheet/plots/cartesian/Symbol.h"
+#include "backend/worksheet/plots/cartesian/XYCurve.h"
 #include "backend/worksheet/plots/PlotArea.h"
 #include "backend/core/AbstractColumn.h"
 #include "backend/lib/macros.h"
 
 class HistogramPrivate;
 
-class Histogram: public WorksheetElement {
+class Histogram : public WorksheetElement {
 	Q_OBJECT
 
 public:
-	enum BinsOption {Number,Width,SquareRoot,RiceRule,SturgisRule};
-	enum ValuesType {NoValues, ValuesY, ValuesYBracketed, ValuesCustomColumn};
-	enum ValuesPosition {ValuesAbove, ValuesUnder, ValuesLeft, ValuesRight};
-	enum FillingPosition {NoFilling, FillingAbove, FillingBelow, FillingZeroBaseline, FillingLeft, FillingRight};
 	enum HistogramType {Ordinary,Cumulative, AvgShift};
+	enum HistogramOrientation {Vertical, Horizontal};
+	enum BinningMethod {ByNumber, ByWidth, SquareRoot, Rice, Sturges, Doane, Scott};
+	enum LineType {NoLine, Bars, Envelope, DropLines};
+	enum ValuesType {NoValues, ValuesBinEntries, ValuesCustomColumn};
+	enum ValuesPosition {ValuesAbove, ValuesUnder, ValuesLeft, ValuesRight};
+	enum ErrorType {NoError};
 
-	struct HistogramData {
-		HistogramData() : type(Ordinary),binsOption(Number), binValue(10) {};
-
-		HistogramType type;
-		BinsOption binsOption;
-		int binValue;
-	};
 	explicit Histogram(const QString &name);
-	//size_t bins;
 
 	QIcon icon() const override;
 	QMenu* createContextMenu() override;
 	QGraphicsItem* graphicsItem() const override;
 	void save(QXmlStreamWriter*) const override;
 	bool load(XmlStreamReader*, bool preview) override;
+	void loadThemeConfig(const KConfig&) override;
+	void saveThemeConfig(const KConfig&) override;
 
-	CLASS_D_ACCESSOR_DECL(HistogramData, histogramData, HistogramData)
+	POINTER_D_ACCESSOR_DECL(const AbstractColumn, dataColumn, DataColumn)
+	QString& dataColumnPath() const;
 
-	POINTER_D_ACCESSOR_DECL(const AbstractColumn, xColumn, XColumn)
-	POINTER_D_ACCESSOR_DECL(const AbstractColumn, yColumn, YColumn)
-	QString& xColumnPath() const;
-	QString& yColumnPath() const;
+	BASIC_D_ACCESSOR_DECL(Histogram::HistogramType, type, Type)
+	BASIC_D_ACCESSOR_DECL(Histogram::HistogramOrientation, orientation, Orientation)
+	BASIC_D_ACCESSOR_DECL(Histogram::BinningMethod, binningMethod, BinningMethod)
+	BASIC_D_ACCESSOR_DECL(int, binCount, BinCount)
+	BASIC_D_ACCESSOR_DECL(float, binWidth, BinWidth)
+	BASIC_D_ACCESSOR_DECL(bool, autoBinRanges, AutoBinRanges)
+	BASIC_D_ACCESSOR_DECL(double, binRangesMin, BinRangesMin)
+	BASIC_D_ACCESSOR_DECL(double, binRangesMax, BinRangesMax)
 
 	BASIC_D_ACCESSOR_DECL(float, xMin, XMin)
 	BASIC_D_ACCESSOR_DECL(float, xMax, XMax)
 	BASIC_D_ACCESSOR_DECL(float, yMin, YMin)
 	BASIC_D_ACCESSOR_DECL(float, yMax, YMax)
 
+	BASIC_D_ACCESSOR_DECL(LineType, lineType, LineType)
+	CLASS_D_ACCESSOR_DECL(QPen, linePen, LinePen)
+	BASIC_D_ACCESSOR_DECL(qreal, lineOpacity, LineOpacity)
+
+	BASIC_D_ACCESSOR_DECL(Symbol::Style, symbolsStyle, SymbolsStyle)
+	BASIC_D_ACCESSOR_DECL(qreal, symbolsOpacity, SymbolsOpacity)
+	BASIC_D_ACCESSOR_DECL(qreal, symbolsRotationAngle, SymbolsRotationAngle)
+	BASIC_D_ACCESSOR_DECL(qreal, symbolsSize, SymbolsSize)
+	CLASS_D_ACCESSOR_DECL(QBrush, symbolsBrush, SymbolsBrush)
+	CLASS_D_ACCESSOR_DECL(QPen, symbolsPen, SymbolsPen)
+
 	BASIC_D_ACCESSOR_DECL(ValuesType, valuesType, ValuesType)
 	POINTER_D_ACCESSOR_DECL(const AbstractColumn, valuesColumn, ValuesColumn)
 	QString& valuesColumnPath() const;
-	CLASS_D_ACCESSOR_DECL(QPen, linePen, LinePen)
 	BASIC_D_ACCESSOR_DECL(ValuesPosition, valuesPosition, ValuesPosition)
 	BASIC_D_ACCESSOR_DECL(qreal, valuesDistance, ValuesDistance)
 	BASIC_D_ACCESSOR_DECL(qreal, valuesRotationAngle, ValuesRotationAngle)
@@ -87,7 +101,7 @@ public:
 	CLASS_D_ACCESSOR_DECL(QColor, valuesColor, ValuesColor)
 	CLASS_D_ACCESSOR_DECL(QFont, valuesFont, ValuesFont)
 
-	BASIC_D_ACCESSOR_DECL(FillingPosition, fillingPosition, FillingPosition)
+	BASIC_D_ACCESSOR_DECL(bool, fillingEnabled, FillingEnabled)
 	BASIC_D_ACCESSOR_DECL(PlotArea::BackgroundType, fillingType, FillingType)
 	BASIC_D_ACCESSOR_DECL(PlotArea::BackgroundColorStyle, fillingColorStyle, FillingColorStyle)
 	BASIC_D_ACCESSOR_DECL(PlotArea::BackgroundImageStyle, fillingImageStyle, FillingImageStyle)
@@ -97,33 +111,38 @@ public:
 	CLASS_D_ACCESSOR_DECL(QString, fillingFileName, FillingFileName)
 	BASIC_D_ACCESSOR_DECL(qreal, fillingOpacity, FillingOpacity)
 
+	BASIC_D_ACCESSOR_DECL(ErrorType, errorType, ErrorType)
+	BASIC_D_ACCESSOR_DECL(XYCurve::ErrorBarsType, errorBarsType, ErrorBarsType)
+	BASIC_D_ACCESSOR_DECL(qreal, errorBarsCapSize, ErrorBarsCapSize)
+	CLASS_D_ACCESSOR_DECL(QPen, errorBarsPen, ErrorBarsPen)
+	BASIC_D_ACCESSOR_DECL(qreal, errorBarsOpacity, ErrorBarsOpacity)
+
 	void setVisible(bool on) override;
 	bool isVisible() const override;
 	void setPrinting(bool on) override;
 	void suppressRetransform(bool);
+
 	double getYMaximum() const;
-	void setHistrogramType(Histogram::HistogramType);
-	Histogram::HistogramType getHistrogramType();
-	void setbinsOption(Histogram::BinsOption);
-	void setBinValue(int);
+	double getYMinimum() const;
+	double getXMaximum() const;
+	double getXMinimum() const;
 
 	typedef WorksheetElement BaseClass;
 	typedef HistogramPrivate Private;
 
-	bool isSourceDataChangedSinceLastPlot() const;
-
 public slots:
 	void retransform() override;
+	void recalcHistogram();
 	void handleResize(double horizontalRatio, double verticalRatio, bool pageResize) override;
 
 private slots:
 	void updateValues();
-	void xColumnAboutToBeRemoved(const AbstractAspect*);
+	void dataColumnAboutToBeRemoved(const AbstractAspect*);
 	void valuesColumnAboutToBeRemoved(const AbstractAspect*);
+
 	//SLOTs for changes triggered via QActions in the context menu
 	void visibilityChangedSlot();
 
-	void handleSourceDataChanged();
 protected:
 	Histogram(const QString& name, HistogramPrivate* dd);
 	HistogramPrivate* const d_ptr;
@@ -132,32 +151,37 @@ private:
 	Q_DECLARE_PRIVATE(Histogram)
 	void init();
 	void initActions();
-	QAction* visibilityAction;
+	QAction* visibilityAction{nullptr};
 
 signals:
 	//General-Tab
-	void HistogramdataChanged();
-	void xHistogramDataChanged();
-	void yHistogramDataChanged();
+	void dataChanged();
+	void dataColumnChanged(const AbstractColumn*);
 	void visibilityChanged(bool);
 
-	friend class HistogramSetXColumnCmd;
-	friend class HistogramSetYColumnCmd;
-	friend class HistogramSetLinePenCmd;
-	void xColumnChanged(const AbstractColumn*);
-	void yColumnChanged(const AbstractColumn*);
+	void typeChanged(Histogram::HistogramType);
+	void orientationChanged(Histogram::HistogramOrientation);
+	void binningMethodChanged(Histogram::BinningMethod);
+	void binCountChanged(int);
+	void binWidthChanged(float);
+	void autoBinRangesChanged(bool);
+	void binRangesMinChanged(double);
+	void binRangesMaxChanged(double);
+
+	//Symbol-Tab
+	void symbolsStyleChanged(Symbol::Style);
+	void symbolsSizeChanged(qreal);
+	void symbolsRotationAngleChanged(qreal);
+	void symbolsOpacityChanged(qreal);
+	void symbolsBrushChanged(QBrush);
+	void symbolsPenChanged(const QPen&);
+
+	//Line-Tab
+	void lineTypeChanged(Histogram::LineType);
+	void linePenChanged(const QPen&);
+	void lineOpacityChanged(qreal);
 
 	//Values-Tab
-	friend class HistogramSetValuesColumnCmd;
-	friend class HistogramSetValuesTypeCmd;
-	friend class HistogramSetValuesPositionCmd;
-	friend class HistogramSetValuesDistanceCmd;
-	friend class HistogramSetValuesRotationAngleCmd;
-	friend class HistogramSetValuesOpacityCmd;
-	friend class HistogramSetValuesPrefixCmd;
-	friend class HistogramSetValuesSuffixCmd;
-	friend class HistogramSetValuesFontCmd;
-	friend class HistogramSetValuesColorCmd;
 	void valuesTypeChanged(Histogram::ValuesType);
 	void valuesColumnChanged(const AbstractColumn*);
 	void valuesPositionChanged(Histogram::ValuesPosition);
@@ -169,19 +193,8 @@ signals:
 	void valuesFontChanged(QFont);
 	void valuesColorChanged(QColor);
 
-	void linePenChanged(const QPen&);
-
 	//Filling
-	friend class HistogramSetFillingPositionCmd;
-	friend class HistogramSetFillingTypeCmd;
-	friend class HistogramSetFillingColorStyleCmd;
-	friend class HistogramSetFillingImageStyleCmd;
-	friend class HistogramSetFillingBrushStyleCmd;
-	friend class HistogramSetFillingFirstColorCmd;
-	friend class HistogramSetFillingSecondColorCmd;
-	friend class HistogramSetFillingFileNameCmd;
-	friend class HistogramSetFillingOpacityCmd;
-	void fillingPositionChanged(Histogram::FillingPosition);
+	void fillingEnabledChanged(bool);
 	void fillingTypeChanged(PlotArea::BackgroundType);
 	void fillingColorStyleChanged(PlotArea::BackgroundColorStyle);
 	void fillingImageStyleChanged(PlotArea::BackgroundImageStyle);
@@ -191,9 +204,12 @@ signals:
 	void fillingFileNameChanged(QString&);
 	void fillingOpacityChanged(float);
 
-	friend class HistogramSetDataCmd;
-	void histogramDataChanged(const Histogram::HistogramData&);
-	void sourceDataChangedSinceLastPlot();
+	//Error bars
+	void errorTypeChanged(Histogram::ErrorType);
+	void errorBarsTypeChanged(XYCurve::ErrorBarsType);
+	void errorBarsPenChanged(QPen);
+	void errorBarsCapSizeChanged(qreal);
+	void errorBarsOpacityChanged(qreal);
 };
 
 #endif
