@@ -1,4 +1,4 @@
-﻿
+
 /***************************************************************************
     File                 : XYFitCurve.cpp
     Project              : LabPlot
@@ -61,11 +61,11 @@ extern "C" {
 #include <QThreadPool>
 
 XYFitCurve::XYFitCurve(const QString& name)
-	: XYAnalysisCurve(name, new XYFitCurvePrivate(this)) {
+	: XYAnalysisCurve(name, new XYFitCurvePrivate(this), AspectType::XYFitCurve) {
 }
 
 XYFitCurve::XYFitCurve(const QString& name, XYFitCurvePrivate* dd)
-	: XYAnalysisCurve(name, dd) {
+	: XYAnalysisCurve(name, dd, AspectType::XYFitCurve) {
 }
 
 //no need to delete the d-pointer here - it inherits from QGraphicsItem
@@ -1584,16 +1584,6 @@ void XYFitCurvePrivate::recalculate() {
 		return;
 	}
 
-	//check column sizes
-	if (tmpXDataColumn->rowCount() != tmpYDataColumn->rowCount()) {
-		fitResult.available = true;
-		fitResult.valid = false;
-		fitResult.status = i18n("Number of x and y data points must be equal.");
-		emit q->dataChanged();
-		sourceDataChangedSinceLastRecalc = false;
-		return;
-	}
-
 	if (yErrorColumn) {
 		if (yErrorColumn->rowCount() < tmpXDataColumn->rowCount()) {
 			fitResult.available = true;
@@ -1620,32 +1610,34 @@ void XYFitCurvePrivate::recalculate() {
 	}
 	DEBUG("fit range = " << xmin << " .. " << xmax);
 
-	for (int row = 0; row < tmpXDataColumn->rowCount(); ++row) {
+	int rowCount = qMin(tmpXDataColumn->rowCount(), tmpYDataColumn->rowCount());
+	for (int row = 0; row < rowCount; ++row) {
 		//only copy those data where _all_ values (for x and y and errors, if given) are valid
-		if (!std::isnan(tmpXDataColumn->valueAt(row)) && !std::isnan(tmpYDataColumn->valueAt(row))
-			&& !tmpXDataColumn->isMasked(row) && !tmpYDataColumn->isMasked(row)) {
+		if (std::isnan(tmpXDataColumn->valueAt(row)) || std::isnan(tmpYDataColumn->valueAt(row))
+			|| tmpXDataColumn->isMasked(row) || tmpYDataColumn->isMasked(row))
+			continue;
 
-			// only when inside given range
-			if (tmpXDataColumn->valueAt(row) >= xmin && tmpXDataColumn->valueAt(row) <= xmax) {
-				if (dataSourceType == XYAnalysisCurve::DataSourceCurve || (!xErrorColumn && !yErrorColumn) || !fitData.useDataErrors) {	// x-y
+		// only when inside given range
+		if (tmpXDataColumn->valueAt(row) >= xmin && tmpXDataColumn->valueAt(row) <= xmax) {
+			if ((!xErrorColumn && !yErrorColumn) || !fitData.useDataErrors) {	// x-y
+				xdataVector.append(tmpXDataColumn->valueAt(row));
+				ydataVector.append(tmpYDataColumn->valueAt(row));
+			} else if (!xErrorColumn && yErrorColumn) {	// x-y-dy
+				if (!std::isnan(yErrorColumn->valueAt(row))) {
 					xdataVector.append(tmpXDataColumn->valueAt(row));
 					ydataVector.append(tmpYDataColumn->valueAt(row));
-				} else if (!xErrorColumn && yErrorColumn) {	// x-y-dy
-					if (!std::isnan(yErrorColumn->valueAt(row))) {
-						xdataVector.append(tmpXDataColumn->valueAt(row));
-						ydataVector.append(tmpYDataColumn->valueAt(row));
-						yerrorVector.append(yErrorColumn->valueAt(row));
-					}
-				} else if (xErrorColumn && yErrorColumn) {	// x-y-dx-dy
-					if (!std::isnan(xErrorColumn->valueAt(row)) && !std::isnan(yErrorColumn->valueAt(row))) {
-						xdataVector.append(tmpXDataColumn->valueAt(row));
-						ydataVector.append(tmpYDataColumn->valueAt(row));
-						xerrorVector.append(xErrorColumn->valueAt(row));
-						yerrorVector.append(yErrorColumn->valueAt(row));
-					}
+					yerrorVector.append(yErrorColumn->valueAt(row));
+				}
+			} else if (xErrorColumn && yErrorColumn) {	// x-y-dx-dy
+				if (!std::isnan(xErrorColumn->valueAt(row)) && !std::isnan(yErrorColumn->valueAt(row))) {
+					xdataVector.append(tmpXDataColumn->valueAt(row));
+					ydataVector.append(tmpYDataColumn->valueAt(row));
+					xerrorVector.append(xErrorColumn->valueAt(row));
+					yerrorVector.append(yErrorColumn->valueAt(row));
 				}
 			}
 		}
+
 	}
 	//number of data points to fit
 	const size_t n = xdataVector.size();
@@ -1668,17 +1660,28 @@ void XYFitCurvePrivate::recalculate() {
 		return;
 	}
 
+	if (fitData.model.simplified().isEmpty()) {
+		fitResult.available = true;
+		fitResult.valid = false;
+		fitResult.status = i18n("Fit model not specified.");
+		emit q->dataChanged();
+		sourceDataChangedSinceLastRecalc = false;
+		return;
+	}
+
 	double* xdata = xdataVector.data();
 	double* ydata = ydataVector.data();
 	double* xerror = xerrorVector.data();	// size may be 0
 	double* yerror = yerrorVector.data();	// size may be 0
-	DEBUG("x errors: " << xerrorVector.size());
-	DEBUG("y errors: " << yerrorVector.size());
+	DEBUG("x error vector size: " << xerrorVector.size());
+	DEBUG("y error vector size: " << yerrorVector.size());
 	double* weight = new double[n];
 
 	for (size_t i = 0; i < n; i++)
 		weight[i] = 1.;
 
+	const double minError = 1.e-199;	// minimum error for weighting
+
 	switch (fitData.yWeightsType) {
 	case nsl_fit_weight_no:
 	case nsl_fit_weight_statistical_fit:
@@ -1687,7 +1690,7 @@ void XYFitCurvePrivate::recalculate() {
 	case nsl_fit_weight_instrumental:	// yerror are sigmas
 		for (int i = 0; i < (int)n; i++)
 			if (i < yerrorVector.size())
-				weight[i] = 1./gsl_pow_2(yerror[i]);
+				weight[i] = 1./gsl_pow_2(qMax(yerror[i], qMax(sqrt(minError), fabs(ydata[i]) * 1.e-15)));
 		break;
 	case nsl_fit_weight_direct:		// yerror are weights
 		for (int i = 0; i < (int)n; i++)
@@ -1697,15 +1700,15 @@ void XYFitCurvePrivate::recalculate() {
 	case nsl_fit_weight_inverse:		// yerror are inverse weights
 		for (int i = 0; i < (int)n; i++)
 			if (i < yerrorVector.size())
-				weight[i] = 1./yerror[i];
+				weight[i] = 1./qMax(yerror[i], qMax(minError, fabs(ydata[i]) * 1.e-15));
 		break;
 	case nsl_fit_weight_statistical:
 		for (int i = 0; i < (int)n; i++)
-			weight[i] = 1./ydata[i];
+			weight[i] = 1./qMax(ydata[i], minError);
 		break;
 	case nsl_fit_weight_relative:
 		for (int i = 0; i < (int)n; i++)
-			weight[i] = 1./gsl_pow_2(ydata[i]);
+			weight[i] = 1./qMax(gsl_pow_2(ydata[i]), minError);
 		break;
 	}
 
@@ -1783,11 +1786,11 @@ void XYFitCurvePrivate::recalculate() {
 		DEBUG("Rerun fit with x errors");
 
 		unsigned int iter2 = 0;
-		double chi = 0, chiOld = 0;
+		double chisq = 0, chisqOld = 0;
 		double *fun = new double[n];
 		do {
 			iter2++;
-			chiOld = chi;
+			chisqOld = chisq;
 			//printf("iter2 = %d\n", iter2);
 
 			// calculate function from residuals
@@ -1810,7 +1813,7 @@ void XYFitCurvePrivate::recalculate() {
 				case nsl_fit_weight_no:
 					break;
 				case nsl_fit_weight_direct:	// xerror = w_x
-					sigmasq = df*df/xerror[i];
+					sigmasq = df*df/qMax(xerror[i], minError);
 					break;
 				case nsl_fit_weight_instrumental:	// xerror = s_x
 					sigmasq = df*df*xerror[i]*xerror[i];
@@ -1834,7 +1837,7 @@ void XYFitCurvePrivate::recalculate() {
 					case nsl_fit_weight_no:
 						break;
 					case nsl_fit_weight_direct:	// yerror = w_y
-						sigmasq += 1./yerror[i];
+						sigmasq += 1./qMax(yerror[i], minError);
 						break;
 					case nsl_fit_weight_instrumental:	// yerror = s_y
 						sigmasq += yerror[i]*yerror[i];
@@ -1855,7 +1858,7 @@ void XYFitCurvePrivate::recalculate() {
 				}
 
 				//printf ("sigma[%d] = %g\n", i, sqrt(sigmasq));
-				weight[i] = 1./sigmasq;
+				weight[i] = 1./qMax(sigmasq, minError);
 			}
 
 			// update weights
@@ -1864,7 +1867,7 @@ void XYFitCurvePrivate::recalculate() {
 			do {	// fit
 				iter++;
 				writeSolverState(s);
-				status = gsl_multifit_fdfsolver_iterate (s);
+				status = gsl_multifit_fdfsolver_iterate(s);
 				//printf ("status = %s\n", gsl_strerror (status));
 				if (status) {
 					DEBUG("iter " << iter << ", status = " << gsl_strerror(status));
@@ -1873,9 +1876,8 @@ void XYFitCurvePrivate::recalculate() {
 				status = gsl_multifit_test_delta(s->dx, s->x, delta, delta);
 			} while (status == GSL_CONTINUE && iter < maxIters);
 
-			chi = gsl_blas_dnrm2(s->f);
-			//printf("chi = %.12g (dchi = %g)\n", chi, fabs(chi-chiOld));
-		} while (iter2 < maxIters && fabs(chi-chiOld) > fitData.eps);
+			chisq = gsl_blas_dnrm2(s->f);
+		} while (iter2 < maxIters && fabs(chisq-chisqOld) > fitData.eps);
 
 		delete[] fun;
 	}
@@ -1908,6 +1910,7 @@ void XYFitCurvePrivate::recalculate() {
 	//gsl_blas_dnrm2() - computes the Euclidian norm (||r||_2 = \sqrt {\sum r_i^2}) of the vector with the elements weight[i]*(Yi - y[i])
 	//gsl_blas_dasum() - computes the absolute sum \sum |r_i| of the elements of the vector with the elements weight[i]*(Yi - y[i])
 	fitResult.sse = gsl_pow_2(gsl_blas_dnrm2(s->f));
+
 	if (fitResult.dof != 0) {
 		fitResult.rms = fitResult.sse/fitResult.dof;
 		fitResult.rsd = sqrt(fitResult.rms);
@@ -2007,7 +2010,8 @@ void XYFitCurvePrivate::evaluate(bool preview) {
 		tmpXDataColumn = xDataColumn;
 	} else {
 		DEBUG("	curve columns as data source");
-		tmpXDataColumn = dataSourceCurve->xColumn();
+		if (dataSourceCurve)
+			tmpXDataColumn = dataSourceCurve->xColumn();
 	}
 
 	if (!tmpXDataColumn) {
@@ -2026,6 +2030,13 @@ void XYFitCurvePrivate::evaluate(bool preview) {
 		return;
 	}
 
+	if (fitData.model.simplified().isEmpty()) {
+		DEBUG(" no fit-model specified.");
+		recalcLogicalPoints();
+		emit q->dataChanged();
+		return;
+	}
+
 	ExpressionParser* parser = ExpressionParser::getInstance();
 	double xmin, xmax;
 	if (fitData.autoEvalRange) { // evaluate fit on full data range
@@ -2321,6 +2332,7 @@ bool XYFitCurve::load(XmlStreamReader* reader, bool preview) {
 				delete column;
 				return false;
 			}
+			DEBUG("############################   reading column " << column->name().toStdString())
 			if (column->name() == "x")
 				d->xColumn = column;
 			else if (column->name() == "y")
@@ -2386,6 +2398,8 @@ bool XYFitCurve::load(XmlStreamReader* reader, bool preview) {
 
 		XYCurve::d_ptr->xColumn = d->xColumn;
 		XYCurve::d_ptr->yColumn = d->yColumn;
+
+		recalcLogicalPoints();
 	}
 
 	return true;
