@@ -52,11 +52,11 @@ extern "C" {
 }
 
 XYSmoothCurve::XYSmoothCurve(const QString& name)
-	: XYAnalysisCurve(name, new XYSmoothCurvePrivate(this)) {
+	: XYAnalysisCurve(name, new XYSmoothCurvePrivate(this), AspectType::XYSmoothCurve) {
 }
 
 XYSmoothCurve::XYSmoothCurve(const QString& name, XYSmoothCurvePrivate* dd)
-	: XYAnalysisCurve(name, dd) {
+	: XYAnalysisCurve(name, dd, AspectType::XYSmoothCurve) {
 }
 
 //no need to delete the d-pointer here - it inherits from QGraphicsItem
@@ -372,10 +372,10 @@ bool XYSmoothCurve::load(XmlStreamReader* reader, bool preview) {
 		d->xVector = static_cast<QVector<double>* >(d->xColumn->data());
 		d->yVector = static_cast<QVector<double>* >(d->yColumn->data());
 
-		setUndoAware(false);
 		XYCurve::d_ptr->xColumn = d->xColumn;
 		XYCurve::d_ptr->yColumn = d->yColumn;
-		setUndoAware(true);
+
+		recalcLogicalPoints();
 	}
 
 	return true;
