@@ -56,6 +56,7 @@ public:
 	void setModel(AspectTreeModel*);
 	void setProject(Project*);
 	QModelIndex currentIndex() const;
+	void updateSelectedAspects();
 
 private:
 	void createActions();
@@ -87,6 +88,7 @@ private:
 	QPushButton* bFilterOptions;
 
 private slots:
+	void projectLoaded();
 	void aspectAdded(const AbstractAspect*);
 	void toggleColumn(int);
 	void showAllColumns();
