@@ -37,6 +37,7 @@
 #include <limits>
 
 #include <QMenu>
+#include <QMessageBox>
 #include <QToolBar>
 #include <QDesktopWidget>
 #include <QWheelEvent>
@@ -44,7 +45,7 @@
 #include <QSvgGenerator>
 #include <QImage>
 #include <QToolButton>
-#include <QApplication>
+#include <QTimeLine>
 
 #include <KLocalizedString>
 
@@ -77,7 +78,6 @@ DatapickerImageView::DatapickerImageView(DatapickerImage* image) : QGraphicsView
 
 	initActions();
 	initMenus();
-	selectAndEditModeAction->setChecked(true);
 	m_image->setSegmentsHoverEvent(true);
 	setInteractive(true);
 
@@ -96,11 +96,27 @@ DatapickerImageView::DatapickerImageView(DatapickerImage* image) : QGraphicsView
 
 	//signal/slot connections
 	//for general actions
-	connect( m_image, SIGNAL(requestProjectContextMenu(QMenu*)), this, SLOT(createContextMenu(QMenu*)) );
-	connect( m_image, SIGNAL(requestUpdate()), this, SLOT(updateBackground()) );
-	connect( m_image, SIGNAL(requestUpdateActions()), this, SLOT(handleImageActions()) );
-	connect( m_datapicker, SIGNAL(requestUpdateActions()), this, SLOT(handleImageActions()) );
-	connect( m_image, SIGNAL(rotationAngleChanged(float)), this, SLOT(changeRotationAngle()) );
+	connect(m_image, &DatapickerImage::requestProjectContextMenu, this, &DatapickerImageView::createContextMenu);
+	connect(m_image, &DatapickerImage::requestUpdate, this, &DatapickerImageView::updateBackground);
+	connect(m_image, &DatapickerImage::requestUpdateActions, this, &DatapickerImageView::handleImageActions);
+	connect(m_datapicker, &Datapicker::requestUpdateActions, this, &DatapickerImageView::handleImageActions);
+	connect(m_image, &DatapickerImage::rotationAngleChanged, this, &DatapickerImageView::changeRotationAngle);
+
+	//resize the view to make the complete scene visible.
+	//no need to resize the view when the project is being opened,
+	//all views will be resized to the stored values at the end
+	if (!m_image->isLoading()) {
+		float w = Worksheet::convertFromSceneUnits(sceneRect().width(), Worksheet::Inch);
+		float h = Worksheet::convertFromSceneUnits(sceneRect().height(), Worksheet::Inch);
+		w *= QApplication::desktop()->physicalDpiX();
+		h *= QApplication::desktop()->physicalDpiY();
+		resize(w*1.1, h*1.1);
+	}
+
+	//rescale to the original size
+	static const float hscale = QApplication::desktop()->physicalDpiX()/(Worksheet::convertToSceneUnits(1,Worksheet::Inch));
+	static const float vscale = QApplication::desktop()->physicalDpiY()/(Worksheet::convertToSceneUnits(1,Worksheet::Inch));
+	setTransform(QTransform::fromScale(hscale, vscale));
 }
 
 DatapickerImageView::~DatapickerImageView() {
@@ -110,7 +126,6 @@ DatapickerImageView::~DatapickerImageView() {
 void DatapickerImageView::initActions() {
 	auto* zoomActionGroup = new QActionGroup(this);
 	auto* mouseModeActionGroup = new QActionGroup(this);
-	auto* plotPointsTypeActionGroup = new QActionGroup(this);
 	navigationActionGroup = new QActionGroup(this);
 	magnificationActionGroup = new QActionGroup(this);
 
@@ -128,26 +143,25 @@ void DatapickerImageView::initActions() {
 	zoomFitPageWidthAction = new QAction(QIcon::fromTheme("zoom-fit-width"), i18n("Fit to Width"), zoomActionGroup);
 
 	// Mouse mode actions
-	selectAndEditModeAction = new QAction(QIcon::fromTheme("labplot-cursor-arrow"), i18n("Select and Edit"), mouseModeActionGroup);
-	selectAndEditModeAction->setCheckable(true);
-
 	navigationModeAction = new QAction(QIcon::fromTheme("input-mouse"), i18n("Navigate"), mouseModeActionGroup);
 	navigationModeAction->setCheckable(true);
+	navigationModeAction->setData(NavigationMode);
 
 	zoomSelectionModeAction = new QAction(QIcon::fromTheme("page-zoom"), i18n("Select and Zoom"), mouseModeActionGroup);
 	zoomSelectionModeAction->setCheckable(true);
+	zoomSelectionModeAction->setData(ZoomSelectionMode);
 
-	selectAndMoveModeAction = new QAction(QIcon::fromTheme("labplot-cursor-arrow"), i18n("Select and Move"), mouseModeActionGroup);
-	selectAndMoveModeAction->setCheckable(true);
-
-	setAxisPointsAction = new QAction(QIcon::fromTheme("labplot-plot-axis-points"), i18n("Set Axis Points"), plotPointsTypeActionGroup);
+	setAxisPointsAction = new QAction(QIcon::fromTheme("labplot-plot-axis-points"), i18n("Set Axis Points"), mouseModeActionGroup);
 	setAxisPointsAction->setCheckable(true);
+	setAxisPointsAction->setData(ReferencePointsEntryMode);
 
-	setCurvePointsAction = new QAction(QIcon::fromTheme("labplot-xy-curve-points"), i18n("Set Curve Points"), plotPointsTypeActionGroup);
+	setCurvePointsAction = new QAction(QIcon::fromTheme("labplot-xy-curve-points"), i18n("Set Curve Points"), mouseModeActionGroup);
 	setCurvePointsAction->setCheckable(true);
+	setCurvePointsAction->setData(CurvePointsEntryMode);
 
-	selectSegmentAction = new QAction(QIcon::fromTheme("labplot-xy-curve-segments"), i18n("Select Curve Segments"), plotPointsTypeActionGroup);
+	selectSegmentAction = new QAction(QIcon::fromTheme("labplot-xy-curve-segments"), i18n("Select Curve Segments"), mouseModeActionGroup);
 	selectSegmentAction->setCheckable(true);
+	selectSegmentAction->setData(CurveSegmentsEntryMode);
 
 	addCurveAction = new QAction(QIcon::fromTheme("labplot-xy-curve"), i18n("New Curve"), this);
 
@@ -179,26 +193,44 @@ void DatapickerImageView::initActions() {
 	fiveTimesMagnificationAction = new QAction(QIcon::fromTheme("labplot-5x-zoom"), i18n("5x Magnification"), magnificationActionGroup);
 	fiveTimesMagnificationAction->setCheckable(true);
 
-	connect( mouseModeActionGroup, SIGNAL(triggered(QAction*)), this, SLOT(mouseModeChanged(QAction*)) );
-	connect( zoomActionGroup, SIGNAL(triggered(QAction*)), this, SLOT(changeZoom(QAction*)) );
-	connect( plotPointsTypeActionGroup, SIGNAL(triggered(QAction*)), this, SLOT(changePointsType(QAction*)) );
-	connect( addCurveAction, SIGNAL(triggered()), this, SLOT(addCurve()) );
-	connect( navigationActionGroup, SIGNAL(triggered(QAction*)), this, SLOT(changeSelectedItemsPosition(QAction*)) );
-	connect( magnificationActionGroup, SIGNAL(triggered(QAction*)), this, SLOT(magnificationChanged(QAction*)) );
+	//set some default values
+	currentZoomAction = zoomInViewAction;
+	currentMagnificationAction = noMagnificationAction;
+
+	switch(m_image->plotPointsType()) {
+	case DatapickerImage::AxisPoints:
+		currentPlotPointsTypeAction = setAxisPointsAction;
+		setAxisPointsAction->setChecked(true);
+		mouseModeChanged(setAxisPointsAction);
+		break;
+	case DatapickerImage::CurvePoints:
+		currentPlotPointsTypeAction = setCurvePointsAction;
+		setCurvePointsAction->setChecked(true);
+		mouseModeChanged(setCurvePointsAction);
+		break;
+	case DatapickerImage::SegmentPoints:
+		currentPlotPointsTypeAction = selectSegmentAction;
+		selectSegmentAction->setChecked(true);
+		mouseModeChanged(selectSegmentAction);
+	}
+
+	//signal-slot connections
+	connect(mouseModeActionGroup, &QActionGroup::triggered, this, &DatapickerImageView::mouseModeChanged);
+	connect(zoomActionGroup, &QActionGroup::triggered, this, &DatapickerImageView::changeZoom);
+	connect(addCurveAction, &QAction::triggered, this, &DatapickerImageView::addCurve);
+	connect(navigationActionGroup, &QActionGroup::triggered, this, &DatapickerImageView::changeSelectedItemsPosition);
+	connect(magnificationActionGroup, &QActionGroup::triggered, this, &DatapickerImageView::magnificationChanged);
 }
 
 void DatapickerImageView::initMenus() {
 	m_viewMouseModeMenu = new QMenu(i18n("Mouse Mode"), this);
 	m_viewMouseModeMenu->setIcon(QIcon::fromTheme("input-mouse"));
-	m_viewMouseModeMenu->addAction(selectAndEditModeAction);
+	m_viewMouseModeMenu->addAction(setAxisPointsAction);
+	m_viewMouseModeMenu->addAction(setCurvePointsAction);
+	m_viewMouseModeMenu->addAction(selectSegmentAction);
+	m_viewMouseModeMenu->addSeparator();
 	m_viewMouseModeMenu->addAction(navigationModeAction);
 	m_viewMouseModeMenu->addAction(zoomSelectionModeAction);
-	m_viewMouseModeMenu->addAction(selectAndMoveModeAction);
-
-	m_viewImageMenu = new QMenu(i18n("Data Entry Mode"), this);
-	m_viewImageMenu->addAction(setAxisPointsAction);
-	m_viewImageMenu->addAction(setCurvePointsAction);
-	m_viewImageMenu->addAction(selectSegmentAction);
 
 	m_zoomMenu = new QMenu(i18n("Zoom View"), this);
 	m_zoomMenu->setIcon(QIcon::fromTheme("zoom-draw"));
@@ -215,7 +247,7 @@ void DatapickerImageView::initMenus() {
 	m_navigationMenu->addAction(shiftDownAction);
 
 	m_magnificationMenu = new QMenu(i18n("Magnification"), this);
-	m_magnificationMenu->setIcon(QIcon::fromTheme("labplot-zoom"));
+	m_magnificationMenu->setIcon(QIcon::fromTheme("zoom-in"));
 	m_magnificationMenu->addAction(noMagnificationAction);
 	m_magnificationMenu->addAction(twoTimesMagnificationAction);
 	m_magnificationMenu->addAction(threeTimesMagnificationAction);
@@ -240,8 +272,6 @@ void DatapickerImageView::createContextMenu(QMenu* menu) const {
 	if (menu->actions().size()>1)
 		firstAction = menu->actions().at(1);
 
-	menu->insertMenu(firstAction, m_viewImageMenu);
-	menu->insertSeparator(firstAction);
 	menu->insertAction(firstAction, addCurveAction);
 	menu->insertSeparator(firstAction);
 	menu->insertMenu(firstAction, m_navigationMenu);
@@ -257,34 +287,30 @@ void DatapickerImageView::fillToolBar(QToolBar* toolBar) {
 	toolBar->addAction(setAxisPointsAction);
 	toolBar->addAction(setCurvePointsAction);
 	toolBar->addAction(selectSegmentAction);
+	toolBar->addAction(navigationModeAction);
+	toolBar->addAction(zoomSelectionModeAction);
 
 	toolBar->addSeparator();
 	toolBar->addAction(addCurveAction);
 
-	toolBar->addSeparator();
-	toolBar->addAction(noMagnificationAction);
-	toolBar->addAction(twoTimesMagnificationAction);
-	toolBar->addAction(threeTimesMagnificationAction);
-	toolBar->addAction(fourTimesMagnificationAction);
-	toolBar->addAction(fiveTimesMagnificationAction);
-
 	toolBar->addSeparator();
 	toolBar->addAction(shiftRightAction);
 	toolBar->addAction(shiftLeftAction);
 	toolBar->addAction(shiftUpAction);
 	toolBar->addAction(shiftDownAction);
 
-	toolBar->addSeparator();
-	toolBar->addAction(selectAndEditModeAction);
-	toolBar->addAction(navigationModeAction);
-	toolBar->addAction(zoomSelectionModeAction);
-	toolBar->addAction(selectAndMoveModeAction);
-
 	tbZoom = new QToolButton(toolBar);
 	tbZoom->setPopupMode(QToolButton::MenuButtonPopup);
 	tbZoom->setMenu(m_zoomMenu);
 	tbZoom->setDefaultAction(currentZoomAction);
+	toolBar->addSeparator();
 	toolBar->addWidget(tbZoom);
+
+	tbMagnification = new QToolButton(toolBar);
+	tbMagnification->setPopupMode(QToolButton::MenuButtonPopup);
+	tbMagnification->setMenu(m_magnificationMenu);
+	tbMagnification->setDefaultAction(currentMagnificationAction);
+	toolBar->addWidget(tbMagnification);
 }
 
 void DatapickerImageView::setScene(QGraphicsScene* scene) {
@@ -313,17 +339,6 @@ void DatapickerImageView::drawBackground(QPainter* painter, const QRectF& rect)
 	if (!scene_rect.contains(rect))
 		painter->fillRect(rect, Qt::lightGray);
 
-	//shadow
-	int shadowSize = scene_rect.width()*0.02;
-	QRectF rightShadowRect(scene_rect.right(), scene_rect.top() + shadowSize,
-				shadowSize, scene_rect.height());
-	QRectF bottomShadowRect(scene_rect.left() + shadowSize, scene_rect.bottom(),
-				scene_rect.width(), shadowSize);
-
-	painter->fillRect(rightShadowRect.intersected(rect), Qt::darkGray);
-	painter->fillRect(bottomShadowRect.intersected(rect), Qt::darkGray);
-
-
 	// canvas
 	if (m_image->isLoaded) {
 		if (m_image->plotImageType() == DatapickerImage::OriginalImage) {
@@ -347,15 +362,40 @@ void DatapickerImageView::drawBackground(QPainter* painter, const QRectF& rect)
 //##############################################################################
 //####################################  Events   ###############################
 //##############################################################################
-void DatapickerImageView::wheelEvent(QWheelEvent *event) {
-	if (m_mouseMode == ZoomSelectionMode) {
-		if (event->delta() > 0)
-			scale(1.2, 1.2);
-		else if (event->delta() < 0)
-			scale(1.0/1.2, 1.0/1.2);
-	} else {
+void DatapickerImageView::wheelEvent(QWheelEvent* event) {
+	//https://wiki.qt.io/Smooth_Zoom_In_QGraphicsView
+	if (m_mouseMode == ZoomSelectionMode || (QApplication::keyboardModifiers() & Qt::ControlModifier)) {
+		int numDegrees = event->delta() / 8;
+		int numSteps = numDegrees / 15; // see QWheelEvent documentation
+		zoom(numSteps);
+	} else
 		QGraphicsView::wheelEvent(event);
-	}
+}
+
+void DatapickerImageView::zoom(int numSteps) {
+	m_numScheduledScalings += numSteps;
+	if (m_numScheduledScalings * numSteps < 0) // if user moved the wheel in another direction, we reset previously scheduled scalings
+		m_numScheduledScalings = numSteps;
+
+	auto* anim = new QTimeLine(350, this);
+	anim->setUpdateInterval(20);
+
+	connect(anim, &QTimeLine::valueChanged, this, &DatapickerImageView::scalingTime);
+	connect(anim, &QTimeLine::finished, this, &DatapickerImageView::animFinished);
+	anim->start();
+}
+
+void DatapickerImageView::scalingTime() {
+	qreal factor = 1.0 + qreal(m_numScheduledScalings) / 300.0;
+	scale(factor, factor);
+}
+
+void DatapickerImageView::animFinished() {
+	if (m_numScheduledScalings > 0)
+		m_numScheduledScalings--;
+	else
+		m_numScheduledScalings++;
+	sender()->~QObject();
 }
 
 void DatapickerImageView::mousePressEvent(QMouseEvent* event) {
@@ -373,7 +413,20 @@ void DatapickerImageView::mousePressEvent(QMouseEvent* event) {
 	}
 
 	QPointF eventPos = mapToScene(event->pos());
-	if ( m_mouseMode == SelectAndEditMode && m_image->isLoaded && sceneRect().contains(eventPos) ) {
+	bool entryMode = (m_mouseMode == ReferencePointsEntryMode
+					  || m_mouseMode == CurvePointsEntryMode || m_mouseMode == CurveSegmentsEntryMode);
+
+	//check whether there is a point item under the cursor
+	bool pointsUnderCursor = false;
+	auto items = this->items(event->pos());
+	for (auto* item : items) {
+		if (item != m_image->m_magnificationWindow) {
+			pointsUnderCursor = true;
+			break;
+		}
+	}
+
+	if (entryMode && !pointsUnderCursor && m_image->isLoaded && sceneRect().contains(eventPos)) {
 		if ( m_image->plotPointsType() == DatapickerImage::AxisPoints ) {
 			int childCount = m_image->childCount<DatapickerPoint>(AbstractAspect::IncludeHidden);
 			if (childCount < 3)
@@ -381,6 +434,9 @@ void DatapickerImageView::mousePressEvent(QMouseEvent* event) {
 		} else if ( m_image->plotPointsType() == DatapickerImage::CurvePoints && m_datapicker->activeCurve() ) {
 			m_datapicker->addNewPoint(eventPos, m_datapicker->activeCurve());
 		}
+
+		if (m_image->m_magnificationWindow && m_image->m_magnificationWindow->isVisible())
+			updateMagnificationWindow();
 	}
 
 	// make sure the datapicker (or its currently active curve) is selected in the project explorer if the view was clicked.
@@ -412,15 +468,6 @@ void DatapickerImageView::mouseReleaseEvent(QMouseEvent* event) {
 }
 
 void DatapickerImageView::mouseMoveEvent(QMouseEvent* event) {
-	if ( m_mouseMode == SelectAndEditMode || m_mouseMode == ZoomSelectionMode ) {
-		if (m_image->isLoaded)
-			setCursor(Qt::CrossCursor);
-		else
-			setCursor(Qt::ArrowCursor);
-	} else {
-		setCursor(Qt::ArrowCursor);
-	}
-
 	//show the selection band
 	if (m_selectionBandIsShown) {
 		QRect rect = QRect(m_selectionStart, m_selectionEnd).normalized();
@@ -461,7 +508,7 @@ void DatapickerImageView::mouseMoveEvent(QMouseEvent* event) {
 	}
 
 	//show the magnification window
-	if ( magnificationFactor && m_mouseMode == SelectAndEditMode && m_image->isLoaded && sceneRect().contains(pos)
+	if ( magnificationFactor && m_image->isLoaded && sceneRect().contains(pos)
 		&& m_image->plotPointsType() != DatapickerImage::SegmentPoints ) {
 
 		if (!m_image->m_magnificationWindow) {
@@ -471,28 +518,7 @@ void DatapickerImageView::mouseMoveEvent(QMouseEvent* event) {
 			m_image->m_magnificationWindow->setZValue(std::numeric_limits<int>::max());
 		}
 
-		m_image->m_magnificationWindow->setVisible(false);
-
-		//copy the part of the view to be shown magnified
-		const int size = Worksheet::convertToSceneUnits(2.0, Worksheet::Centimeter)/transform().m11();
-		const QRectF copyRect(pos.x() - size/(2*magnificationFactor), pos.y() - size/(2*magnificationFactor), size/magnificationFactor, size/magnificationFactor);
-		QPixmap px = QPixmap::grabWidget(this, mapFromScene(copyRect).boundingRect());
-		px = px.scaled(size, size, Qt::IgnoreAspectRatio, Qt::SmoothTransformation);
-
-		//draw the bounding rect
-		QPainter painter(&px);
-		const QPen pen = QPen(Qt::lightGray, 2/transform().m11());
-		painter.setPen(pen);
-		QRect rect = px.rect();
-		rect.setWidth(rect.width()-pen.widthF()/2);
-		rect.setHeight(rect.height()-pen.widthF()/2);
-		painter.drawRect(rect);
-
-		//set the pixmap
-		m_image->m_magnificationWindow->setPixmap(px);
-		m_image->m_magnificationWindow->setPos(pos.x()- px.width()/2, pos.y()- px.height()/2);
-
-		m_image->m_magnificationWindow->setVisible(true);
+		updateMagnificationWindow();
 	} else if (m_image->m_magnificationWindow) {
 		m_image->m_magnificationWindow->setVisible(false);
 	}
@@ -500,6 +526,32 @@ void DatapickerImageView::mouseMoveEvent(QMouseEvent* event) {
 	QGraphicsView::mouseMoveEvent(event);
 }
 
+void DatapickerImageView::updateMagnificationWindow() {
+	m_image->m_magnificationWindow->setVisible(false);
+	QPointF pos = mapToScene(mapFromGlobal(QCursor::pos()));
+
+	//copy the part of the view to be shown magnified
+	const int size = Worksheet::convertToSceneUnits(2.0, Worksheet::Centimeter)/transform().m11();
+	const QRectF copyRect(pos.x() - size/(2*magnificationFactor), pos.y() - size/(2*magnificationFactor), size/magnificationFactor, size/magnificationFactor);
+	QPixmap px = grab(mapFromScene(copyRect).boundingRect());
+	px = px.scaled(size, size, Qt::IgnoreAspectRatio, Qt::SmoothTransformation);
+
+	//draw the bounding rect
+	QPainter painter(&px);
+	const QPen pen = QPen(Qt::lightGray, 2/transform().m11());
+	painter.setPen(pen);
+	QRect rect = px.rect();
+	rect.setWidth(rect.width()-pen.widthF()/2);
+	rect.setHeight(rect.height()-pen.widthF()/2);
+	painter.drawRect(rect);
+
+	//set the pixmap
+	m_image->m_magnificationWindow->setPixmap(px);
+	m_image->m_magnificationWindow->setPos(pos.x()- px.width()/2, pos.y()- px.height()/2);
+
+	m_image->m_magnificationWindow->setVisible(true);
+}
+
 void DatapickerImageView::contextMenuEvent(QContextMenuEvent* e) {
 	Q_UNUSED(e);
 	//no need to propagate the event to the scene and graphics items
@@ -511,21 +563,53 @@ void DatapickerImageView::contextMenuEvent(QContextMenuEvent* e) {
 //##############################################################################
 //####################################  SLOTs   ###############################
 //##############################################################################
-void DatapickerImageView::changePointsType(QAction* action) {
-	if (action == setAxisPointsAction)
-		m_image->setPlotPointsType(DatapickerImage::AxisPoints);
-	else if (action == setCurvePointsAction)
-		m_image->setPlotPointsType(DatapickerImage::CurvePoints);
-	else if (action == selectSegmentAction)
-		m_image->setPlotPointsType(DatapickerImage::SegmentPoints);
+void DatapickerImageView::mouseModeChanged(QAction* action) {
+	m_mouseMode = (DatapickerImageView::MouseMode)action->data().toInt();
+
+	if (action == navigationModeAction) {
+		setInteractive(false);
+		setDragMode(QGraphicsView::ScrollHandDrag);
+		m_image->setSegmentsHoverEvent(false);
+	} else if (action == zoomSelectionModeAction){
+		setInteractive(false);
+		setDragMode(QGraphicsView::NoDrag);
+		m_image->setSegmentsHoverEvent(false);
+		setCursor(Qt::ArrowCursor);
+	} else {
+		setInteractive(true);
+		setDragMode(QGraphicsView::NoDrag);
+		m_image->setSegmentsHoverEvent(true);
+		setCursor(Qt::CrossCursor);
+
+		if (currentPlotPointsTypeAction != action) {
+			if (action == setAxisPointsAction) {
+				int count = m_image->childCount<DatapickerPoint>(AbstractAspect::IncludeHidden);
+				if (count) {
+					auto button = QMessageBox::question(this, i18n("Remove existing reference points?"),
+														i18n("All available reference points will be removed. Do you want to continue?"));
+					if (button != QMessageBox::Yes) {
+						currentPlotPointsTypeAction->setChecked(true);
+						return;
+					}
+				}
+
+				m_image->setPlotPointsType(DatapickerImage::AxisPoints);
+			} else if (action == setCurvePointsAction)
+				m_image->setPlotPointsType(DatapickerImage::CurvePoints);
+			else if (action == selectSegmentAction)
+				m_image->setPlotPointsType(DatapickerImage::SegmentPoints);
+
+			currentPlotPointsTypeAction = action;
+		}
+	}
 }
 
 void DatapickerImageView::changeZoom(QAction* action) {
-	if (action == zoomInViewAction) {
-		scale(1.2, 1.2);
-	} else if (action == zoomOutViewAction) {
-		scale(1.0/1.2, 1.0/1.2);
-	} else if (action == zoomOriginAction) {
+	if (action == zoomInViewAction)
+		zoom(1);
+	else if (action == zoomOutViewAction)
+		zoom(-1);
+	else if (action == zoomOriginAction) {
 		static const float hscale = QApplication::desktop()->physicalDpiX()/(25.4*Worksheet::convertToSceneUnits(1,Worksheet::Millimeter));
 		static const float vscale = QApplication::desktop()->physicalDpiY()/(25.4*Worksheet::convertToSceneUnits(1,Worksheet::Millimeter));
 		setTransform(QTransform::fromScale(hscale, vscale));
@@ -594,30 +678,8 @@ void DatapickerImageView::changeSelectedItemsPosition(QAction* action) {
 	}
 
 	m_image->endMacro();
-}
-
-void DatapickerImageView::mouseModeChanged(QAction* action) {
-	if (action == selectAndEditModeAction) {
-		m_mouseMode = SelectAndEditMode;
-		setInteractive(true);
-		setDragMode(QGraphicsView::NoDrag);
-		m_image->setSegmentsHoverEvent(true);
-	} else if (action == navigationModeAction) {
-		m_mouseMode = NavigationMode;
-		setInteractive(false);
-		setDragMode(QGraphicsView::ScrollHandDrag);
-		m_image->setSegmentsHoverEvent(false);
-	} else if (action == zoomSelectionModeAction) {
-		m_mouseMode = ZoomSelectionMode;
-		setInteractive(false);
-		setDragMode(QGraphicsView::NoDrag);
-		m_image->setSegmentsHoverEvent(false);
-	} else {
-		m_mouseMode = SelectAndMoveMode;
-		setInteractive(true);
-		setDragMode(QGraphicsView::NoDrag);
-		m_image->setSegmentsHoverEvent(false);
-	}
+	if (m_image->m_magnificationWindow && m_image->m_magnificationWindow->isVisible())
+		updateMagnificationWindow();
 }
 
 void DatapickerImageView::magnificationChanged(QAction* action) {
@@ -639,6 +701,9 @@ void DatapickerImageView::addCurve() {
 	curve->addDatasheet(m_image->axisPoints().type);
 	m_datapicker->addChild(curve);
 	m_datapicker->endMacro();
+
+	setCurvePointsAction->setChecked(true);
+	mouseModeChanged(setCurvePointsAction);
 }
 
 void DatapickerImageView::changeRotationAngle() {
@@ -672,11 +737,6 @@ void DatapickerImageView::handleImageActions() {
 			addCurveAction->setEnabled(false);
 			setCurvePointsAction->setEnabled(false);
 			selectSegmentAction->setEnabled(false);
-			if (m_image->plotPointsType() != DatapickerImage::AxisPoints) {
-				m_image->setUndoAware(false);
-				m_image->setPlotPointsType(DatapickerImage::AxisPoints);
-				m_image->setUndoAware(true);
-			}
 		}
 	} else {
 		navigationActionGroup->setEnabled(false);
