@@ -4,7 +4,7 @@
     Description          : View class for Matrix
     --------------------------------------------------------------------
     Copyright            : (C) 2008-2009 Tilman Benkert (thzs@gmx.net)
-    Copyright            : (C) 2015 Alexander Semke (alexander.semke@web.de)
+    Copyright            : (C) 2015-2019 Alexander Semke (alexander.semke@web.de)
     Copyright            : (C) 2017 Stefan Gerlach (stefan.gerlach@uni.kn)
 
  ***************************************************************************/
@@ -45,7 +45,6 @@
 #include <QStackedWidget>
 #include <QTableView>
 #include <QKeyEvent>
-#include <QShortcut>
 #include <QMenu>
 #include <QPainter>
 #include <QPrinter>
@@ -133,7 +132,7 @@ void MatrixView::init() {
 	connect(m_model, SIGNAL(changed()), this, SLOT(matrixDataChanged()));
 
 	//keyboard shortcuts
-	QShortcut* sel_all = new QShortcut(QKeySequence(tr("Ctrl+A", "Matrix: select all")), m_tableView);
+	sel_all = new QShortcut(QKeySequence(tr("Ctrl+A", "Matrix: select all")), m_tableView);
 	connect(sel_all, SIGNAL(activated()), m_tableView, SLOT(selectAll()));
 
 	//TODO: add shortcuts for copy&paste,
@@ -212,7 +211,6 @@ void MatrixView::modifyValues() {
 	dlg->exec();
 }
 
-
 void MatrixView::connectActions() {
 	// selection related actions
 	connect(action_cut_selection, SIGNAL(triggered()), this, SLOT(cutSelection()));
@@ -254,6 +252,7 @@ void MatrixView::connectActions() {
 void MatrixView::initMenus() {
 	//selection menu
 	m_selectionMenu = new QMenu(i18n("Selection"), this);
+	m_selectionMenu->setIcon(QIcon::fromTheme("selection"));
 	m_selectionMenu->addAction(action_cut_selection);
 	m_selectionMenu->addAction(action_copy_selection);
 	m_selectionMenu->addAction(action_paste_into_selection);
@@ -301,17 +300,18 @@ void MatrixView::initMenus() {
 	m_matrixMenu->addSeparator();
 
 	submenu = new QMenu(i18n("View"), this);
+	submenu->setIcon(QIcon::fromTheme("view-choose"));
 	submenu->addAction(action_data_view);
 	submenu->addAction(action_image_view);
 	m_matrixMenu->addMenu(submenu);
 	m_matrixMenu->addSeparator();
 
-
 	m_matrixMenu->addAction(action_select_all);
 	m_matrixMenu->addAction(action_clear_matrix);
 	m_matrixMenu->addSeparator();
 
 	m_headerFormatMenu = new QMenu(i18n("Header Format"), this);
+	m_headerFormatMenu->setIcon(QIcon::fromTheme("format-border-style"));
 	m_headerFormatMenu->addAction(action_header_format_1);
 	m_headerFormatMenu->addAction(action_header_format_2);
 	m_headerFormatMenu->addAction(action_header_format_3);
@@ -347,7 +347,6 @@ void MatrixView::createContextMenu(QMenu* menu) const {
 	menu->insertMenu(firstAction, submenu);
 	menu->insertSeparator(firstAction);
 
-
 	// Data manipulation sub-menu
 	submenu = new QMenu(i18n("Manipulate Data"), const_cast<MatrixView*>(this));
 	submenu->addAction(action_transpose);
@@ -764,7 +763,6 @@ void MatrixView::clearSelectedCells() {
 	RESET_CURSOR;
 }
 
-
 class UpdateImageTask : public QRunnable {
 public:
 	UpdateImageTask(int start, int end, QImage& image, const void* data, double scaleFactor, double min) : m_image(image), m_data(data) {
@@ -1029,7 +1027,6 @@ void MatrixView::print(QPrinter* printer) const {
 	if (remainingColumns > 0)
 		tablesCount++;
 	for (int table = 0; table < tablesCount; ++table) {
-		right = margin + vertHeaderWidth;
 		//Paint the horizontal header first
 		painter.setFont(hHeader->font());
 		QString headerString = m_tableView->model()->headerData(0, Qt::Horizontal).toString();
@@ -1522,3 +1519,10 @@ void MatrixView::exportToFits(const QString &fileName, const int exportTo) const
 	delete filter;
 }
 
+void MatrixView::registerShortcuts() {
+	action_clear_selection ->setShortcut(QKeySequence::Delete);
+}
+
+void MatrixView::unregisterShortcuts() {
+	action_clear_selection->setShortcut(QKeySequence());
+}
