@@ -49,7 +49,7 @@ SpreadsheetItemDelegate::SpreadsheetItemDelegate(QObject* parent)  : QItemDelega
 }
 
 void SpreadsheetItemDelegate::paint(QPainter *painter, const QStyleOptionViewItem &option,
-                                    const QModelIndex &index) const {
+		const QModelIndex &index) const {
 
 	QItemDelegate::paint(painter, option, index);
 	if (!index.data(SpreadsheetModel::MaskingRole).toBool())
@@ -84,7 +84,7 @@ void SpreadsheetItemDelegate::setEditorData ( QWidget * editor, const QModelInde
 
  bool SpreadsheetItemDelegate::eventFilter(QObject* editor, QEvent* event) {
 	if (event->type() == QEvent::KeyPress) {
-		QKeyEvent* keyEvent = static_cast<QKeyEvent*>(event);
+		auto* keyEvent = static_cast<QKeyEvent*>(event);
 		if (keyEvent->key() == Qt::Key_Return || keyEvent->key() == Qt::Key_Enter) {
 			emit commitData((QWidget*)editor);
 			emit closeEditor((QWidget*)editor, QAbstractItemDelegate::EditNextItem);
