@@ -36,6 +36,8 @@ class QGroupBox;
 class QLineEdit;
 class QTreeView;
 
+enum class AspectType : quint64;
+
 class TreeViewComboBox : public QComboBox {
 	Q_OBJECT
 
@@ -46,18 +48,26 @@ public:
 	void setCurrentModelIndex(const QModelIndex&);
 	QModelIndex currentModelIndex() const;
 
-	void setTopLevelClasses(const QList<const char *> &);
+	void setTopLevelClasses(const QList<AspectType>&);
 	void setHiddenAspects(const QList<const AbstractAspect*>&);
 
 	void showPopup() override;
 	void hidePopup() override;
+	void setInvalid(bool invalid, QString tooltip = QString());
+
+	void useCurrentIndexText(const bool set);
+
+	QString currentText() const;
+	void setText(QString text);
 
 private:
 	QTreeView* m_treeView;
 	QGroupBox* m_groupBox;
 	QLineEdit* m_lineEdit;
+	QString m_lineEditText{""};
+	bool m_useCurrentIndexText{true};
 
-	QList<const char*> m_topLevelClasses;
+	QList<AspectType> m_topLevelClasses;
 	QList<const char*> m_selectableClasses;
 	QList<const AbstractAspect*> m_hiddenAspects;
 
@@ -67,6 +77,8 @@ private:
 	bool isTopLevel(const AbstractAspect*) const;
 	bool isHidden(const AbstractAspect*) const;
 
+	void paintEvent(QPaintEvent *) override;
+
 private slots:
 	void treeViewIndexActivated(const QModelIndex&);
 	void filterChanged(const QString&);
