@@ -3,7 +3,7 @@
     Project              : LabPlot
     Description          : Worksheet view
     --------------------------------------------------------------------
-    Copyright            : (C) 2009-2016 by Alexander Semke (alexander.semke@web.de)
+    Copyright            : (C) 2009-2019 by Alexander Semke (alexander.semke@web.de)
     Copyright            : (C) 2018 by Stefan Gerlach (stefan.gerlach@uni.kn)
 
  ***************************************************************************/
@@ -62,17 +62,23 @@ public:
 		double opacity;
 	};
 
+	enum MouseMode {SelectionMode, NavigationMode, ZoomSelectionMode};
+
 	void setScene(QGraphicsScene*);
 	void exportToFile(const QString&, const ExportFormat, const ExportArea, const bool, const int);
 	void exportToClipboard();
 	void setIsClosing();
 	void setIsBeingPresented(bool presenting);
 	void setCartesianPlotActionMode(Worksheet::CartesianPlotActionMode mode);
+	void setCartesianPlotCursorMode(Worksheet::CartesianPlotActionMode mode);
 	void setPlotLock(bool lock);
 
-private:
-	enum MouseMode {SelectionMode, NavigationMode, ZoomSelectionMode};
+	Worksheet::CartesianPlotActionMode getCartesianPlotActionMode();
+	void registerShortcuts();
+	void unregisterShortcuts();
 
+private:
+	void initBasicActions();
 	void initActions();
 	void initMenus();
 	void processResize();
@@ -99,7 +105,6 @@ private:
 
 	Worksheet* m_worksheet;
 	MouseMode m_mouseMode{SelectionMode};
-	Worksheet::CartesianPlotActionMode m_cartesianPlotActionMode{Worksheet::CartesianPlotActionMode::ApplyActionToSelection};
 	CartesianPlot::MouseMode m_cartesianPlotMouseMode{CartesianPlot::SelectionMode};
 	bool m_selectionBandIsShown{false};
 	QPoint m_selectionStart;
@@ -113,9 +118,10 @@ private:
 	QTimeLine* m_fadeInTimeLine{nullptr};
 	QTimeLine* m_fadeOutTimeLine{nullptr};
 	bool m_isClosing{false};
+	bool m_actionsInitialized{false};
 	bool m_menusInitialized{false};
-	bool m_ctrlPressed{false};
 	int m_numScheduledScalings{0};
+	bool m_suppressMouseModeChange{false};
 
 	//Menus
 	QMenu* m_addNewMenu{nullptr};
@@ -129,116 +135,122 @@ private:
 	QMenu* m_cartesianPlotMenu{nullptr};
 	QMenu* m_cartesianPlotMouseModeMenu{nullptr};
 	QMenu* m_cartesianPlotAddNewMenu{nullptr};
+	QMenu* m_cartesianPlotAddNewAnalysisMenu{nullptr};
 	QMenu* m_cartesianPlotZoomMenu{nullptr};
 	QMenu* m_cartesianPlotActionModeMenu{nullptr};
+	QMenu* m_cartesianPlotCursorModeMenu{nullptr};
 	QMenu* m_dataManipulationMenu{nullptr};
 
 	QToolButton* tbNewCartesianPlot{nullptr};
 	QToolButton* tbZoom{nullptr};
 	QToolButton* tbMagnification{nullptr};
-	QAction* currentZoomAction;
-	QAction* currentMagnificationAction;
+	QAction* currentZoomAction{nullptr};
+	QAction* currentMagnificationAction{nullptr};
 
 	//Actions
-	QAction* selectAllAction;
-	QAction* deleteAction;
-	QAction* backspaceAction;
+	QAction* selectAllAction{nullptr};
+	QAction* deleteAction{nullptr};
+	QAction* backspaceAction{nullptr};
 
-	QAction* zoomInViewAction;
-	QAction* zoomOutViewAction;
-	QAction* zoomOriginAction;
-	QAction* zoomFitPageHeightAction;
-	QAction* zoomFitPageWidthAction;
-	QAction* zoomFitSelectionAction;
+	QAction* zoomInViewAction{nullptr};
+	QAction* zoomOutViewAction{nullptr};
+	QAction* zoomOriginAction{nullptr};
+	QAction* zoomFitPageHeightAction{nullptr};
+	QAction* zoomFitPageWidthAction{nullptr};
+	QAction* zoomFitSelectionAction{nullptr};
 
-	QAction* navigationModeAction;
-	QAction* zoomSelectionModeAction;
-	QAction* selectionModeAction;
+	QAction* navigationModeAction{nullptr};
+	QAction* zoomSelectionModeAction{nullptr};
+	QAction* selectionModeAction{nullptr};
 
-	QAction* addCartesianPlot1Action;
-	QAction* addCartesianPlot2Action;
-	QAction* addCartesianPlot3Action;
-	QAction* addCartesianPlot4Action;
-	QAction* addTextLabelAction;
-	QAction* addHistogram;
-	QAction* addBarChartPlot;
+	QAction* addCartesianPlot1Action{nullptr};
+	QAction* addCartesianPlot2Action{nullptr};
+	QAction* addCartesianPlot3Action{nullptr};
+	QAction* addCartesianPlot4Action{nullptr};
+	QAction* addTextLabelAction{nullptr};
+	QAction* addHistogram{nullptr};
+	QAction* addBarChartPlot{nullptr};
 
-	QAction* verticalLayoutAction;
-	QAction* horizontalLayoutAction;
-	QAction* gridLayoutAction;
-	QAction* breakLayoutAction;
+	QAction* verticalLayoutAction{nullptr};
+	QAction* horizontalLayoutAction{nullptr};
+	QAction* gridLayoutAction{nullptr};
+	QAction* breakLayoutAction{nullptr};
 
-	QAction* noGridAction;
-	QAction* denseLineGridAction;
-	QAction* sparseLineGridAction;
-	QAction* denseDotGridAction;
-	QAction* sparseDotGridAction;
-	QAction* customGridAction;
-	QAction* snapToGridAction;
+	QAction* noGridAction{nullptr};
+	QAction* denseLineGridAction{nullptr};
+	QAction* sparseLineGridAction{nullptr};
+	QAction* denseDotGridAction{nullptr};
+	QAction* sparseDotGridAction{nullptr};
+	QAction* customGridAction{nullptr};
+	QAction* snapToGridAction{nullptr};
 
-	QAction* noMagnificationAction;
-	QAction* twoTimesMagnificationAction;
-	QAction* threeTimesMagnificationAction;
-	QAction* fourTimesMagnificationAction;
-	QAction* fiveTimesMagnificationAction;
+	QAction* noMagnificationAction{nullptr};
+	QAction* twoTimesMagnificationAction{nullptr};
+	QAction* threeTimesMagnificationAction{nullptr};
+	QAction* fourTimesMagnificationAction{nullptr};
+	QAction* fiveTimesMagnificationAction{nullptr};
 
-	QAction* plotsLockedAction;
-	QAction* showPresenterMode;
+	QAction* plotsLockedAction{nullptr};
+	QAction* showPresenterMode{nullptr};
 
 	//Actions for cartesian plots
-	QAction* cartesianPlotApplyToSelectionAction;
-	QAction* cartesianPlotApplyToAllAction;
-	QAction* cartesianPlotSelectionModeAction;
-	QAction* cartesianPlotZoomSelectionModeAction;
-	QAction* cartesianPlotZoomXSelectionModeAction;
-	QAction* cartesianPlotZoomYSelectionModeAction;
+	QAction* cartesianPlotApplyToSelectionAction{nullptr};
+	QAction* cartesianPlotApplyToAllAction{nullptr};
+	QAction* cartesianPlotApplyToAllCursor{nullptr};
+	QAction* cartesianPlotApplyToSelectionCursor{nullptr};
+	QAction* cartesianPlotSelectionModeAction{nullptr};
+	QAction* cartesianPlotZoomSelectionModeAction{nullptr};
+	QAction* cartesianPlotZoomXSelectionModeAction{nullptr};
+	QAction* cartesianPlotZoomYSelectionModeAction{nullptr};
+	QAction* cartesianPlotCursorModeAction{nullptr};
 
-	QAction* addCurveAction;
-	QAction* addHistogramAction;
-	QAction* addEquationCurveAction;
-	QAction* addDataOperationCurveAction;
-	QAction* addDataReductionCurveAction;
-	QAction* addDifferentiationCurveAction;
-	QAction* addIntegrationCurveAction;
-	QAction* addInterpolationCurveAction;
-	QAction* addSmoothCurveAction;
-	QAction* addFitCurveAction;
-	QAction* addFourierFilterCurveAction;
-	QAction* addFourierTransformCurveAction;
-	QAction* addConvolutionCurveAction;
-	QAction* addCorrelationCurveAction;
+	QAction* addCurveAction{nullptr};
+	QAction* addHistogramAction{nullptr};
+	QAction* addEquationCurveAction{nullptr};
+	QAction* addDataOperationCurveAction{nullptr};
+	QAction* addDataReductionCurveAction{nullptr};
+	QAction* addDifferentiationCurveAction{nullptr};
+	QAction* addIntegrationCurveAction{nullptr};
+	QAction* addInterpolationCurveAction{nullptr};
+	QAction* addSmoothCurveAction{nullptr};
+	QAction* addFitCurveAction{nullptr};
+	QAction* addFourierFilterCurveAction{nullptr};
+	QAction* addFourierTransformCurveAction{nullptr};
+	QAction* addConvolutionCurveAction{nullptr};
+	QAction* addCorrelationCurveAction{nullptr};
 
-	QAction* addHorizontalAxisAction;
-	QAction* addVerticalAxisAction;
-	QAction* addLegendAction;
-	QAction* addCustomPointAction;
+	QAction* addHorizontalAxisAction{nullptr};
+	QAction* addVerticalAxisAction{nullptr};
+	QAction* addLegendAction{nullptr};
+	QAction* addPlotTextLabelAction{nullptr};
+	QAction* addCustomPointAction{nullptr};
 
-	QAction* scaleAutoXAction;
-	QAction* scaleAutoYAction;
-	QAction* scaleAutoAction;
-	QAction* zoomInAction;
-	QAction* zoomOutAction;
-	QAction* zoomInXAction;
-	QAction* zoomOutXAction;
-	QAction* zoomInYAction;
-	QAction* zoomOutYAction;
-	QAction* shiftLeftXAction;
-	QAction* shiftRightXAction;
-	QAction* shiftUpYAction;
-	QAction* shiftDownYAction;
+	QAction* scaleAutoXAction{nullptr};
+	QAction* scaleAutoYAction{nullptr};
+	QAction* scaleAutoAction{nullptr};
+	QAction* zoomInAction{nullptr};
+	QAction* zoomOutAction{nullptr};
+	QAction* zoomInXAction{nullptr};
+	QAction* zoomOutXAction{nullptr};
+	QAction* zoomInYAction{nullptr};
+	QAction* zoomOutYAction{nullptr};
+	QAction* shiftLeftXAction{nullptr};
+	QAction* shiftRightXAction{nullptr};
+	QAction* shiftUpYAction{nullptr};
+	QAction* shiftDownYAction{nullptr};
 
 	// Analysis menu
-	QAction* addDataOperationAction;
-	QAction* addDataReductionAction;
-	QAction* addDifferentiationAction;
-	QAction* addIntegrationAction;
-	QAction* addInterpolationAction;
-	QAction* addSmoothAction;
-	QAction* addFitAction;
-	QAction* addFourierFilterAction;
-	QAction* addFourierTransformAction;
-	QAction* addConvolutionAction;
-	QAction* addCorrelationAction;
+	QAction* addDataOperationAction{nullptr};
+	QAction* addDataReductionAction{nullptr};
+	QAction* addDifferentiationAction{nullptr};
+	QAction* addIntegrationAction{nullptr};
+	QAction* addInterpolationAction{nullptr};
+	QAction* addSmoothAction{nullptr};
+	QAction* addFitAction{nullptr};
+	QAction* addFourierFilterAction{nullptr};
+	QAction* addFourierTransformAction{nullptr};
+	QAction* addConvolutionAction{nullptr};
+	QAction* addCorrelationAction{nullptr};
 
 public slots:
 	void createContextMenu(QMenu*);
@@ -248,6 +260,7 @@ public slots:
 	void print(QPrinter*);
 	void selectItem(QGraphicsItem*);
 	void presenterMode();
+	void cartesianPlotMouseModeChangedSlot(CartesianPlot::MouseMode mouseMode); // from cartesian Plot
 
 private slots:
 	void addNew(QAction*);
@@ -278,6 +291,7 @@ private slots:
 
 	//SLOTs for cartesian plots
 	void cartesianPlotActionModeChanged(QAction*);
+	void cartesianPlotCursorModeChanged(QAction*);
 	void cartesianPlotMouseModeChanged(QAction*);
 	void cartesianPlotNavigationChanged(QAction*);
 	void cartesianPlotAddNew(QAction*);
