@@ -56,12 +56,13 @@ int main (int argc, char *argv[]) {
 	KLocalizedString::setApplicationDomain("labplot2");
 	KCrash::initialize();
 
-	KAboutData aboutData( QStringLiteral("labplot2"), QString("labplot2"),
+	KAboutData aboutData( QStringLiteral("labplot2"), QString("LabPlot"),
 		LVERSION, i18n("LabPlot2 is a KDE-application for interactive graphing and analysis of scientific data."),
 		KAboutLicense::GPL,i18n("(c) 2007-2019"), QString(), QStringLiteral("https://labplot.kde.org"));
 	aboutData.addAuthor(i18n("Stefan Gerlach"), i18nc("@info:credit", "Developer"), "stefan.gerlach@uni.kn", nullptr);
 	aboutData.addAuthor(i18n("Alexander Semke"), i18nc("@info:credit", "Developer"), "alexander.semke@web.de", nullptr);
 	aboutData.addAuthor(i18n("Fábián Kristóf-Szabolcs"), i18nc("@info:credit", "Developer"), "f-kristof@hotmail.com", nullptr);
+	aboutData.addAuthor(i18n("Martin Marmsoler"), i18nc("@info:credit", "Developer"), "martin.marmsoler@gmail.com", nullptr);
 	aboutData.addAuthor(i18n("Andreas Kainz"), i18nc("@info:credit", "Icon designer"), "kainz.a@gmail.com", nullptr);
 	aboutData.addCredit(i18n("Yuri Chornoivan"), i18nc("@info:credit", "Help on many questions about the KDE-infrastructure and translation related topics"), "yurchor@ukr.net", nullptr);
 	aboutData.addCredit(i18n("Garvit Khatri"), i18nc("@info:credit", "Porting LabPlot2 to KF5 and Integration with Cantor"), "garvitdelhi@gmail.com", nullptr);
@@ -114,11 +115,6 @@ int main (int argc, char *argv[]) {
 		splash->show();
 	}
 
-	// debugging paths
-	QStringList appdatapaths = QStandardPaths::standardLocations(QStandardPaths::AppDataLocation);
-	QDEBUG("AppDataLocation paths = " << appdatapaths);
-	QDEBUG("Icon theme search paths = " << QIcon::themeSearchPaths());
-
 	// needed in order to have the signals triggered by SignallingUndoCommand
 	//TODO: redesign/remove this
 	qRegisterMetaType<const AbstractAspect*>("const AbstractAspect*");
@@ -131,6 +127,20 @@ int main (int argc, char *argv[]) {
 		freopen("CONOUT$", "w", stderr);
 	}
 #endif
+	DEBUG("DEBUG debugging enabled")
+	QDEBUG("QDEBUG debugging enabled")
+
+	// debugging paths
+	QStringList appdatapaths = QStandardPaths::standardLocations(QStandardPaths::AppDataLocation);
+	DEBUG("AppDataLocation paths:")
+	for (const QString &path: appdatapaths)
+		DEBUG("	" << path.toStdString());
+	DEBUG("Icon theme search paths:")
+	for (const QString &path: QIcon::themeSearchPaths())
+		DEBUG("	" << path.toStdString());
+	DEBUG("Library search paths:")
+	for (const QString &path: QCoreApplication::libraryPaths())
+		DEBUG("	" << path.toStdString());
 
 	KConfigGroup generalGlobalsGroup = KSharedConfig::openConfig(QLatin1String("kdeglobals"))->group("General");
 	QString defaultSchemeName = generalGlobalsGroup.readEntry("ColorScheme", QStringLiteral("Breeze"));
