@@ -46,6 +46,7 @@
 #include "backend/datapicker/Datapicker.h"
 #include "backend/note/Note.h"
 #include "backend/lib/macros.h"
+#include "backend/worksheet/plots/cartesian/CartesianPlot.h"
 
 #ifdef HAVE_MQTT
 #include "backend/datasources/MQTTClient.h"
@@ -67,6 +68,7 @@
 #include "kdefrontend/datasources/ImportFileDialog.h"
 #include "kdefrontend/datasources/ImportProjectDialog.h"
 #include "kdefrontend/datasources/ImportSQLDatabaseDialog.h"
+#include <kdefrontend/dockwidgets/CursorDock.h>
 #include "kdefrontend/dockwidgets/ProjectDock.h"
 #include "kdefrontend/HistoryDialog.h"
 #include "kdefrontend/SettingsDialog.h"
@@ -84,6 +86,7 @@
 #include <QElapsedTimer>
 #include <QHash>
 #include <QStatusBar>
+#include <QTemporaryFile>
 #include <QTimeLine>
 
 #include <KActionCollection>
@@ -144,7 +147,7 @@ MainWin::~MainWin() {
 }
 
 void MainWin::showPresenter() {
-	Worksheet* w = activeWorksheet();
+	const Worksheet* w = dynamic_cast<Worksheet*>(m_currentAspect);
 	if (w) {
 		auto* view = dynamic_cast<WorksheetView*>(w->view());
 		view->presenterMode();
@@ -183,7 +186,7 @@ void MainWin::initGUI(const QString& fileName) {
 #else
 	setupGUI(Default, KXMLGUIClient::xmlFile());	// should be "labplot2ui.rc"
 #endif
-	DEBUG("component name: " << KXMLGUIClient::componentName().toStdString());
+	DEBUG("Component name: " << KXMLGUIClient::componentName().toStdString());
 	DEBUG("XML file: " << KXMLGUIClient::xmlFile().toStdString() << " (should be \"labplot2ui.rc\")");
 
 	//all toolbars created via the KXMLGUI framework are locked on default:
@@ -281,7 +284,7 @@ void MainWin::initGUI(const QString& fileName) {
 			newWorksheet();
 		} else if (load == 3) { //open last used project
 			if (!m_recentProjectsAction->urls().isEmpty()) {
-				QDEBUG("TO OPEN m_recentProjectsAction->urls() =" << m_recentProjectsAction->urls().first());
+				QDEBUG("TO OPEN m_recentProjectsAction->urls() =" << m_recentProjectsAction->urls().constFirst());
 				openRecentProject( m_recentProjectsAction->urls().constFirst() );
 			}
 		}
@@ -309,7 +312,11 @@ void MainWin::initActions() {
 	m_saveAsAction = KStandardAction::saveAs(this, SLOT(saveProjectAs()),actionCollection());
 	m_printAction = KStandardAction::print(this, SLOT(print()),actionCollection());
 	m_printPreviewAction = KStandardAction::printPreview(this, SLOT(printPreview()),actionCollection());
-	KStandardAction::fullScreen(this, SLOT(toggleFullScreen()), this, actionCollection());
+
+    //TODO: on Mac OS when going full-screen we get a crash because of an stack-overflow
+#ifndef Q_OS_MAC
+    KStandardAction::fullScreen(this, SLOT(toggleFullScreen()), this, actionCollection());
+#endif
 
 	//New Folder/Workbook/Spreadsheet/Matrix/Worksheet/Datasources
 	m_newWorkbookAction = new QAction(QIcon::fromTheme("labplot-workbook-new"),i18n("Workbook"),this);
@@ -390,7 +397,7 @@ void MainWin::initActions() {
 	actionCollection()->addAction("export", m_exportAction);
 	connect(m_exportAction, &QAction::triggered, this, &MainWin::exportDialog);
 
-	m_editFitsFileAction = new QAction(i18n("FITS Metadata Editor"), this);
+	m_editFitsFileAction = new QAction(QIcon::fromTheme("editor"), i18n("FITS Metadata Editor"), this);
 	m_editFitsFileAction->setWhatsThis(i18n("Open editor to edit FITS meta data"));
 	actionCollection()->addAction("edit_fits", m_editFitsFileAction);
 	connect(m_editFitsFileAction, &QAction::triggered, this, &MainWin::editFitsFileDialog);
@@ -483,9 +490,13 @@ void MainWin::initActions() {
 }
 
 void MainWin::initMenus() {
-	//menu for adding new aspects
+	//menu in the main toolbar for adding new aspects
+	auto* menu = dynamic_cast<QMenu*>(factory()->container("new", this));
+	menu->setIcon(QIcon::fromTheme("window-new"));
+
+	//menu in the project explorer and in the toolbar for adding new aspects
 	m_newMenu = new QMenu(i18n("Add New"), this);
-	m_newMenu->setIcon(QIcon::fromTheme("document-new"));
+	m_newMenu->setIcon(QIcon::fromTheme("window-new"));
 	m_newMenu->addAction(m_newFolderAction);
 	m_newMenu->addAction(m_newWorkbookAction);
 	m_newMenu->addAction(m_newSpreadsheetAction);
@@ -509,10 +520,10 @@ void MainWin::initMenus() {
 
 #ifdef HAVE_CANTOR_LIBS
 	m_newMenu->addSeparator();
-	m_newCantorWorksheetMenu = new QMenu(i18n("CAS Worksheet"));
+	m_newCantorWorksheetMenu = new QMenu(i18n("CAS Worksheet"), this);
 	m_newCantorWorksheetMenu->setIcon(QIcon::fromTheme("archive-insert"));
 
-	//"Adding Cantor backends to menue and context menu"
+	//"Adding Cantor backends to menu and context menu"
 	QStringList m_availableBackend = Cantor::Backend::listAvailableBackends();
 	if (m_availableBackend.count() > 0) {
 		unplugActionList(QLatin1String("backends_list"));
@@ -692,7 +703,7 @@ void MainWin::updateGUI() {
 	if (m_project->isLoading())
 		return;
 
-	if (m_closing)
+	if (m_closing || m_projectClosing)
 		return;
 
 	KXMLGUIFactory* factory = this->guiFactory();
@@ -721,29 +732,23 @@ void MainWin::updateGUI() {
 		return;
 	}
 
-
 	//Handle the Worksheet-object
-	Worksheet* w = this->activeWorksheet();
-	if (w != nullptr) {
-		//enable worksheet related menus
-		factory->container("worksheet", this)->setEnabled(true);
-		factory->container("analysis", this)->setEnabled(true);
-//TODO 		factory->container("drawing", this)->setEnabled(true);
-
-		//disable spreadsheet and matrix related menus
-		factory->container("spreadsheet", this)->setEnabled(false);
-		factory->container("matrix", this)->setEnabled(false);
-
+	const Worksheet* w = dynamic_cast<Worksheet*>(m_currentAspect);
+	if (!w)
+		w = dynamic_cast<Worksheet*>(m_currentAspect->parent(AspectType::Worksheet));
+	if (w) {
 		//populate worksheet menu
 		auto* view = qobject_cast<WorksheetView*>(w->view());
 		auto* menu = qobject_cast<QMenu*>(factory->container("worksheet", this));
 		menu->clear();
 		view->createContextMenu(menu);
+		menu->setEnabled(true);
 
 		//populate analysis menu
 		menu = qobject_cast<QMenu*>(factory->container("analysis", this));
 		menu->clear();
 		view->createAnalysisMenu(menu);
+		menu->setEnabled(true);
 
 		//populate worksheet-toolbar
 		auto* toolbar = qobject_cast<QToolBar*>(factory->container("worksheet_toolbar", this));
@@ -763,6 +768,7 @@ void MainWin::updateGUI() {
 		factory->container("spreadsheet_toolbar", this)->setVisible(false);
 	} else {
 		factory->container("worksheet", this)->setEnabled(false);
+		factory->container("worksheet_toolbar", this)->setVisible(false);
 		factory->container("analysis", this)->setEnabled(false);
 //		factory->container("drawing", this)->setEnabled(false);
 		factory->container("worksheet_toolbar", this)->setEnabled(false);
@@ -770,16 +776,16 @@ void MainWin::updateGUI() {
 	}
 
 	//Handle the Spreadsheet-object
-	const  auto* spreadsheet = this->activeSpreadsheet();
+	const auto* spreadsheet = this->activeSpreadsheet();
+	if (!spreadsheet)
+		spreadsheet = dynamic_cast<Spreadsheet*>(m_currentAspect->parent(AspectType::Spreadsheet));
 	if (spreadsheet) {
-		//enable spreadsheet related menus
-		factory->container("spreadsheet", this)->setEnabled(true);
-
 		//populate spreadsheet-menu
 		auto* view = qobject_cast<SpreadsheetView*>(spreadsheet->view());
 		auto* menu = qobject_cast<QMenu*>(factory->container("spreadsheet", this));
 		menu->clear();
 		view->createContextMenu(menu);
+		menu->setEnabled(true);
 
 		//populate spreadsheet-toolbar
 		auto* toolbar = qobject_cast<QToolBar*>(factory->container("spreadsheet_toolbar", this));
@@ -789,31 +795,34 @@ void MainWin::updateGUI() {
 		toolbar->setEnabled(true);
 	} else {
 		factory->container("spreadsheet", this)->setEnabled(false);
-		factory->container("spreadsheet_toolbar", this)->setEnabled(false);
+		factory->container("spreadsheet_toolbar", this)->setVisible(false);
 	}
 
 	//Handle the Matrix-object
-	const  Matrix* matrix = this->activeMatrix();
+	const  Matrix* matrix = dynamic_cast<Matrix*>(m_currentAspect);
+	if (!matrix)
+		matrix = dynamic_cast<Matrix*>(m_currentAspect->parent(AspectType::Matrix));
 	if (matrix) {
-		factory->container("matrix", this)->setEnabled(true);
-
 		//populate matrix-menu
 		auto* view = qobject_cast<MatrixView*>(matrix->view());
 		auto* menu = qobject_cast<QMenu*>(factory->container("matrix", this));
 		menu->clear();
 		view->createContextMenu(menu);
+		menu->setEnabled(true);
 	} else
 		factory->container("matrix", this)->setEnabled(false);
 
 #ifdef HAVE_CANTOR_LIBS
-	CantorWorksheet* cantorworksheet = this->activeCantorWorksheet();
+	const CantorWorksheet* cantorworksheet = dynamic_cast<CantorWorksheet*>(m_currentAspect);
+	if (!cantorworksheet)
+		cantorworksheet = dynamic_cast<CantorWorksheet*>(m_currentAspect->parent(AspectType::CantorWorksheet));
 	if (cantorworksheet) {
-		// enable Cantor Worksheet related menus
-		factory->container("cas_worksheet", this)->setEnabled(true);
 		auto* view = qobject_cast<CantorWorksheetView*>(cantorworksheet->view());
 		auto* menu = qobject_cast<QMenu*>(factory->container("cas_worksheet", this));
 		menu->clear();
 		view->createContextMenu(menu);
+		menu->setEnabled(true);
+
 		auto* toolbar = qobject_cast<QToolBar*>(factory->container("cas_worksheet_toolbar", this));
 		toolbar->setVisible(true);
 		toolbar->clear();
@@ -825,14 +834,21 @@ void MainWin::updateGUI() {
 	}
 #endif
 
-	const Datapicker* datapicker = this->activeDatapicker();
+	const Datapicker* datapicker = dynamic_cast<Datapicker*>(m_currentAspect);
+	if (!datapicker)
+		datapicker = dynamic_cast<Datapicker*>(m_currentAspect->parent(AspectType::Datapicker));
+	if (!datapicker) {
+		if (m_currentAspect->type() == AspectType::DatapickerCurve)
+			datapicker = dynamic_cast<Datapicker*>(m_currentAspect->parentAspect());
+	}
+
 	if (datapicker) {
-		factory->container("datapicker", this)->setEnabled(true);
 		//populate datapicker-menu
 		auto* view = qobject_cast<DatapickerView*>(datapicker->view());
 		auto* menu = qobject_cast<QMenu*>(factory->container("datapicker", this));
 		menu->clear();
 		view->createContextMenu(menu);
+		menu->setEnabled(true);
 
 		//populate spreadsheet-toolbar
 		auto* toolbar = qobject_cast<QToolBar*>(factory->container("datapicker_toolbar", this));
@@ -876,6 +892,7 @@ bool MainWin::newProject() {
 		m_visibilityAllAction->setChecked(true);
 
 	m_aspectTreeModel = new AspectTreeModel(m_project, this);
+	connect(m_aspectTreeModel, &AspectTreeModel::statusInfo, [=](const QString& text){ statusBar()->showMessage(text); });
 
 	//newProject is called for the first time, there is no project explorer yet
 	//-> initialize the project explorer,  the GUI-observer and the dock widgets.
@@ -925,6 +942,7 @@ bool MainWin::newProject() {
 	connect(m_project, &Project::requestProjectContextMenu, this, &MainWin::createContextMenu);
 	connect(m_project, &Project::requestFolderContextMenu, this, &MainWin::createFolderContextMenu);
 	connect(m_project, &Project::mdiWindowVisibilityChanged, this, &MainWin::updateMdiWindowVisibility);
+	connect(m_project, &Project::closeRequested, this, &MainWin::closeProject);
 
 	m_undoViewEmptyLabel = i18n("%1: created", m_project->name());
 	setCaption(m_project->name());
@@ -969,10 +987,11 @@ void MainWin::openProject(const QString& filename) {
 	QElapsedTimer timer;
 	timer.start();
 	bool rc = false;
-	if (Project::isLabPlotProject(filename))
+	if (Project::isLabPlotProject(filename)) {
+		m_project->setFileName(filename);
 		rc = m_project->load(filename);
 #ifdef HAVE_LIBORIGIN
-	else if (OriginProjectParser::isOriginProject(filename)) {
+	} else if (OriginProjectParser::isOriginProject(filename)) {
 		OriginProjectParser parser;
 		parser.setProjectFileName(filename);
 		parser.importTo(m_project, QStringList()); //TODO: add return code
@@ -987,7 +1006,6 @@ void MainWin::openProject(const QString& filename) {
 	}
 
 	m_currentFileName = filename;
-	m_project->setFileName(filename);
 	m_project->undoStack()->clear();
 	m_undoViewEmptyLabel = i18n("%1: opened", m_project->name());
 	m_recentProjectsAction->addUrl( QUrl(filename) );
@@ -1021,11 +1039,14 @@ bool MainWin::closeProject() {
 	if (warnModified())
 		return false;
 
+	m_projectClosing = true;
+	statusBar()->clearMessage();
 	delete m_aspectTreeModel;
 	m_aspectTreeModel = nullptr;
 	delete m_project;
 	m_project = nullptr;
 	m_currentFileName.clear();
+	m_projectClosing = false;
 
 	//update the UI if we're just closing a project
 	//and not closing(quitting) the application
@@ -1040,6 +1061,10 @@ bool MainWin::closeProject() {
 			m_autoSaveTimer.stop();
 	}
 
+	removeDockWidget(cursorDock);
+	delete cursorDock;
+	cursorDock = nullptr;
+	cursorWidget = nullptr; // is deleted, because it's the cild of cursorDock
 	return true;
 }
 
@@ -1078,45 +1103,71 @@ bool MainWin::saveProjectAs() {
  * auxiliary function that does the actual saving of the project
  */
 bool MainWin::save(const QString& fileName) {
+	QTemporaryFile tempFile(QDir::tempPath() + "/" + QLatin1String("labplot_save_XXXXXX"));
+	if (!tempFile.open()) {
+		KMessageBox::error(this, i18n("Couldn't open the temporary file for writing."));
+		return false;
+	}
+
 	WAIT_CURSOR;
+	const QString& tempFileName = tempFile.fileName();
+	DEBUG("Using temporary file " << tempFileName.toStdString())
+	tempFile.close();
+
 	// use file ending to find out how to compress file
 	QIODevice* file;
 	// if ending is .lml, do gzip compression anyway
 	if (fileName.endsWith(QLatin1String(".lml")))
-		file = new KCompressionDevice(fileName, KCompressionDevice::GZip);
+		file = new KCompressionDevice(tempFileName, KCompressionDevice::GZip);
 	else
-		file = new KFilterDev(fileName);
+		file = new KFilterDev(tempFileName);
 
 	if (file == nullptr)
-		file = new QFile(fileName);
+		file = new QFile(tempFileName);
 
 	bool ok;
 	if (file->open(QIODevice::WriteOnly)) {
 		m_project->setFileName(fileName);
 
+		QPixmap thumbnail = centralWidget()->grab();
+
 		QXmlStreamWriter writer(file);
-		m_project->save(&writer);
+		m_project->setFileName(fileName);
+		m_project->save(thumbnail, &writer);
 		m_project->undoStack()->clear();
 		m_project->setChanged(false);
 		file->close();
 
-		setCaption(m_project->name());
-		statusBar()->showMessage(i18n("Project saved"));
-		m_saveAction->setEnabled(false);
-		m_recentProjectsAction->addUrl( QUrl(fileName) );
-		ok = true;
+		// target file must not exist
+		if (QFile::exists(fileName))
+			QFile::remove(fileName);
 
-		//if the project dock is visible, refresh the shown content
-		//(version and modification time might have been changed)
-		if (stackedWidget->currentWidget() == projectDock)
-			projectDock->setProject(m_project);
+		// do not rename temp file. Qt still holds a handle (which fails renaming on Windows) and deletes it
+		bool rc = QFile::copy(tempFileName, fileName);
+		if (rc) {
+			setCaption(m_project->name());
+			statusBar()->showMessage(i18n("Project saved"));
+			m_saveAction->setEnabled(false);
+			m_recentProjectsAction->addUrl( QUrl(fileName) );
+			ok = true;
 
-		//we have a file name now
-		// -> auto save can be activated now if not happened yet
-		if (m_autoSaveActive && !m_autoSaveTimer.isActive())
-			m_autoSaveTimer.start();
+			//if the project dock is visible, refresh the shown content
+			//(version and modification time might have been changed)
+			if (stackedWidget->currentWidget() == projectDock)
+				projectDock->setProject(m_project);
+
+			//we have a file name now
+			// -> auto save can be activated now if not happened yet
+			if (m_autoSaveActive && !m_autoSaveTimer.isActive())
+				m_autoSaveTimer.start();
+		} else {
+			RESET_CURSOR;
+			KMessageBox::error(this, i18n("Couldn't save the file '%1'.", fileName));
+			ok = false;
+		}
 	} else {
-		KMessageBox::error(this, i18n("Sorry. Could not open file for writing."));
+		RESET_CURSOR;
+		KMessageBox::error(this, i18n("Couldn't open the file '%1' for writing.", fileName));
 		ok = false;
 	}
 
@@ -1151,7 +1202,7 @@ void MainWin::print() {
 	if (part->printView())
 		statusBar()->showMessage(i18n("%1 printed", part->name()));
 	else
-		statusBar()->showMessage(QString());
+		statusBar()->clearMessage();
 }
 
 void MainWin::printPreview() {
@@ -1164,7 +1215,7 @@ void MainWin::printPreview() {
 	if (part->printPreview())
 		statusBar()->showMessage(i18n("%1 printed", part->name()));
 	else
-		statusBar()->showMessage(QString());
+		statusBar()->clearMessage();
 }
 
 /**************************************************************************************/
@@ -1200,11 +1251,11 @@ void MainWin::newSpreadsheet() {
 
 	//if the current active window is a workbook and no folder/project is selected in the project explorer,
 	//add the new spreadsheet to the workbook
-	Workbook* workbook = activeWorkbook();
+	Workbook* workbook = dynamic_cast<Workbook*>(m_currentAspect);
 	if (workbook) {
 		QModelIndex index = m_projectExplorer->currentIndex();
 		const auto* aspect = static_cast<AbstractAspect*>(index.internalPointer());
-		if (!aspect->inherits("Folder")) {
+		if (!aspect->inherits(AspectType::Folder)) {
 			workbook->addChild(spreadsheet);
 			return;
 		}
@@ -1221,11 +1272,11 @@ void MainWin::newMatrix() {
 
 	//if the current active window is a workbook and no folder/project is selected in the project explorer,
 	//add the new matrix to the workbook
-	Workbook* workbook = activeWorkbook();
+	Workbook* workbook = dynamic_cast<Workbook*>(m_currentAspect);
 	if (workbook) {
 		QModelIndex index = m_projectExplorer->currentIndex();
 		const auto* aspect = static_cast<AbstractAspect*>(index.internalPointer());
-		if (!aspect->inherits("Folder")) {
+		if (!aspect->inherits(AspectType::Folder)) {
 			workbook->addChild(matrix);
 			return;
 		}
@@ -1250,108 +1301,28 @@ void MainWin::newNotes() {
 	this->addAspectToProject(notes);
 }
 
-/*!
-	returns a pointer to a Workbook-object, if the currently active Mdi-Subwindow is \a WorkbookView.
-	Otherwise returns \a 0.
-*/
-Workbook* MainWin::activeWorkbook() const {
-	QMdiSubWindow* win = m_mdiArea->currentSubWindow();
-	if (!win)
-		return nullptr;
-
-	AbstractPart* part = dynamic_cast<PartMdiView*>(win)->part();
-	Q_ASSERT(part);
-	return dynamic_cast<Workbook*>(part);
-}
-
-/*!
-	returns a pointer to a Datapicker-object, if the currently active Mdi-Subwindow is \a DatapickerView.
-	Otherwise returns \a 0.
-*/
-Datapicker* MainWin::activeDatapicker() const {
-	QMdiSubWindow* win = m_mdiArea->currentSubWindow();
-	if (!win)
-		return nullptr;
-
-	AbstractPart* part = dynamic_cast<PartMdiView*>(win)->part();
-	Q_ASSERT(part);
-	return dynamic_cast<Datapicker*>(part);
-}
-
 /*!
 	returns a pointer to a \c Spreadsheet object, if the currently active Mdi-Subwindow
 	or if the currently selected tab in a \c WorkbookView is a \c SpreadsheetView
 	Otherwise returns \c 0.
 */
 Spreadsheet* MainWin::activeSpreadsheet() const {
-	QMdiSubWindow* win = m_mdiArea->currentSubWindow();
-	if (!win)
+	if (!m_currentAspect)
 		return nullptr;
 
-	AbstractPart* part = dynamic_cast<PartMdiView*>(win)->part();
-	Q_ASSERT(part);
 	Spreadsheet* spreadsheet = nullptr;
-	const auto* workbook = dynamic_cast<const Workbook*>(part);
-	if (workbook) {
-		spreadsheet = workbook->currentSpreadsheet();
-		if (!spreadsheet) {
-			//potentially, the spreadsheet was not selected in workbook yet since the selection in project explorer
-			//arrives in workbook's slot later than in this function
-			//->check whether we have a spreadsheet or one of its columns currently selected in the project explorer
-			spreadsheet = dynamic_cast<Spreadsheet*>(m_currentAspect);
-			if (!spreadsheet) {
-				if (m_currentAspect->parentAspect())
-					spreadsheet = dynamic_cast<Spreadsheet*>(m_currentAspect->parentAspect());
-			}
-		}
-	} else
-		spreadsheet = dynamic_cast<Spreadsheet*>(part);
+	if (m_currentAspect->type() == AspectType::Spreadsheet)
+		spreadsheet = dynamic_cast<Spreadsheet*>(m_currentAspect);
+	else {
+		//check whether one of spreadsheet columns is selected and determine the spreadsheet
+		auto* parent = m_currentAspect->parentAspect();
+		if (parent && parent->type() == AspectType::Spreadsheet)
+			spreadsheet = dynamic_cast<Spreadsheet*>(parent);
+	}
 
 	return spreadsheet;
 }
 
-/*!
-	returns a pointer to a \c Matrix object, if the currently active Mdi-Subwindow
-	or if the currently selected tab in a \c WorkbookView is a \c MatrixView
-	Otherwise returns \c 0.
-*/
-Matrix* MainWin::activeMatrix() const {
-	QMdiSubWindow* win = m_mdiArea->currentSubWindow();
-	if (!win)
-		return nullptr;
-
-	AbstractPart* part = dynamic_cast<PartMdiView*>(win)->part();
-	Q_ASSERT(part);
-	Matrix* matrix = nullptr;
-	const auto* workbook = dynamic_cast<Workbook*>(part);
-	if (workbook) {
-		matrix = workbook->currentMatrix();
-		if (!matrix) {
-			//potentially, the matrix was not selected in workbook yet since the selection in project explorer
-			//arrives in workbook's slot later than in this function
-			//->check whether we have a matrix currently selected in the project explorer
-			matrix = dynamic_cast<Matrix*>(m_currentAspect);
-		}
-	} else
-		matrix = dynamic_cast<Matrix*>(part);
-
-	return matrix;
-}
-
-/*!
-	returns a pointer to a Worksheet-object, if the currently active Mdi-Subwindow is \a WorksheetView
-	Otherwise returns \a 0.
-*/
-Worksheet* MainWin::activeWorksheet() const {
-	QMdiSubWindow* win = m_mdiArea->currentSubWindow();
-	if (!win)
-		return nullptr;
-
-	AbstractPart* part = dynamic_cast<PartMdiView*>(win)->part();
-	Q_ASSERT(part);
-	return dynamic_cast<Worksheet*>(part);
-}
-
 #ifdef HAVE_CANTOR_LIBS
 /*
     adds a new Cantor Spreadsheet to the project.
@@ -1362,19 +1333,6 @@ void MainWin::newCantorWorksheet(QAction* action) {
 }
 
 /********************************************************************************/
-/*!
-    returns a pointer to a CantorWorksheet-object, if the currently active Mdi-Subwindow is \a CantorWorksheetView
-    Otherwise returns \a 0.
-*/
-CantorWorksheet* MainWin::activeCantorWorksheet() const {
-	QMdiSubWindow* win = m_mdiArea->currentSubWindow();
-	if (!win)
-		return nullptr;
-
-	AbstractPart* part = dynamic_cast<PartMdiView*>(win)->part();
-	Q_ASSERT(part);
-	return dynamic_cast<CantorWorksheet*>(part);
-}
 #endif
 
 /*!
@@ -1422,9 +1380,14 @@ void MainWin::handleAspectAdded(const AbstractAspect* aspect) {
 		connect(part, &AbstractPart::printRequested, this, &MainWin::print);
 		connect(part, &AbstractPart::printPreviewRequested, this, &MainWin::printPreview);
 		connect(part, &AbstractPart::showRequested, this, &MainWin::handleShowSubWindowRequested);
+
+		const auto* worksheet = dynamic_cast<const Worksheet*>(aspect);
+		if (worksheet)
+			connect(worksheet, &Worksheet::cartesianPlotMouseModeChanged, this, &MainWin::cartesianPlotMouseModeChanged);
 	}
 }
 
+// void MainWin::cartesianPlotMouseModeChanged(CartesianPlot::MouseMode
 void MainWin::handleAspectRemoved(const AbstractAspect* parent,const AbstractAspect* before,const AbstractAspect* aspect) {
 	Q_UNUSED(before);
 	Q_UNUSED(aspect);
@@ -1536,7 +1499,7 @@ void MainWin::activateSubWindowForAspect(const AbstractAspect* aspect) const {
 	return;
 }
 
-void MainWin::setMdiWindowVisibility(QAction * action) {
+void MainWin::setMdiWindowVisibility(QAction* action) {
 	m_project->setMdiWindowVisibility((Project::MdiWindowVisibility)(action->data().toInt()));
 }
 
@@ -1553,12 +1516,22 @@ void MainWin::handleShowSubWindowRequested() {
 	this is called on a right click on the root folder in the project explorer
 */
 void MainWin::createContextMenu(QMenu* menu) const {
-	menu->addMenu(m_newMenu);
+	QAction* firstAction = nullptr;
+	// if we're populating the context menu for the project explorer, then
+	//there're already actions available there. Skip the first title-action
+	//and insert the action at the beginning of the menu.
+	if (menu->actions().size()>1)
+		firstAction = menu->actions().at(1);
+
+	menu->insertMenu(firstAction, m_newMenu);
 
 	//The tabbed view collides with the visibility policy for the subwindows.
 	//Hide the menus for the visibility policy if the tabbed view is used.
-	if (m_mdiArea->viewMode() != QMdiArea::TabbedView)
-		menu->addMenu(m_visibilityMenu);
+	if (m_mdiArea->viewMode() != QMdiArea::TabbedView) {
+		menu->insertSeparator(firstAction);
+		menu->insertMenu(firstAction, m_visibilityMenu);
+		menu->insertSeparator(firstAction);
+	}
 }
 
 /*!
@@ -1712,6 +1685,39 @@ void MainWin::propertiesDockVisibilityChanged(bool visible) {
 	m_togglePropertiesDockAction->setChecked(visible);
 }
 
+void MainWin::cursorDockVisibilityChanged(bool visible) {
+	//if the cursor dock was closed, switch to the "Select and Edit" mouse mode
+	if (!visible) {
+// 		auto* worksheet = activeWorksheet();
+		//TODO:
+	}
+}
+
+void MainWin::cartesianPlotMouseModeChanged(CartesianPlot::MouseMode mode) {
+	if (mode != CartesianPlot::Cursor) {
+		if (cursorDock)
+			cursorDock->hide();
+	} else {
+		if (!cursorDock) {
+			cursorDock = new QDockWidget(i18n("Cursor"), this);
+			cursorWidget = new CursorDock(cursorDock);
+			cursorDock->setWidget(cursorWidget);
+			connect(cursorDock, &QDockWidget::visibilityChanged, this, &MainWin::cursorDockVisibilityChanged);
+	// 		cursorDock->setFloating(true);
+
+			// does not work. Don't understand why
+	//		if (m_propertiesDock)
+	//			tabifyDockWidget(cursorDock, m_propertiesDock);
+	//		else
+				addDockWidget(Qt::DockWidgetArea::RightDockWidgetArea, cursorDock);
+		}
+
+		auto* worksheet = static_cast<Worksheet*>(QObject::sender());
+		cursorWidget->setWorksheet(worksheet);
+		cursorDock->show();
+	}
+}
+
 void MainWin::toggleFullScreen() {
 	if (this->windowState() == Qt::WindowFullScreen)
 		this->setWindowState(m_lastWindowState);
@@ -1841,12 +1847,13 @@ void MainWin::importFileDialog(const QString& fileName) {
 	auto* dlg = new ImportFileDialog(this, false, fileName);
 
 	// select existing container
-	if (m_currentAspect->inherits("Spreadsheet") || m_currentAspect->inherits("Matrix") || m_currentAspect->inherits("Workbook"))
-		dlg->setCurrentIndex( m_projectExplorer->currentIndex());
-	else if (m_currentAspect->inherits("Column")) {
-		if (m_currentAspect->parentAspect()->inherits("Spreadsheet"))
-			dlg->setCurrentIndex(m_aspectTreeModel->modelIndexOfAspect(m_currentAspect->parentAspect()));
-	}
+	if (m_currentAspect->type() == AspectType::Spreadsheet ||
+		m_currentAspect->type() == AspectType::Matrix ||
+		m_currentAspect->type() == AspectType::Workbook)
+		dlg->setCurrentIndex(m_projectExplorer->currentIndex());
+	else if (m_currentAspect->type() == AspectType::Column &&
+             m_currentAspect->parentAspect()->type() == AspectType::Spreadsheet)
+		dlg->setCurrentIndex(m_aspectTreeModel->modelIndexOfAspect(m_currentAspect->parentAspect()));
 
 	if (dlg->exec() == QDialog::Accepted) {
 		dlg->importTo(statusBar());
@@ -1862,12 +1869,14 @@ void MainWin::importSqlDialog() {
 	auto* dlg = new ImportSQLDatabaseDialog(this);
 
 	// select existing container
-	if (m_currentAspect->inherits("Spreadsheet") || m_currentAspect->inherits("Matrix") || m_currentAspect->inherits("Workbook"))
-		dlg->setCurrentIndex( m_projectExplorer->currentIndex());
-	else if (m_currentAspect->inherits("Column")) {
-		if (m_currentAspect->parentAspect()->inherits("Spreadsheet"))
-			dlg->setCurrentIndex( m_aspectTreeModel->modelIndexOfAspect(m_currentAspect->parentAspect()));
-	}
+	if (m_currentAspect->type() == AspectType::Spreadsheet ||
+		m_currentAspect->type() == AspectType::Matrix ||
+		m_currentAspect->type() == AspectType::Workbook)
+		dlg->setCurrentIndex(m_projectExplorer->currentIndex());
+	else if (m_currentAspect->type() == AspectType::Column &&
+             m_currentAspect->parentAspect()->type() == AspectType::Spreadsheet)
+		dlg->setCurrentIndex(m_aspectTreeModel->modelIndexOfAspect(m_currentAspect->parentAspect()));
+
 
 	if (dlg->exec() == QDialog::Accepted) {
 		dlg->importTo(statusBar());
