@@ -28,6 +28,8 @@
 #ifndef MAINWIN_H
 #define MAINWIN_H
 
+#include "backend/worksheet/plots/cartesian/CartesianPlot.h"
+
 #include <KXmlGuiWindow>
 #include <QTimer>
 
@@ -45,6 +47,7 @@ class Spreadsheet;
 class Matrix;
 class GuiObserver;
 class AxisDock;
+class CursorDock;
 class NoteDock;
 class CartesianPlotDock;
 class HistogramDock;
@@ -73,6 +76,7 @@ class LabelWidget;
 class DatapickerImageWidget;
 class DatapickerCurveWidget;
 class MemoryWidget;
+class CartesianPlot;
 
 #ifdef HAVE_CANTOR_LIBS
 class CantorWorksheet;
@@ -87,6 +91,7 @@ class QMdiArea;
 class QMdiSubWindow;
 class QToolButton;
 class KRecentFilesAction;
+class TreeModel;
 
 class MainWin : public KXmlGuiWindow {
 	Q_OBJECT
@@ -114,6 +119,7 @@ private:
 	QString m_undoViewEmptyLabel;
 	bool m_suppressCurrentSubWindowChangedEvent{false};
 	bool m_closing{false};
+	bool m_projectClosing{false};
 	bool m_autoSaveActive{false};
 	QTimer m_autoSaveTimer;
 	bool m_showMemoryInfo{true};
@@ -185,6 +191,8 @@ private:
 	//Docks
 	QStackedWidget* stackedWidget;
 	AxisDock* axisDock{nullptr};
+	QDockWidget* cursorDock{nullptr};
+	CursorDock* cursorWidget{nullptr};
 	NoteDock* notesDock{nullptr};
 	CartesianPlotDock* cartesianPlotDock{nullptr};
 	CartesianPlotLegendDock* cartesianPlotLegendDock{nullptr};
@@ -220,17 +228,12 @@ private:
 // 	void toggleShowWidget(QWidget* widget, bool showToRight);
 // 	void toggleHideWidget(QWidget* widget, bool hideToLeft);
 
-	Workbook* activeWorkbook() const;
 	Spreadsheet* activeSpreadsheet() const;
-	Matrix* activeMatrix() const;
-	Worksheet* activeWorksheet() const;
-	Datapicker* activeDatapicker() const;
 
 	//Cantor
 #ifdef HAVE_CANTOR_LIBS
 	QMenu* m_newCantorWorksheetMenu;
 	CantorWorksheetDock* cantorWorksheetDock{nullptr};
-	CantorWorksheet* activeCantorWorksheet() const;
 #endif
 
 	friend class GuiObserver;
@@ -304,6 +307,9 @@ private slots:
 	void toggleFullScreen();
 	void projectExplorerDockVisibilityChanged(bool);
 	void propertiesDockVisibilityChanged(bool);
+	void cursorDockVisibilityChanged(bool);
+
+	void cartesianPlotMouseModeChanged(CartesianPlot::MouseMode);
 };
 
 #endif
