@@ -2,9 +2,9 @@
     File                 : SettingsDialog.cpp
     Project              : LabPlot
     --------------------------------------------------------------------
-    Copyright            : (C) 2008-2017 by Alexander Semke (alexander.semke@web.de)
+    Copyright            : (C) 2008-2019 by Alexander Semke (alexander.semke@web.de)
     Description          : application settings dialog
- 
+
  ***************************************************************************/
 
 /***************************************************************************
@@ -33,6 +33,7 @@
 
 #include <QPushButton>
 #include <QDialogButtonBox>
+#include <QWindow>
 
 #include <KMessageBox>
 #include <KConfigGroup>
@@ -46,47 +47,53 @@
  * Contains the pages for general settings and view settings.
  *
  */
-SettingsDialog::SettingsDialog(QWidget* parent) : KPageDialog(parent), m_changed(false) {
+SettingsDialog::SettingsDialog(QWidget* parent) : KPageDialog(parent) {
 	setFaceType(List);
-	setWindowTitle(i18n("Preferences"));
+	setWindowTitle(i18nc("@title:window", "Preferences"));
 	setWindowIcon(QIcon::fromTheme("preferences-other"));
 	setAttribute(Qt::WA_DeleteOnClose);
 
 	buttonBox()->addButton(QDialogButtonBox::Apply)->setEnabled(false);
 	buttonBox()->addButton(QDialogButtonBox::RestoreDefaults);
-	connect(buttonBox(), SIGNAL(clicked(QAbstractButton*)), this, SLOT(slotButtonClicked(QAbstractButton*)));
+	connect(buttonBox(), &QDialogButtonBox::clicked, this, &SettingsDialog::slotButtonClicked);
 
 	m_generalPage = new SettingsGeneralPage(this);
 	KPageWidgetItem* generalFrame = addPage(m_generalPage, i18n("General"));
 	generalFrame->setIcon(QIcon::fromTheme("system-run"));
-	connect(m_generalPage, SIGNAL(settingsChanged()), this, SLOT(changed()));
+	connect(m_generalPage, &SettingsGeneralPage::settingsChanged, this, &SettingsDialog::changed);
 
 	m_worksheetPage = new SettingsWorksheetPage(this);
 	KPageWidgetItem* worksheetFrame = addPage(m_worksheetPage, i18n("Worksheet"));
 	worksheetFrame->setIcon(QIcon::fromTheme(QLatin1String("labplot-worksheet")));
-	connect(m_worksheetPage, SIGNAL(settingsChanged()), this, SLOT(changed()));
+	connect(m_worksheetPage, &SettingsWorksheetPage::settingsChanged, this, &SettingsDialog::changed);
 
-	const KConfigGroup dialogConfig = KSharedConfig::openConfig()->group("SettingsDialog");
-	KWindowConfig::restoreWindowSize(windowHandle(), dialogConfig);
+	//restore saved settings if available
+	create(); // ensure there's a window created
+	KConfigGroup conf(KSharedConfig::openConfig(), "SettingsDialog");
+	if (conf.exists()) {
+		KWindowConfig::restoreWindowSize(windowHandle(), conf);
+		resize(windowHandle()->size()); // workaround for QTBUG-40584
+	} else
+		resize(QSize(0, 0).expandedTo(minimumSize()));
 }
 
-SettingsDialog::~SettingsDialog(){
+SettingsDialog::~SettingsDialog() {
 	KConfigGroup dialogConfig = KSharedConfig::openConfig()->group("SettingsDialog");
 	KWindowConfig::saveWindowSize(windowHandle(), dialogConfig);
 }
 
 void SettingsDialog::slotButtonClicked(QAbstractButton* button) {
 	if ((button == buttonBox()->button(QDialogButtonBox::Ok)) || (button == buttonBox()->button(QDialogButtonBox::Apply))) {
-		if (m_changed){
+		if (m_changed) {
 			applySettings();
-			setWindowTitle(i18n("Preferences"));
+			setWindowTitle(i18nc("@title:window", "Preferences"));
 			buttonBox()->button(QDialogButtonBox::Apply)->setEnabled(false);
 		}
 	} else if (button == buttonBox()->button(QDialogButtonBox::RestoreDefaults)) {
 		const QString text(i18n("All settings will be reset to default values. Do you want to continue?"));
 		if (KMessageBox::questionYesNo(this, text) == KMessageBox::Yes) {
 			restoreDefaults();
-			setWindowTitle(i18n("Preferences"));
+			setWindowTitle(i18nc("@title:window", "Preferences"));
 			buttonBox()->button(QDialogButtonBox::Apply)->setEnabled(false);
 		}
 	}
@@ -94,11 +101,11 @@ void SettingsDialog::slotButtonClicked(QAbstractButton* button) {
 
 void SettingsDialog::changed() {
 	m_changed = true;
-	setWindowTitle(i18n("Preferences    [Changed]"));
+	setWindowTitle(i18nc("@title:window", "Preferences    [Changed]"));
 	buttonBox()->button(QDialogButtonBox::Apply)->setEnabled(true);
 }
 
-void SettingsDialog::applySettings(){
+void SettingsDialog::applySettings() {
 	m_changed = false;
 	m_generalPage->applySettings();
 	m_worksheetPage->applySettings();
@@ -106,7 +113,7 @@ void SettingsDialog::applySettings(){
 	emit settingsChanged();
 }
 
-void SettingsDialog::restoreDefaults(){
+void SettingsDialog::restoreDefaults() {
 	m_changed = false;
 	m_generalPage->restoreDefaults();
 	m_worksheetPage->restoreDefaults();
