@@ -39,18 +39,19 @@ class SettingsGeneralPage : public SettingsPage {
 public:
 	explicit SettingsGeneralPage(QWidget*);
 
-	virtual void applySettings();
-	virtual void restoreDefaults();
+	void applySettings() override;
+	void restoreDefaults() override;
 
 private:
 	Ui::SettingsGeneralPage ui;
-	bool m_changed;
+	bool m_changed{false};
 
 	void loadSettings();
 	void retranslateUi();
 
 private slots:
 	void interfaceChanged(int);
+	void autoSaveChanged(int);
 	void changed();
 
 signals:
