@@ -30,16 +30,14 @@
 #include "tools/TeXRenderer.h"
 #include "kdefrontend/widgets/ThemesComboBox.h"
 
-#include <KLocale>
+#include <KLocalizedString>
 #include <KSharedConfig>
 #include <KConfigGroup>
 
 /**
  * \brief Page for the 'General' settings of the Labplot settings dialog.
  */
-SettingsWorksheetPage::SettingsWorksheetPage(QWidget* parent) : SettingsPage(parent),
-	m_changed(false) {
-
+SettingsWorksheetPage::SettingsWorksheetPage(QWidget* parent) : SettingsPage(parent) {
 	ui.setupUi(this);
 
 	m_cbThemes = new ThemesComboBox();
@@ -132,7 +130,7 @@ void SettingsWorksheetPage::checkTeX(int engineIndex) {
 		return;
 	}
 
-	//engine found, check the precense of other required tools (s.a. TeXRenderer.cpp):
+	//engine found, check the presence of other required tools (s.a. TeXRenderer.cpp):
 	//to convert the generated PDF/PS files to PNG we need 'convert' from the ImageMagic package
 	if (!TeXRenderer::executableExists(QLatin1String("convert"))) {
 		ui.lLatexWarning->show();
@@ -141,7 +139,7 @@ void SettingsWorksheetPage::checkTeX(int engineIndex) {
 	}
 
 	QString engine = ui.cbTexEngine->itemData(engineIndex).toString();
-	if (engine=="latex") {
+	if (engine == "latex") {
 		//to convert the generated PS files to DVI we need 'dvips'
 		if (!TeXRenderer::executableExists(QLatin1String("dvips"))) {
 			ui.lLatexWarning->show();
