@@ -1,10 +1,10 @@
 /***************************************************************************
-File                 : FITSOptionsWidget.cpp
-Project              : LabPlot
-Description          : Widget providing options for the import of FITS data
---------------------------------------------------------------------
-Copyright            : (C) 2016 Fabian Kristof (fkristofszabolcs@gmail.com)
-Copyright            : (C) 2017 Stefan Gerlach (stefan.gerlach@uni.kn)
+    File                 : FITSOptionsWidget.cpp
+    Project              : LabPlot
+    Description          : Widget providing options for the import of FITS data
+    --------------------------------------------------------------------
+    Copyright            : (C) 2016 Fabian Kristof (fkristofszabolcs@gmail.com)
+    Copyright            : (C) 2017 Stefan Gerlach (stefan.gerlach@uni.kn)
 
 ***************************************************************************/
 
@@ -26,6 +26,7 @@ Copyright            : (C) 2017 Stefan Gerlach (stefan.gerlach@uni.kn)
 *   Boston, MA  02110-1301  USA                                           *
 *                                                                         *
 ***************************************************************************/
+
 #include "FITSOptionsWidget.h"
 #include "ImportFileWidget.h"
 #include "backend/datasources/filters/FITSFilter.h"
@@ -40,6 +41,8 @@ FITSOptionsWidget::FITSOptionsWidget(QWidget* parent, ImportFileWidget* fileWidg
 	ui.twExtensions->header()->setSectionResizeMode(QHeaderView::ResizeToContents);
 	ui.twPreview->setEditTriggers(QAbstractItemView::NoEditTriggers);
 
+	ui.bRefreshPreview->setIcon( QIcon::fromTheme("view-refresh") );
+
 	connect(ui.twExtensions, &QTreeWidget::itemSelectionChanged, this, &FITSOptionsWidget::fitsTreeWidgetSelectionChanged);
 	connect(ui.bRefreshPreview, &QPushButton::clicked, fileWidget, &ImportFileWidget::refreshPreview);
 }
@@ -52,13 +55,13 @@ void FITSOptionsWidget::clear() {
 QString FITSOptionsWidget::currentExtensionName() {
 	QString name;
 
-	if (ui.twExtensions->currentItem() != 0 && ui.twExtensions->currentItem()->text(0) != i18n("Primary header"))
+	if (ui.twExtensions->currentItem() != nullptr && ui.twExtensions->currentItem()->text(0) != i18n("Primary header"))
 		name = ui.twExtensions->currentItem()->text(ui.twExtensions->currentColumn());
 
 	return name;
 }
 
-void FITSOptionsWidget::updateContent(FITSFilter *filter, const QString& fileName) {
+void FITSOptionsWidget::updateContent(FITSFilter* filter, const QString& fileName) {
 	DEBUG("FITSOptionsWidget::updateContent() file name = " << fileName.toStdString());
 	ui.twExtensions->clear();
 	filter->parseExtensions(fileName, ui.twExtensions, true);
@@ -90,25 +93,25 @@ void FITSOptionsWidget::fitsTreeWidgetSelectionChanged() {
 	else if (!itemText.compare(i18n("Primary header")))
 		extType = 2;
 	if (extType == 0) {
-		if (item->parent() != 0) {
-			if (item->parent()->parent() != 0)
+		if (item->parent() != nullptr) {
+			if (item->parent()->parent() != nullptr)
 				selectedExtension = item->parent()->parent()->text(0) + QLatin1String("[") + item->text(column) + QLatin1String("]");
 		}
 	} else if (extType == 1) {
-		if (item->parent() != 0) {
-			if (item->parent()->parent() != 0) {
+		if (item->parent() != nullptr) {
+			if (item->parent()->parent() != nullptr) {
 				bool ok;
 				int hduNum = itemText.rightRef(1).toInt(&ok);
 				selectedExtension = item->parent()->parent()->text(0) + QLatin1String("[") + QString::number(hduNum-1) + QLatin1String("]");
 			}
 		}
 	} else {
-		if (item->parent()->parent() != 0)
+		if (item->parent()->parent() != nullptr)
 			selectedExtension = item->parent()->parent()->text(column);
 	}
 
 	if (!selectedExtension.isEmpty()) {
-		FITSFilter* filter = dynamic_cast<FITSFilter*>(m_fileWidget->currentFileFilter());
+		auto filter = static_cast<FITSFilter*>(m_fileWidget->currentFileFilter());
 		bool readFitsTableToMatrix;
 		const QVector<QStringList> importedStrings = filter->readChdu(selectedExtension, &readFitsTableToMatrix, ui.sbPreviewLines->value());
 		emit m_fileWidget->checkedFitsTableToMatrix(readFitsTableToMatrix);
@@ -128,7 +131,7 @@ void FITSOptionsWidget::fitsTreeWidgetSelectionChanged() {
 			colCount = lineString.size() > maxColumns ? maxColumns : lineString.size();
 
 			for (int j = 0; j < colCount; ++j) {
-				QTableWidgetItem* item = new QTableWidgetItem(lineString[j]);
+				auto* item = new QTableWidgetItem(lineString[j]);
 				ui.twPreview->setItem(i, j, item);
 			}
 		}
@@ -140,16 +143,16 @@ void FITSOptionsWidget::fitsTreeWidgetSelectionChanged() {
 /*!
 	return list of selected FITS extension names
 */
-const QStringList FITSOptionsWidget::selectedFITSExtensions() const {
+const QStringList FITSOptionsWidget::selectedExtensions() const {
 	QStringList names;
-	for (const auto* item: ui.twExtensions->selectedItems())
+	for (const auto* item : ui.twExtensions->selectedItems())
 		names << item->text(0);
 
 	return names;
 }
 
 const QString FITSOptionsWidget::extensionName(bool* ok) {
-	if (ui.twExtensions->currentItem() != 0) {
+	if (ui.twExtensions->currentItem() != nullptr) {
 		const QTreeWidgetItem* item = ui.twExtensions->currentItem();
 		const int currentColumn = ui.twExtensions->currentColumn();
 		QString itemText = item->text(currentColumn);
@@ -162,15 +165,15 @@ const QString FITSOptionsWidget::extensionName(bool* ok) {
 			extType = 2;
 
 		if (extType == 0) {
-			if (item->parent() != 0 && item->parent()->parent() != 0)
+			if (item->parent() != nullptr && item->parent()->parent() != nullptr)
 				return item->parent()->parent()->text(0) + QLatin1String("[")+ item->text(currentColumn) + QLatin1String("]");
 		} else if (extType == 1) {
-			if (item->parent() != 0 && item->parent()->parent() != 0) {
+			if (item->parent() != nullptr && item->parent()->parent() != nullptr) {
 				int hduNum = itemText.rightRef(1).toInt(ok);
 				return item->parent()->parent()->text(0) + QLatin1String("[") + QString::number(hduNum-1) + QLatin1String("]");
 			}
 		} else {
-			if (item->parent()->parent() != 0)
+			if (item->parent()->parent() != nullptr)
 				return item->parent()->parent()->text(currentColumn);
 		}
 	}
