@@ -53,6 +53,8 @@
 FileInfoDialog::FileInfoDialog(QWidget* parent) : QDialog(parent) {
 	m_textEditWidget.setReadOnly(true);
 	m_textEditWidget.setLineWrapMode(QTextEdit::NoWrap);
+	m_textEditWidget.setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
+	m_textEditWidget.setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
 
 	auto* layout = new QVBoxLayout(this);
 	layout->addWidget(&m_textEditWidget);
@@ -99,6 +101,11 @@ void FileInfoDialog::setFiles(QStringList& files) {
 	}
 
 	m_textEditWidget.document()->setHtml(infoString);
+
+	//resize to fit the content
+	QSize size = m_textEditWidget.document()->size().toSize();
+	m_textEditWidget.setMinimumSize(size.width() + m_textEditWidget.contentsMargins().left() + m_textEditWidget.contentsMargins().right(),
+									size.height() + m_textEditWidget.contentsMargins().top() + m_textEditWidget.contentsMargins().bottom());
 }
 
 /*!
@@ -160,7 +167,12 @@ QString FileInfoDialog::fileInfoString(const QString& name) const {
 		infoStrings << i18n("Writable: %1", fileInfo.isWritable() ? i18n("yes") : i18n("no"));
 		infoStrings << i18n("Executable: %1", fileInfo.isExecutable() ? i18n("yes") : i18n("no"));
 
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 10, 0))
+		infoStrings << i18n("Birth time: %1", fileInfo.birthTime().toString());
+		infoStrings << i18n("Last metadata changed: %1", fileInfo.metadataChangeTime().toString());
+#else
 		infoStrings << i18n("Created: %1", fileInfo.created().toString());
+#endif
 		infoStrings << i18n("Last modified: %1", fileInfo.lastModified().toString());
 		infoStrings << i18n("Last read: %1", fileInfo.lastRead().toString());
 		infoStrings << i18n("Owner: %1", fileInfo.owner());
