@@ -102,30 +102,31 @@ ImportFileDialog::ImportFileDialog(MainWin* parent, bool liveDataSource, const Q
 	KConfigGroup conf(KSharedConfig::openConfig(), "ImportFileDialog");
 	if (conf.exists()) {
 		m_showOptions = conf.readEntry("ShowOptions", false);
-		m_showOptions ? m_optionsButton->setText(i18n("Hide Options")) : m_optionsButton->setText(i18n("Show Options"));
-		m_importFileWidget->showOptions(m_showOptions);
-
-		//do the signal-slot connections after all settings were loaded in import file widget and check the OK button after this
-		connect(m_importFileWidget, &ImportFileWidget::checkedFitsTableToMatrix, this, &ImportFileDialog::checkOnFitsTableToMatrix);
-		connect(m_importFileWidget, static_cast<void (ImportFileWidget::*)()>(&ImportFileWidget::fileNameChanged), this, &ImportFileDialog::checkOkButton);
-		connect(m_importFileWidget, static_cast<void (ImportFileWidget::*)()>(&ImportFileWidget::sourceTypeChanged), this, &ImportFileDialog::checkOkButton);
-		connect(m_importFileWidget, &ImportFileWidget::hostChanged, this, &ImportFileDialog::checkOkButton);
-		connect(m_importFileWidget, &ImportFileWidget::portChanged, this, &ImportFileDialog::checkOkButton);
-		//TODO: do we really need to check the ok button when the preview was refreshed?
-		//If not, remove this together with the previewRefreshed signal in ImportFileWidget
-		//connect(m_importFileWidget, &ImportFileWidget::previewRefreshed, this, &ImportFileDialog::checkOkButton);
-#ifdef HAVE_MQTT
-		connect(m_importFileWidget, &ImportFileWidget::subscriptionsChanged, this, &ImportFileDialog::checkOkButton);
-		connect(m_importFileWidget, &ImportFileWidget::checkFileType, this, &ImportFileDialog::checkOkButton);
-#endif
-		connect(m_optionsButton, &QPushButton::clicked, this, &ImportFileDialog::toggleOptions);
 
 		KWindowConfig::restoreWindowSize(windowHandle(), conf);
 		resize(windowHandle()->size()); // workaround for QTBUG-40584
 	} else
 		resize(QSize(0, 0).expandedTo(minimumSize()));
 
-	checkOkButton();
+	m_importFileWidget->showOptions(m_showOptions);
+	//do the signal-slot connections after all settings were loaded in import file widget and check the OK button after this
+	connect(m_importFileWidget, &ImportFileWidget::checkedFitsTableToMatrix, this, &ImportFileDialog::checkOnFitsTableToMatrix);
+	connect(m_importFileWidget, static_cast<void (ImportFileWidget::*)()>(&ImportFileWidget::fileNameChanged), this, &ImportFileDialog::checkOkButton);
+	connect(m_importFileWidget, static_cast<void (ImportFileWidget::*)()>(&ImportFileWidget::sourceTypeChanged), this, &ImportFileDialog::checkOkButton);
+	connect(m_importFileWidget, &ImportFileWidget::hostChanged, this, &ImportFileDialog::checkOkButton);
+	connect(m_importFileWidget, &ImportFileWidget::portChanged, this, &ImportFileDialog::checkOkButton);
+	//TODO: do we really need to check the ok button when the preview was refreshed?
+	//If not, remove this together with the previewRefreshed signal in ImportFileWidget
+	//connect(m_importFileWidget, &ImportFileWidget::previewRefreshed, this, &ImportFileDialog::checkOkButton);
+#ifdef HAVE_MQTT
+	connect(m_importFileWidget, &ImportFileWidget::subscriptionsChanged, this, &ImportFileDialog::checkOkButton);
+	connect(m_importFileWidget, &ImportFileWidget::checkFileType, this, &ImportFileDialog::checkOkButton);
+#endif
+
+	m_showOptions ? m_optionsButton->setText(i18n("Hide Options")) : m_optionsButton->setText(i18n("Show Options"));
+	connect(m_optionsButton, &QPushButton::clicked, this, &ImportFileDialog::toggleOptions);
+
+	ImportFileDialog::checkOkButton();
 }
 
 ImportFileDialog::~ImportFileDialog() {
@@ -166,7 +167,6 @@ void ImportFileDialog::importToLiveDataSource(LiveDataSource* source, QStatusBar
 
 	RESET_CURSOR;
 	statusBar->removeWidget(progressBar);
-	source->ready();
 }
 
 #ifdef HAVE_MQTT
@@ -217,19 +217,20 @@ void ImportFileDialog::importTo(QStatusBar* statusBar) const {
 	QTime timer;
 	timer.start();
 
-	if (aspect->inherits("Matrix")) {
+	if (aspect->inherits(AspectType::Matrix)) {
 		DEBUG("ImportFileDialog::importTo(): to Matrix");
 		auto* matrix = qobject_cast<Matrix*>(aspect);
 		filter->readDataFromFile(fileName, matrix, mode);
-	} else if (aspect->inherits("Spreadsheet")) {
+	} else if (aspect->inherits(AspectType::Spreadsheet)) {
 		DEBUG("ImportFileDialog::importTo(): to Spreadsheet");
 		auto* spreadsheet = qobject_cast<Spreadsheet*>(aspect);
 		DEBUG(" Calling filter->readDataFromFile() with spreadsheet " << spreadsheet);
 		filter->readDataFromFile(fileName, spreadsheet, mode);
-	} else if (aspect->inherits("Workbook")) {
+	} else if (aspect->inherits(AspectType::Workbook)) {
 		DEBUG("ImportFileDialog::importTo(): to Workbook");
-		auto* workbook = qobject_cast<Workbook*>(aspect);
-		QVector<AbstractAspect*> sheets = workbook->children<AbstractAspect>();
+		auto* workbook = static_cast<Workbook*>(aspect);
+		workbook->setUndoAware(false);
+		auto sheets = workbook->children<AbstractAspect>();
 
 		AbstractFileFilter::FileType fileType = m_importFileWidget->currentFileType();
 		// multiple data sets/variables for HDF5, NetCDF and ROOT
@@ -248,16 +249,46 @@ void ImportFileDialog::importTo(QStatusBar* statusBar) const {
 			//TODO: think about importing multiple sets into one sheet
 
 			int start = 0;	// add nrNames sheets (0 to nrNames)
-			if (mode == AbstractFileFilter::Replace) // add only missing sheets (from offset to nrNames)
+
+			//in replace mode add only missing sheets (from offset to nrNames)
+			//and rename the already available sheets
+			if (mode == AbstractFileFilter::Replace) {
 				start = offset;
 
-			// add additional sheets
+				// if there are more available spreadsheets, than needed,
+				// delete the unneeded spreadsheets
+				if (offset > nrNames) {
+					for (int i = nrNames; i < offset; i++)
+						sheets[i]->remove();
+					offset = nrNames;
+				}
+
+				//rename the available sheets
+				for (int i = 0; i < offset; ++i) {
+					//HDF5 variable names contain the whole path, remove it and keep the name only
+					QString sheetName = names.at(i);
+					if (fileType == AbstractFileFilter::HDF5)
+						sheetName = names[i].mid(names[i].lastIndexOf("/") + 1);
+
+					auto* sheet = sheets.at(i);
+					sheet->setUndoAware(false);
+					sheet->setName(sheetName);
+					sheet->setUndoAware(true);
+				}
+			}
+
+			// add additional spreadsheets
 			for (int i = start; i < nrNames; ++i) {
-				Spreadsheet *spreadsheet = new Spreadsheet(i18n("Spreadsheet"));
-				if (mode == AbstractFileFilter::Prepend)
+				//HDF5 variable names contain the whole path, remove it and keep the name only
+				QString sheetName = names.at(i);
+				if (fileType == AbstractFileFilter::HDF5)
+					sheetName = names[i].mid(names[i].lastIndexOf("/") + 1);
+
+				auto* spreadsheet = new Spreadsheet(sheetName);
+				if (mode == AbstractFileFilter::Prepend && !sheets.isEmpty())
 					workbook->insertChildBefore(spreadsheet, sheets[0]);
 				else
-					workbook->addChild(spreadsheet);
+					workbook->addChildFast(spreadsheet);
 			}
 
 			// start at offset for append, else at 0
@@ -275,22 +306,20 @@ void ImportFileDialog::importTo(QStatusBar* statusBar) const {
 					static_cast<ROOTFilter*>(filter)->setCurrentObject(names[i]);
 
 				int index = i + offset;
-				if (sheets[index]->inherits("Matrix"))
-					filter->readDataFromFile(fileName, qobject_cast<Matrix*>(sheets[index]));
-				else if (sheets[index]->inherits("Spreadsheet"))
-					filter->readDataFromFile(fileName, qobject_cast<Spreadsheet*>(sheets[index]));
+				filter->readDataFromFile(fileName, qobject_cast<Spreadsheet*>(sheets[index]));
 			}
+
+			workbook->setUndoAware(true);
 		} else { // single import file types
 			// use active spreadsheet/matrix if present, else new spreadsheet
-			Spreadsheet* spreadsheet = workbook->currentSpreadsheet();
-			Matrix* matrix = workbook->currentMatrix();
-			if (spreadsheet)
-				filter->readDataFromFile(fileName, spreadsheet, mode);
-			else if (matrix)
-				filter->readDataFromFile(fileName, matrix, mode);
+			auto* sheet = workbook->currentSpreadsheet();
+			if (sheet)
+				filter->readDataFromFile(fileName, sheet, mode);
 			else {
-				spreadsheet = new Spreadsheet(i18n("Spreadsheet"));
+				workbook->setUndoAware(true);
+				auto* spreadsheet = new Spreadsheet(fileName);
 				workbook->addChild(spreadsheet);
+				workbook->setUndoAware(false);
 				filter->readDataFromFile(fileName, spreadsheet, mode);
 			}
 		}
@@ -320,7 +349,7 @@ void ImportFileDialog::checkOnFitsTableToMatrix(const bool enable) {
 			return;
 		}
 
-		if (aspect->inherits("Matrix")) {
+		if (aspect->inherits(AspectType::Matrix)) {
 			okButton->setEnabled(enable);
 			if (enable)
 				okButton->setToolTip(i18n("Close the dialog and import the data."));
@@ -361,7 +390,7 @@ void ImportFileDialog::checkOkButton() {
 	DEBUG("Data Source Type: " << ENUM_TO_STRING(LiveDataSource, SourceType, m_importFileWidget->currentSourceType()));
 	switch (m_importFileWidget->currentSourceType()) {
 	case LiveDataSource::SourceType::FileOrPipe: {
-		DEBUG("fileName = " << fileName.toUtf8().constData());
+		DEBUG("	fileName = " << fileName.toUtf8().constData());
 		const bool enable = QFile::exists(fileName);
 		okButton->setEnabled(enable);
 		if (enable)
