@@ -3,7 +3,7 @@
     Project              : LabPlot
     Description          : import data dialog
     --------------------------------------------------------------------
-    Copyright            : (C) 2008-2017 Alexander Semke (alexander.semke@web.de)
+    Copyright            : (C) 2008-2019 Alexander Semke (alexander.semke@web.de)
     Copyright            : (C) 2008-2015 by Stefan Gerlach (stefan.gerlach@uni.kn)
 
  ***************************************************************************/
@@ -36,6 +36,10 @@ class MainWin;
 class ImportFileWidget;
 class LiveDataSource;
 
+#ifdef HAVE_MQTT
+class MQTTClient;
+#endif
+
 class QStatusBar;
 class QMenu;
 
@@ -44,26 +48,31 @@ class ImportFileDialog : public ImportDialog {
 
 public:
 	explicit ImportFileDialog(MainWin*, bool liveDataSource = false, const QString& fileName = QString());
-	~ImportFileDialog();
+	~ImportFileDialog() override;
 
-	virtual QString selectedObject() const;
+	QString selectedObject() const override;
+
+	int sourceType() const;
 
 	void importToLiveDataSource(LiveDataSource*, QStatusBar*) const;
-	virtual void importTo(QStatusBar*) const;
+
+#ifdef HAVE_MQTT
+	void importToMQTT(MQTTClient*) const;
+#endif
+
+	void importTo(QStatusBar*) const override;
 
 private:
 	ImportFileWidget* m_importFileWidget;
-	bool m_showOptions;
-	QMenu* m_newDataContainerMenu;
+	bool m_showOptions{false};
 	QPushButton* m_optionsButton;
 
 protected  slots:
-	virtual void checkOkButton();
+	void checkOkButton() override;
 
 private slots:
 	void toggleOptions();
 	void checkOnFitsTableToMatrix(const bool enable);
-	void loadSettings();
 };
 
 #endif //IMPORTFILEDIALOG_H
