@@ -62,6 +62,7 @@ Copyright            : (C) 2018-2019 Kovacs Ferencz (kferike98@gmail.com)
 #include <KConfigGroup>
 #include <KLocalizedString>
 #include <KSharedConfig>
+#include <KUrlComboBox>
 
 #ifdef HAVE_MQTT
 #include "kdefrontend/widgets/MQTTWillSettingsWidget.h"
@@ -92,7 +93,6 @@ ImportFileWidget::ImportFileWidget(QWidget* parent, bool liveDataSource, const Q
 #endif
 {
 	ui.setupUi(this);
-	ui.leFileName->setCompleter(new QCompleter(new QDirModel));
 
 	//add supported file types
 	if (!liveDataSource) {
@@ -134,6 +134,9 @@ ImportFileWidget::ImportFileWidget(QWidget* parent, bool liveDataSource, const Q
 
 		ui.tabWidget->removeTab(2);
 
+		ui.chbLinkFile->setToolTip(i18n("If this option is checked, only the link to the file is stored in the project file but not its content."));
+		ui.chbRelativePath->setToolTip(i18n("If this option is checked, the relative path of the file (relative to project's folder) will be saved."));
+
 #ifdef HAVE_MQTT
 		m_connectTimeoutTimer->setInterval(6000);
 #endif
@@ -168,6 +171,47 @@ ImportFileWidget::ImportFileWidget(QWidget* parent, bool liveDataSource, const Q
 	ui.tePreview->setLayout(layout);
 	m_twPreview->hide();
 
+	// the combobox for the import path
+	m_cbFileName = new KUrlComboBox(KUrlComboBox::Mode::Files, ui.tePreview);
+	m_cbFileName->setMaxItems(7);
+	auto* gridLayout = dynamic_cast<QGridLayout*>(ui.gbDataSource->layout());
+	if (gridLayout)
+		gridLayout->addWidget(m_cbFileName, 1, 2, 1, 3);
+
+
+	//tooltips
+	QString info = i18n("Specify how the data source has to be processed on every read:"
+					   "<ul>"
+					   "<li>Continuously fixed - fixed amount of samples is processed starting from the beginning of the newly received data.</li>"
+					   "<li>From End - fixed amount of samples is processed starting from the end of the newly received data.</li>"
+					   "<li>Till the End - all newly received data is processed.</li>"
+					   "<li>Whole file - on every read the whole file is re-read completely and processed. Only available for \"File Or Named Pipe\" data sources.</li>"
+					   "</ul>");
+	ui.lReadingType->setToolTip(info);
+	ui.cbReadingType->setToolTip(info);
+
+	info = i18n("Number of samples (lines) to be processed on every read.\n"
+				"Only needs to be specified for the reading mode \"Continuously Fixed\" and \"From End\".");
+	ui.lSampleSize->setToolTip(info);
+	ui.sbSampleSize->setToolTip(info);
+
+	info = i18n("Specify when and how frequently the data source needs to be read:"
+				"<ul>"
+				"<li>Periodically - the data source is read periodically with user specified time interval.</li>"
+				"<li>On New Data - the data source is read when new data arrives.</li>"
+				"</ul>");
+	ui.lUpdateType->setToolTip(info);
+	ui.cbUpdateType->setToolTip(info);
+
+	info = i18n("Specify how frequently the data source has to be read.");
+	ui.lUpdateInterval->setToolTip(info);
+	ui.sbUpdateInterval->setToolTip(info);
+
+	info = i18n("Specify how many samples need to be kept in memory after reading.\n"
+				"Use \"All\" if all data has to be kept.");
+	ui.lKeepLastValues->setToolTip(info);
+	ui.sbKeepNValues->setToolTip(info);
+
 #ifdef HAVE_MQTT
 	ui.cbSourceType->addItem(QLatin1String("MQTT"));
 	m_configPath = QStandardPaths::standardLocations(QStandardPaths::AppDataLocation).constFirst() + QLatin1String("MQTT_connections");
@@ -182,7 +226,7 @@ ImportFileWidget::ImportFileWidget(QWidget* parent, bool liveDataSource, const Q
 	ui.bManageConnections->setIcon(QIcon::fromTheme(QLatin1String("network-server")));
 	ui.bManageConnections->setToolTip(i18n("Manage MQTT connections"));
 
-	QString info = i18n("Specify the 'Last Will and Testament' message (LWT). At least one topic has to be subscribed.");
+	info = i18n("Specify the 'Last Will and Testament' message (LWT). At least one topic has to be subscribed.");
 	ui.lLWT->setToolTip(info);
 	ui.bLWT->setToolTip(info);
 	ui.bLWT->setEnabled(false);
@@ -221,24 +265,30 @@ void ImportFileWidget::loadSettings() {
 		}
 	}
 
-	ui.cbFilter->setCurrentIndex(conf.readEntry("Filter", 0));
-	filterChanged(ui.cbFilter->currentIndex());	// needed if filter is not changed
-	if (m_fileName.isEmpty())
-		ui.leFileName->setText(conf.readEntry("LastImportedFile", ""));
-	else
-		ui.leFileName->setText(m_fileName);
+	if (m_fileName.isEmpty()) {
+		ui.cbFilter->setCurrentIndex(conf.readEntry("Filter", 0));
+		m_cbFileName->setUrl(conf.readEntry("LastImportedFile", ""));
+		QStringList urls = m_cbFileName->urls();
+		urls.append(conf.readXdgListEntry("LastImportedFiles"));
+		m_cbFileName->setUrls(urls);
+		filterChanged(ui.cbFilter->currentIndex());	// needed if filter is not changed
+	} else
+		m_cbFileName->setUrl(QUrl(m_fileName));
+
 
 	//live data related settings
-	ui.cbBaudRate->setCurrentIndex(conf.readEntry("BaudRate").toInt());
-	ui.cbReadingType->setCurrentIndex(conf.readEntry("ReadingType").toInt());
+	ui.cbBaudRate->setCurrentIndex(conf.readEntry("BaudRate", 13)); // index for bautrate 19200b/s
+	ui.cbReadingType->setCurrentIndex(conf.readEntry("ReadingType", (int)LiveDataSource::WholeFile));
 	ui.cbSerialPort->setCurrentIndex(conf.readEntry("SerialPort").toInt());
-	ui.cbUpdateType->setCurrentIndex(conf.readEntry("UpdateType").toInt());
+	ui.cbUpdateType->setCurrentIndex(conf.readEntry("UpdateType", (int)LiveDataSource::NewData));
 	updateTypeChanged(ui.cbUpdateType->currentIndex());
 	ui.leHost->setText(conf.readEntry("Host",""));
-	ui.sbKeepNValues->setValue(conf.readEntry("KeepNValues").toInt());
+	ui.sbKeepNValues->setValue(conf.readEntry("KeepNValues", 0)); // keep all values
 	ui.lePort->setText(conf.readEntry("Port",""));
-	ui.sbSampleSize->setValue(conf.readEntry("SampleSize").toInt());
-	ui.sbUpdateInterval->setValue(conf.readEntry("UpdateInterval").toInt());
+	ui.sbSampleSize->setValue(conf.readEntry("SampleSize", 1));
+	ui.sbUpdateInterval->setValue(conf.readEntry("UpdateInterval", 1000));
+	ui.chbLinkFile->setCheckState((Qt::CheckState)conf.readEntry("LinkFile", (int)Qt::CheckState::Unchecked));
+	ui.chbRelativePath->setCheckState((Qt::CheckState)conf.readEntry("RelativePath", (int)Qt::CheckState::Unchecked));
 
 #ifdef HAVE_MQTT
 	//read available MQTT connections
@@ -286,7 +336,8 @@ ImportFileWidget::~ImportFileWidget() {
 	// general settings
 	conf.writeEntry("Type", (int)currentFileType());
 	conf.writeEntry("Filter", ui.cbFilter->currentIndex());
-	conf.writeEntry("LastImportedFile", ui.leFileName->text());
+	conf.writeEntry("LastImportedFile", m_cbFileName->currentText());
+	conf.writeXdgListEntry("LastImportedFiles", m_cbFileName->urls());
 
 	//live data related settings
 	conf.writeEntry("SourceType", (int)currentSourceType());
@@ -299,6 +350,8 @@ ImportFileWidget::~ImportFileWidget() {
 	conf.writeEntry("Host", ui.leHost->text());
 	conf.writeEntry("Port", ui.lePort->text());
 	conf.writeEntry("UpdateInterval", ui.sbUpdateInterval->value());
+	conf.writeEntry("LinkFile", (int)ui.chbLinkFile->checkState());
+	conf.writeEntry("RelativePath", (int)ui.chbRelativePath->checkState());
 
 #ifdef HAVE_MQTT
 
@@ -337,8 +390,8 @@ void ImportFileWidget::initSlots() {
 	//SLOTs for the general part of the data source configuration
 	connect(ui.cbSourceType, static_cast<void (QComboBox::*) (int)>(&QComboBox::currentIndexChanged),
 	        this, static_cast<void (ImportFileWidget::*) (int)>(&ImportFileWidget::sourceTypeChanged));
-	connect(ui.leFileName, &QLineEdit::textChanged,
-	        this, static_cast<void (ImportFileWidget::*) (const QString&)>(&ImportFileWidget::fileNameChanged));
+	connect(m_cbFileName, &KUrlComboBox::urlActivated,
+			this, [=](const QUrl &url){fileNameChanged(url.path());});
 	connect(ui.leHost, &QLineEdit::textChanged, this, &ImportFileWidget::hostChanged);
 	connect(ui.lePort, &QLineEdit::textChanged, this, &ImportFileWidget::portChanged);
 	connect(ui.tvJson, &QTreeView::clicked, this, &ImportFileWidget::refreshPreview);
@@ -390,14 +443,15 @@ void ImportFileWidget::showOptions(bool b) {
 }
 
 QString ImportFileWidget::fileName() const {
-	return ui.leFileName->text();
+	DEBUG("ImportFileWidget::fileName() : " << m_cbFileName->currentText().toStdString())
+	return m_cbFileName->currentText();
 }
 
 QString ImportFileWidget::selectedObject() const {
-	const QString& path = ui.leFileName->text();
+	const QString& path = fileName();
 
 	//determine the file name only
-	QString name = path.right(path.length() - path.lastIndexOf(QDir::separator()) - 1);
+	QString name = path.right(path.length() - path.lastIndexOf('/') - 1);
 
 	//strip away the extension if available
 	if (name.indexOf('.') != -1)
@@ -459,33 +513,22 @@ void ImportFileWidget::saveSettings(LiveDataSource* source) const {
 	LiveDataSource::SourceType sourceType = currentSourceType();
 	auto readingType = static_cast<LiveDataSource::ReadingType>(ui.cbReadingType->currentIndex());
 
-	source->setComment( ui.leFileName->text() );
+	source->setComment( fileName() );
 	source->setFileType(fileType);
 	currentFileFilter();
 	source->setFilter(m_currentFilter.release()); // pass ownership of the filter to the LiveDataSource
 
 	source->setSourceType(sourceType);
-	source->setReadingType(readingType);
-
-	if (updateType == LiveDataSource::UpdateType::TimeInterval)
-		source->setUpdateInterval(ui.sbUpdateInterval->value());
-	else
-		source->setFileWatched(true);
-
-	source->setKeepNValues(ui.sbKeepNValues->value());
-	source->setUpdateType(updateType);
-
-	if (readingType != LiveDataSource::ReadingType::TillEnd)
-		source->setSampleSize(ui.sbSampleSize->value());
 
 	switch (sourceType) {
 	case LiveDataSource::SourceType::FileOrPipe:
-		source->setFileName(ui.leFileName->text());
+		source->setFileName(fileName());
 		source->setFileLinked(ui.chbLinkFile->isChecked());
+		source->setUseRelativePath(ui.chbRelativePath->isChecked());
 		break;
 	case LiveDataSource::SourceType::LocalSocket:
-		source->setFileName(ui.leFileName->text());
-		source->setLocalSocketName(ui.leFileName->text());
+		source->setFileName(fileName());
+		source->setLocalSocketName(fileName());
 		break;
 	case LiveDataSource::SourceType::NetworkTcpSocket:
 	case LiveDataSource::SourceType::NetworkUdpSocket:
@@ -501,6 +544,16 @@ void ImportFileWidget::saveSettings(LiveDataSource* source) const {
 	default:
 		break;
 	}
+
+	//reading options
+	source->setReadingType(readingType);
+	source->setKeepNValues(ui.sbKeepNValues->value());
+	source->setUpdateType(updateType);
+	if (updateType == LiveDataSource::UpdateType::TimeInterval)
+		source->setUpdateInterval(ui.sbUpdateInterval->value());
+
+	if (readingType != LiveDataSource::ReadingType::TillEnd)
+		source->setSampleSize(ui.sbSampleSize->value());
 }
 
 #ifdef HAVE_MQTT
@@ -512,7 +565,7 @@ void ImportFileWidget::saveMQTTSettings(MQTTClient* client) const {
 	MQTTClient::UpdateType updateType = static_cast<MQTTClient::UpdateType>(ui.cbUpdateType->currentIndex());
 	MQTTClient::ReadingType readingType = static_cast<MQTTClient::ReadingType>(ui.cbReadingType->currentIndex());
 
-	client->setComment(ui.leFileName->text());
+	client->setComment(fileName());
 	currentFileFilter();
 	client->setFilter(static_cast<AsciiFilter*>(m_currentFilter.release())); // pass ownership of the filter to MQTTClient
 
@@ -735,13 +788,16 @@ AbstractFileFilter* ImportFileWidget::currentFileFilter() const {
 	opens a file dialog and lets the user select the file data source.
 */
 void ImportFileWidget::selectFile() {
+	DEBUG("ImportFileWidget::selectFile()")
 	KConfigGroup conf(KSharedConfig::openConfig(), QLatin1String("ImportFileWidget"));
 	const QString& dir = conf.readEntry(QLatin1String("LastDir"), "");
 	const QString& path = QFileDialog::getOpenFileName(this, i18n("Select the File Data Source"), dir);
+	DEBUG("	dir = " << dir.toStdString())
+	DEBUG("	path = " << path.toStdString())
 	if (path.isEmpty())	//cancel was clicked in the file-dialog
 		return;
 
-	int pos = path.lastIndexOf(QDir::separator());
+	int pos = path.lastIndexOf('/');
 	if (pos != -1) {
 		QString newDir = path.left(pos);
 		if (newDir != dir)
@@ -752,7 +808,12 @@ void ImportFileWidget::selectFile() {
 	//before we start calculating the preview
 	QApplication::processEvents(QEventLoop::AllEvents, 0);
 
-	ui.leFileName->setText(path);
+	QStringList urls = m_cbFileName->urls();
+	urls.insert(0, QUrl::fromLocalFile(path).url()); // add type of path
+	m_cbFileName->setUrls(urls);
+	m_cbFileName->setCurrentText(urls.first());
+	DEBUG("	combobox text = " << m_cbFileName->currentText().toStdString())
+	fileNameChanged(path); // why do I have to call this function separately
 }
 
 /*!
@@ -865,14 +926,14 @@ QString absolutePath(const QString& fileName) {
 	and activates the corresponding options.
 */
 void ImportFileWidget::fileNameChanged(const QString& name) {
-	DEBUG("ImportFileWidget::fileNameChanged()");
+	DEBUG("ImportFileWidget::fileNameChanged() : " << name.toStdString())
 	const QString fileName = absolutePath(name);
 
 	bool fileExists = QFile::exists(fileName);
 	if (fileExists)
-		ui.leFileName->setStyleSheet(QString());
+		m_cbFileName->setStyleSheet(QString());
 	else
-		ui.leFileName->setStyleSheet("QLineEdit{background:red;}");
+		m_cbFileName->setStyleSheet("QComboBox{background:red;}");
 
 	ui.gbOptions->setEnabled(fileExists);
 	ui.bManageFilters->setEnabled(fileExists);
@@ -899,10 +960,19 @@ void ImportFileWidget::fileNameChanged(const QString& name) {
 				if (ui.cbFileType->currentIndex() != i) {
 					ui.cbFileType->setCurrentIndex(i); // will call the slot fileTypeChanged which updates content and preview
 
+					//automatically set the comma separator if a csv file was selected
+					if (fileType == AbstractFileFilter::Ascii && name.endsWith(QLatin1String("csv"), Qt::CaseInsensitive))
+						m_asciiOptionsWidget->setSeparatingCharacter(QLatin1Char(','));
+
 					emit fileNameChanged();
 					return;
 				} else {
 					initOptionsWidget();
+
+					//automatically set the comma separator if a csv file was selected
+					if (fileType == AbstractFileFilter::Ascii && name.endsWith(QLatin1String("csv"), Qt::CaseInsensitive))
+						m_asciiOptionsWidget->setSeparatingCharacter(QLatin1Char(','));
+
 					updateContent(fileName);
 					break;
 				}
@@ -936,7 +1006,7 @@ void ImportFileWidget::manageFilters() {
 
 /*!
 	Depending on the selected file type, activates the corresponding options in the data portion tab
-	and populates the combobox with the available pre-defined fllter settings for the selected type.
+	and populates the combobox with the available pre-defined filter settings for the selected type.
 */
 void ImportFileWidget::fileTypeChanged(int index) {
 	Q_UNUSED(index);
@@ -1026,7 +1096,8 @@ void ImportFileWidget::fileTypeChanged(int index) {
 	filterChanged(lastUsedFilterIndex);
 
 	if (currentSourceType() == LiveDataSource::FileOrPipe) {
-		const QString& fileName = absolutePath(ui.leFileName->text());
+		QString tempFileName = fileName();
+		const QString& fileName = absolutePath(tempFileName);
 		if (QFile::exists(fileName))
 			updateContent(fileName);
 	}
@@ -1155,7 +1226,7 @@ const QStringList ImportFileWidget::selectedROOTNames() const {
 	shows the dialog with the information about the file(s) to be imported.
 */
 void ImportFileWidget::fileInfoDialog() {
-	QStringList files = ui.leFileName->text().split(';');
+	QStringList files = fileName().split(';');
 	auto* dlg = new FileInfoDialog(this);
 	dlg->setFiles(files);
 	dlg->exec();
@@ -1192,13 +1263,14 @@ void ImportFileWidget::refreshPreview() {
 	DEBUG("ImportFileWidget::refreshPreview()");
 	WAIT_CURSOR;
 
-	QString fileName = absolutePath(ui.leFileName->text());
+	QString tempFileName = fileName();
+	QString fileName = absolutePath(tempFileName);
 	AbstractFileFilter::FileType fileType = currentFileType();
 	LiveDataSource::SourceType sourceType = currentSourceType();
 	int lines = ui.sbPreviewLines->value();
 
 	if (sourceType == LiveDataSource::SourceType::FileOrPipe)
-		DEBUG("refreshPreview(): file name = " << fileName.toStdString());
+		DEBUG("	file name = " << fileName.toStdString());
 
 	// generic table widget
 	if (fileType == AbstractFileFilter::Ascii || fileType == AbstractFileFilter::Binary
@@ -1386,7 +1458,7 @@ void ImportFileWidget::refreshPreview() {
 		importedStrings = filter->previewCurrentObject(
 		                      fileName,
 		                      m_rootOptionsWidget->startRow(),
-		                      qMin(m_rootOptionsWidget->startRow() + m_rootOptionsWidget->lines() - 1,
+		                      qMin(m_rootOptionsWidget->startRow() + lines - 1,
 		                           m_rootOptionsWidget->endRow())
 		                  );
 		tmpTableWidget = m_rootOptionsWidget->previewWidget();
@@ -1545,9 +1617,11 @@ void ImportFileWidget::sourceTypeChanged(int idx) {
 	switch (sourceType) {
 	case LiveDataSource::SourceType::FileOrPipe:
 		ui.lFileName->show();
-		ui.leFileName->show();
+		m_cbFileName->show();
 		ui.bFileInfo->show();
 		ui.bOpen->show();
+		ui.lRelativePath->show();
+		ui.chbRelativePath->show();
 		ui.chbLinkFile->show();
 
 		//option for sample size are available for "continuously fixed" and "from end" reading options
@@ -1570,7 +1644,7 @@ void ImportFileWidget::sourceTypeChanged(int idx) {
 
 		item->setFlags(Qt::ItemIsSelectable | Qt::ItemIsEnabled);
 
-		fileNameChanged(ui.leFileName->text());
+		fileNameChanged(fileName());
 		ui.cbFileType->show();
 		ui.lFileType->show();
 		setMQTTVisible(false);
@@ -1595,9 +1669,11 @@ void ImportFileWidget::sourceTypeChanged(int idx) {
 		ui.cbSerialPort->hide();
 
 		ui.lFileName->hide();
-		ui.leFileName->hide();
+		m_cbFileName->hide();
 		ui.bFileInfo->hide();
 		ui.bOpen->hide();
+		ui.lRelativePath->hide();
+		ui.chbRelativePath->hide();
 		ui.chbLinkFile->hide();
 
 		item->setFlags(item->flags() & ~(Qt::ItemIsSelectable | Qt::ItemIsEnabled));
@@ -1612,12 +1688,14 @@ void ImportFileWidget::sourceTypeChanged(int idx) {
 		break;
 	case LiveDataSource::SourceType::LocalSocket:
 		ui.lFileName->show();
-		ui.leFileName->show();
+		m_cbFileName->show();
+		ui.bFileInfo->hide();
 		ui.bOpen->show();
+		ui.lRelativePath->hide();
+		ui.chbRelativePath->hide();
+
 		ui.lSampleSize->hide();
 		ui.sbSampleSize->hide();
-
-		ui.bFileInfo->hide();
 		ui.cbBaudRate->hide();
 		ui.lBaudRate->hide();
 		ui.lHost->hide();
@@ -1650,10 +1728,13 @@ void ImportFileWidget::sourceTypeChanged(int idx) {
 		ui.leHost->hide();
 		ui.lePort->hide();
 		ui.lPort->hide();
+
 		ui.lFileName->hide();
-		ui.leFileName->hide();
+		m_cbFileName->hide();
 		ui.bFileInfo->hide();
 		ui.bOpen->hide();
+		ui.lRelativePath->hide();
+		ui.chbRelativePath->hide();
 		ui.chbLinkFile->hide();
 
 		item->setFlags(item->flags() & ~(Qt::ItemIsSelectable | Qt::ItemIsEnabled));
@@ -1693,9 +1774,11 @@ void ImportFileWidget::sourceTypeChanged(int idx) {
 		ui.lPort->hide();
 		ui.lePort->hide();
 		ui.lFileName->hide();
-		ui.leFileName->hide();
+		m_cbFileName->hide();
 		ui.bFileInfo->hide();
 		ui.bOpen->hide();
+		ui.lRelativePath->hide();
+		ui.chbRelativePath->hide();
 		ui.chbLinkFile->hide();
 
 		setMQTTVisible(true);
@@ -1826,7 +1909,7 @@ void ImportFileWidget::onMqttDisconnect() {
 	ui.lLWT->hide();
 	ui.bLWT->hide();
 
-	ui.cbConnection->setItemText(ui.cbConnection->currentIndex(), ui.cbConnection->currentText() + " " + i18n("(Disconnected)"));
+	ui.cbConnection->setItemText(ui.cbConnection->currentIndex(), ui.cbConnection->currentText() + ' ' + i18n("(Disconnected)"));
 
 	emit subscriptionsChanged();
 	RESET_CURSOR;
@@ -1855,7 +1938,7 @@ void ImportFileWidget::mqttSubscribe(const QString& name, uint QoS) {
  */
 void ImportFileWidget::mqttMessageReceived(const QByteArray& message, const QMqttTopicName& topic) {
 	Q_UNUSED(message);
-// 	qDebug()<<"recieved " << topic.name();
+// 	qDebug()<<"received " << topic.name();
 	if (m_addedTopics.contains(topic.name()))
 		return;
 
