@@ -80,8 +80,7 @@ ImportProjectDialog::ImportProjectDialog(MainWin* parent, ProjectType type) : QD
 	m_cbAddTo->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);
 	ui.gbImportTo->layout()->addWidget(m_cbAddTo);
 
-	QList<const char*> list;
-	list << "Folder";
+	QList<AspectType> list{AspectType::Folder};
 	m_cbAddTo->setTopLevelClasses(list);
 	m_aspectTreeModel->setSelectableAspects(list);
 	m_cbAddTo->setModel(m_aspectTreeModel);
@@ -104,7 +103,7 @@ ImportProjectDialog::ImportProjectDialog(MainWin* parent, ProjectType type) : QD
 	connect(m_bNewFolder, SIGNAL(clicked()), this, SLOT(newFolder()));
 	connect(ui.chbUnusedObjects, &QCheckBox::stateChanged, this, &ImportProjectDialog::refreshPreview);
 	connect(m_buttonBox, &QDialogButtonBox::accepted, this, &QDialog::accept);
-    connect(m_buttonBox, &QDialogButtonBox::rejected, this, &QDialog::reject);
+	connect(m_buttonBox, &QDialogButtonBox::rejected, this, &QDialog::reject);
 
 	QString title;
 	switch (m_projectType) {
@@ -124,6 +123,19 @@ ImportProjectDialog::ImportProjectDialog(MainWin* parent, ProjectType type) : QD
 	setWindowTitle(title);
 	setWindowIcon(QIcon::fromTheme("document-import"));
 
+	//"What's this?" texts
+    QString info = i18n("Specify the file where the project content has to be imported from.");
+	ui.leFileName->setWhatsThis(info);
+
+    info = i18n("Select one or several objects to be imported into the current project.\n"
+	            "Note, all children of the selected objects as well as all the dependent objects will be automatically selected.\n"
+	            "To import the whole project, select the top-level project node."
+	           );
+	ui.tvPreview->setWhatsThis(info);
+
+    info = i18n("Specify the target folder in the current project where the selected objects have to be imported into.");
+	m_cbAddTo->setWhatsThis(info);
+
 	//restore saved settings if available
 	create(); // ensure there's a window created
 	KConfigGroup conf(KSharedConfig::openConfig(), "ImportProjectDialog");
@@ -211,8 +223,8 @@ void ImportProjectDialog::importTo(QStatusBar* statusBar) const {
 
 	if (!existingPathes.isEmpty()) {
 		QString msg = i18np("The object listed below already exists in target folder and will be overwritten:",
-							"The objects listed below already exist in target folder and will be overwritten:",
-							existingPathes.size());
+		                    "The objects listed below already exist in target folder and will be overwritten:",
+		                    existingPathes.size());
 		msg += '\n';
 		for (const auto& path : existingPathes)
 			msg += '\n' + path.right(path.length() - path.indexOf('/') - 1); //strip away the name of the root folder "Project"
@@ -273,7 +285,7 @@ void ImportProjectDialog::refreshPreview() {
 	ui.tvPreview->setModel(m_projectParser->model());
 
 	connect(ui.tvPreview->selectionModel(), SIGNAL(selectionChanged(QItemSelection,QItemSelection)),
-			this, SLOT(selectionChanged(QItemSelection,QItemSelection)) );
+	        this, SLOT(selectionChanged(QItemSelection,QItemSelection)) );
 
 	//show top-level containers only
 	if (ui.tvPreview->model()) {
@@ -281,7 +293,9 @@ void ImportProjectDialog::refreshPreview() {
 		showTopLevelOnly(root);
 	}
 
-	//extand the tree to show all available top-level objects and adjust the header sizes
+	//select the first top-level node and
+	//expand the tree to show all available top-level objects and adjust the header sizes
+	ui.tvPreview->setCurrentIndex(ui.tvPreview->model()->index(0,0));
 	ui.tvPreview->expandAll();
 	ui.tvPreview->header()->resizeSections(QHeaderView::ResizeToContents);
 }
@@ -292,7 +306,7 @@ void ImportProjectDialog::refreshPreview() {
 void ImportProjectDialog::showTopLevelOnly(const QModelIndex& index) {
 	int rows = index.model()->rowCount(index);
 	for (int i = 0; i < rows; ++i) {
-		QModelIndex child = index.child(i, 0);
+		QModelIndex child = index.model()->index(i, 0, index);
 		showTopLevelOnly(child);
 		const auto* aspect = static_cast<const AbstractAspect*>(child.internalPointer());
 		ui.tvPreview->setRowHidden(i, index, !isTopLevel(aspect));
@@ -303,9 +317,9 @@ void ImportProjectDialog::showTopLevelOnly(const QModelIndex& index) {
 	checks whether \c aspect is one of the allowed top level types
 */
 bool ImportProjectDialog::isTopLevel(const AbstractAspect* aspect) const {
-	foreach (const char* classString, m_projectParser->topLevelClasses()) {
-		if (aspect->inherits(classString))
-				return true;
+	foreach (AspectType type, m_projectParser->topLevelClasses()) {
+		if (aspect->inherits(type))
+			return true;
 	}
 	return false;
 }
