@@ -33,6 +33,12 @@
 #include "backend/datasources/filters/AbstractFileFilter.h"
 #include "backend/lib/macros.h"
 
+#include <QTimer>
+#include <QSqlError>
+#include <QSqlQuery>
+#include <QSqlRecord>
+#include <QStandardItem>
+
 #include <KConfig>
 #include <KConfigGroup>
 #include <KLocalizedString>
@@ -44,9 +50,6 @@
 #include <KF5/KSyntaxHighlighting/Theme>
 #endif
 
-#include <QtSql>
-#include <QStandardItem>
-
 ImportSQLDatabaseWidget::ImportSQLDatabaseWidget(QWidget* parent) : QWidget(parent) {
 	ui.setupUi(this);
 
@@ -177,7 +180,7 @@ void ImportSQLDatabaseWidget::connectionChanged() {
 	KConfig config(m_configPath, KConfig::SimpleConfig);
 	KConfigGroup group = config.group(ui.cbConnection->currentText());
 
-	//close and remove the previos connection, if available
+	//close and remove the previous connection, if available
 	if (m_db.isOpen()) {
 		m_db.close();
 		QSqlDatabase::removeDatabase(m_db.driverName());
@@ -252,7 +255,7 @@ void ImportSQLDatabaseWidget::refreshPreview() {
 	q.prepare(currentQuery(true));
 	q.setForwardOnly(true);
 	q.exec();
-	if (!q.isActive() || !q.next()) { // check if query was succesful and got to first record
+	if (!q.isActive() || !q.next()) { // check if query was successful and got to first record
 		RESET_CURSOR;
 		if (!q.lastError().databaseText().isEmpty())
 			KMessageBox::error(this, q.lastError().databaseText(), i18n("Unable to Execute Query"));
@@ -361,7 +364,7 @@ void ImportSQLDatabaseWidget::read(AbstractDataSource* dataSource, AbstractFileF
 
 	// pointers to the actual data containers
 	//columnOffset indexes the "start column" in the datasource. Data will be imported starting from this column.
-	QVector<void*> dataContainer;
+	std::vector<void*> dataContainer;
 	int columnOffset = dataSource->prepareImport(dataContainer, importMode, rows, m_cols, m_columnNames, m_columnModes);
 
 	//number and DateTime formatting
@@ -407,7 +410,7 @@ void ImportSQLDatabaseWidget::read(AbstractDataSource* dataSource, AbstractFileF
 	} while (q.next());
 	DEBUG("	Read " << row << " rows");
 
-	dataSource->finalizeImport(columnOffset, 1, m_cols, row, dateTimeFormat, importMode);
+	dataSource->finalizeImport(columnOffset, 1, m_cols, dateTimeFormat, importMode);
 	RESET_CURSOR;
 }
 
