@@ -52,8 +52,10 @@
  \ingroup kdefrontend
 */
 
-AxisDock::AxisDock(QWidget* parent) : QWidget(parent) {
+AxisDock::AxisDock(QWidget* parent) : BaseDock(parent) {
 	ui.setupUi(this);
+	m_leName = ui.leName;
+	m_leComment = ui.leComment;
 
 	//"Title"-tab
 	auto* hboxLayout = new QHBoxLayout(ui.tabTitle);
@@ -168,13 +170,19 @@ AxisDock::AxisDock(QWidget* parent) : QWidget(parent) {
 	connect( ui.sbMinorGridWidth, SIGNAL(valueChanged(double)), this, SLOT(minorGridWidthChanged(double)) );
 	connect( ui.sbMinorGridOpacity, SIGNAL(valueChanged(int)), this, SLOT(minorGridOpacityChanged(int)) );
 
+	//template handler
+	auto* frame = new QFrame(this);
+	auto* hlayout = new QHBoxLayout(frame);
+	hlayout->setContentsMargins(0, 11, 0, 11);
 
 	auto* templateHandler = new TemplateHandler(this, TemplateHandler::Axis);
-	ui.verticalLayout->addWidget(templateHandler);
+	hlayout->addWidget(templateHandler);
 	connect(templateHandler, SIGNAL(loadConfigRequested(KConfig&)), this, SLOT(loadConfigFromTemplate(KConfig&)));
 	connect(templateHandler, SIGNAL(saveConfigRequested(KConfig&)), this, SLOT(saveConfigAsTemplate(KConfig&)));
 	connect(templateHandler, SIGNAL(info(QString)), this, SIGNAL(info(QString)));
 
+	ui.verticalLayout->addWidget(frame);
+
 	init();
 }
 
@@ -322,6 +330,8 @@ void AxisDock::init() {
 	GuiTools::updatePenStyles(ui.cbLineStyle, QColor(Qt::black));
 	GuiTools::updatePenStyles(ui.cbMajorTicksLineStyle, QColor(Qt::black));
 	GuiTools::updatePenStyles(ui.cbMinorTicksLineStyle, QColor(Qt::black));
+	GuiTools::updatePenStyles(ui.cbMajorGridStyle, QColor(Qt::black));
+	GuiTools::updatePenStyles(ui.cbMinorGridStyle, QColor(Qt::black));
 
 	//labels
 	ui.cbLabelsPosition->addItem(i18n("No labels"));
@@ -341,13 +351,11 @@ void AxisDock::init() {
 }
 
 void AxisDock::setModel() {
-	QList<const char*>  list;
-	list<<"Folder"<<"Spreadsheet"<<"FileDataSource"<<"Column";
+	QList<AspectType> list{AspectType::Folder, AspectType::Spreadsheet, AspectType::Column};
 	cbMajorTicksColumn->setTopLevelClasses(list);
 	cbMinorTicksColumn->setTopLevelClasses(list);
 
-	list.clear();
-	list<<"Column";
+	list = {AspectType::Column};
 	m_aspectTreeModel->setSelectableAspects(list);
 
 	cbMajorTicksColumn->setModel(m_aspectTreeModel);
@@ -361,6 +369,7 @@ void AxisDock::setAxes(QList<Axis*> list) {
 	m_initializing = true;
 	m_axesList = list;
 	m_axis = list.first();
+	m_aspect = list.first();
 	Q_ASSERT(m_axis != nullptr);
 	m_aspectTreeModel = new AspectTreeModel(m_axis->project());
 	this->setModel();
@@ -387,6 +396,8 @@ void AxisDock::setAxes(QList<Axis*> list) {
 		cbMajorTicksColumn->setCurrentModelIndex(QModelIndex());
 		cbMinorTicksColumn->setCurrentModelIndex(QModelIndex());
 	}
+	ui.leName->setStyleSheet("");
+	ui.leName->setToolTip("");
 
 	//show the properties of the first axis
 	this->load();
@@ -465,20 +476,6 @@ void AxisDock::setModelIndexFromColumn(TreeViewComboBox* cb, const AbstractColum
 //********** SLOTs for changes triggered in AxisDock **********
 //*************************************************************
 //"General"-tab
-void AxisDock::nameChanged() {
-	if (m_initializing)
-		return;
-
-	m_axis->setName(ui.leName->text());
-}
-
-void AxisDock::commentChanged() {
-	if (m_initializing)
-		return;
-
-	m_axis->setComment(ui.leComment->text());
-}
-
 void AxisDock::visibilityChanged(bool state) {
 	if (m_initializing)
 		return;
@@ -519,7 +516,7 @@ void AxisDock::orientationChanged(int index) {
 	if (m_initializing)
 		return;
 
-	//depending on the current orientation we need to update axis possition and labels position
+	//depending on the current orientation we need to update axis position and labels position
 
 	//axis position, map from the current index in the combobox to the enum value in Axis::AxisPosition
 	Axis::AxisPosition axisPosition;
@@ -528,9 +525,8 @@ void AxisDock::orientationChanged(int index) {
 		if (posIndex > 1)
 			posIndex += 2;
 		axisPosition = Axis::AxisPosition(posIndex);
-	} else {
+	} else
 		axisPosition = Axis::AxisPosition(posIndex+2);
-	}
 
 	//labels position
 	posIndex = ui.cbLabelsPosition->currentIndex();
@@ -568,9 +564,8 @@ void AxisDock::positionChanged(int index) {
 		if (index>1)
 			index += 2;
 		position = Axis::AxisPosition(index);
-	} else {
+	} else
 		position = Axis::AxisPosition(index+2);
-	}
 
 	for (auto* axis : m_axesList)
 		axis->setPosition(position);
@@ -637,6 +632,7 @@ void AxisDock::startChanged() {
 		}
 	}
 
+	const Lock lock(m_initializing);
 	for (auto* axis : m_axesList)
 		axis->setStart(value);
 }
@@ -646,6 +642,7 @@ void AxisDock::endChanged() {
 		return;
 
 	double value = ui.leEnd->text().toDouble();
+	const Lock lock(m_initializing);
 	for (auto* axis : m_axesList)
 		axis->setEnd(value);
 }
@@ -673,6 +670,7 @@ void AxisDock::zeroOffsetChanged() {
 		return;
 
 	double offset = ui.leZeroOffset->text().toDouble();
+	const Lock lock(m_initializing);
 	for (auto* axis : m_axesList)
 		axis->setZeroOffset(offset);
 }
@@ -682,9 +680,11 @@ void AxisDock::scalingFactorChanged() {
 		return;
 
 	double scalingFactor = ui.leScalingFactor->text().toDouble();
-	if (scalingFactor != 0.0)
+	if (scalingFactor != 0.0) {
+		const Lock lock(m_initializing);
 		for (auto* axis : m_axesList)
 			axis->setScalingFactor(scalingFactor);
+	}
 }
 
 // "Line"-tab
@@ -1529,7 +1529,9 @@ void AxisDock::axisAutoScaleChanged(bool on) {
 }
 
 void AxisDock::axisStartChanged(double value) {
-	m_initializing = true;
+	if (m_initializing) return;
+	const Lock lock(m_initializing);
+
 	ui.leStart->setText( QString::number(value) );
 	ui.dateTimeEditStart->setDateTime( QDateTime::fromMSecsSinceEpoch(value) );
 
@@ -1538,11 +1540,12 @@ void AxisDock::axisStartChanged(double value) {
 	int decimal = determineDecimals(diff);
 	ui.sbMajorTicksIncrementNumeric->setDecimals(decimal);
 	ui.sbMajorTicksIncrementNumeric->setSingleStep(determineStep(diff, decimal));
-	m_initializing = false;
 }
 
 void AxisDock::axisEndChanged(double value) {
-	m_initializing = true;
+	if (m_initializing) return;
+	const Lock lock(m_initializing);
+
 	ui.leEnd->setText( QString::number(value) );
 	ui.dateTimeEditEnd->setDateTime( QDateTime::fromMSecsSinceEpoch(value) );
 	ui.sbMajorTicksIncrementNumeric->setSingleStep(floor(m_axis->end() - m_axis->start())/10);
@@ -1552,19 +1555,18 @@ void AxisDock::axisEndChanged(double value) {
 	int decimal = determineDecimals(diff);
 	ui.sbMajorTicksIncrementNumeric->setDecimals(decimal);
 	ui.sbMajorTicksIncrementNumeric->setSingleStep(determineStep(diff, decimal));
-	m_initializing = false;
 }
 
 void AxisDock::axisZeroOffsetChanged(qreal value) {
-	m_initializing = true;
+	if (m_initializing) return;
+	const Lock lock(m_initializing);
 	ui.leZeroOffset->setText( QString::number(value) );
-	m_initializing = false;
 }
 
 void AxisDock::axisScalingFactorChanged(qreal value) {
-	m_initializing = true;
+	if (m_initializing) return;
+	const Lock lock(m_initializing);
 	ui.leScalingFactor->setText( QString::number(value) );
-	m_initializing = false;
 }
 
 //line
@@ -1959,8 +1961,8 @@ int AxisDock::determineDecimals(double diff) {
  * \return
  */
 double AxisDock::determineStep(double diff, int decimal) {
-	double ten = 1;
 	if (decimal == 0) {
+		double ten = 1;
 		for (unsigned int i = 1; i < 1000000000; i++) {
 			if (diff/ten <= 10) {
 				return ten/10; // use one decimal before
@@ -2143,7 +2145,7 @@ void AxisDock::saveConfigAsTemplate(KConfig& config) {
 	group.writeEntry("LineStyle", ui.cbLineStyle->currentIndex());
 	group.writeEntry("LineColor", ui.kcbLineColor->color());
 	group.writeEntry("LineWidth", Worksheet::convertToSceneUnits(ui.sbLineWidth->value(), Worksheet::Point));
-	group.writeEntry("LineOpacity", ui.sbLineOpacity->value()/100);
+	group.writeEntry("LineOpacity", ui.sbLineOpacity->value()/100.);
 
 	//Major ticks
 	group.writeEntry("MajorTicksDirection", ui.cbMajorTicksDirection->currentIndex());
@@ -2157,7 +2159,7 @@ void AxisDock::saveConfigAsTemplate(KConfig& config) {
 	group.writeEntry("MajorTicksColor", ui.kcbMajorTicksColor->color());
 	group.writeEntry("MajorTicksWidth", Worksheet::convertToSceneUnits(ui.sbMajorTicksWidth->value(),Worksheet::Point));
 	group.writeEntry("MajorTicksLength", Worksheet::convertToSceneUnits(ui.sbMajorTicksLength->value(),Worksheet::Point));
-	group.writeEntry("MajorTicksOpacity", ui.sbMajorTicksOpacity->value()/100);
+	group.writeEntry("MajorTicksOpacity", ui.sbMajorTicksOpacity->value()/100.);
 
 	//Minor ticks
 	group.writeEntry("MinorTicksDirection", ui.cbMinorTicksDirection->currentIndex());
@@ -2171,7 +2173,7 @@ void AxisDock::saveConfigAsTemplate(KConfig& config) {
 	group.writeEntry("MinorTicksColor", ui.kcbMinorTicksColor->color());
 	group.writeEntry("MinorTicksWidth", Worksheet::convertFromSceneUnits(ui.sbMinorTicksWidth->value(),Worksheet::Point));
 	group.writeEntry("MinorTicksLength", Worksheet::convertFromSceneUnits(ui.sbMinorTicksLength->value(),Worksheet::Point));
-	group.writeEntry("MinorTicksOpacity", ui.sbMinorTicksOpacity->value()/100);
+	group.writeEntry("MinorTicksOpacity", ui.sbMinorTicksOpacity->value()/100.);
 
 	//Extra ticks
 	// TODO
@@ -2187,17 +2189,17 @@ void AxisDock::saveConfigAsTemplate(KConfig& config) {
 	group.writeEntry("LabelsFontColor", ui.kcbLabelsFontColor->color());
 	group.writeEntry("LabelsPrefix", ui.leLabelsPrefix->text());
 	group.writeEntry("LabelsSuffix", ui.leLabelsSuffix->text());
-	group.writeEntry("LabelsOpacity", ui.sbLabelsOpacity->value()/100);
+	group.writeEntry("LabelsOpacity", ui.sbLabelsOpacity->value()/100.);
 
 	//Grid
 	group.writeEntry("MajorGridStyle", ui.cbMajorGridStyle->currentIndex());
 	group.writeEntry("MajorGridColor", ui.kcbMajorGridColor->color());
 	group.writeEntry("MajorGridWidth", Worksheet::convertToSceneUnits(ui.sbMajorGridWidth->value(), Worksheet::Point));
-	group.writeEntry("MajorGridOpacity", ui.sbMajorGridOpacity->value()/100);
+	group.writeEntry("MajorGridOpacity", ui.sbMajorGridOpacity->value()/100.);
 
 	group.writeEntry("MinorGridStyle", ui.cbMinorGridStyle->currentIndex());
 	group.writeEntry("MinorGridColor", ui.kcbMinorGridColor->color());
 	group.writeEntry("MinorGridWidth", Worksheet::convertToSceneUnits(ui.sbMinorGridWidth->value(), Worksheet::Point));
-	group.writeEntry("MinorGridOpacity", ui.sbMinorGridOpacity->value()/100);
+	group.writeEntry("MinorGridOpacity", ui.sbMinorGridOpacity->value()/100.);
 	config.sync();
 }
