@@ -33,6 +33,7 @@
 #include "backend/worksheet/Worksheet.h"
 #include "backend/worksheet/plots/cartesian/CartesianPlot.h"
 #include "ui_cartesianplotdock.h"
+#include "kdefrontend/dockwidgets/BaseDock.h"
 
 #include <KConfig>
 
@@ -41,7 +42,7 @@ class LabelWidget;
 class ThemeHandler;
 class KLocalizedString;
 
-class CartesianPlotDock : public QWidget {
+class CartesianPlotDock : public BaseDock {
 	Q_OBJECT
 
 public:
@@ -54,7 +55,6 @@ private:
 	QList<CartesianPlot*> m_plotList;
 	CartesianPlot* m_plot{nullptr};
 	LabelWidget* labelWidget{nullptr};
-	bool m_initializing{false};
 	ThemeHandler* m_themeHandler;
 
 	void loadConfig(KConfig&);
@@ -65,8 +65,6 @@ private slots:
 
 	//SLOTs for changes triggered in CartesianPlotDock
 	//"General"-tab
-	void nameChanged();
-	void commentChanged();
 	void visibilityChanged(bool);
 	void geometryChanged();
 	void layoutChanged(Worksheet::Layout);
@@ -125,8 +123,16 @@ private slots:
 	void borderWidthChanged(double);
 	void borderCornerRadiusChanged(double);
 	void borderOpacityChanged(int);
+	void symmetricPaddingChanged(bool);
 	void horizontalPaddingChanged(double);
+	void rightPaddingChanged(double);
 	void verticalPaddingChanged(double);
+	void bottomPaddingChanged(double);
+
+	// "Cursor"-tab
+	void cursorLineWidthChanged(int width);
+	void cursorLineColorChanged(QColor color);
+	void cursorLineStyleChanged(int index);
 
 	//SLOTs for changes triggered in CartesianPlot
 	//general
@@ -171,6 +177,12 @@ private slots:
 	void plotBorderOpacityChanged(float);
 	void plotHorizontalPaddingChanged(float);
 	void plotVerticalPaddingChanged(float);
+	void plotRightPaddingChanged(double);
+	void plotBottomPaddingChanged(double);
+	void plotSymmetricPaddingChanged(bool);
+
+	// Cursor
+	void plotCursorPenChanged(QPen);
 
 	//save/load template
 	void loadConfigFromTemplate(KConfig&);
