@@ -2,7 +2,7 @@
     File                 : ColumnDock.cpp
     Project              : LabPlot
     --------------------------------------------------------------------
-    Copyright            : (C) 2011-2018 by Alexander Semke (alexander.semke@web.de)
+	Copyright            : (C) 2011-2019 by Alexander Semke (alexander.semke@web.de)
     Copyright            : (C) 2013-2017 by Stefan Gerlach (stefan.gerlach@uni.kn)
     Description          : widget for column properties
 
@@ -35,6 +35,7 @@
 #include "backend/core/datatypes/String2DoubleFilter.h"
 #include "backend/core/datatypes/DateTime2StringFilter.h"
 #include "backend/core/datatypes/String2DateTimeFilter.h"
+#include "backend/datapicker/DatapickerCurve.h"
 #include "backend/datasources/LiveDataSource.h"
 #include "backend/spreadsheet/Spreadsheet.h"
 
@@ -47,8 +48,10 @@
   \ingroup kdefrontend
 */
 
-ColumnDock::ColumnDock(QWidget* parent) : QWidget(parent) {
+ColumnDock::ColumnDock(QWidget* parent) : BaseDock(parent) {
 	ui.setupUi(this);
+	m_leName = ui.leName;
+	m_leComment = ui.leComment;
 
 	connect(ui.leName, &QLineEdit::textChanged, this, &ColumnDock::nameChanged);
 	connect(ui.leComment, &QLineEdit::textChanged, this, &ColumnDock::commentChanged);
@@ -64,13 +67,17 @@ void ColumnDock::setColumns(QList<Column*> list) {
 	m_initializing = true;
 	m_columnsList = list;
 	m_column = list.first();
+	m_aspect = list.first();
 
-	//check whether we have non-editable columns (e.g. columns for residuals calculated in XYFitCurve)
+	//check whether we have non-editable columns:
+	//1. columns in a LiveDataSource
+	//2. columns in the spreadsheet of a datapicker curve
+	//3. columns for residuals calculated in XYFitCurve)
 	bool nonEditable = false;
 	for (auto* col : m_columnsList) {
 		auto* s = dynamic_cast<Spreadsheet*>(col->parentAspect());
 		if (s) {
-			if (dynamic_cast<LiveDataSource*>(s)) {
+			if (dynamic_cast<LiveDataSource*>(s) || dynamic_cast<DatapickerCurve*>(s->parentAspect())) {
 				nonEditable = true;
 				break;
 			}
@@ -99,6 +106,8 @@ void ColumnDock::setColumns(QList<Column*> list) {
 		ui.leName->setText(QString());
 		ui.leComment->setText(QString());
 	}
+	ui.leName->setStyleSheet("");
+	ui.leName->setToolTip("");
 
 	//show the properties of the first column
 	AbstractColumn::ColumnMode columnMode = m_column->columnMode();
@@ -106,23 +115,15 @@ void ColumnDock::setColumns(QList<Column*> list) {
 	this->updateTypeWidgets(columnMode);
 	ui.cbPlotDesignation->setCurrentIndex( int(m_column->plotDesignation()) );
 
-	if (!nonEditable) {
-		// slots
-		connect(m_column, &AbstractColumn::aspectDescriptionChanged, this, &ColumnDock::columnDescriptionChanged);
-		connect(m_column, &AbstractColumn::modeChanged, this, &ColumnDock::columnModeChanged);
-		connect(m_column->outputFilter(), &AbstractSimpleFilter::formatChanged, this, &ColumnDock::columnFormatChanged);
-		connect(m_column->outputFilter(), &AbstractSimpleFilter::digitsChanged, this, &ColumnDock::columnPrecisionChanged);
-		connect(m_column, &AbstractColumn::plotDesignationChanged, this, &ColumnDock::columnPlotDesignationChanged);
-	} else {
-		//disable widgets if we have at least one non-editable column
-		ui.cbType->setEnabled(false);
-		ui.lFormat->hide();
-		ui.cbFormat->hide();
-		ui.lPrecision->hide();
-		ui.sbPrecision->hide();
-		ui.lPlotDesignation->hide();
-		ui.cbPlotDesignation->hide();
-	}
+	// slots
+	connect(m_column, &AbstractColumn::aspectDescriptionChanged, this, &ColumnDock::columnDescriptionChanged);
+	connect(m_column, &AbstractColumn::modeChanged, this, &ColumnDock::columnModeChanged);
+	connect(m_column->outputFilter(), &AbstractSimpleFilter::formatChanged, this, &ColumnDock::columnFormatChanged);
+	connect(m_column->outputFilter(), &AbstractSimpleFilter::digitsChanged, this, &ColumnDock::columnPrecisionChanged);
+	connect(m_column, &AbstractColumn::plotDesignationChanged, this, &ColumnDock::columnPlotDesignationChanged);
+
+	//don't allow to change the column type at least one non-editable column
+	ui.cbType->setEnabled(!nonEditable);
 
 	m_initializing = false;
 }
@@ -241,20 +242,6 @@ void ColumnDock::retranslateUi() {
 	m_initializing = false;
 }
 
-void ColumnDock::nameChanged() {
-	if (m_initializing)
-		return;
-
-	m_columnsList.first()->setName(ui.leName->text());
-}
-
-void ColumnDock::commentChanged() {
-	if (m_initializing)
-		return;
-
-	m_columnsList.first()->setComment(ui.leComment->text());
-}
-
 /*!
   called when the type (column mode - numeric, text etc.) of the column was changed.
 */
@@ -264,7 +251,6 @@ void ColumnDock::typeChanged(int index) {
 		return;
 
 	AbstractColumn::ColumnMode columnMode = (AbstractColumn::ColumnMode)ui.cbType->itemData(index).toInt();
-	int format_index = ui.cbFormat->currentIndex();
 
 	m_initializing = true;
 	this->updateFormatWidgets(columnMode);
@@ -277,7 +263,13 @@ void ColumnDock::typeChanged(int index) {
 				col->beginMacro(i18n("%1: change column type", col->name()));
 				col->setColumnMode(columnMode);
 				auto* filter = static_cast<Double2StringFilter*>(col->outputFilter());
-				filter->setNumericFormat(ui.cbFormat->itemData(format_index).toChar().toLatin1());
+
+				//TODO: using
+				//char format = ui.cbFormat->itemData(ui.cbFormat->currentIndex()).toChar().toLatin1();
+				//outside of the for-loop and
+				//filter->setNumericFormat(format);
+				//inseide the loop leads to wrong results when converting from integer to numeric -> 'f' is set instead of 'e'
+				filter->setNumericFormat(ui.cbFormat->itemData(ui.cbFormat->currentIndex()).toChar().toLatin1());
 				filter->setNumDigits(digits);
 				col->endMacro();
 			}
@@ -324,13 +316,13 @@ void ColumnDock::formatChanged(int index) {
 		return;
 
 	AbstractColumn::ColumnMode mode = (AbstractColumn::ColumnMode)ui.cbType->itemData(ui.cbType->currentIndex()).toInt();
-	int format_index = index;
 
 	switch (mode) {
 	case AbstractColumn::Numeric: {
+			char format = ui.cbFormat->itemData(index).toChar().toLatin1();
 			for (auto* col : m_columnsList) {
 				auto* filter = static_cast<Double2StringFilter*>(col->outputFilter());
-				filter->setNumericFormat(ui.cbFormat->itemData(format_index).toChar().toLatin1());
+				filter->setNumericFormat(format);
 			}
 			break;
 		}
@@ -340,7 +332,7 @@ void ColumnDock::formatChanged(int index) {
 	case AbstractColumn::Month:
 	case AbstractColumn::Day:
 	case AbstractColumn::DateTime: {
-			QString format = ui.cbFormat->itemData(ui.cbFormat->currentIndex()).toString();
+			QString format = ui.cbFormat->itemData(index).toString();
 			for (auto* col : m_columnsList) {
 				auto* filter = static_cast<DateTime2StringFilter*>(col->outputFilter());
 				filter->setFormat(format);
