@@ -67,8 +67,6 @@ protected:
 private slots:
 	//SLOTs for changes triggered in XYDataReductionCurveDock
 	//general tab
-	void nameChanged();
-	void commentChanged();
 	void dataSourceTypeChanged(int);
 	void dataSourceCurveChanged(const QModelIndex&);
 	void xDataColumnChanged(const QModelIndex&);
