@@ -63,8 +63,6 @@ protected:
 private slots:
 	//SLOTs for changes triggered in XYDifferentiationCurveDock
 	//general tab
-	void nameChanged();
-	void commentChanged();
 	void dataSourceTypeChanged(int);
 	void dataSourceCurveChanged(const QModelIndex&);
 	void xDataColumnChanged(const QModelIndex&);
