@@ -61,8 +61,6 @@ protected:
 private slots:
 	//SLOTs for changes triggered in XYFourierFilterCurveDock
 	//general tab
-	void nameChanged();
-	void commentChanged();
 	void dataSourceTypeChanged(int);
 	void dataSourceCurveChanged(const QModelIndex&);
 	void xDataColumnChanged(const QModelIndex&);
