@@ -62,8 +62,6 @@ protected:
 private slots:
 	//SLOTs for changes triggered in XYIntegrationCurveDock
 	//general tab
-	void nameChanged();
-	void commentChanged();
 	void dataSourceTypeChanged(int);
 	void dataSourceCurveChanged(const QModelIndex&);
 	void xDataColumnChanged(const QModelIndex&);
