@@ -3,7 +3,7 @@
     Project              : LabPlot
     Description          : Dialog for generating matrix values from a mathematical function
     ------------------------------------------------------------------------
-    Copyright            : (C) 2015-2016 by Alexander Semke (alexander.semke@web.de)
+    Copyright            : (C) 2015-2019 by Alexander Semke (alexander.semke@web.de)
     Copyright            : (C) 2016 by Stefan Gerlach (stefan.gerlach@uni.kn)
 
  ***************************************************************************/
@@ -32,34 +32,37 @@
 #include "kdefrontend/widgets/ConstantsWidget.h"
 #include "kdefrontend/widgets/FunctionsWidget.h"
 
-extern "C" {
-#include "backend/gsl/parser.h"
-}
-#include <cmath>
-
 #include <QMenu>
 #include <QWidgetAction>
 #include <QDialogButtonBox>
 #include <QPushButton>
 #include <KLocalizedString>
 #include <QThreadPool>
+#include <QWindow>
 #ifndef NDEBUG
 #include <QElapsedTimer>
 #endif
 
+#include <KSharedConfig>
+#include <KWindowConfig>
+
+extern "C" {
+#include "backend/gsl/parser.h"
+}
+#include <cmath>
+
 /*!
 	\class MatrixFunctionDialog
 	\brief Dialog for generating matrix values from a mathematical function.
 
 	\ingroup kdefrontend
  */
-
-MatrixFunctionDialog::MatrixFunctionDialog(Matrix* m, QWidget* parent, Qt::WFlags fl) : QDialog(parent, fl), m_matrix(m) {
+MatrixFunctionDialog::MatrixFunctionDialog(Matrix* m, QWidget* parent) : QDialog(parent), m_matrix(m) {
 	Q_ASSERT(m_matrix);
-	setWindowTitle(i18n("Function values"));
+	setWindowTitle(i18nc("@title:window", "Function Values"));
 
 	ui.setupUi(this);
-    setAttribute(Qt::WA_DeleteOnClose);
+	setAttribute(Qt::WA_DeleteOnClose);
 	ui.tbConstants->setIcon( QIcon::fromTheme("labplot-format-text-symbol") );
 	ui.tbFunctions->setIcon( QIcon::fromTheme("preferences-desktop-font") );
 
@@ -77,7 +80,7 @@ MatrixFunctionDialog::MatrixFunctionDialog(Matrix* m, QWidget* parent, Qt::WFlag
 	ui.teEquation->setPlainText(m_matrix->formula());
 	QDialogButtonBox* btnBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel);
 
-	ui.gridLayout_2->addWidget(btnBox);
+	ui.gridLayout_2->addWidget(btnBox, 3, 0, 1, 3);
 	m_okButton = btnBox->button(QDialogButtonBox::Ok);
 
 	connect(btnBox->button(QDialogButtonBox::Cancel), &QPushButton::clicked, this, &MatrixFunctionDialog::close);
@@ -92,7 +95,19 @@ MatrixFunctionDialog::MatrixFunctionDialog(Matrix* m, QWidget* parent, Qt::WFlag
 	connect(ui.tbFunctions, &QToolButton::clicked, this, &MatrixFunctionDialog::showFunctions);
 	connect(m_okButton, &QPushButton::clicked, this, &MatrixFunctionDialog::generate);
 
-	resize(QSize(300,0).expandedTo(minimumSize()));
+	//restore saved settings if available
+	create(); // ensure there's a window created
+	KConfigGroup conf(KSharedConfig::openConfig(), "MatrixFunctionDialog");
+	if (conf.exists()) {
+		KWindowConfig::restoreWindowSize(windowHandle(), conf);
+		resize(windowHandle()->size()); // workaround for QTBUG-40584
+	} else
+		resize(QSize(300, 0).expandedTo(minimumSize()));
+}
+
+MatrixFunctionDialog::~MatrixFunctionDialog() {
+	KConfigGroup conf(KSharedConfig::openConfig(), "MatrixFunctionDialog");
+	KWindowConfig::saveWindowSize(windowHandle(), conf);
 }
 
 void MatrixFunctionDialog::checkValues() {
@@ -111,7 +126,7 @@ void MatrixFunctionDialog::showConstants() {
 	connect(&constants, &ConstantsWidget::constantSelected, &menu, &QMenu::close);
 	connect(&constants, &ConstantsWidget::canceled, &menu, &QMenu::close);
 
-	QWidgetAction* widgetAction = new QWidgetAction(this);
+	auto* widgetAction = new QWidgetAction(this);
 	widgetAction->setDefaultWidget(&constants);
 	menu.addAction(widgetAction);
 
@@ -126,7 +141,7 @@ void MatrixFunctionDialog::showFunctions() {
 	connect(&functions, &FunctionsWidget::functionSelected, &menu, &QMenu::close);
 	connect(&functions, &FunctionsWidget::canceled, &menu, &QMenu::close);
 
-	QWidgetAction* widgetAction = new QWidgetAction(this);
+	auto* widgetAction = new QWidgetAction(this);
 	widgetAction->setDefaultWidget(&functions);
 	menu.addAction(widgetAction);
 
@@ -151,7 +166,7 @@ public:
 		m_xStart(xStart), m_yStart(yStart), m_xStep(xStep), m_yStep(yStep), m_func(func) {
 	};
 
-	void run() {
+	void run() override {
 		const int rows = m_matrixData[m_startCol].size();
 		double x = m_xStart;
 		double y = m_yStart;
@@ -190,7 +205,7 @@ void MatrixFunctionDialog::generate() {
 	m_matrix->beginMacro(i18n("%1: fill matrix with function values", m_matrix->name()));
 
 	//TODO: data types
-	QVector<QVector<double>>* new_data = static_cast<QVector<QVector<double>>*>(m_matrix->data());
+	auto* new_data = static_cast<QVector<QVector<double>>*>(m_matrix->data());
 
 	QByteArray funcba = ui.teEquation->toPlainText().toLocal8Bit();
 	char* func = funcba.data();
