@@ -221,7 +221,7 @@ class DropValuesTask : public QRunnable {
 
 			//equal to
 			if (m_operator == 0) {
-				for (auto d : new_data) {
+				for (auto& d : new_data) {
 					if (d == m_value1) {
 						d = NAN;
 						changed = true;
@@ -231,7 +231,7 @@ class DropValuesTask : public QRunnable {
 
 			//between (including end points)
 			else if (m_operator == 1) {
-				for (auto d : new_data) {
+				for (auto& d : new_data) {
 					if (d >= m_value1 && d <= m_value2) {
 						d = NAN;
 						changed = true;
@@ -241,7 +241,7 @@ class DropValuesTask : public QRunnable {
 
 			//between (excluding end points)
 			else if (m_operator == 2) {
-				for (auto d : new_data) {
+				for (auto& d : new_data) {
 					if (d > m_value1 && d < m_value2) {
 						d = NAN;
 						changed = true;
@@ -251,7 +251,7 @@ class DropValuesTask : public QRunnable {
 
 			//greater than
 			else if (m_operator == 3) {
-				for (auto d : new_data) {
+				for (auto& d : new_data) {
 					if (d > m_value1) {
 						d = NAN;
 						changed = true;
@@ -261,7 +261,7 @@ class DropValuesTask : public QRunnable {
 
 			//greater than or equal to
 			else if (m_operator == 4) {
-				for (auto d : new_data) {
+				for (auto& d : new_data) {
 					if (d >= m_value1) {
 						d = NAN;
 						changed = true;
@@ -271,7 +271,7 @@ class DropValuesTask : public QRunnable {
 
 			//less than
 			else if (m_operator == 5) {
-				for (auto d : new_data) {
+				for (auto& d : new_data) {
 					if (d < m_value1) {
 						d = NAN;
 						changed = true;
@@ -281,7 +281,7 @@ class DropValuesTask : public QRunnable {
 
 			//less than or equal to
 			else if (m_operator == 6) {
-				for (auto d : new_data) {
+				for (auto& d : new_data) {
 					if (d <= m_value1) {
 						d = NAN;
 						changed = true;
@@ -315,6 +315,7 @@ void DropValuesDialog::maskValues() const {
 		task->run();
 		//TODO: writing to the undo-stack in Column::setMasked() is not tread-safe -> redesign
 // 		QThreadPool::globalInstance()->start(task);
+		delete task;
 	}
 
 	//wait until all columns were processed
