@@ -3,7 +3,7 @@
     Project              : LabPlot
     Description          : export spreadsheet dialog
     --------------------------------------------------------------------
-    Copyright            : (C) 2014-2016 by Alexander Semke (alexander.semke@web.de)
+    Copyright            : (C) 2014-2019 by Alexander Semke (alexander.semke@web.de)
 
  ***************************************************************************/
 
@@ -28,13 +28,16 @@
 
 #include "ExportSpreadsheetDialog.h"
 #include "ui_exportspreadsheetwidget.h"
+#include "backend/datasources/filters/AbstractFileFilter.h"
+#include "backend/datasources/filters/AsciiFilter.h"
 
 #include <QCompleter>
 #include <QDirModel>
 #include <QFileDialog>
 #include <QStandardItemModel>
 #include <QDialogButtonBox>
-#include <QTimer>
+#include <QSqlDatabase>
+#include <QWindow>
 
 #include <KMessageBox>
 #include <KLocalizedString>
@@ -48,11 +51,7 @@
 
 	\ingroup kdefrontend
 */
-ExportSpreadsheetDialog::ExportSpreadsheetDialog(QWidget* parent) : QDialog(parent),
-	ui(new Ui::ExportSpreadsheetWidget()),
-	m_showOptions(true),
-	m_matrixMode(false),
-	m_format(Format::ASCII) {
+ExportSpreadsheetDialog::ExportSpreadsheetDialog(QWidget* parent) : QDialog(parent), ui(new Ui::ExportSpreadsheetWidget()) {
 	ui->setupUi(this);
 
 	ui->gbOptions->hide();
@@ -60,7 +59,7 @@ ExportSpreadsheetDialog::ExportSpreadsheetDialog(QWidget* parent) : QDialog(pare
 	QDialogButtonBox* btnBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel);
 	m_showOptionsButton = new QPushButton;
 
-	connect(btnBox, SIGNAL(clicked(QAbstractButton*)), this, SLOT(slotButtonClicked(QAbstractButton*)));
+	connect(btnBox, &QDialogButtonBox::clicked, this, &ExportSpreadsheetDialog::slotButtonClicked);
 
 	btnBox->addButton(m_showOptionsButton, QDialogButtonBox::ActionRole);
 	ui->verticalLayout->addWidget(btnBox);
@@ -68,34 +67,33 @@ ExportSpreadsheetDialog::ExportSpreadsheetDialog(QWidget* parent) : QDialog(pare
 	m_okButton = btnBox->button(QDialogButtonBox::Ok);
 	m_cancelButton = btnBox->button(QDialogButtonBox::Cancel);
 
-	QCompleter* completer = new QCompleter(this);
-	completer->setModel(new QDirModel);
-	ui->leFileName->setCompleter(completer);
+	ui->leFileName->setCompleter(new QCompleter(new QDirModel, this));
 
-	ui->cbFormat->addItem("ASCII");
-	ui->cbFormat->addItem("Binary");
-	ui->cbFormat->addItem("LaTeX");
-	ui->cbFormat->addItem("FITS");
+	ui->cbFormat->addItem("ASCII", ASCII);
+	ui->cbFormat->addItem("Binary", Binary);
+	ui->cbFormat->addItem("LaTeX", LaTeX);
+	ui->cbFormat->addItem("FITS", FITS);
 
-	ui->cbSeparator->addItem("TAB");
-	ui->cbSeparator->addItem("SPACE");
-	ui->cbSeparator->addItem(",");
-	ui->cbSeparator->addItem(";");
-	ui->cbSeparator->addItem(":");
-	ui->cbSeparator->addItem(",TAB");
-	ui->cbSeparator->addItem(";TAB");
-	ui->cbSeparator->addItem(":TAB");
-	ui->cbSeparator->addItem(",SPACE");
-	ui->cbSeparator->addItem(";SPACE");
-	ui->cbSeparator->addItem(":SPACE");
+	const QStringList& drivers = QSqlDatabase::drivers();
+	if (drivers.contains(QLatin1String("QSQLITE")) || drivers.contains(QLatin1String("QSQLITE3")))
+		ui->cbFormat->addItem("SQLite", SQLite);
 
-	ui->cbLaTeXExport->addItem(i18n("Export spreadsheet"));
-	ui->cbLaTeXExport->addItem(i18n("Export selection"));
+	QStringList separators = AsciiFilter::separatorCharacters();
+	separators.takeAt(0); //remove the first entry "auto"
+	ui->cbSeparator->addItems(separators);
+	ui->cbNumberFormat->addItems(AbstractFileFilter::numberFormats());
+
+	ui->cbLaTeXExport->addItem(i18n("Export Spreadsheet"));
+	ui->cbLaTeXExport->addItem(i18n("Export Selection"));
 
 	ui->bOpen->setIcon( QIcon::fromTheme("document-open") );
 
 	ui->leFileName->setFocus();
 
+	const QString textNumberFormatShort = i18n("This option determines how the convert numbers to strings.");
+	ui->lNumberFormat->setToolTip(textNumberFormatShort);
+	ui->cbNumberFormat->setToolTip(textNumberFormatShort);
+
 	connect(btnBox, &QDialogButtonBox::accepted, this, &ExportSpreadsheetDialog::accept);
 	connect(btnBox, &QDialogButtonBox::rejected, this, &ExportSpreadsheetDialog::reject);
 
@@ -105,19 +103,16 @@ ExportSpreadsheetDialog::ExportSpreadsheetDialog(QWidget* parent) : QDialog(pare
 	connect(ui->cbFormat, static_cast<void (QComboBox::*)(int)>(&QComboBox::currentIndexChanged), this, &ExportSpreadsheetDialog::formatChanged);
 	connect(ui->cbExportToFITS, static_cast<void (QComboBox::*)(int)>(&QComboBox::currentIndexChanged), this, &ExportSpreadsheetDialog::fitsExportToChanged);
 
-	setWindowTitle(i18n("Export spreadsheet"));
+	setWindowTitle(i18nc("@title:window", "Export Spreadsheet"));
 	setWindowIcon(QIcon::fromTheme("document-export-database"));
 
-	QTimer::singleShot(0, this, &ExportSpreadsheetDialog::loadSettings);
-}
-
-void ExportSpreadsheetDialog::loadSettings() {
-	//restore saved settings
+	//restore saved settings if available
 	KConfigGroup conf(KSharedConfig::openConfig(), "ExportSpreadsheetDialog");
 	KWindowConfig::restoreWindowSize(windowHandle(), conf);
 	ui->cbFormat->setCurrentIndex(conf.readEntry("Format", 0));
 	ui->chkExportHeader->setChecked(conf.readEntry("Header", true));
 	ui->cbSeparator->setCurrentItem(conf.readEntry("Separator", "TAB"));
+	ui->cbNumberFormat->setCurrentIndex(conf.readEntry("NumberFormat", (int)QLocale::AnyLanguage));
 	ui->chkHeaders->setChecked(conf.readEntry("LaTeXHeaders", true));
 	ui->chkGridLines->setChecked(conf.readEntry("LaTeXGridLines", true));
 	ui->chkCaptions->setChecked(conf.readEntry("LaTeXCaptions", true));
@@ -131,6 +126,13 @@ void ExportSpreadsheetDialog::loadSettings() {
 	ui->gbOptions->setVisible(m_showOptions);
 	m_showOptions ? m_showOptionsButton->setText(i18n("Hide Options")) :
 			m_showOptionsButton->setText(i18n("Show Options"));
+
+	create(); // ensure there's a window created
+	if (conf.exists()) {
+		KWindowConfig::restoreWindowSize(windowHandle(), conf);
+		resize(windowHandle()->size()); // workaround for QTBUG-40584
+	} else
+		resize(QSize(0, 0).expandedTo(minimumSize()));
 }
 
 ExportSpreadsheetDialog::~ExportSpreadsheetDialog() {
@@ -138,7 +140,8 @@ ExportSpreadsheetDialog::~ExportSpreadsheetDialog() {
 	KConfigGroup conf(KSharedConfig::openConfig(), "ExportSpreadsheetDialog");
 	conf.writeEntry("Format", ui->cbFormat->currentIndex());
 	conf.writeEntry("Header", ui->chkExportHeader->isChecked());
-	conf.writeEntry("Separator", ui->cbSeparator->currentIndex());
+	conf.writeEntry("Separator", ui->cbSeparator->currentText());
+	conf.writeEntry("NumberFormat", ui->cbNumberFormat->currentIndex());
 	conf.writeEntry("ShowOptions", m_showOptions);
 	conf.writeEntry("LaTeXHeaders", ui->chkHeaders->isChecked());
 	conf.writeEntry("LaTeXGridLines", ui->chkGridLines->isChecked());
@@ -175,7 +178,7 @@ void ExportSpreadsheetDialog::fitsExportToChanged(int idx) {
 
 void ExportSpreadsheetDialog::setMatrixMode(bool b) {
 	if (b) {
-		setWindowTitle(i18n("Export matrix"));
+		setWindowTitle(i18nc("@title:window", "Export Matrix"));
 		ui->lExportHeader->hide();
 		ui->chkExportHeader->hide();
 		ui->lEmptyRows->hide();
@@ -251,6 +254,10 @@ QString ExportSpreadsheetDialog::separator() const {
 	return ui->cbSeparator->currentText();
 }
 
+QLocale::Language ExportSpreadsheetDialog::numberFormat() const {
+	return (QLocale::Language)ui->cbNumberFormat->currentIndex();
+}
+
 void ExportSpreadsheetDialog::slotButtonClicked(QAbstractButton* button) {
     if (button == m_okButton)
 	    okClicked();
@@ -270,8 +277,8 @@ void ExportSpreadsheetDialog::setExportToImage(bool possible) {
 void ExportSpreadsheetDialog::okClicked() {
 	if (format() != FITS)
 		if ( QFile::exists(ui->leFileName->text()) ) {
-			int r=KMessageBox::questionYesNo(this, i18n("The file already exists. Do you really want to overwrite it?"), i18n("Export"));
-			if (r==KMessageBox::No)
+			int r = KMessageBox::questionYesNo(this, i18n("The file already exists. Do you really want to overwrite it?"), i18n("Export"));
+			if (r == KMessageBox::No)
 				return;
 		}
 	KConfigGroup conf(KSharedConfig::openConfig(), "ExportSpreadsheetDialog");
@@ -284,9 +291,9 @@ void ExportSpreadsheetDialog::okClicked() {
 		QString dir = conf.readEntry("LastDir", "");
 		ui->leFileName->setText(path);
 		int pos = path.lastIndexOf(QDir::separator());
-		if (pos!=-1) {
+		if (pos != -1) {
 			QString newDir = path.left(pos);
-			if (newDir!=dir)
+			if (newDir != dir)
 				conf.writeEntry("LastDir", newDir);
 		}
 	}
@@ -314,24 +321,34 @@ void ExportSpreadsheetDialog::selectFile() {
 	KConfigGroup conf(KSharedConfig::openConfig(), "ExportSpreadsheetDialog");
 	QString dir = conf.readEntry("LastDir", "");
 
-	QString format;
-	if (ui->cbFormat->currentIndex() == 0)
-		format = i18n("Text files (*.txt *.dat *.csv)");
-	else if (ui->cbFormat->currentIndex() == 1)
-		format = i18n("Binary files (*.*)");
-	else if (ui->cbFormat->currentIndex() == 2)
-		format = i18n("LaTeX files (*.tex)");
-	else
-		format =  i18n("FITS files (*.fits *.fit *.fts)");
+	QString extensions;
+	const Format format = (Format)(ui->cbFormat->itemData(ui->cbFormat->currentIndex()).toInt());
+	switch (format) {
+	case ASCII:
+		extensions = i18n("Text files (*.txt *.dat *.csv)");
+		break;
+	case Binary:
+		extensions = i18n("Binary files (*.*)");
+		break;
+	case LaTeX:
+		extensions = i18n("LaTeX files (*.tex)");
+		break;
+	case FITS:
+		extensions = i18n("FITS files (*.fits *.fit *.fts)");
+		break;
+	case SQLite:
+		extensions = i18n("SQLite databases files (*.db *.sqlite *.sdb *.db2 *.sqlite2 *.sdb2 *.db3 *.sqlite3 *.sdb3)");
+		break;
+	}
 
-	const QString path = QFileDialog::getSaveFileName(this, i18n("Export to file"), dir, format);
+	const QString path = QFileDialog::getSaveFileName(this, i18n("Export to file"), dir, extensions);
 	if (!path.isEmpty()) {
 		ui->leFileName->setText(path);
 
 		int pos = path.lastIndexOf(QDir::separator());
-		if (pos!=-1) {
+		if (pos != -1) {
 			QString newDir = path.left(pos);
-			if (newDir!=dir)
+			if (newDir != dir)
 				conf.writeEntry("LastDir", newDir);
 		}
 	}
@@ -342,18 +359,22 @@ void ExportSpreadsheetDialog::selectFile() {
  */
 void ExportSpreadsheetDialog::formatChanged(int index) {
 	QStringList extensions;
-	extensions << ".txt" << ".bin" << ".tex" << ".fits";
+	extensions << ".txt" << ".bin" << ".tex" << ".fits" << ".db";
 	QString path = ui->leFileName->text();
 	int i = path.indexOf(".");
 	if (index != 1) {
-		if (i==-1)
+		if (i == -1)
 			path = path + extensions.at(index);
 		else
-			path=path.left(i) + extensions.at(index);
+			path = path.left(i) + extensions.at(index);
 	}
-	if (ui->cbFormat->currentIndex() == 2) {
+
+	const Format format = (Format)(ui->cbFormat->itemData(ui->cbFormat->currentIndex()).toInt());
+	if (format == LaTeX) {
 		ui->cbSeparator->hide();
 		ui->lSeparator->hide();
+		ui->lNumberFormat->hide();
+		ui->cbNumberFormat->hide();
 
 		ui->chkCaptions->show();
 		ui->chkGridLines->show();
@@ -381,8 +402,7 @@ void ExportSpreadsheetDialog::formatChanged(int index) {
 		ui->lExportToFITS->hide();
 		ui->lColumnAsUnits->hide();
 		ui->chkColumnsAsUnits->hide();
-		//FITS
-	} else if(ui->cbFormat->currentIndex() == 3) {
+	} else if (format == FITS) {
 		ui->lCaptions->hide();
 		ui->lEmptyRows->hide();
 		ui->lExportArea->hide();
@@ -401,6 +421,8 @@ void ExportSpreadsheetDialog::formatChanged(int index) {
 		ui->chkCaptions->hide();
 		ui->cbLaTeXExport->hide();
 		ui->cbSeparator->hide();
+		ui->lNumberFormat->hide();
+		ui->cbNumberFormat->hide();
 
 		ui->cbExportToFITS->show();
 		ui->lExportToFITS->show();
@@ -410,9 +432,40 @@ void ExportSpreadsheetDialog::formatChanged(int index) {
 				ui->chkColumnsAsUnits->show();
 			}
 		}
+	} else if (format == SQLite) {
+		ui->cbSeparator->hide();
+		ui->lSeparator->hide();
+		ui->lNumberFormat->hide();
+		ui->cbNumberFormat->hide();
+
+		ui->chkCaptions->hide();
+		ui->chkEmptyRows->hide();
+		ui->chkGridLines->hide();
+		ui->lEmptyRows->hide();
+		ui->lExportArea->hide();
+		ui->lGridLines->hide();
+		ui->lCaptions->hide();
+		ui->cbLaTeXExport->hide();
+		ui->cbLaTeXExport->hide();
+		ui->lMatrixHHeader->hide();
+		ui->lMatrixVHeader->hide();
+		ui->chkMatrixHHeader->hide();
+		ui->chkMatrixVHeader->hide();
+
+		ui->lHeader->hide();
+		ui->chkHeaders->hide();
+		ui->chkExportHeader->hide();
+		ui->lExportHeader->hide();
+
+		ui->cbExportToFITS->hide();
+		ui->lExportToFITS->hide();
+		ui->lColumnAsUnits->hide();
+		ui->chkColumnsAsUnits->hide();
 	} else {
 		ui->cbSeparator->show();
 		ui->lSeparator->show();
+		ui->lNumberFormat->show();
+		ui->cbNumberFormat->show();
 
 		ui->chkCaptions->hide();
 		ui->chkEmptyRows->hide();
@@ -436,16 +489,9 @@ void ExportSpreadsheetDialog::formatChanged(int index) {
 		ui->chkColumnsAsUnits->hide();
 	}
 
-	if (!m_matrixMode) {
+	if (!m_matrixMode && !(format == FITS || format == SQLite)) {
 		ui->chkExportHeader->show();
 		ui->lExportHeader->show();
-	} else {
-		ui->chkExportHeader->hide();
-		ui->lExportHeader->hide();
-	}
-	if (ui->cbFormat->currentIndex() == 3) {
-		ui->chkExportHeader->hide();
-		ui->lExportHeader->hide();
 	}
 
 	setFormat(static_cast<Format>(index));
@@ -454,7 +500,7 @@ void ExportSpreadsheetDialog::formatChanged(int index) {
 
 void ExportSpreadsheetDialog::setExportSelection(bool enable) {
 	if (!enable) {
-		const QStandardItemModel* areaToExportModel = qobject_cast<const QStandardItemModel*>(ui->cbLaTeXExport->model());
+		const auto* areaToExportModel = qobject_cast<const QStandardItemModel*>(ui->cbLaTeXExport->model());
 		QStandardItem* item = areaToExportModel->item(1);
 		item->setFlags(item->flags() & ~(Qt::ItemIsSelectable|Qt::ItemIsEnabled));
 	}
