@@ -40,6 +40,8 @@ class AspectTreeModel;
 class QPushButton;
 class QLineEdit;
 
+enum class AspectType : quint64;
+
 class FunctionValuesDialog : public QDialog {
 	Q_OBJECT
 
@@ -47,6 +49,7 @@ public:
 	explicit FunctionValuesDialog(Spreadsheet* s, QWidget* parent = nullptr);
 	~FunctionValuesDialog() override;
 	void setColumns(QVector<Column*>);
+	bool validVariableName(QLineEdit *le);
 
 private:
 	Ui::FunctionValuesWidget ui;
@@ -57,8 +60,8 @@ private:
 #else
 	std::unique_ptr<AspectTreeModel> m_aspectTreeModel;
 #endif
-	QList<const char*>  m_topLevelClasses;
-	QList<const char*>  m_selectableClasses;
+	QList<AspectType>  m_topLevelClasses;
+	QList<AspectType>  m_selectableClasses;
 
 	QList<QLineEdit*> m_variableNames;
 	QList<QLabel*> m_variableLabels;
@@ -76,6 +79,7 @@ private slots:
 	void addVariable();
 	void deleteVariable();
 	void variableNameChanged();
+	void variableColumnChanged(const QModelIndex&);
 };
 
 #endif
