@@ -30,6 +30,7 @@
 #include "backend/core/AspectTreeModel.h"
 #include "backend/core/Project.h"
 #include "backend/core/column/Column.h"
+#include "backend/datapicker/DatapickerCurve.h"
 #include "backend/spreadsheet/Spreadsheet.h"
 #include "backend/worksheet/plots/cartesian/Axis.h"
 #include "backend/worksheet/plots/cartesian/XYAnalysisCurve.h"
@@ -103,11 +104,9 @@ PlotDataDialog::PlotDataDialog(Spreadsheet* s, PlotType type, QWidget* parent) :
 	cbExistingWorksheets->setSizePolicy(QSizePolicy(QSizePolicy::Expanding, QSizePolicy::Preferred));
 	gridLayout->addWidget(cbExistingWorksheets, 1, 1, 1, 1);
 
-	QList<const char*> list;
-	list<<"Folder"<<"Worksheet"<<"CartesianPlot";
+	QList<AspectType> list{AspectType::Folder, AspectType::Worksheet, AspectType::CartesianPlot};
 	cbExistingPlots->setTopLevelClasses(list);
-	list.clear();
-	list<<"CartesianPlot";
+	list = {AspectType::CartesianPlot};
 	m_plotsModel->setSelectableAspects(list);
 	cbExistingPlots->setModel(m_plotsModel);
 
@@ -118,11 +117,9 @@ PlotDataDialog::PlotDataDialog(Spreadsheet* s, PlotType type, QWidget* parent) :
 		cbExistingPlots->setCurrentModelIndex(m_plotsModel->modelIndexOfAspect(plot));
 	}
 
-	list.clear();
-	list<<"Folder"<<"Worksheet";
+	list = {AspectType::Folder, AspectType::Worksheet};
 	cbExistingWorksheets->setTopLevelClasses(list);
-	list.clear();
-	list<<"Worksheet";
+	list = {AspectType::Worksheet};
 	m_worksheetsModel->setSelectableAspects(list);
 	cbExistingWorksheets->setModel(m_worksheetsModel);
 
@@ -133,8 +130,19 @@ PlotDataDialog::PlotDataDialog(Spreadsheet* s, PlotType type, QWidget* parent) :
 		cbExistingWorksheets->setCurrentModelIndex(m_worksheetsModel->modelIndexOfAspect(worksheet));
 	}
 
+	//in the grid layout of the scroll area we have on default one row for the x-column,
+	//one row for the separating line and one line for the y-column.
+	//set the height of this default content as the minimal size of the scroll area.
+	gridLayout = dynamic_cast<QGridLayout*>(ui->scrollAreaColumns->widget()->layout());
+	int height = 2*ui->cbXColumn->height() + ui->line->height()
+				+ 2*gridLayout->verticalSpacing()
+				+ gridLayout->contentsMargins().top()
+				+ gridLayout->contentsMargins().bottom();
+	ui->scrollAreaColumns->setMinimumSize(0, height);
+
 	//hide the check box for creation of original data, only shown if analysis curves are to be created
-	ui->chkCreateDataCurve->setVisible(false);
+	ui->spacer->changeSize(0, 0);
+	ui->chkCreateDataCurve->hide();
 
 	//SIGNALs/SLOTs
 	connect(buttonBox, &QDialogButtonBox::accepted, this, [=]() { hide();  plot(); });
@@ -190,7 +198,8 @@ PlotDataDialog::~PlotDataDialog() {
 void PlotDataDialog::setAnalysisAction(AnalysisAction action) {
 	m_analysisAction = action;
 	m_analysisMode = true;
-	ui->chkCreateDataCurve->setVisible(true);
+	ui->spacer->changeSize(0, 40);
+	ui->chkCreateDataCurve->show();
 }
 
 void PlotDataDialog::processColumns() {
@@ -250,6 +259,17 @@ void PlotDataDialog::processColumns() {
 		processColumnsForHistogram(columnNames);
 		break;
 	}
+
+	//resize the scroll area to show five ComboBoxes at maximum without showing the scroll bars
+	int size = m_columnComboBoxes.size() >=5 ? 5 : m_columnComboBoxes.size();
+	int height = size * ui->cbXColumn->height();
+	auto* layout = dynamic_cast<QGridLayout*>(ui->scrollAreaColumns->widget()->layout());
+	if (layout) {
+		height += (size + 1)*layout->verticalSpacing();
+		if (m_plotType == PlotXYCurve)
+			height += layout->verticalSpacing(); //one more spacing for the separating line
+	}
+	ui->scrollAreaColumns->setMinimumSize(ui->scrollAreaColumns->width(), height);
 }
 
 void PlotDataDialog::processColumnsForXYCurve(const QStringList& columnNames, const QString& xColumnName) {
@@ -258,7 +278,7 @@ void PlotDataDialog::processColumnsForXYCurve(const QStringList& columnNames, co
 
 	//ui-widget only has one combobox for the y-data -> add additional comboboxes dynamically if required
 	if (m_columns.size()>2) {
-		auto* gridLayout = dynamic_cast<QGridLayout*>(ui->scrollAreaYColumns->widget()->layout());
+		auto* gridLayout = dynamic_cast<QGridLayout*>(ui->scrollAreaColumns->widget()->layout());
 		for (int i = 2; i < m_columns.size(); ++i) {
 			QLabel* label = new QLabel(i18n("Y-data"));
 			auto* comboBox = new QComboBox();
@@ -306,6 +326,7 @@ void PlotDataDialog::processColumnsForXYCurve(const QStringList& columnNames, co
 void PlotDataDialog::processColumnsForHistogram(const QStringList& columnNames) {
 	ui->gbData->setTitle(i18n("Histogram Data"));
 	ui->line->hide();
+	ui->spacer->changeSize(0, 0);
 	ui->chkCreateDataCurve->hide();
 
 	//use the already available cbXColumn combo box
@@ -317,10 +338,11 @@ void PlotDataDialog::processColumnsForHistogram(const QStringList& columnNames)
 	if (m_columns.size() == 1) {
 		//one column provided, only one histogram is possible
 		//-> hide the curve placement options and the scroll areas for further columns
+		ui->lYColumn->hide();
+		ui->cbYColumn->hide();
 		ui->rbCurvePlacement1->setChecked(true);
 		ui->gbCurvePlacement->hide();
 		ui->gbPlotPlacement->setTitle(i18n("Add Histogram to"));
-		ui->scrollAreaYColumns->hide();
 	} else {
 		ui->gbCurvePlacement->setTitle(i18n("Histogram Placement"));
 		ui->rbCurvePlacement1->setText(i18n("All histograms in one plot"));
@@ -334,7 +356,7 @@ void PlotDataDialog::processColumnsForHistogram(const QStringList& columnNames)
 		ui->cbYColumn->setCurrentIndex(1);
 
 		//add a ComboBox for every further column to be plotted
-		auto* gridLayout = dynamic_cast<QGridLayout*>(ui->scrollAreaYColumns->widget()->layout());
+		auto* gridLayout = dynamic_cast<QGridLayout*>(ui->scrollAreaColumns->widget()->layout());
 		for (int i = 2; i < m_columns.size(); ++i) {
 			auto* label = new QLabel(i18n("Data"));
 			auto* comboBox = new QComboBox();
@@ -350,6 +372,9 @@ void PlotDataDialog::processColumnsForHistogram(const QStringList& columnNames)
 void PlotDataDialog::plot() {
 	DEBUG("PlotDataDialog::plot()");
 	WAIT_CURSOR;
+	m_spreadsheet->project()->setSuppressAspectAddedSignal(true);
+	m_lastAddedCurve = nullptr;
+
 	if (ui->rbPlotPlacement1->isChecked()) {
 		//add curves to an existing plot
 		auto* aspect = static_cast<AbstractAspect*>(cbExistingPlots->currentModelIndex().internalPointer());
@@ -399,10 +424,11 @@ void PlotDataDialog::plot() {
 	} else {
 		//add curves to a new plot(s) in a new worksheet
 		AbstractAspect* parent = m_spreadsheet->parentAspect();
+		if (dynamic_cast<DatapickerCurve*>(parent))
+			parent = parent->parentAspect()->parentAspect();
 #ifdef HAVE_MQTT
-		MQTTTopic* topic = qobject_cast<MQTTTopic*>(m_spreadsheet);
-		if (topic != nullptr)
-			parent = qobject_cast<AbstractAspect*>(m_spreadsheet->project());
+		else if (dynamic_cast<MQTTTopic*>(m_spreadsheet))
+			parent = m_spreadsheet->project();
 #endif
 		parent->beginMacro( i18n("Plot data from %1", m_spreadsheet->name()) );
 		Worksheet* worksheet = new Worksheet(i18n("Plot data from %1", m_spreadsheet->name()));
@@ -443,6 +469,11 @@ void PlotDataDialog::plot() {
 
 		parent->endMacro();
 	}
+
+	//select the parent plot of the last added curve in the project explorer
+	m_spreadsheet->project()->setSuppressAspectAddedSignal(false);
+	if (m_lastAddedCurve)
+		m_spreadsheet->project()->requestNavigateTo(m_lastAddedCurve->parentAspect()->path());
 	RESET_CURSOR;
 }
 
@@ -457,7 +488,7 @@ Column* PlotDataDialog::columnFromName(const QString& name) const {
 /*!
  * * for the selected columns in this dialog, creates a curve in the already existing plot \c plot.
  */
-void PlotDataDialog::addCurvesToPlot(CartesianPlot* plot) const {
+void PlotDataDialog::addCurvesToPlot(CartesianPlot* plot) {
 	QApplication::processEvents(QEventLoop::AllEvents, 100);
 	switch (m_plotType) {
 	case PlotXYCurve: {
@@ -486,7 +517,7 @@ void PlotDataDialog::addCurvesToPlot(CartesianPlot* plot) const {
 /*!
  * for the selected columns in this dialog, creates a plot and a curve in the already existing worksheet \c worksheet.
  */
-void PlotDataDialog::addCurvesToPlots(Worksheet* worksheet) const {
+void PlotDataDialog::addCurvesToPlots(Worksheet* worksheet) {
 	QApplication::processEvents(QEventLoop::AllEvents, 100);
 	worksheet->setSuppressLayoutUpdate(true);
 
@@ -497,6 +528,8 @@ void PlotDataDialog::addCurvesToPlots(Worksheet* worksheet) const {
 		for (auto* comboBox : m_columnComboBoxes) {
 			const QString& name = comboBox->currentText();
 			Column* yColumn = columnFromName(name);
+			if (yColumn == xColumn)
+				continue;
 
 			CartesianPlot* plot = new CartesianPlot(i18n("Plot %1", name));
 			plot->initDefault(CartesianPlot::FourAxes);
@@ -551,7 +584,7 @@ void PlotDataDialog::addCurvesToPlots(Worksheet* worksheet) const {
 /*!
  * helper function that does the actual creation of the curve and adding it as child to the \c plot.
  */
-void PlotDataDialog::addCurve(const QString& name, Column* xColumn, Column* yColumn, CartesianPlot* plot) const {
+void PlotDataDialog::addCurve(const QString& name, Column* xColumn, Column* yColumn, CartesianPlot* plot) {
 	DEBUG("PlotDataDialog::addCurve()");
 	if (!m_analysisMode) {
 		auto* curve = new XYCurve(name);
@@ -560,6 +593,7 @@ void PlotDataDialog::addCurve(const QString& name, Column* xColumn, Column* yCol
 		curve->setYColumn(yColumn);
 		curve->suppressRetransform(false);
 		plot->addChild(curve);
+		m_lastAddedCurve = curve;
 	} else {
 		bool createDataCurve = ui->chkCreateDataCurve->isChecked();
 		XYCurve* curve = nullptr;
@@ -570,6 +604,7 @@ void PlotDataDialog::addCurve(const QString& name, Column* xColumn, Column* yCol
 			curve->setYColumn(yColumn);
 			curve->suppressRetransform(false);
 			plot->addChild(curve);
+			m_lastAddedCurve = curve;
 		}
 
 		XYAnalysisCurve* analysisCurve = nullptr;
@@ -613,19 +648,22 @@ void PlotDataDialog::addCurve(const QString& name, Column* xColumn, Column* yCol
 			analysisCurve->suppressRetransform(true);
 			analysisCurve->setXDataColumn(xColumn);
 			analysisCurve->setYDataColumn(yColumn);
-			analysisCurve->recalculate();
+			if (m_analysisAction != FitCustom) //no custom fit-model set yet, no need to recalculate
+				analysisCurve->recalculate();
 			analysisCurve->suppressRetransform(false);
 			plot->addChild(analysisCurve);
+			m_lastAddedCurve = analysisCurve;
 		}
 	}
 }
 
-void PlotDataDialog::addHistogram(const QString& name, Column* column, CartesianPlot* plot) const {
+void PlotDataDialog::addHistogram(const QString& name, Column* column, CartesianPlot* plot) {
 	auto* hist = new Histogram(name);
 	plot->addChild(hist);
 // 	hist->suppressRetransform(true);
 	hist->setDataColumn(column);
 // 	hist->suppressRetransform(false);
+	m_lastAddedCurve = hist;
 }
 
 //################################################################
