@@ -36,11 +36,11 @@ class Spreadsheet;
 class QPushButton;
 
 class RandomValuesDialog : public QDialog {
-Q_OBJECT
+	Q_OBJECT
 
 public:
-	explicit RandomValuesDialog(Spreadsheet* s, QWidget* parent = 0, Qt::WFlags fl = 0);
-	~RandomValuesDialog();
+	explicit RandomValuesDialog(Spreadsheet* s, QWidget* parent = nullptr);
+	~RandomValuesDialog() override;
 	void setColumns(QVector<Column*>);
 
 private:
