@@ -4,7 +4,7 @@
     Description          : Dialog showing statistics for column values
     --------------------------------------------------------------------
     Copyright            : (C) 2016-2017 by Fabian Kristof (fkristofszabolcs@gmail.com))
-    Copyright            : (C) 2016-2017 by Alexander Semke (alexander.semke@web.de)
+    Copyright            : (C) 2016-2019 by Alexander Semke (alexander.semke@web.de)
 
  ***************************************************************************/
 
@@ -30,20 +30,21 @@
 #include "StatisticsDialog.h"
 #include "backend/core/column/Column.h"
 
-#include <QTextEdit>
-#include <QTimer>
-#include <QTabWidget>
-#include <KLocale>
 #include <QDialogButtonBox>
-#include <QVBoxLayout>
-#include <KWindowConfig>
 #include <QPushButton>
+#include <QTabWidget>
+#include <QTextEdit>
+#include <QVBoxLayout>
+#include <QWindow>
+
+#include <KLocalizedString>
+#include <KSharedConfig>
+#include <KWindowConfig>
+
 #include <cmath>
 
-StatisticsDialog::StatisticsDialog(const QString& title, QWidget* parent) :
-	QDialog(parent) {
-
-	m_twStatistics = new QTabWidget;
+StatisticsDialog::StatisticsDialog(const QString& title, QWidget* parent) : QDialog(parent),
+	m_twStatistics(new QTabWidget) {
 
 	QDialogButtonBox* btnBox = new QDialogButtonBox(QDialogButtonBox::Ok);
 
@@ -53,13 +54,14 @@ StatisticsDialog::StatisticsDialog(const QString& title, QWidget* parent) :
 	connect(btnOk, &QPushButton::clicked, this, &StatisticsDialog::close);
 	connect(btnBox, &QDialogButtonBox::accepted, this, &StatisticsDialog::accept);
 
-	QVBoxLayout* layout = new QVBoxLayout;
+	auto* layout = new QVBoxLayout;
 	layout->addWidget(m_twStatistics);
 	layout->addWidget(btnBox);
 
 	setLayout(layout);
 
 	setWindowTitle(title);
+	setWindowIcon(QIcon::fromTheme("view-statistics"));
 	setAttribute(Qt::WA_DeleteOnClose);
 
 	const QString htmlColor = (palette().color(QPalette::Base).lightness() < 128) ? QLatin1String("#5f5f5f") : QLatin1String("#D1D1D1");
@@ -178,16 +180,14 @@ StatisticsDialog::StatisticsDialog(const QString& title, QWidget* parent) :
 	                     "</table>");
 
 	connect(m_twStatistics, &QTabWidget::currentChanged, this, &StatisticsDialog::currentTabChanged);
-	QTimer::singleShot(0, this, &StatisticsDialog::loadSettings);
-}
 
-void StatisticsDialog::loadSettings() {
 	//restore saved settings if available
-	QApplication::processEvents(QEventLoop::AllEvents, 0);
+	create(); // ensure there's a window created
 	KConfigGroup conf(KSharedConfig::openConfig(), "StatisticsDialog");
-	if (conf.exists())
+	if (conf.exists()) {
 		KWindowConfig::restoreWindowSize(windowHandle(), conf);
-	else
+		resize(windowHandle()->size()); // workaround for QTBUG-40584
+	} else
 		resize(QSize(490, 520));
 }
 
@@ -202,10 +202,10 @@ void StatisticsDialog::setColumns(const QVector<Column*>& columns) {
 
 	m_columns = columns;
 
-	for (int i = 0; i < m_columns.size(); ++i) {
-		QTextEdit* textEdit = new QTextEdit;
+	for (auto* col : m_columns) {
+		auto* textEdit = new QTextEdit;
 		textEdit->setReadOnly(true);
-		m_twStatistics->addTab(textEdit, m_columns[i]->name());
+		m_twStatistics->addTab(textEdit, col->name());
 	}
 	currentTabChanged(0);
 }
@@ -219,7 +219,7 @@ void StatisticsDialog::currentTabChanged(int index) {
 	const Column::ColumnStatistics& statistics = m_columns[index]->statistics();
 	RESET_CURSOR;
 
-	QTextEdit* const textEdit = static_cast<QTextEdit*>(m_twStatistics->currentWidget());
+	auto* const textEdit = static_cast<QTextEdit*>(m_twStatistics->currentWidget());
 	textEdit->setHtml(m_htmlText.arg(isNanValue(statistics.minimum == INFINITY ? NAN : statistics.minimum),
 	                                 isNanValue(statistics.maximum == -INFINITY ? NAN : statistics.maximum),
 	                                 isNanValue(statistics.arithmeticMean),
