@@ -32,9 +32,10 @@
 
 #include "ui_datapickercurvewidget.h"
 #include "backend/datapicker/DatapickerCurve.h"
+#include "kdefrontend/dockwidgets/BaseDock.h"
 
 
-class DatapickerCurveWidget : public QWidget {
+class DatapickerCurveWidget : public BaseDock {
 	Q_OBJECT
 
 public:
@@ -47,7 +48,6 @@ public:
 private:
 	Ui::DatapickerCurveWidget ui;
 	void init();
-	void initConnections();
 	void hideErrorBarWidgets(bool);
 
 	DatapickerCurve* m_curve{nullptr};
@@ -57,8 +57,6 @@ private:
 
 private slots:
 	//SLOTs for changes triggered in DatapickerCurveDock
-	void nameChanged();
-	void commentChanged();
 	void updateSymbolWidgets();
 	void xErrorTypeChanged(int);
 	void yErrorTypeChanged(int);
