@@ -33,6 +33,7 @@
 
 #include "ui_datapickerimagewidget.h"
 #include "backend/datapicker/DatapickerImage.h"
+#include "kdefrontend/dockwidgets/BaseDock.h"
 
 class QxtSpanSlider;
 
@@ -56,7 +57,7 @@ private:
 	int m_range;
 };
 
-class DatapickerImageWidget : public QWidget {
+class DatapickerImageWidget : public BaseDock {
 	Q_OBJECT
 
 public:
@@ -72,7 +73,6 @@ private:
 
 	DatapickerImage* m_image;
 	QList<DatapickerImage*> m_imagesList;
-	bool m_initializing;
 
 	QxtSpanSlider* ssIntensity;
 	QxtSpanSlider* ssForeground;
@@ -89,8 +89,6 @@ private:
 private slots:
 	//SLOTs for changes triggered in DatapickerImageWidget
 	//"General"-tab
-	void nameChanged();
-	void commentChanged();
 	void fileNameChanged();
 	void selectFile();
 	void plotImageTypeChanged(int);
@@ -109,7 +107,7 @@ private slots:
 	void ternaryScaleChanged(double);
 	void logicalPositionChanged();
 
-	//symbol propeties
+	//symbol properties
 	void pointsStyleChanged(int);
 	void pointsSizeChanged(double);
 	void pointsRotationChanged(int);
