@@ -40,15 +40,12 @@
 
 	\ingroup kdefrontend
  */
-FitParametersWidget::FitParametersWidget(QWidget* parent, XYFitCurve::FitData* data) : QWidget(parent),
-	m_fitData(data), m_changed(false), m_rehighlighting(false), m_invalidRanges(false) {
+FitParametersWidget::FitParametersWidget(QWidget* parent) : QWidget(parent) {
 	ui.setupUi(this);
-	ui.pbApply->setIcon(QIcon::fromTheme("dialog-ok-apply"));
-	ui.pbCancel->setIcon(QIcon::fromTheme("dialog-cancel"));
 
 	ui.tableWidget->setColumnCount(5);
 
-	QTableWidgetItem* headerItem = new QTableWidgetItem();
+	auto* headerItem = new QTableWidgetItem();
 	headerItem->setText(i18n("Name"));
 	ui.tableWidget->setHorizontalHeaderItem(0, headerItem);
 
@@ -70,20 +67,32 @@ FitParametersWidget::FitParametersWidget(QWidget* parent, XYFitCurve::FitData* d
 
 	ui.tableWidget->horizontalHeader()->resizeSections(QHeaderView::ResizeToContents);
 	ui.tableWidget->horizontalHeader()->setStretchLastSection(true);
-	ui.tableWidget->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
 
+	ui.tableWidget->installEventFilter(this);
+
+	connect( ui.tableWidget, SIGNAL(cellChanged(int,int)), this, SLOT(changed()) );
+}
+
+void FitParametersWidget::setFitData(XYFitCurve::FitData* data) {
+	DEBUG("FitParametersWidget::setFitData()");
+	m_initializing = true;
+	m_fitData = data;
+
+	int np = m_fitData->paramNames.size();
+	DEBUG("# params = " << np);
+	DEBUG("# start values = " << m_fitData->paramStartValues.size());
 	if (m_fitData->modelCategory != nsl_fit_model_custom) {	// pre-defined models
-		ui.tableWidget->setRowCount(m_fitData->paramNames.size());
+		ui.tableWidget->setRowCount(np);
 
-		for (int i = 0; i < m_fitData->paramNames.size(); ++i) {
+		for (int i = 0; i < np; ++i) {
 			// name
-			QTableWidgetItem* item = new QTableWidgetItem(m_fitData->paramNamesUtf8.at(i));
+			auto* item = new QTableWidgetItem(m_fitData->paramNamesUtf8.at(i));
 			item->setFlags(item->flags() ^ Qt::ItemIsEditable);
 			item->setBackground(QApplication::palette().color(QPalette::Window));
 			ui.tableWidget->setItem(i, 0, item);
 
 			// start value
-			QLineEdit *le = new QLineEdit(ui.tableWidget);
+			auto* le = new QLineEdit(ui.tableWidget);
 			le->setValidator(new QDoubleValidator(le));
 			le->setFrame(false);
 			le->insert(QString::number(m_fitData->paramStartValues.at(i), 'g'));
@@ -91,10 +100,10 @@ FitParametersWidget::FitParametersWidget(QWidget* parent, XYFitCurve::FitData* d
 			connect(le, SIGNAL(textChanged(QString)), this, SLOT(startValueChanged()) );
 
 			// fixed
-			QWidget *widget = new QWidget();
-			QCheckBox *cb = new QCheckBox();
+			QWidget* widget = new QWidget();
+			auto* cb = new QCheckBox();
 			cb->setChecked(m_fitData->paramFixed.at(i));
-			QHBoxLayout *cbl = new QHBoxLayout(widget);
+			auto* cbl = new QHBoxLayout(widget);
 			cbl->addWidget(cb);
 			cbl->setAlignment(Qt::AlignCenter);
 			cbl->setContentsMargins(0, 0, 0, 0);
@@ -120,20 +129,18 @@ FitParametersWidget::FitParametersWidget(QWidget* parent, XYFitCurve::FitData* d
 			connect(le, SIGNAL(textChanged(QString)), this, SLOT(upperLimitChanged()) );
 		}
 		ui.tableWidget->setCurrentCell(0, 1);
-		ui.pbAdd->setVisible(false);
-		ui.pbRemove->setVisible(false);
 	} else {	// custom model
 		if (!m_fitData->paramNames.isEmpty()) {	// parameters for the custom model are already available -> show them
-			ui.tableWidget->setRowCount(m_fitData->paramNames.size());
+			ui.tableWidget->setRowCount(np);
 
-			for (int i = 0; i < m_fitData->paramNames.size(); ++i){
+			for (int i = 0; i < np; ++i) {
 				// name
-				QTableWidgetItem* item = new QTableWidgetItem(m_fitData->paramNames.at(i));
+				auto* item = new QTableWidgetItem(m_fitData->paramNames.at(i));
 				item->setBackground(QApplication::palette().color(QPalette::Window));
 				ui.tableWidget->setItem(i, 0, item);
 
 				// start value
-				QLineEdit *le = new QLineEdit(ui.tableWidget);
+				auto* le = new QLineEdit(ui.tableWidget);
 				le->setValidator(new QDoubleValidator(le));
 				le->setFrame(false);
 				le->insert(QString::number(m_fitData->paramStartValues.at(i), 'g'));
@@ -141,10 +148,10 @@ FitParametersWidget::FitParametersWidget(QWidget* parent, XYFitCurve::FitData* d
 				connect(le, SIGNAL(textChanged(QString)), this, SLOT(startValueChanged()) );
 
 				// fixed
-				QWidget *widget = new QWidget();
-				QCheckBox *cb = new QCheckBox();
+				QWidget* widget = new QWidget();
+				auto* cb = new QCheckBox();
 				cb->setChecked(m_fitData->paramFixed.at(i));
-				QHBoxLayout *cbl = new QHBoxLayout(widget);
+				auto* cbl = new QHBoxLayout(widget);
 				cbl->addWidget(cb);
 				cbl->setAlignment(Qt::AlignCenter);
 				cbl->setContentsMargins(0, 0, 0, 0);
@@ -172,21 +179,21 @@ FitParametersWidget::FitParametersWidget(QWidget* parent, XYFitCurve::FitData* d
 		} else {			// no parameters available yet -> create the first row in the table for the first parameter
 			ui.tableWidget->setRowCount(1);
 			// name
-			QTableWidgetItem* item = new QTableWidgetItem();
+			auto* item = new QTableWidgetItem();
 			item->setBackground(QApplication::palette().color(QPalette::Window));
 			ui.tableWidget->setItem(0, 0, item);
 
 			// start value
-			QLineEdit *le = new QLineEdit(ui.tableWidget);
+			auto* le = new QLineEdit(ui.tableWidget);
 			le->setValidator(new QDoubleValidator(le));
 			le->setFrame(false);
 			ui.tableWidget->setCellWidget(0, 1, le);
 			connect(le, SIGNAL(textChanged(QString)), this, SLOT(startValueChanged()) );
 
 			// fixed
-			QWidget *widget = new QWidget();
-			QCheckBox *cb = new QCheckBox();
-			QHBoxLayout *cbl = new QHBoxLayout(widget);
+			QWidget* widget = new QWidget();
+			auto* cb = new QCheckBox();
+			auto* cbl = new QHBoxLayout(widget);
 			cbl->addWidget(cb);
 			cbl->setAlignment(Qt::AlignCenter);
 			cbl->setContentsMargins(0, 0, 0, 0);
@@ -208,56 +215,22 @@ FitParametersWidget::FitParametersWidget(QWidget* parent, XYFitCurve::FitData* d
 			connect(le, SIGNAL(textChanged(QString)), this, SLOT(upperLimitChanged()) );
 		}
 		ui.tableWidget->setCurrentCell(0, 0);
-		/* we don't need add/remove since parameter are detected automatically
-		ui.pbAdd->setIcon(QIcon::fromTheme("list-add"));
-		ui.pbAdd->setVisible(true);
-		ui.pbRemove->setIcon(QIcon::fromTheme("list-remove"));
-		ui.pbRemove->setVisible(true);
-		ui.pbRemove->setEnabled(m_fitData->paramNames.size() > 1);
-		*/
-		ui.pbAdd->setVisible(false);
-		ui.pbRemove->setVisible(false);
 	}
-
-	ui.tableWidget->installEventFilter(this);
-
-	connect( ui.tableWidget, SIGNAL(cellChanged(int,int)), this, SLOT(changed()) );
-	connect( ui.pbApply, SIGNAL(clicked()), this, SLOT(applyClicked()) );
-	connect( ui.pbCancel, SIGNAL(clicked()), this, SIGNAL(finished()) );
-// we don't need add/remove since parameter are detected automatically
-//	connect( ui.pbAdd, SIGNAL(clicked()), this, SLOT(addParameter()) );
-//	connect( ui.pbRemove, SIGNAL(clicked()), this, SLOT(removeParameter()) );
+	m_initializing = false;
 }
 
 bool FitParametersWidget::eventFilter(QObject* watched, QEvent* event) {
 	if (watched == ui.tableWidget) {
 		if (event->type() == QEvent::KeyPress) {
-			QKeyEvent* keyEvent = static_cast<QKeyEvent*>(event);
+			auto* keyEvent = static_cast<QKeyEvent*>(event);
 			if (keyEvent->key() == Qt::Key_Return || keyEvent->key() == Qt::Key_Enter) {
-				if (m_fitData->modelCategory != nsl_fit_model_custom) {
-					//on the second column with the values is editable.
-					//navigate to the next cell in the second column, or to the apply-button
-					if (ui.tableWidget->currentRow() == ui.tableWidget->rowCount() - 1) {
-						ui.pbApply->setFocus();
-						ui.tableWidget->clearSelection();
-					} else {
-						ui.tableWidget->setCurrentCell(ui.tableWidget->currentRow() + 1, 1);
-					}
-				} else {
-					//both columns (names and start values) are editable
-					if (ui.tableWidget->currentColumn() == 0) {
-						//name was entered, navigate to the value-cell
-						ui.tableWidget->setCurrentCell(ui.tableWidget->currentRow(), 1);
-					} else {
-						//start value was entered, navigate to the next name-cell or to the apply-button
-						if (ui.tableWidget->currentRow() == ui.tableWidget->rowCount() - 1) {
-							ui.pbApply->setFocus();
-							ui.tableWidget->clearSelection();
-						} else {
-							ui.tableWidget->setCurrentCell(ui.tableWidget->currentRow() + 1, 0);
-						}
-					}
-				}
+				//on the second column with the values is editable.
+				//navigate to the next cell in the second column
+				if (ui.tableWidget->currentRow() == ui.tableWidget->rowCount() - 1)
+					ui.tableWidget->clearSelection();
+				else
+					ui.tableWidget->setCurrentCell(ui.tableWidget->currentRow() + 1, 1);
+
 				return true;
 			}
 		}
@@ -266,9 +239,21 @@ bool FitParametersWidget::eventFilter(QObject* watched, QEvent* event) {
 	return QWidget::eventFilter(watched, event);
 }
 
-void FitParametersWidget::applyClicked() {
+void FitParametersWidget::changed() {
+	DEBUG("FitParametersWidget::changed()");
+	if (!m_initializing) {
+		apply();
+		emit parametersChanged(false);
+	}
+}
+
+/*
+ * Apply parameter settings by setting m_fitData
+ */
+void FitParametersWidget::apply() {
+	DEBUG("FitParametersWidget::apply()");
 	if (m_fitData->modelCategory != nsl_fit_model_custom) {	// pre-defined models
-		for (int i=0; i < ui.tableWidget->rowCount(); ++i) {
+		for (int i = 0; i < ui.tableWidget->rowCount(); ++i) {
 			m_fitData->paramStartValues[i] = ((QLineEdit *)ui.tableWidget->cellWidget(i, 1))->text().toDouble();
 
 			QWidget *widget = ui.tableWidget->cellWidget(i, 2)->layout()->itemAt(0)->widget();
@@ -290,7 +275,7 @@ void FitParametersWidget::applyClicked() {
 		m_fitData->paramFixed.clear();
 		m_fitData->paramLowerLimits.clear();
 		m_fitData->paramUpperLimits.clear();
-		for (int i=0; i < ui.tableWidget->rowCount(); ++i) {
+		for (int i = 0; i < ui.tableWidget->rowCount(); ++i) {
 			// skip those rows where either the name or the value is empty
 			if ( !ui.tableWidget->item(i, 0)->text().simplified().isEmpty()
 				&& !((QLineEdit *)ui.tableWidget->cellWidget(i, 1))->text().simplified().isEmpty() ) {
@@ -312,15 +297,13 @@ void FitParametersWidget::applyClicked() {
 			}
 		}
 	}
-
-	if (m_changed)
-		emit parametersChanged();
-
-	emit finished();
 }
 
-// check if start values are inside limits
+/*
+ * called when a start value is changed
+ */
 void FitParametersWidget::startValueChanged() {
+	DEBUG("FitParametersWidget::startValueChanged()");
 	const int row = ui.tableWidget->currentRow();
 	const double value = ((QLineEdit *)ui.tableWidget->cellWidget(row, 1))->text().toDouble();
 
@@ -349,11 +332,12 @@ void FitParametersWidget::startValueChanged() {
 	upperLimitChanged();
 	m_rehighlighting = false;
 
-	m_changed = true;
+	changed();
 }
 
 // check if lower limit fits to start value and upper limit
 void FitParametersWidget::lowerLimitChanged() {
+	DEBUG("FitParametersWidget::lowerLimitChanged()");
 	const int row = ui.tableWidget->currentRow();
 
 	const double value = ((QLineEdit *)ui.tableWidget->cellWidget(row, 1))->text().toDouble();
@@ -383,11 +367,12 @@ void FitParametersWidget::lowerLimitChanged() {
 	upperLimitChanged();
 	m_rehighlighting = false;
 
-	m_changed = true;
+	changed();
 }
 
 // check if upper limit fits to start value and lower limit
 void FitParametersWidget::upperLimitChanged() {
+	DEBUG("FitParametersWidget::upperLimitChanged()");
 	const int row = ui.tableWidget->currentRow();
 
 	const double value = ((QLineEdit *)ui.tableWidget->cellWidget(row, 1))->text().toDouble();
@@ -417,75 +402,18 @@ void FitParametersWidget::upperLimitChanged() {
 	lowerLimitChanged();
 	m_rehighlighting = false;
 
-	m_changed = true;
-}
-
-void FitParametersWidget::addParameter() {
-	const int rows = ui.tableWidget->rowCount();
-	ui.tableWidget->setRowCount(rows+1);
-
-	// name
-	QTableWidgetItem* item = new QTableWidgetItem();
-	item->setBackground(QBrush(Qt::lightGray));
-	ui.tableWidget->setItem(rows, 0, item);
-
-	// start value
-	QLineEdit *le = new QLineEdit(ui.tableWidget);
-	le->setValidator(new QDoubleValidator(le));
-	le->setFrame(false);
-	le->insert("1");
-	ui.tableWidget->setCellWidget(rows, 1, le);
-	connect(le, SIGNAL(textChanged(QString)), this, SLOT(startValueChanged()) );
-
-	// fixed
-	QWidget *widget = new QWidget();
-	QCheckBox *cb = new QCheckBox();
-	QHBoxLayout *cbl = new QHBoxLayout(widget);
-	cbl->addWidget(cb);
-	cbl->setAlignment(Qt::AlignCenter);
-	cbl->setContentsMargins(0, 0, 0, 0);
-	widget->setLayout(cbl);
-	ui.tableWidget->setCellWidget(rows, 2, widget);
-	connect(cb, SIGNAL(stateChanged(int)), this, SLOT(changed()) );
-
-	// limits
-	le = new QLineEdit(ui.tableWidget);
-	le->setValidator(new QDoubleValidator(le));
-	le->setFrame(false);
-	ui.tableWidget->setCellWidget(rows, 3, le);
-	connect(le, SIGNAL(textChanged(QString)), this, SLOT(lowerLimitChanged()) );
-
-	le = new QLineEdit(ui.tableWidget);
-	le->setValidator(new QDoubleValidator(le));
-	le->setFrame(false);
-	ui.tableWidget->setCellWidget(rows, 4, le);
-	connect(le, SIGNAL(textChanged(QString)), this, SLOT(lowerLimitChanged()) );
-
-	ui.tableWidget->setCurrentCell(rows, 0);
-	ui.pbRemove->setEnabled(true);
 	changed();
 }
 
-void FitParametersWidget::removeParameter() {
-	ui.tableWidget->removeRow(ui.tableWidget->currentRow());
-	if (ui.tableWidget->rowCount() == 1)
-		ui.pbRemove->setEnabled(false);
-	changed();
-}
-
-void FitParametersWidget::changed() {
-	m_changed = true;
-}
-
-void FitParametersWidget::highlightInvalid(int row, int col, bool invalid) const {
+void FitParametersWidget::highlightInvalid(int row, int col, bool invalid) {
 	QLineEdit* le = ((QLineEdit*)ui.tableWidget->cellWidget(row, col));
 	if (invalid)
 		le->setStyleSheet("QLineEdit{background: red;}");
 	else
-		le->setStyleSheet("");
+		le->setStyleSheet(QString());
 
 	if (m_invalidRanges)
-		ui.pbApply->setEnabled(false);
+		emit parametersValid(false);
 	else
-		ui.pbApply->setEnabled(true);
+		emit parametersValid(true);
 }
