@@ -4,7 +4,7 @@
     Description          : widget for editing the fit parameters
     --------------------------------------------------------------------
     Copyright            : (C) 2014-2016 by Alexander Semke (alexander.semke@web.de)
-    Copyright            : (C) 2016 by Stefan Gerlach (stefan.gerlach@uni-konstanz.de)
+    Copyright            : (C) 2016-2018 by Stefan Gerlach (stefan.gerlach@uni-konstanz.de)
 
  ***************************************************************************/
 
@@ -38,30 +38,29 @@ class FitParametersWidget : public QWidget {
 	Q_OBJECT
 
 public:
-	explicit FitParametersWidget(QWidget*, XYFitCurve::FitData*);
+	explicit FitParametersWidget(QWidget*);
+	void setFitData(XYFitCurve::FitData*);
 
 private:
 	Ui::FitParametersWidget ui;
-	XYFitCurve::FitData* m_fitData;
-	bool m_changed;
-	bool m_rehighlighting;
-	bool m_invalidRanges;
+	XYFitCurve::FitData* m_fitData{nullptr};
+	bool m_initializing{false};
+	bool m_rehighlighting{false};
+	bool m_invalidRanges{false};
 
-	bool eventFilter(QObject*, QEvent*);
-	void highlightInvalid(int row, int col, bool invalid) const;
+	bool eventFilter(QObject*, QEvent*) override;
+	void highlightInvalid(int row, int col, bool invalid);
 
 signals:
-	void finished();
-	void parametersChanged();
+	void parametersChanged(bool);
+	void parametersValid(bool);
 
 private slots:
-	void applyClicked();
+	void changed();
+	void apply();
 	void startValueChanged();
 	void lowerLimitChanged();
 	void upperLimitChanged();
-	void addParameter();
-	void removeParameter();
-	void changed();
 };
 
 #endif //FITPARAMETERSWIDGET_H
