@@ -51,21 +51,22 @@ ThemesWidget::ThemesWidget(QWidget* parent) : QListView(parent) {
 	setSelectionMode(QAbstractItemView::SingleSelection);
 	setWordWrap(true);
 	setViewMode(QListWidget::IconMode);
-	setResizeMode(QListWidget::Adjust);
+	setResizeMode(QListWidget::Fixed);
 	setDragDropMode(QListView::NoDragDrop);
 
 	//make the icon 3x3cm big and show two of them in the height
 	int size = 3.0/2.54 * QApplication::desktop()->physicalDpiX();
 	setIconSize(QSize(size, size));
-	setMinimumSize(1.1*size, 2.1*size); //add some offset here to take care of potential scrollbars, etc. (not very precise...)
 	setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
 
 	//show preview pixmaps
 	auto* mContentItemModel = new QStandardItemModel(this);
 	QStringList themeList = ThemeHandler::themes();
 	QStringList themeImgPathList = QStandardPaths::locateAll(QStandardPaths::DataLocation, "themes/screenshots/", QStandardPaths::LocateDirectory);
-	if (themeImgPathList.isEmpty())
+	if (themeImgPathList.isEmpty()) {
+		delete mContentItemModel;
 		return;
+	}
 
 	const QString& themeImgPath = themeImgPathList.first();
 	QString tempPath;
@@ -88,11 +89,10 @@ ThemesWidget::ThemesWidget(QWidget* parent) : QListView(parent) {
 	const QColor& color = (palette().color(QPalette::Base).lightness() < 128) ? Qt::white : Qt::black;
 	pen.setColor(color);
 	QPainter pa;
-	pa.setPen(pen);
 	pm.fill(Qt::transparent);
 	pa.begin(&pm);
 	pa.setPen(pen);
-	pa.drawRect(5, 5, size-10, size-10);
+	pa.drawRect(2, 2, size - 4, size - 4);
 	pa.end();
 
 	auto* listItem = new QStandardItem();
@@ -108,7 +108,15 @@ ThemesWidget::ThemesWidget(QWidget* parent) : QListView(parent) {
 // 	listItem->setData("file_download_theme", Qt::UserRole);
 // 	mContentItemModel->appendRow(listItem);
 
-	setModel(mContentItemModel);
+	QListView::setModel(mContentItemModel);
+
+	//resize the widget to show three items
+	QFont font;
+	QFontMetrics fm(font);
+	QSize widgetSize(size + qApp->style()->pixelMetric(QStyle::PM_ScrollBarExtent),
+					 3*(size + fm.height() + spacing())  + fm.height());
+	setMinimumSize(widgetSize);
+	setMaximumSize(widgetSize);
 
 	//SLOTS
 	connect(this, &ThemesWidget::clicked, this, &ThemesWidget::applyClicked);
