@@ -29,13 +29,11 @@ Copyright            : (C) 2016 by Fabian Kristof (fkristofszabolcs@gmail.com)
 #include "SlidingPanel.h"
 
 #include <QKeyEvent>
-#include <QDesktopWidget>
-#include <QTimeLine>
 #include <QPushButton>
+#include <QScreen>
+#include <QTimeLine>
 
-#include <KLocalizedString>
-
-DynamicPresenterWidget::DynamicPresenterWidget(Worksheet *worksheet, QWidget *parent) : QWidget(parent),
+DynamicPresenterWidget::DynamicPresenterWidget(Worksheet* worksheet, QWidget* parent) : QWidget(parent),
 	m_view(new WorksheetView(worksheet)), m_timeLine(new QTimeLine(600)) {
 
 	setAttribute(Qt::WA_DeleteOnClose);
@@ -48,9 +46,7 @@ DynamicPresenterWidget::DynamicPresenterWidget(Worksheet *worksheet, QWidget *pa
 	m_view->fitInView(m_view->sceneRect(), Qt::KeepAspectRatio);
 	m_view->adjustSize();
 
-	QDesktopWidget* const dw = QApplication::desktop();
-	const int primaryScreenIdx = dw->primaryScreen();
-	const QRect& screenSize = dw->availableGeometry(primaryScreenIdx);
+	const QRect& screenSize = QGuiApplication::primaryScreen()->availableGeometry();
 
 	const int moveRight = (screenSize.width() - m_view->width()) / 2.0;
 	const int moveDown = (screenSize.height() - m_view->height()) / 2.0;
@@ -62,8 +58,6 @@ DynamicPresenterWidget::DynamicPresenterWidget(Worksheet *worksheet, QWidget *pa
 	connect(m_timeLine, &QTimeLine::valueChanged, m_panel, &SlidingPanel::movePanel);
 	connect(m_panel->quitButton(), &QPushButton::clicked, this, &DynamicPresenterWidget::close);
 	grabMouse();
-
-	slideUp();
 }
 
 DynamicPresenterWidget::~DynamicPresenterWidget() {
