@@ -203,10 +203,10 @@ void ExportWorksheetDialog::toggleOptions() {
 	ui->gbOptions->setVisible(m_showOptions);
 	m_showOptions ? m_showOptionsButton->setText(i18n("Hide Options")) :
 			m_showOptionsButton->setText(i18n("Show Options"));
+
 	//resize the dialog
-	resize(layout()->minimumSize());
 	layout()->activate();
-	resize( QSize(this->width(),0).expandedTo(minimumSize()) );
+	resize( QSize(this->width(), 0).expandedTo(minimumSize()) );
 }
 
 /*!
@@ -257,8 +257,9 @@ void ExportWorksheetDialog::formatChanged(int index) {
 	ui->leFileName->setText(path);
 
 	// show resolution option for png format
-	ui->lResolution->setVisible(index == 3);
-	ui->cbResolution->setVisible(index == 3);
+	bool visible = (index == 2);
+	ui->lResolution->setVisible(visible);
+	ui->cbResolution->setVisible(visible);
 }
 
 void ExportWorksheetDialog::fileNameChanged(const QString& name) {
