@@ -27,14 +27,12 @@ Copyright            : (C) 2016 by Fabian Kristof (fkristofszabolcs@gmail.com)
 #include "PresenterWidget.h"
 #include "SlidingPanel.h"
 
+#include <QApplication>
 #include <QKeyEvent>
 #include <QLabel>
-#include <QDesktopWidget>
-#include <QApplication>
-#include <QTimeLine>
 #include <QPushButton>
-
-#include <KLocalizedString>
+#include <QScreen>
+#include <QTimeLine>
 
 PresenterWidget::PresenterWidget(const QPixmap &pixmap, const QString& worksheetName, QWidget *parent) : QWidget(parent),
 	m_imageLabel(new QLabel(this)), m_timeLine(new QTimeLine(600)) {
@@ -43,9 +41,7 @@ PresenterWidget::PresenterWidget(const QPixmap &pixmap, const QString& worksheet
 	m_imageLabel->setPixmap(pixmap);
 	m_imageLabel->adjustSize();
 
-	QDesktopWidget* const dw = QApplication::desktop();
-	const int primaryScreenIdx = dw->primaryScreen();
-	const QRect& screenSize = dw->availableGeometry(primaryScreenIdx);
+	const QRect& screenSize = QGuiApplication::primaryScreen()->availableGeometry();
 
 	const int moveRight = (screenSize.width() - m_imageLabel->width()) / 2.0;
 	const int moveDown = (screenSize.height() - m_imageLabel->height()) / 2.0;
@@ -55,9 +51,6 @@ PresenterWidget::PresenterWidget(const QPixmap &pixmap, const QString& worksheet
 	qApp->installEventFilter(this);
 	connect(m_timeLine, &QTimeLine::valueChanged, m_panel, &SlidingPanel::movePanel);
 	connect(m_panel->quitButton(), &QPushButton::clicked, this, &PresenterWidget::close);
-
-	slideUp();
-	setFocus();
 }
 
 PresenterWidget::~PresenterWidget() {
