@@ -26,11 +26,13 @@ Copyright            : (C) 2016 by Fabian Kristof (fkristofszabolcs@gmail.com)
 ***************************************************************************/
 #include "SlidingPanel.h"
 
+#include <QApplication>
+#include <QHBoxLayout>
 #include <QLabel>
 #include <QPushButton>
-#include <QDesktopWidget>
-#include <QHBoxLayout>
-#include <QApplication>
+#include <QScreen>
+#include <QSize>
+
 #include <KLocalizedString>
 
 SlidingPanel::SlidingPanel(QWidget *parent, const QString &worksheetName) : QFrame(parent) {
@@ -78,9 +80,7 @@ QPushButton* SlidingPanel::quitButton() const {
 
 QSize SlidingPanel::sizeHint() const {
 	QSize sh;
-	QDesktopWidget* const dw = QApplication::desktop();
-	const int primaryScreenIdx = dw->primaryScreen();
-	const QRect& screenSize = dw->availableGeometry(primaryScreenIdx);
+	const QRect& screenSize = QGuiApplication::primaryScreen()->availableGeometry();
 	sh.setWidth(screenSize.width());
 
 	//for the height use 1.5 times the height of the font used in the label (20 points) in pixels
