@@ -199,7 +199,7 @@ void AsciiFilterTest::testSparseFile03() {
 	filter.setSeparatingCharacter(",");
 	filter.setNaNValueToZero(true);
 	filter.setSimplifyWhitespacesEnabled(true);
-	filter.setSkipEmptyParts(true);
+	filter.setSkipEmptyParts(false);
 	filter.setHeaderEnabled(true);
 	filter.readDataFromFile(fileName, &spreadsheet, mode);
 
@@ -217,17 +217,17 @@ void AsciiFilterTest::testSparseFile03() {
 	QCOMPARE(spreadsheet.column(0)->integerAt(0), 1);
 	QCOMPARE(spreadsheet.column(0)->integerAt(1), 2);
 	QCOMPARE(spreadsheet.column(0)->integerAt(2), 3);
-	QCOMPARE(spreadsheet.column(0)->integerAt(3), 3);
+	QCOMPARE(spreadsheet.column(0)->integerAt(3), 0);
 
  	QCOMPARE(spreadsheet.column(1)->valueAt(0), 1.);
-	QCOMPARE(spreadsheet.column(1)->valueAt(1), 2.);
+	QCOMPARE(spreadsheet.column(1)->valueAt(1), 0.);
 	QCOMPARE(spreadsheet.column(1)->valueAt(2), 1.);
 	QCOMPARE(spreadsheet.column(1)->valueAt(3), 0.);
 
 	QCOMPARE(spreadsheet.column(2)->valueAt(0), 2.);
-	QCOMPARE(spreadsheet.column(2)->valueAt(1), 0.);
+	QCOMPARE(spreadsheet.column(2)->valueAt(1), 2.);
 	QCOMPARE(spreadsheet.column(2)->valueAt(2), 0.);
-	QCOMPARE(spreadsheet.column(2)->valueAt(3), 0.);
+	QCOMPARE(spreadsheet.column(2)->valueAt(3), 3.);
 }
 
 //##############################################################################
@@ -542,7 +542,7 @@ void AsciiFilterTest::testRowRange01() {
 	filter.setEndRow(10);
 	filter.readDataFromFile(fileName, &spreadsheet, mode);
 
-	//end row larger than the the number of available rows, three rows to read
+	//end row larger than the number of available rows, three rows to read
 	QCOMPARE(spreadsheet.rowCount(), 3);
 	QCOMPARE(spreadsheet.columnCount(), 3);
 
@@ -761,4 +761,54 @@ void AsciiFilterTest::testQuotedStrings03() {
 	QCOMPARE(spreadsheet.column(3)->valueAt(0), 1.1);
 }
 
+
+//##############################################################################
+//###############################  skip comments ###############################
+//##############################################################################
+void AsciiFilterTest::testComments00() {
+	Spreadsheet spreadsheet("test", false);
+	AsciiFilter filter;
+	const QString fileName = m_dataDir + "multi_line_comment.txt";
+
+	AbstractFileFilter::ImportMode mode = AbstractFileFilter::Replace;
+	filter.setSeparatingCharacter(",");
+	filter.readDataFromFile(fileName, &spreadsheet, mode);
+
+	QCOMPARE(spreadsheet.columnCount(), 2);
+
+	//data types
+	QCOMPARE(spreadsheet.column(0)->columnMode(), AbstractColumn::Integer);
+	QCOMPARE(spreadsheet.column(1)->columnMode(), AbstractColumn::Numeric);
+
+	//values
+	QCOMPARE(spreadsheet.column(0)->integerAt(0), 1);
+	QCOMPARE(spreadsheet.column(1)->valueAt(0), 1.1);
+
+	QCOMPARE(spreadsheet.column(0)->integerAt(1), 2);
+	QCOMPARE(spreadsheet.column(1)->valueAt(1), 2.2);
+}
+
+void AsciiFilterTest::testComments01() {
+	Spreadsheet spreadsheet("test", false);
+	AsciiFilter filter;
+	const QString fileName = m_dataDir + "multi_line_comment_with_empty_lines.txt";
+
+	AbstractFileFilter::ImportMode mode = AbstractFileFilter::Replace;
+	filter.setSeparatingCharacter(",");
+	filter.readDataFromFile(fileName, &spreadsheet, mode);
+
+	QCOMPARE(spreadsheet.columnCount(), 2);
+
+	//data types
+	QCOMPARE(spreadsheet.column(0)->columnMode(), AbstractColumn::Integer);
+	QCOMPARE(spreadsheet.column(1)->columnMode(), AbstractColumn::Numeric);
+
+	//values
+	QCOMPARE(spreadsheet.column(0)->integerAt(0), 1);
+	QCOMPARE(spreadsheet.column(1)->valueAt(0), 1.1);
+
+	QCOMPARE(spreadsheet.column(0)->integerAt(1), 2);
+	QCOMPARE(spreadsheet.column(1)->valueAt(1), 2.2);
+}
+
 QTEST_MAIN(AsciiFilterTest)
